import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
/**
 * Amazon Certificate Manager.
 *
 * @stability stable
 */
export interface AcmCertificateValidationConfig extends cdktf.TerraformMetaArguments {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/acm_certificate_validation#certificate_arn AcmCertificateValidation#certificate_arn}.
     *
     * @stability stable
     */
    readonly certificateArn: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/acm_certificate_validation#validation_record_fqdns AcmCertificateValidation#validation_record_fqdns}.
     *
     * @stability stable
     */
    readonly validationRecordFqdns?: string[];
    /**
     * timeouts block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/acm_certificate_validation#timeouts AcmCertificateValidation#timeouts}
     *
     * @stability stable
     */
    readonly timeouts?: AcmCertificateValidationTimeouts;
}
/**
 * @stability stable
 */
export interface AcmCertificateValidationTimeouts {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/acm_certificate_validation#create AcmCertificateValidation#create}.
     *
     * @stability stable
     */
    readonly create?: string;
}
export declare function acmCertificateValidationTimeoutsToTerraform(struct?: AcmCertificateValidationTimeoutsOutputReference | AcmCertificateValidationTimeouts | cdktf.IResolvable): any;
/**
 * @stability stable
 */
export declare class AcmCertificateValidationTimeoutsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): AcmCertificateValidationTimeouts | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: AcmCertificateValidationTimeouts | undefined);
    private _create?;
    /**
     * @stability stable
     */
    get create(): string;
    /**
     * @stability stable
     */
    set create(value: string);
    /**
     * @stability stable
     */
    resetCreate(): void;
    /**
     * @stability stable
     */
    get createInput(): string | undefined;
}
/**
 * Represents a {@link https://www.terraform.io/docs/providers/aws/r/acm_certificate_validation aws_acm_certificate_validation}.
 *
 * @stability stable
 */
export declare class AcmCertificateValidation extends cdktf.TerraformResource {
    /**
     * @stability stable
     */
    static readonly tfResourceType: string;
    /**
     * Create a new {@link https://www.terraform.io/docs/providers/aws/r/acm_certificate_validation aws_acm_certificate_validation} Resource.
     *
     * @param scope The scope in which to define this construct.
     * @param id The scoped construct ID.
     * @stability stable
     */
    constructor(scope: Construct, id: string, config: AcmCertificateValidationConfig);
    private _certificateArn?;
    /**
     * @stability stable
     */
    get certificateArn(): string;
    /**
     * @stability stable
     */
    set certificateArn(value: string);
    /**
     * @stability stable
     */
    get certificateArnInput(): string | undefined;
    /**
     * @stability stable
     */
    get id(): string;
    private _validationRecordFqdns?;
    /**
     * @stability stable
     */
    get validationRecordFqdns(): string[];
    /**
     * @stability stable
     */
    set validationRecordFqdns(value: string[]);
    /**
     * @stability stable
     */
    resetValidationRecordFqdns(): void;
    /**
     * @stability stable
     */
    get validationRecordFqdnsInput(): string[] | undefined;
    private _timeouts;
    /**
     * @stability stable
     */
    get timeouts(): AcmCertificateValidationTimeoutsOutputReference;
    /**
     * @stability stable
     */
    putTimeouts(value: AcmCertificateValidationTimeouts): void;
    /**
     * @stability stable
     */
    resetTimeouts(): void;
    /**
     * @stability stable
     */
    get timeoutsInput(): AcmCertificateValidationTimeouts | undefined;
    /**
     * @stability stable
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
