import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
/**
 * API Gateway.
 *
 * @stability stable
 */
export interface ApiGatewayIntegrationConfig extends cdktf.TerraformMetaArguments {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/api_gateway_integration#cache_key_parameters ApiGatewayIntegration#cache_key_parameters}.
     *
     * @stability stable
     */
    readonly cacheKeyParameters?: string[];
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/api_gateway_integration#cache_namespace ApiGatewayIntegration#cache_namespace}.
     *
     * @stability stable
     */
    readonly cacheNamespace?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/api_gateway_integration#connection_id ApiGatewayIntegration#connection_id}.
     *
     * @stability stable
     */
    readonly connectionId?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/api_gateway_integration#connection_type ApiGatewayIntegration#connection_type}.
     *
     * @stability stable
     */
    readonly connectionType?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/api_gateway_integration#content_handling ApiGatewayIntegration#content_handling}.
     *
     * @stability stable
     */
    readonly contentHandling?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/api_gateway_integration#credentials ApiGatewayIntegration#credentials}.
     *
     * @stability stable
     */
    readonly credentials?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/api_gateway_integration#http_method ApiGatewayIntegration#http_method}.
     *
     * @stability stable
     */
    readonly httpMethod: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/api_gateway_integration#integration_http_method ApiGatewayIntegration#integration_http_method}.
     *
     * @stability stable
     */
    readonly integrationHttpMethod?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/api_gateway_integration#passthrough_behavior ApiGatewayIntegration#passthrough_behavior}.
     *
     * @stability stable
     */
    readonly passthroughBehavior?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/api_gateway_integration#request_parameters ApiGatewayIntegration#request_parameters}.
     *
     * @stability stable
     */
    readonly requestParameters?: {
        [key: string]: string;
    };
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/api_gateway_integration#request_templates ApiGatewayIntegration#request_templates}.
     *
     * @stability stable
     */
    readonly requestTemplates?: {
        [key: string]: string;
    };
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/api_gateway_integration#resource_id ApiGatewayIntegration#resource_id}.
     *
     * @stability stable
     */
    readonly resourceId: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/api_gateway_integration#rest_api_id ApiGatewayIntegration#rest_api_id}.
     *
     * @stability stable
     */
    readonly restApiId: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/api_gateway_integration#timeout_milliseconds ApiGatewayIntegration#timeout_milliseconds}.
     *
     * @stability stable
     */
    readonly timeoutMilliseconds?: number;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/api_gateway_integration#type ApiGatewayIntegration#type}.
     *
     * @stability stable
     */
    readonly type: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/api_gateway_integration#uri ApiGatewayIntegration#uri}.
     *
     * @stability stable
     */
    readonly uri?: string;
    /**
     * tls_config block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/api_gateway_integration#tls_config ApiGatewayIntegration#tls_config}
     *
     * @stability stable
     */
    readonly tlsConfig?: ApiGatewayIntegrationTlsConfig;
}
/**
 * @stability stable
 */
export interface ApiGatewayIntegrationTlsConfig {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/api_gateway_integration#insecure_skip_verification ApiGatewayIntegration#insecure_skip_verification}.
     *
     * @stability stable
     */
    readonly insecureSkipVerification?: boolean | cdktf.IResolvable;
}
export declare function apiGatewayIntegrationTlsConfigToTerraform(struct?: ApiGatewayIntegrationTlsConfigOutputReference | ApiGatewayIntegrationTlsConfig): any;
/**
 * @stability stable
 */
export declare class ApiGatewayIntegrationTlsConfigOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): ApiGatewayIntegrationTlsConfig | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: ApiGatewayIntegrationTlsConfig | undefined);
    private _insecureSkipVerification?;
    /**
     * @stability stable
     */
    get insecureSkipVerification(): boolean | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set insecureSkipVerification(value: boolean | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetInsecureSkipVerification(): void;
    /**
     * @stability stable
     */
    get insecureSkipVerificationInput(): boolean | cdktf.IResolvable | undefined;
}
/**
 * Represents a {@link https://www.terraform.io/docs/providers/aws/r/api_gateway_integration aws_api_gateway_integration}.
 *
 * @stability stable
 */
export declare class ApiGatewayIntegration extends cdktf.TerraformResource {
    /**
     * @stability stable
     */
    static readonly tfResourceType: string;
    /**
     * Create a new {@link https://www.terraform.io/docs/providers/aws/r/api_gateway_integration aws_api_gateway_integration} Resource.
     *
     * @param scope The scope in which to define this construct.
     * @param id The scoped construct ID.
     * @stability stable
     */
    constructor(scope: Construct, id: string, config: ApiGatewayIntegrationConfig);
    private _cacheKeyParameters?;
    /**
     * @stability stable
     */
    get cacheKeyParameters(): string[];
    /**
     * @stability stable
     */
    set cacheKeyParameters(value: string[]);
    /**
     * @stability stable
     */
    resetCacheKeyParameters(): void;
    /**
     * @stability stable
     */
    get cacheKeyParametersInput(): string[] | undefined;
    private _cacheNamespace?;
    /**
     * @stability stable
     */
    get cacheNamespace(): string;
    /**
     * @stability stable
     */
    set cacheNamespace(value: string);
    /**
     * @stability stable
     */
    resetCacheNamespace(): void;
    /**
     * @stability stable
     */
    get cacheNamespaceInput(): string | undefined;
    private _connectionId?;
    /**
     * @stability stable
     */
    get connectionId(): string;
    /**
     * @stability stable
     */
    set connectionId(value: string);
    /**
     * @stability stable
     */
    resetConnectionId(): void;
    /**
     * @stability stable
     */
    get connectionIdInput(): string | undefined;
    private _connectionType?;
    /**
     * @stability stable
     */
    get connectionType(): string;
    /**
     * @stability stable
     */
    set connectionType(value: string);
    /**
     * @stability stable
     */
    resetConnectionType(): void;
    /**
     * @stability stable
     */
    get connectionTypeInput(): string | undefined;
    private _contentHandling?;
    /**
     * @stability stable
     */
    get contentHandling(): string;
    /**
     * @stability stable
     */
    set contentHandling(value: string);
    /**
     * @stability stable
     */
    resetContentHandling(): void;
    /**
     * @stability stable
     */
    get contentHandlingInput(): string | undefined;
    private _credentials?;
    /**
     * @stability stable
     */
    get credentials(): string;
    /**
     * @stability stable
     */
    set credentials(value: string);
    /**
     * @stability stable
     */
    resetCredentials(): void;
    /**
     * @stability stable
     */
    get credentialsInput(): string | undefined;
    private _httpMethod?;
    /**
     * @stability stable
     */
    get httpMethod(): string;
    /**
     * @stability stable
     */
    set httpMethod(value: string);
    /**
     * @stability stable
     */
    get httpMethodInput(): string | undefined;
    /**
     * @stability stable
     */
    get id(): string;
    private _integrationHttpMethod?;
    /**
     * @stability stable
     */
    get integrationHttpMethod(): string;
    /**
     * @stability stable
     */
    set integrationHttpMethod(value: string);
    /**
     * @stability stable
     */
    resetIntegrationHttpMethod(): void;
    /**
     * @stability stable
     */
    get integrationHttpMethodInput(): string | undefined;
    private _passthroughBehavior?;
    /**
     * @stability stable
     */
    get passthroughBehavior(): string;
    /**
     * @stability stable
     */
    set passthroughBehavior(value: string);
    /**
     * @stability stable
     */
    resetPassthroughBehavior(): void;
    /**
     * @stability stable
     */
    get passthroughBehaviorInput(): string | undefined;
    private _requestParameters?;
    /**
     * @stability stable
     */
    get requestParameters(): {
        [key: string]: string;
    };
    /**
     * @stability stable
     */
    set requestParameters(value: {
        [key: string]: string;
    });
    /**
     * @stability stable
     */
    resetRequestParameters(): void;
    /**
     * @stability stable
     */
    get requestParametersInput(): {
        [key: string]: string;
    } | undefined;
    private _requestTemplates?;
    /**
     * @stability stable
     */
    get requestTemplates(): {
        [key: string]: string;
    };
    /**
     * @stability stable
     */
    set requestTemplates(value: {
        [key: string]: string;
    });
    /**
     * @stability stable
     */
    resetRequestTemplates(): void;
    /**
     * @stability stable
     */
    get requestTemplatesInput(): {
        [key: string]: string;
    } | undefined;
    private _resourceId?;
    /**
     * @stability stable
     */
    get resourceId(): string;
    /**
     * @stability stable
     */
    set resourceId(value: string);
    /**
     * @stability stable
     */
    get resourceIdInput(): string | undefined;
    private _restApiId?;
    /**
     * @stability stable
     */
    get restApiId(): string;
    /**
     * @stability stable
     */
    set restApiId(value: string);
    /**
     * @stability stable
     */
    get restApiIdInput(): string | undefined;
    private _timeoutMilliseconds?;
    /**
     * @stability stable
     */
    get timeoutMilliseconds(): number;
    /**
     * @stability stable
     */
    set timeoutMilliseconds(value: number);
    /**
     * @stability stable
     */
    resetTimeoutMilliseconds(): void;
    /**
     * @stability stable
     */
    get timeoutMillisecondsInput(): number | undefined;
    private _type?;
    /**
     * @stability stable
     */
    get type(): string;
    /**
     * @stability stable
     */
    set type(value: string);
    /**
     * @stability stable
     */
    get typeInput(): string | undefined;
    private _uri?;
    /**
     * @stability stable
     */
    get uri(): string;
    /**
     * @stability stable
     */
    set uri(value: string);
    /**
     * @stability stable
     */
    resetUri(): void;
    /**
     * @stability stable
     */
    get uriInput(): string | undefined;
    private _tlsConfig;
    /**
     * @stability stable
     */
    get tlsConfig(): ApiGatewayIntegrationTlsConfigOutputReference;
    /**
     * @stability stable
     */
    putTlsConfig(value: ApiGatewayIntegrationTlsConfig): void;
    /**
     * @stability stable
     */
    resetTlsConfig(): void;
    /**
     * @stability stable
     */
    get tlsConfigInput(): ApiGatewayIntegrationTlsConfig | undefined;
    /**
     * @stability stable
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
