import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
/**
 * API Gateway.
 *
 * @stability stable
 */
export interface ApiGatewayMethodSettingsConfig extends cdktf.TerraformMetaArguments {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/api_gateway_method_settings#method_path ApiGatewayMethodSettings#method_path}.
     *
     * @stability stable
     */
    readonly methodPath: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/api_gateway_method_settings#rest_api_id ApiGatewayMethodSettings#rest_api_id}.
     *
     * @stability stable
     */
    readonly restApiId: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/api_gateway_method_settings#stage_name ApiGatewayMethodSettings#stage_name}.
     *
     * @stability stable
     */
    readonly stageName: string;
    /**
     * settings block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/api_gateway_method_settings#settings ApiGatewayMethodSettings#settings}
     *
     * @stability stable
     */
    readonly settings: ApiGatewayMethodSettingsSettings;
}
/**
 * @stability stable
 */
export interface ApiGatewayMethodSettingsSettings {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/api_gateway_method_settings#cache_data_encrypted ApiGatewayMethodSettings#cache_data_encrypted}.
     *
     * @stability stable
     */
    readonly cacheDataEncrypted?: boolean | cdktf.IResolvable;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/api_gateway_method_settings#cache_ttl_in_seconds ApiGatewayMethodSettings#cache_ttl_in_seconds}.
     *
     * @stability stable
     */
    readonly cacheTtlInSeconds?: number;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/api_gateway_method_settings#caching_enabled ApiGatewayMethodSettings#caching_enabled}.
     *
     * @stability stable
     */
    readonly cachingEnabled?: boolean | cdktf.IResolvable;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/api_gateway_method_settings#data_trace_enabled ApiGatewayMethodSettings#data_trace_enabled}.
     *
     * @stability stable
     */
    readonly dataTraceEnabled?: boolean | cdktf.IResolvable;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/api_gateway_method_settings#logging_level ApiGatewayMethodSettings#logging_level}.
     *
     * @stability stable
     */
    readonly loggingLevel?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/api_gateway_method_settings#metrics_enabled ApiGatewayMethodSettings#metrics_enabled}.
     *
     * @stability stable
     */
    readonly metricsEnabled?: boolean | cdktf.IResolvable;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/api_gateway_method_settings#require_authorization_for_cache_control ApiGatewayMethodSettings#require_authorization_for_cache_control}.
     *
     * @stability stable
     */
    readonly requireAuthorizationForCacheControl?: boolean | cdktf.IResolvable;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/api_gateway_method_settings#throttling_burst_limit ApiGatewayMethodSettings#throttling_burst_limit}.
     *
     * @stability stable
     */
    readonly throttlingBurstLimit?: number;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/api_gateway_method_settings#throttling_rate_limit ApiGatewayMethodSettings#throttling_rate_limit}.
     *
     * @stability stable
     */
    readonly throttlingRateLimit?: number;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/api_gateway_method_settings#unauthorized_cache_control_header_strategy ApiGatewayMethodSettings#unauthorized_cache_control_header_strategy}.
     *
     * @stability stable
     */
    readonly unauthorizedCacheControlHeaderStrategy?: string;
}
export declare function apiGatewayMethodSettingsSettingsToTerraform(struct?: ApiGatewayMethodSettingsSettingsOutputReference | ApiGatewayMethodSettingsSettings): any;
/**
 * @stability stable
 */
export declare class ApiGatewayMethodSettingsSettingsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): ApiGatewayMethodSettingsSettings | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: ApiGatewayMethodSettingsSettings | undefined);
    private _cacheDataEncrypted?;
    /**
     * @stability stable
     */
    get cacheDataEncrypted(): boolean | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set cacheDataEncrypted(value: boolean | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetCacheDataEncrypted(): void;
    /**
     * @stability stable
     */
    get cacheDataEncryptedInput(): boolean | cdktf.IResolvable | undefined;
    private _cacheTtlInSeconds?;
    /**
     * @stability stable
     */
    get cacheTtlInSeconds(): number;
    /**
     * @stability stable
     */
    set cacheTtlInSeconds(value: number);
    /**
     * @stability stable
     */
    resetCacheTtlInSeconds(): void;
    /**
     * @stability stable
     */
    get cacheTtlInSecondsInput(): number | undefined;
    private _cachingEnabled?;
    /**
     * @stability stable
     */
    get cachingEnabled(): boolean | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set cachingEnabled(value: boolean | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetCachingEnabled(): void;
    /**
     * @stability stable
     */
    get cachingEnabledInput(): boolean | cdktf.IResolvable | undefined;
    private _dataTraceEnabled?;
    /**
     * @stability stable
     */
    get dataTraceEnabled(): boolean | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set dataTraceEnabled(value: boolean | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetDataTraceEnabled(): void;
    /**
     * @stability stable
     */
    get dataTraceEnabledInput(): boolean | cdktf.IResolvable | undefined;
    private _loggingLevel?;
    /**
     * @stability stable
     */
    get loggingLevel(): string;
    /**
     * @stability stable
     */
    set loggingLevel(value: string);
    /**
     * @stability stable
     */
    resetLoggingLevel(): void;
    /**
     * @stability stable
     */
    get loggingLevelInput(): string | undefined;
    private _metricsEnabled?;
    /**
     * @stability stable
     */
    get metricsEnabled(): boolean | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set metricsEnabled(value: boolean | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetMetricsEnabled(): void;
    /**
     * @stability stable
     */
    get metricsEnabledInput(): boolean | cdktf.IResolvable | undefined;
    private _requireAuthorizationForCacheControl?;
    /**
     * @stability stable
     */
    get requireAuthorizationForCacheControl(): boolean | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set requireAuthorizationForCacheControl(value: boolean | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetRequireAuthorizationForCacheControl(): void;
    /**
     * @stability stable
     */
    get requireAuthorizationForCacheControlInput(): boolean | cdktf.IResolvable | undefined;
    private _throttlingBurstLimit?;
    /**
     * @stability stable
     */
    get throttlingBurstLimit(): number;
    /**
     * @stability stable
     */
    set throttlingBurstLimit(value: number);
    /**
     * @stability stable
     */
    resetThrottlingBurstLimit(): void;
    /**
     * @stability stable
     */
    get throttlingBurstLimitInput(): number | undefined;
    private _throttlingRateLimit?;
    /**
     * @stability stable
     */
    get throttlingRateLimit(): number;
    /**
     * @stability stable
     */
    set throttlingRateLimit(value: number);
    /**
     * @stability stable
     */
    resetThrottlingRateLimit(): void;
    /**
     * @stability stable
     */
    get throttlingRateLimitInput(): number | undefined;
    private _unauthorizedCacheControlHeaderStrategy?;
    /**
     * @stability stable
     */
    get unauthorizedCacheControlHeaderStrategy(): string;
    /**
     * @stability stable
     */
    set unauthorizedCacheControlHeaderStrategy(value: string);
    /**
     * @stability stable
     */
    resetUnauthorizedCacheControlHeaderStrategy(): void;
    /**
     * @stability stable
     */
    get unauthorizedCacheControlHeaderStrategyInput(): string | undefined;
}
/**
 * Represents a {@link https://www.terraform.io/docs/providers/aws/r/api_gateway_method_settings aws_api_gateway_method_settings}.
 *
 * @stability stable
 */
export declare class ApiGatewayMethodSettings extends cdktf.TerraformResource {
    /**
     * @stability stable
     */
    static readonly tfResourceType: string;
    /**
     * Create a new {@link https://www.terraform.io/docs/providers/aws/r/api_gateway_method_settings aws_api_gateway_method_settings} Resource.
     *
     * @param scope The scope in which to define this construct.
     * @param id The scoped construct ID.
     * @stability stable
     */
    constructor(scope: Construct, id: string, config: ApiGatewayMethodSettingsConfig);
    /**
     * @stability stable
     */
    get id(): string;
    private _methodPath?;
    /**
     * @stability stable
     */
    get methodPath(): string;
    /**
     * @stability stable
     */
    set methodPath(value: string);
    /**
     * @stability stable
     */
    get methodPathInput(): string | undefined;
    private _restApiId?;
    /**
     * @stability stable
     */
    get restApiId(): string;
    /**
     * @stability stable
     */
    set restApiId(value: string);
    /**
     * @stability stable
     */
    get restApiIdInput(): string | undefined;
    private _stageName?;
    /**
     * @stability stable
     */
    get stageName(): string;
    /**
     * @stability stable
     */
    set stageName(value: string);
    /**
     * @stability stable
     */
    get stageNameInput(): string | undefined;
    private _settings;
    /**
     * @stability stable
     */
    get settings(): ApiGatewayMethodSettingsSettingsOutputReference;
    /**
     * @stability stable
     */
    putSettings(value: ApiGatewayMethodSettingsSettings): void;
    /**
     * @stability stable
     */
    get settingsInput(): ApiGatewayMethodSettingsSettings | undefined;
    /**
     * @stability stable
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
