import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
/**
 * API Gateway.
 *
 * @stability stable
 */
export interface ApiGatewayRestApiConfig extends cdktf.TerraformMetaArguments {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/api_gateway_rest_api#api_key_source ApiGatewayRestApi#api_key_source}.
     *
     * @stability stable
     */
    readonly apiKeySource?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/api_gateway_rest_api#binary_media_types ApiGatewayRestApi#binary_media_types}.
     *
     * @stability stable
     */
    readonly binaryMediaTypes?: string[];
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/api_gateway_rest_api#body ApiGatewayRestApi#body}.
     *
     * @stability stable
     */
    readonly body?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/api_gateway_rest_api#description ApiGatewayRestApi#description}.
     *
     * @stability stable
     */
    readonly description?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/api_gateway_rest_api#disable_execute_api_endpoint ApiGatewayRestApi#disable_execute_api_endpoint}.
     *
     * @stability stable
     */
    readonly disableExecuteApiEndpoint?: boolean | cdktf.IResolvable;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/api_gateway_rest_api#minimum_compression_size ApiGatewayRestApi#minimum_compression_size}.
     *
     * @stability stable
     */
    readonly minimumCompressionSize?: number;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/api_gateway_rest_api#name ApiGatewayRestApi#name}.
     *
     * @stability stable
     */
    readonly name: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/api_gateway_rest_api#parameters ApiGatewayRestApi#parameters}.
     *
     * @stability stable
     */
    readonly parameters?: {
        [key: string]: string;
    };
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/api_gateway_rest_api#policy ApiGatewayRestApi#policy}.
     *
     * @stability stable
     */
    readonly policy?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/api_gateway_rest_api#tags ApiGatewayRestApi#tags}.
     *
     * @stability stable
     */
    readonly tags?: {
        [key: string]: string;
    };
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/api_gateway_rest_api#tags_all ApiGatewayRestApi#tags_all}.
     *
     * @stability stable
     */
    readonly tagsAll?: {
        [key: string]: string;
    };
    /**
     * endpoint_configuration block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/api_gateway_rest_api#endpoint_configuration ApiGatewayRestApi#endpoint_configuration}
     *
     * @stability stable
     */
    readonly endpointConfiguration?: ApiGatewayRestApiEndpointConfiguration;
}
/**
 * @stability stable
 */
export interface ApiGatewayRestApiEndpointConfiguration {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/api_gateway_rest_api#types ApiGatewayRestApi#types}.
     *
     * @stability stable
     */
    readonly types: string[];
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/api_gateway_rest_api#vpc_endpoint_ids ApiGatewayRestApi#vpc_endpoint_ids}.
     *
     * @stability stable
     */
    readonly vpcEndpointIds?: string[];
}
export declare function apiGatewayRestApiEndpointConfigurationToTerraform(struct?: ApiGatewayRestApiEndpointConfigurationOutputReference | ApiGatewayRestApiEndpointConfiguration): any;
/**
 * @stability stable
 */
export declare class ApiGatewayRestApiEndpointConfigurationOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): ApiGatewayRestApiEndpointConfiguration | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: ApiGatewayRestApiEndpointConfiguration | undefined);
    private _types?;
    /**
     * @stability stable
     */
    get types(): string[];
    /**
     * @stability stable
     */
    set types(value: string[]);
    /**
     * @stability stable
     */
    get typesInput(): string[] | undefined;
    private _vpcEndpointIds?;
    /**
     * @stability stable
     */
    get vpcEndpointIds(): string[];
    /**
     * @stability stable
     */
    set vpcEndpointIds(value: string[]);
    /**
     * @stability stable
     */
    resetVpcEndpointIds(): void;
    /**
     * @stability stable
     */
    get vpcEndpointIdsInput(): string[] | undefined;
}
/**
 * Represents a {@link https://www.terraform.io/docs/providers/aws/r/api_gateway_rest_api aws_api_gateway_rest_api}.
 *
 * @stability stable
 */
export declare class ApiGatewayRestApi extends cdktf.TerraformResource {
    /**
     * @stability stable
     */
    static readonly tfResourceType: string;
    /**
     * Create a new {@link https://www.terraform.io/docs/providers/aws/r/api_gateway_rest_api aws_api_gateway_rest_api} Resource.
     *
     * @param scope The scope in which to define this construct.
     * @param id The scoped construct ID.
     * @stability stable
     */
    constructor(scope: Construct, id: string, config: ApiGatewayRestApiConfig);
    private _apiKeySource?;
    /**
     * @stability stable
     */
    get apiKeySource(): string;
    /**
     * @stability stable
     */
    set apiKeySource(value: string);
    /**
     * @stability stable
     */
    resetApiKeySource(): void;
    /**
     * @stability stable
     */
    get apiKeySourceInput(): string | undefined;
    /**
     * @stability stable
     */
    get arn(): string;
    private _binaryMediaTypes?;
    /**
     * @stability stable
     */
    get binaryMediaTypes(): string[];
    /**
     * @stability stable
     */
    set binaryMediaTypes(value: string[]);
    /**
     * @stability stable
     */
    resetBinaryMediaTypes(): void;
    /**
     * @stability stable
     */
    get binaryMediaTypesInput(): string[] | undefined;
    private _body?;
    /**
     * @stability stable
     */
    get body(): string;
    /**
     * @stability stable
     */
    set body(value: string);
    /**
     * @stability stable
     */
    resetBody(): void;
    /**
     * @stability stable
     */
    get bodyInput(): string | undefined;
    /**
     * @stability stable
     */
    get createdDate(): string;
    private _description?;
    /**
     * @stability stable
     */
    get description(): string;
    /**
     * @stability stable
     */
    set description(value: string);
    /**
     * @stability stable
     */
    resetDescription(): void;
    /**
     * @stability stable
     */
    get descriptionInput(): string | undefined;
    private _disableExecuteApiEndpoint?;
    /**
     * @stability stable
     */
    get disableExecuteApiEndpoint(): boolean | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set disableExecuteApiEndpoint(value: boolean | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetDisableExecuteApiEndpoint(): void;
    /**
     * @stability stable
     */
    get disableExecuteApiEndpointInput(): boolean | cdktf.IResolvable | undefined;
    /**
     * @stability stable
     */
    get executionArn(): string;
    /**
     * @stability stable
     */
    get id(): string;
    private _minimumCompressionSize?;
    /**
     * @stability stable
     */
    get minimumCompressionSize(): number;
    /**
     * @stability stable
     */
    set minimumCompressionSize(value: number);
    /**
     * @stability stable
     */
    resetMinimumCompressionSize(): void;
    /**
     * @stability stable
     */
    get minimumCompressionSizeInput(): number | undefined;
    private _name?;
    /**
     * @stability stable
     */
    get name(): string;
    /**
     * @stability stable
     */
    set name(value: string);
    /**
     * @stability stable
     */
    get nameInput(): string | undefined;
    private _parameters?;
    /**
     * @stability stable
     */
    get parameters(): {
        [key: string]: string;
    };
    /**
     * @stability stable
     */
    set parameters(value: {
        [key: string]: string;
    });
    /**
     * @stability stable
     */
    resetParameters(): void;
    /**
     * @stability stable
     */
    get parametersInput(): {
        [key: string]: string;
    } | undefined;
    private _policy?;
    /**
     * @stability stable
     */
    get policy(): string;
    /**
     * @stability stable
     */
    set policy(value: string);
    /**
     * @stability stable
     */
    resetPolicy(): void;
    /**
     * @stability stable
     */
    get policyInput(): string | undefined;
    /**
     * @stability stable
     */
    get rootResourceId(): string;
    private _tags?;
    /**
     * @stability stable
     */
    get tags(): {
        [key: string]: string;
    };
    /**
     * @stability stable
     */
    set tags(value: {
        [key: string]: string;
    });
    /**
     * @stability stable
     */
    resetTags(): void;
    /**
     * @stability stable
     */
    get tagsInput(): {
        [key: string]: string;
    } | undefined;
    private _tagsAll?;
    /**
     * @stability stable
     */
    get tagsAll(): {
        [key: string]: string;
    };
    /**
     * @stability stable
     */
    set tagsAll(value: {
        [key: string]: string;
    });
    /**
     * @stability stable
     */
    resetTagsAll(): void;
    /**
     * @stability stable
     */
    get tagsAllInput(): {
        [key: string]: string;
    } | undefined;
    private _endpointConfiguration;
    /**
     * @stability stable
     */
    get endpointConfiguration(): ApiGatewayRestApiEndpointConfigurationOutputReference;
    /**
     * @stability stable
     */
    putEndpointConfiguration(value: ApiGatewayRestApiEndpointConfiguration): void;
    /**
     * @stability stable
     */
    resetEndpointConfiguration(): void;
    /**
     * @stability stable
     */
    get endpointConfigurationInput(): ApiGatewayRestApiEndpointConfiguration | undefined;
    /**
     * @stability stable
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
