import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
/**
 * App Runner.
 *
 * @stability stable
 */
export interface ApprunnerServiceConfig extends cdktf.TerraformMetaArguments {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/apprunner_service#auto_scaling_configuration_arn ApprunnerService#auto_scaling_configuration_arn}.
     *
     * @stability stable
     */
    readonly autoScalingConfigurationArn?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/apprunner_service#service_name ApprunnerService#service_name}.
     *
     * @stability stable
     */
    readonly serviceName: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/apprunner_service#tags ApprunnerService#tags}.
     *
     * @stability stable
     */
    readonly tags?: {
        [key: string]: string;
    };
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/apprunner_service#tags_all ApprunnerService#tags_all}.
     *
     * @stability stable
     */
    readonly tagsAll?: {
        [key: string]: string;
    };
    /**
     * encryption_configuration block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/apprunner_service#encryption_configuration ApprunnerService#encryption_configuration}
     *
     * @stability stable
     */
    readonly encryptionConfiguration?: ApprunnerServiceEncryptionConfiguration;
    /**
     * health_check_configuration block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/apprunner_service#health_check_configuration ApprunnerService#health_check_configuration}
     *
     * @stability stable
     */
    readonly healthCheckConfiguration?: ApprunnerServiceHealthCheckConfiguration;
    /**
     * instance_configuration block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/apprunner_service#instance_configuration ApprunnerService#instance_configuration}
     *
     * @stability stable
     */
    readonly instanceConfiguration?: ApprunnerServiceInstanceConfiguration;
    /**
     * source_configuration block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/apprunner_service#source_configuration ApprunnerService#source_configuration}
     *
     * @stability stable
     */
    readonly sourceConfiguration: ApprunnerServiceSourceConfiguration;
}
/**
 * @stability stable
 */
export interface ApprunnerServiceEncryptionConfiguration {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/apprunner_service#kms_key ApprunnerService#kms_key}.
     *
     * @stability stable
     */
    readonly kmsKey: string;
}
export declare function apprunnerServiceEncryptionConfigurationToTerraform(struct?: ApprunnerServiceEncryptionConfigurationOutputReference | ApprunnerServiceEncryptionConfiguration): any;
/**
 * @stability stable
 */
export declare class ApprunnerServiceEncryptionConfigurationOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): ApprunnerServiceEncryptionConfiguration | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: ApprunnerServiceEncryptionConfiguration | undefined);
    private _kmsKey?;
    /**
     * @stability stable
     */
    get kmsKey(): string;
    /**
     * @stability stable
     */
    set kmsKey(value: string);
    /**
     * @stability stable
     */
    get kmsKeyInput(): string | undefined;
}
/**
 * @stability stable
 */
export interface ApprunnerServiceHealthCheckConfiguration {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/apprunner_service#healthy_threshold ApprunnerService#healthy_threshold}.
     *
     * @stability stable
     */
    readonly healthyThreshold?: number;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/apprunner_service#interval ApprunnerService#interval}.
     *
     * @stability stable
     */
    readonly interval?: number;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/apprunner_service#path ApprunnerService#path}.
     *
     * @stability stable
     */
    readonly path?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/apprunner_service#protocol ApprunnerService#protocol}.
     *
     * @stability stable
     */
    readonly protocol?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/apprunner_service#timeout ApprunnerService#timeout}.
     *
     * @stability stable
     */
    readonly timeout?: number;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/apprunner_service#unhealthy_threshold ApprunnerService#unhealthy_threshold}.
     *
     * @stability stable
     */
    readonly unhealthyThreshold?: number;
}
export declare function apprunnerServiceHealthCheckConfigurationToTerraform(struct?: ApprunnerServiceHealthCheckConfigurationOutputReference | ApprunnerServiceHealthCheckConfiguration): any;
/**
 * @stability stable
 */
export declare class ApprunnerServiceHealthCheckConfigurationOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): ApprunnerServiceHealthCheckConfiguration | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: ApprunnerServiceHealthCheckConfiguration | undefined);
    private _healthyThreshold?;
    /**
     * @stability stable
     */
    get healthyThreshold(): number;
    /**
     * @stability stable
     */
    set healthyThreshold(value: number);
    /**
     * @stability stable
     */
    resetHealthyThreshold(): void;
    /**
     * @stability stable
     */
    get healthyThresholdInput(): number | undefined;
    private _interval?;
    /**
     * @stability stable
     */
    get interval(): number;
    /**
     * @stability stable
     */
    set interval(value: number);
    /**
     * @stability stable
     */
    resetInterval(): void;
    /**
     * @stability stable
     */
    get intervalInput(): number | undefined;
    private _path?;
    /**
     * @stability stable
     */
    get path(): string;
    /**
     * @stability stable
     */
    set path(value: string);
    /**
     * @stability stable
     */
    resetPath(): void;
    /**
     * @stability stable
     */
    get pathInput(): string | undefined;
    private _protocol?;
    /**
     * @stability stable
     */
    get protocol(): string;
    /**
     * @stability stable
     */
    set protocol(value: string);
    /**
     * @stability stable
     */
    resetProtocol(): void;
    /**
     * @stability stable
     */
    get protocolInput(): string | undefined;
    private _timeout?;
    /**
     * @stability stable
     */
    get timeout(): number;
    /**
     * @stability stable
     */
    set timeout(value: number);
    /**
     * @stability stable
     */
    resetTimeout(): void;
    /**
     * @stability stable
     */
    get timeoutInput(): number | undefined;
    private _unhealthyThreshold?;
    /**
     * @stability stable
     */
    get unhealthyThreshold(): number;
    /**
     * @stability stable
     */
    set unhealthyThreshold(value: number);
    /**
     * @stability stable
     */
    resetUnhealthyThreshold(): void;
    /**
     * @stability stable
     */
    get unhealthyThresholdInput(): number | undefined;
}
/**
 * @stability stable
 */
export interface ApprunnerServiceInstanceConfiguration {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/apprunner_service#cpu ApprunnerService#cpu}.
     *
     * @stability stable
     */
    readonly cpu?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/apprunner_service#instance_role_arn ApprunnerService#instance_role_arn}.
     *
     * @stability stable
     */
    readonly instanceRoleArn?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/apprunner_service#memory ApprunnerService#memory}.
     *
     * @stability stable
     */
    readonly memory?: string;
}
export declare function apprunnerServiceInstanceConfigurationToTerraform(struct?: ApprunnerServiceInstanceConfigurationOutputReference | ApprunnerServiceInstanceConfiguration): any;
/**
 * @stability stable
 */
export declare class ApprunnerServiceInstanceConfigurationOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): ApprunnerServiceInstanceConfiguration | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: ApprunnerServiceInstanceConfiguration | undefined);
    private _cpu?;
    /**
     * @stability stable
     */
    get cpu(): string;
    /**
     * @stability stable
     */
    set cpu(value: string);
    /**
     * @stability stable
     */
    resetCpu(): void;
    /**
     * @stability stable
     */
    get cpuInput(): string | undefined;
    private _instanceRoleArn?;
    /**
     * @stability stable
     */
    get instanceRoleArn(): string;
    /**
     * @stability stable
     */
    set instanceRoleArn(value: string);
    /**
     * @stability stable
     */
    resetInstanceRoleArn(): void;
    /**
     * @stability stable
     */
    get instanceRoleArnInput(): string | undefined;
    private _memory?;
    /**
     * @stability stable
     */
    get memory(): string;
    /**
     * @stability stable
     */
    set memory(value: string);
    /**
     * @stability stable
     */
    resetMemory(): void;
    /**
     * @stability stable
     */
    get memoryInput(): string | undefined;
}
/**
 * @stability stable
 */
export interface ApprunnerServiceSourceConfigurationAuthenticationConfiguration {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/apprunner_service#access_role_arn ApprunnerService#access_role_arn}.
     *
     * @stability stable
     */
    readonly accessRoleArn?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/apprunner_service#connection_arn ApprunnerService#connection_arn}.
     *
     * @stability stable
     */
    readonly connectionArn?: string;
}
export declare function apprunnerServiceSourceConfigurationAuthenticationConfigurationToTerraform(struct?: ApprunnerServiceSourceConfigurationAuthenticationConfigurationOutputReference | ApprunnerServiceSourceConfigurationAuthenticationConfiguration): any;
/**
 * @stability stable
 */
export declare class ApprunnerServiceSourceConfigurationAuthenticationConfigurationOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): ApprunnerServiceSourceConfigurationAuthenticationConfiguration | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: ApprunnerServiceSourceConfigurationAuthenticationConfiguration | undefined);
    private _accessRoleArn?;
    /**
     * @stability stable
     */
    get accessRoleArn(): string;
    /**
     * @stability stable
     */
    set accessRoleArn(value: string);
    /**
     * @stability stable
     */
    resetAccessRoleArn(): void;
    /**
     * @stability stable
     */
    get accessRoleArnInput(): string | undefined;
    private _connectionArn?;
    /**
     * @stability stable
     */
    get connectionArn(): string;
    /**
     * @stability stable
     */
    set connectionArn(value: string);
    /**
     * @stability stable
     */
    resetConnectionArn(): void;
    /**
     * @stability stable
     */
    get connectionArnInput(): string | undefined;
}
/**
 * @stability stable
 */
export interface ApprunnerServiceSourceConfigurationCodeRepositoryCodeConfigurationCodeConfigurationValues {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/apprunner_service#build_command ApprunnerService#build_command}.
     *
     * @stability stable
     */
    readonly buildCommand?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/apprunner_service#port ApprunnerService#port}.
     *
     * @stability stable
     */
    readonly port?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/apprunner_service#runtime ApprunnerService#runtime}.
     *
     * @stability stable
     */
    readonly runtime: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/apprunner_service#runtime_environment_variables ApprunnerService#runtime_environment_variables}.
     *
     * @stability stable
     */
    readonly runtimeEnvironmentVariables?: {
        [key: string]: string;
    };
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/apprunner_service#start_command ApprunnerService#start_command}.
     *
     * @stability stable
     */
    readonly startCommand?: string;
}
export declare function apprunnerServiceSourceConfigurationCodeRepositoryCodeConfigurationCodeConfigurationValuesToTerraform(struct?: ApprunnerServiceSourceConfigurationCodeRepositoryCodeConfigurationCodeConfigurationValuesOutputReference | ApprunnerServiceSourceConfigurationCodeRepositoryCodeConfigurationCodeConfigurationValues): any;
/**
 * @stability stable
 */
export declare class ApprunnerServiceSourceConfigurationCodeRepositoryCodeConfigurationCodeConfigurationValuesOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): ApprunnerServiceSourceConfigurationCodeRepositoryCodeConfigurationCodeConfigurationValues | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: ApprunnerServiceSourceConfigurationCodeRepositoryCodeConfigurationCodeConfigurationValues | undefined);
    private _buildCommand?;
    /**
     * @stability stable
     */
    get buildCommand(): string;
    /**
     * @stability stable
     */
    set buildCommand(value: string);
    /**
     * @stability stable
     */
    resetBuildCommand(): void;
    /**
     * @stability stable
     */
    get buildCommandInput(): string | undefined;
    private _port?;
    /**
     * @stability stable
     */
    get port(): string;
    /**
     * @stability stable
     */
    set port(value: string);
    /**
     * @stability stable
     */
    resetPort(): void;
    /**
     * @stability stable
     */
    get portInput(): string | undefined;
    private _runtime?;
    /**
     * @stability stable
     */
    get runtime(): string;
    /**
     * @stability stable
     */
    set runtime(value: string);
    /**
     * @stability stable
     */
    get runtimeInput(): string | undefined;
    private _runtimeEnvironmentVariables?;
    /**
     * @stability stable
     */
    get runtimeEnvironmentVariables(): {
        [key: string]: string;
    };
    /**
     * @stability stable
     */
    set runtimeEnvironmentVariables(value: {
        [key: string]: string;
    });
    /**
     * @stability stable
     */
    resetRuntimeEnvironmentVariables(): void;
    /**
     * @stability stable
     */
    get runtimeEnvironmentVariablesInput(): {
        [key: string]: string;
    } | undefined;
    private _startCommand?;
    /**
     * @stability stable
     */
    get startCommand(): string;
    /**
     * @stability stable
     */
    set startCommand(value: string);
    /**
     * @stability stable
     */
    resetStartCommand(): void;
    /**
     * @stability stable
     */
    get startCommandInput(): string | undefined;
}
/**
 * @stability stable
 */
export interface ApprunnerServiceSourceConfigurationCodeRepositoryCodeConfiguration {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/apprunner_service#configuration_source ApprunnerService#configuration_source}.
     *
     * @stability stable
     */
    readonly configurationSource: string;
    /**
     * code_configuration_values block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/apprunner_service#code_configuration_values ApprunnerService#code_configuration_values}
     *
     * @stability stable
     */
    readonly codeConfigurationValues?: ApprunnerServiceSourceConfigurationCodeRepositoryCodeConfigurationCodeConfigurationValues;
}
export declare function apprunnerServiceSourceConfigurationCodeRepositoryCodeConfigurationToTerraform(struct?: ApprunnerServiceSourceConfigurationCodeRepositoryCodeConfigurationOutputReference | ApprunnerServiceSourceConfigurationCodeRepositoryCodeConfiguration): any;
/**
 * @stability stable
 */
export declare class ApprunnerServiceSourceConfigurationCodeRepositoryCodeConfigurationOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): ApprunnerServiceSourceConfigurationCodeRepositoryCodeConfiguration | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: ApprunnerServiceSourceConfigurationCodeRepositoryCodeConfiguration | undefined);
    private _configurationSource?;
    /**
     * @stability stable
     */
    get configurationSource(): string;
    /**
     * @stability stable
     */
    set configurationSource(value: string);
    /**
     * @stability stable
     */
    get configurationSourceInput(): string | undefined;
    private _codeConfigurationValues;
    /**
     * @stability stable
     */
    get codeConfigurationValues(): ApprunnerServiceSourceConfigurationCodeRepositoryCodeConfigurationCodeConfigurationValuesOutputReference;
    /**
     * @stability stable
     */
    putCodeConfigurationValues(value: ApprunnerServiceSourceConfigurationCodeRepositoryCodeConfigurationCodeConfigurationValues): void;
    /**
     * @stability stable
     */
    resetCodeConfigurationValues(): void;
    /**
     * @stability stable
     */
    get codeConfigurationValuesInput(): ApprunnerServiceSourceConfigurationCodeRepositoryCodeConfigurationCodeConfigurationValues | undefined;
}
/**
 * @stability stable
 */
export interface ApprunnerServiceSourceConfigurationCodeRepositorySourceCodeVersion {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/apprunner_service#type ApprunnerService#type}.
     *
     * @stability stable
     */
    readonly type: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/apprunner_service#value ApprunnerService#value}.
     *
     * @stability stable
     */
    readonly value: string;
}
export declare function apprunnerServiceSourceConfigurationCodeRepositorySourceCodeVersionToTerraform(struct?: ApprunnerServiceSourceConfigurationCodeRepositorySourceCodeVersionOutputReference | ApprunnerServiceSourceConfigurationCodeRepositorySourceCodeVersion): any;
/**
 * @stability stable
 */
export declare class ApprunnerServiceSourceConfigurationCodeRepositorySourceCodeVersionOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): ApprunnerServiceSourceConfigurationCodeRepositorySourceCodeVersion | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: ApprunnerServiceSourceConfigurationCodeRepositorySourceCodeVersion | undefined);
    private _type?;
    /**
     * @stability stable
     */
    get type(): string;
    /**
     * @stability stable
     */
    set type(value: string);
    /**
     * @stability stable
     */
    get typeInput(): string | undefined;
    private _value?;
    /**
     * @stability stable
     */
    get value(): string;
    /**
     * @stability stable
     */
    set value(value: string);
    /**
     * @stability stable
     */
    get valueInput(): string | undefined;
}
/**
 * @stability stable
 */
export interface ApprunnerServiceSourceConfigurationCodeRepository {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/apprunner_service#repository_url ApprunnerService#repository_url}.
     *
     * @stability stable
     */
    readonly repositoryUrl: string;
    /**
     * code_configuration block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/apprunner_service#code_configuration ApprunnerService#code_configuration}
     *
     * @stability stable
     */
    readonly codeConfiguration?: ApprunnerServiceSourceConfigurationCodeRepositoryCodeConfiguration;
    /**
     * source_code_version block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/apprunner_service#source_code_version ApprunnerService#source_code_version}
     *
     * @stability stable
     */
    readonly sourceCodeVersion: ApprunnerServiceSourceConfigurationCodeRepositorySourceCodeVersion;
}
export declare function apprunnerServiceSourceConfigurationCodeRepositoryToTerraform(struct?: ApprunnerServiceSourceConfigurationCodeRepositoryOutputReference | ApprunnerServiceSourceConfigurationCodeRepository): any;
/**
 * @stability stable
 */
export declare class ApprunnerServiceSourceConfigurationCodeRepositoryOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): ApprunnerServiceSourceConfigurationCodeRepository | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: ApprunnerServiceSourceConfigurationCodeRepository | undefined);
    private _repositoryUrl?;
    /**
     * @stability stable
     */
    get repositoryUrl(): string;
    /**
     * @stability stable
     */
    set repositoryUrl(value: string);
    /**
     * @stability stable
     */
    get repositoryUrlInput(): string | undefined;
    private _codeConfiguration;
    /**
     * @stability stable
     */
    get codeConfiguration(): ApprunnerServiceSourceConfigurationCodeRepositoryCodeConfigurationOutputReference;
    /**
     * @stability stable
     */
    putCodeConfiguration(value: ApprunnerServiceSourceConfigurationCodeRepositoryCodeConfiguration): void;
    /**
     * @stability stable
     */
    resetCodeConfiguration(): void;
    /**
     * @stability stable
     */
    get codeConfigurationInput(): ApprunnerServiceSourceConfigurationCodeRepositoryCodeConfiguration | undefined;
    private _sourceCodeVersion;
    /**
     * @stability stable
     */
    get sourceCodeVersion(): ApprunnerServiceSourceConfigurationCodeRepositorySourceCodeVersionOutputReference;
    /**
     * @stability stable
     */
    putSourceCodeVersion(value: ApprunnerServiceSourceConfigurationCodeRepositorySourceCodeVersion): void;
    /**
     * @stability stable
     */
    get sourceCodeVersionInput(): ApprunnerServiceSourceConfigurationCodeRepositorySourceCodeVersion | undefined;
}
/**
 * @stability stable
 */
export interface ApprunnerServiceSourceConfigurationImageRepositoryImageConfiguration {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/apprunner_service#port ApprunnerService#port}.
     *
     * @stability stable
     */
    readonly port?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/apprunner_service#runtime_environment_variables ApprunnerService#runtime_environment_variables}.
     *
     * @stability stable
     */
    readonly runtimeEnvironmentVariables?: {
        [key: string]: string;
    };
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/apprunner_service#start_command ApprunnerService#start_command}.
     *
     * @stability stable
     */
    readonly startCommand?: string;
}
export declare function apprunnerServiceSourceConfigurationImageRepositoryImageConfigurationToTerraform(struct?: ApprunnerServiceSourceConfigurationImageRepositoryImageConfigurationOutputReference | ApprunnerServiceSourceConfigurationImageRepositoryImageConfiguration): any;
/**
 * @stability stable
 */
export declare class ApprunnerServiceSourceConfigurationImageRepositoryImageConfigurationOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): ApprunnerServiceSourceConfigurationImageRepositoryImageConfiguration | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: ApprunnerServiceSourceConfigurationImageRepositoryImageConfiguration | undefined);
    private _port?;
    /**
     * @stability stable
     */
    get port(): string;
    /**
     * @stability stable
     */
    set port(value: string);
    /**
     * @stability stable
     */
    resetPort(): void;
    /**
     * @stability stable
     */
    get portInput(): string | undefined;
    private _runtimeEnvironmentVariables?;
    /**
     * @stability stable
     */
    get runtimeEnvironmentVariables(): {
        [key: string]: string;
    };
    /**
     * @stability stable
     */
    set runtimeEnvironmentVariables(value: {
        [key: string]: string;
    });
    /**
     * @stability stable
     */
    resetRuntimeEnvironmentVariables(): void;
    /**
     * @stability stable
     */
    get runtimeEnvironmentVariablesInput(): {
        [key: string]: string;
    } | undefined;
    private _startCommand?;
    /**
     * @stability stable
     */
    get startCommand(): string;
    /**
     * @stability stable
     */
    set startCommand(value: string);
    /**
     * @stability stable
     */
    resetStartCommand(): void;
    /**
     * @stability stable
     */
    get startCommandInput(): string | undefined;
}
/**
 * @stability stable
 */
export interface ApprunnerServiceSourceConfigurationImageRepository {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/apprunner_service#image_identifier ApprunnerService#image_identifier}.
     *
     * @stability stable
     */
    readonly imageIdentifier: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/apprunner_service#image_repository_type ApprunnerService#image_repository_type}.
     *
     * @stability stable
     */
    readonly imageRepositoryType: string;
    /**
     * image_configuration block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/apprunner_service#image_configuration ApprunnerService#image_configuration}
     *
     * @stability stable
     */
    readonly imageConfiguration?: ApprunnerServiceSourceConfigurationImageRepositoryImageConfiguration;
}
export declare function apprunnerServiceSourceConfigurationImageRepositoryToTerraform(struct?: ApprunnerServiceSourceConfigurationImageRepositoryOutputReference | ApprunnerServiceSourceConfigurationImageRepository): any;
/**
 * @stability stable
 */
export declare class ApprunnerServiceSourceConfigurationImageRepositoryOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): ApprunnerServiceSourceConfigurationImageRepository | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: ApprunnerServiceSourceConfigurationImageRepository | undefined);
    private _imageIdentifier?;
    /**
     * @stability stable
     */
    get imageIdentifier(): string;
    /**
     * @stability stable
     */
    set imageIdentifier(value: string);
    /**
     * @stability stable
     */
    get imageIdentifierInput(): string | undefined;
    private _imageRepositoryType?;
    /**
     * @stability stable
     */
    get imageRepositoryType(): string;
    /**
     * @stability stable
     */
    set imageRepositoryType(value: string);
    /**
     * @stability stable
     */
    get imageRepositoryTypeInput(): string | undefined;
    private _imageConfiguration;
    /**
     * @stability stable
     */
    get imageConfiguration(): ApprunnerServiceSourceConfigurationImageRepositoryImageConfigurationOutputReference;
    /**
     * @stability stable
     */
    putImageConfiguration(value: ApprunnerServiceSourceConfigurationImageRepositoryImageConfiguration): void;
    /**
     * @stability stable
     */
    resetImageConfiguration(): void;
    /**
     * @stability stable
     */
    get imageConfigurationInput(): ApprunnerServiceSourceConfigurationImageRepositoryImageConfiguration | undefined;
}
/**
 * @stability stable
 */
export interface ApprunnerServiceSourceConfiguration {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/apprunner_service#auto_deployments_enabled ApprunnerService#auto_deployments_enabled}.
     *
     * @stability stable
     */
    readonly autoDeploymentsEnabled?: boolean | cdktf.IResolvable;
    /**
     * authentication_configuration block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/apprunner_service#authentication_configuration ApprunnerService#authentication_configuration}
     *
     * @stability stable
     */
    readonly authenticationConfiguration?: ApprunnerServiceSourceConfigurationAuthenticationConfiguration;
    /**
     * code_repository block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/apprunner_service#code_repository ApprunnerService#code_repository}
     *
     * @stability stable
     */
    readonly codeRepository?: ApprunnerServiceSourceConfigurationCodeRepository;
    /**
     * image_repository block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/apprunner_service#image_repository ApprunnerService#image_repository}
     *
     * @stability stable
     */
    readonly imageRepository?: ApprunnerServiceSourceConfigurationImageRepository;
}
export declare function apprunnerServiceSourceConfigurationToTerraform(struct?: ApprunnerServiceSourceConfigurationOutputReference | ApprunnerServiceSourceConfiguration): any;
/**
 * @stability stable
 */
export declare class ApprunnerServiceSourceConfigurationOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): ApprunnerServiceSourceConfiguration | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: ApprunnerServiceSourceConfiguration | undefined);
    private _autoDeploymentsEnabled?;
    /**
     * @stability stable
     */
    get autoDeploymentsEnabled(): boolean | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set autoDeploymentsEnabled(value: boolean | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetAutoDeploymentsEnabled(): void;
    /**
     * @stability stable
     */
    get autoDeploymentsEnabledInput(): boolean | cdktf.IResolvable | undefined;
    private _authenticationConfiguration;
    /**
     * @stability stable
     */
    get authenticationConfiguration(): ApprunnerServiceSourceConfigurationAuthenticationConfigurationOutputReference;
    /**
     * @stability stable
     */
    putAuthenticationConfiguration(value: ApprunnerServiceSourceConfigurationAuthenticationConfiguration): void;
    /**
     * @stability stable
     */
    resetAuthenticationConfiguration(): void;
    /**
     * @stability stable
     */
    get authenticationConfigurationInput(): ApprunnerServiceSourceConfigurationAuthenticationConfiguration | undefined;
    private _codeRepository;
    /**
     * @stability stable
     */
    get codeRepository(): ApprunnerServiceSourceConfigurationCodeRepositoryOutputReference;
    /**
     * @stability stable
     */
    putCodeRepository(value: ApprunnerServiceSourceConfigurationCodeRepository): void;
    /**
     * @stability stable
     */
    resetCodeRepository(): void;
    /**
     * @stability stable
     */
    get codeRepositoryInput(): ApprunnerServiceSourceConfigurationCodeRepository | undefined;
    private _imageRepository;
    /**
     * @stability stable
     */
    get imageRepository(): ApprunnerServiceSourceConfigurationImageRepositoryOutputReference;
    /**
     * @stability stable
     */
    putImageRepository(value: ApprunnerServiceSourceConfigurationImageRepository): void;
    /**
     * @stability stable
     */
    resetImageRepository(): void;
    /**
     * @stability stable
     */
    get imageRepositoryInput(): ApprunnerServiceSourceConfigurationImageRepository | undefined;
}
/**
 * Represents a {@link https://www.terraform.io/docs/providers/aws/r/apprunner_service aws_apprunner_service}.
 *
 * @stability stable
 */
export declare class ApprunnerService extends cdktf.TerraformResource {
    /**
     * @stability stable
     */
    static readonly tfResourceType: string;
    /**
     * Create a new {@link https://www.terraform.io/docs/providers/aws/r/apprunner_service aws_apprunner_service} Resource.
     *
     * @param scope The scope in which to define this construct.
     * @param id The scoped construct ID.
     * @stability stable
     */
    constructor(scope: Construct, id: string, config: ApprunnerServiceConfig);
    /**
     * @stability stable
     */
    get arn(): string;
    private _autoScalingConfigurationArn?;
    /**
     * @stability stable
     */
    get autoScalingConfigurationArn(): string;
    /**
     * @stability stable
     */
    set autoScalingConfigurationArn(value: string);
    /**
     * @stability stable
     */
    resetAutoScalingConfigurationArn(): void;
    /**
     * @stability stable
     */
    get autoScalingConfigurationArnInput(): string | undefined;
    /**
     * @stability stable
     */
    get id(): string;
    /**
     * @stability stable
     */
    get serviceId(): string;
    private _serviceName?;
    /**
     * @stability stable
     */
    get serviceName(): string;
    /**
     * @stability stable
     */
    set serviceName(value: string);
    /**
     * @stability stable
     */
    get serviceNameInput(): string | undefined;
    /**
     * @stability stable
     */
    get serviceUrl(): string;
    /**
     * @stability stable
     */
    get status(): string;
    private _tags?;
    /**
     * @stability stable
     */
    get tags(): {
        [key: string]: string;
    };
    /**
     * @stability stable
     */
    set tags(value: {
        [key: string]: string;
    });
    /**
     * @stability stable
     */
    resetTags(): void;
    /**
     * @stability stable
     */
    get tagsInput(): {
        [key: string]: string;
    } | undefined;
    private _tagsAll?;
    /**
     * @stability stable
     */
    get tagsAll(): {
        [key: string]: string;
    };
    /**
     * @stability stable
     */
    set tagsAll(value: {
        [key: string]: string;
    });
    /**
     * @stability stable
     */
    resetTagsAll(): void;
    /**
     * @stability stable
     */
    get tagsAllInput(): {
        [key: string]: string;
    } | undefined;
    private _encryptionConfiguration;
    /**
     * @stability stable
     */
    get encryptionConfiguration(): ApprunnerServiceEncryptionConfigurationOutputReference;
    /**
     * @stability stable
     */
    putEncryptionConfiguration(value: ApprunnerServiceEncryptionConfiguration): void;
    /**
     * @stability stable
     */
    resetEncryptionConfiguration(): void;
    /**
     * @stability stable
     */
    get encryptionConfigurationInput(): ApprunnerServiceEncryptionConfiguration | undefined;
    private _healthCheckConfiguration;
    /**
     * @stability stable
     */
    get healthCheckConfiguration(): ApprunnerServiceHealthCheckConfigurationOutputReference;
    /**
     * @stability stable
     */
    putHealthCheckConfiguration(value: ApprunnerServiceHealthCheckConfiguration): void;
    /**
     * @stability stable
     */
    resetHealthCheckConfiguration(): void;
    /**
     * @stability stable
     */
    get healthCheckConfigurationInput(): ApprunnerServiceHealthCheckConfiguration | undefined;
    private _instanceConfiguration;
    /**
     * @stability stable
     */
    get instanceConfiguration(): ApprunnerServiceInstanceConfigurationOutputReference;
    /**
     * @stability stable
     */
    putInstanceConfiguration(value: ApprunnerServiceInstanceConfiguration): void;
    /**
     * @stability stable
     */
    resetInstanceConfiguration(): void;
    /**
     * @stability stable
     */
    get instanceConfigurationInput(): ApprunnerServiceInstanceConfiguration | undefined;
    private _sourceConfiguration;
    /**
     * @stability stable
     */
    get sourceConfiguration(): ApprunnerServiceSourceConfigurationOutputReference;
    /**
     * @stability stable
     */
    putSourceConfiguration(value: ApprunnerServiceSourceConfiguration): void;
    /**
     * @stability stable
     */
    get sourceConfigurationInput(): ApprunnerServiceSourceConfiguration | undefined;
    /**
     * @stability stable
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
