import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
/**
 * AWS Backup.
 *
 * @stability stable
 */
export interface BackupPlanConfig extends cdktf.TerraformMetaArguments {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/backup_plan#name BackupPlan#name}.
     *
     * @stability stable
     */
    readonly name: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/backup_plan#tags BackupPlan#tags}.
     *
     * @stability stable
     */
    readonly tags?: {
        [key: string]: string;
    };
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/backup_plan#tags_all BackupPlan#tags_all}.
     *
     * @stability stable
     */
    readonly tagsAll?: {
        [key: string]: string;
    };
    /**
     * advanced_backup_setting block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/backup_plan#advanced_backup_setting BackupPlan#advanced_backup_setting}
     *
     * @stability stable
     */
    readonly advancedBackupSetting?: BackupPlanAdvancedBackupSetting[] | cdktf.IResolvable;
    /**
     * rule block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/backup_plan#rule BackupPlan#rule}
     *
     * @stability stable
     */
    readonly rule: BackupPlanRule[] | cdktf.IResolvable;
}
/**
 * @stability stable
 */
export interface BackupPlanAdvancedBackupSetting {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/backup_plan#backup_options BackupPlan#backup_options}.
     *
     * @stability stable
     */
    readonly backupOptions: {
        [key: string]: string;
    };
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/backup_plan#resource_type BackupPlan#resource_type}.
     *
     * @stability stable
     */
    readonly resourceType: string;
}
export declare function backupPlanAdvancedBackupSettingToTerraform(struct?: BackupPlanAdvancedBackupSetting | cdktf.IResolvable): any;
/**
 * @stability stable
 */
export interface BackupPlanRuleCopyActionLifecycle {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/backup_plan#cold_storage_after BackupPlan#cold_storage_after}.
     *
     * @stability stable
     */
    readonly coldStorageAfter?: number;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/backup_plan#delete_after BackupPlan#delete_after}.
     *
     * @stability stable
     */
    readonly deleteAfter?: number;
}
export declare function backupPlanRuleCopyActionLifecycleToTerraform(struct?: BackupPlanRuleCopyActionLifecycleOutputReference | BackupPlanRuleCopyActionLifecycle): any;
/**
 * @stability stable
 */
export declare class BackupPlanRuleCopyActionLifecycleOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): BackupPlanRuleCopyActionLifecycle | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: BackupPlanRuleCopyActionLifecycle | undefined);
    private _coldStorageAfter?;
    /**
     * @stability stable
     */
    get coldStorageAfter(): number;
    /**
     * @stability stable
     */
    set coldStorageAfter(value: number);
    /**
     * @stability stable
     */
    resetColdStorageAfter(): void;
    /**
     * @stability stable
     */
    get coldStorageAfterInput(): number | undefined;
    private _deleteAfter?;
    /**
     * @stability stable
     */
    get deleteAfter(): number;
    /**
     * @stability stable
     */
    set deleteAfter(value: number);
    /**
     * @stability stable
     */
    resetDeleteAfter(): void;
    /**
     * @stability stable
     */
    get deleteAfterInput(): number | undefined;
}
/**
 * @stability stable
 */
export interface BackupPlanRuleCopyAction {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/backup_plan#destination_vault_arn BackupPlan#destination_vault_arn}.
     *
     * @stability stable
     */
    readonly destinationVaultArn: string;
    /**
     * lifecycle block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/backup_plan#lifecycle BackupPlan#lifecycle}
     *
     * @stability stable
     */
    readonly lifecycle?: BackupPlanRuleCopyActionLifecycle;
}
export declare function backupPlanRuleCopyActionToTerraform(struct?: BackupPlanRuleCopyAction | cdktf.IResolvable): any;
/**
 * @stability stable
 */
export interface BackupPlanRuleLifecycle {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/backup_plan#cold_storage_after BackupPlan#cold_storage_after}.
     *
     * @stability stable
     */
    readonly coldStorageAfter?: number;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/backup_plan#delete_after BackupPlan#delete_after}.
     *
     * @stability stable
     */
    readonly deleteAfter?: number;
}
export declare function backupPlanRuleLifecycleToTerraform(struct?: BackupPlanRuleLifecycleOutputReference | BackupPlanRuleLifecycle): any;
/**
 * @stability stable
 */
export declare class BackupPlanRuleLifecycleOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): BackupPlanRuleLifecycle | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: BackupPlanRuleLifecycle | undefined);
    private _coldStorageAfter?;
    /**
     * @stability stable
     */
    get coldStorageAfter(): number;
    /**
     * @stability stable
     */
    set coldStorageAfter(value: number);
    /**
     * @stability stable
     */
    resetColdStorageAfter(): void;
    /**
     * @stability stable
     */
    get coldStorageAfterInput(): number | undefined;
    private _deleteAfter?;
    /**
     * @stability stable
     */
    get deleteAfter(): number;
    /**
     * @stability stable
     */
    set deleteAfter(value: number);
    /**
     * @stability stable
     */
    resetDeleteAfter(): void;
    /**
     * @stability stable
     */
    get deleteAfterInput(): number | undefined;
}
/**
 * @stability stable
 */
export interface BackupPlanRule {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/backup_plan#completion_window BackupPlan#completion_window}.
     *
     * @stability stable
     */
    readonly completionWindow?: number;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/backup_plan#enable_continuous_backup BackupPlan#enable_continuous_backup}.
     *
     * @stability stable
     */
    readonly enableContinuousBackup?: boolean | cdktf.IResolvable;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/backup_plan#recovery_point_tags BackupPlan#recovery_point_tags}.
     *
     * @stability stable
     */
    readonly recoveryPointTags?: {
        [key: string]: string;
    };
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/backup_plan#rule_name BackupPlan#rule_name}.
     *
     * @stability stable
     */
    readonly ruleName: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/backup_plan#schedule BackupPlan#schedule}.
     *
     * @stability stable
     */
    readonly schedule?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/backup_plan#start_window BackupPlan#start_window}.
     *
     * @stability stable
     */
    readonly startWindow?: number;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/backup_plan#target_vault_name BackupPlan#target_vault_name}.
     *
     * @stability stable
     */
    readonly targetVaultName: string;
    /**
     * copy_action block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/backup_plan#copy_action BackupPlan#copy_action}
     *
     * @stability stable
     */
    readonly copyAction?: BackupPlanRuleCopyAction[] | cdktf.IResolvable;
    /**
     * lifecycle block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/backup_plan#lifecycle BackupPlan#lifecycle}
     *
     * @stability stable
     */
    readonly lifecycle?: BackupPlanRuleLifecycle;
}
export declare function backupPlanRuleToTerraform(struct?: BackupPlanRule | cdktf.IResolvable): any;
/**
 * Represents a {@link https://www.terraform.io/docs/providers/aws/r/backup_plan aws_backup_plan}.
 *
 * @stability stable
 */
export declare class BackupPlan extends cdktf.TerraformResource {
    /**
     * @stability stable
     */
    static readonly tfResourceType: string;
    /**
     * Create a new {@link https://www.terraform.io/docs/providers/aws/r/backup_plan aws_backup_plan} Resource.
     *
     * @param scope The scope in which to define this construct.
     * @param id The scoped construct ID.
     * @stability stable
     */
    constructor(scope: Construct, id: string, config: BackupPlanConfig);
    /**
     * @stability stable
     */
    get arn(): string;
    /**
     * @stability stable
     */
    get id(): string;
    private _name?;
    /**
     * @stability stable
     */
    get name(): string;
    /**
     * @stability stable
     */
    set name(value: string);
    /**
     * @stability stable
     */
    get nameInput(): string | undefined;
    private _tags?;
    /**
     * @stability stable
     */
    get tags(): {
        [key: string]: string;
    };
    /**
     * @stability stable
     */
    set tags(value: {
        [key: string]: string;
    });
    /**
     * @stability stable
     */
    resetTags(): void;
    /**
     * @stability stable
     */
    get tagsInput(): {
        [key: string]: string;
    } | undefined;
    private _tagsAll?;
    /**
     * @stability stable
     */
    get tagsAll(): {
        [key: string]: string;
    };
    /**
     * @stability stable
     */
    set tagsAll(value: {
        [key: string]: string;
    });
    /**
     * @stability stable
     */
    resetTagsAll(): void;
    /**
     * @stability stable
     */
    get tagsAllInput(): {
        [key: string]: string;
    } | undefined;
    /**
     * @stability stable
     */
    get version(): string;
    private _advancedBackupSetting?;
    /**
     * @stability stable
     */
    get advancedBackupSetting(): BackupPlanAdvancedBackupSetting[] | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set advancedBackupSetting(value: BackupPlanAdvancedBackupSetting[] | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetAdvancedBackupSetting(): void;
    /**
     * @stability stable
     */
    get advancedBackupSettingInput(): cdktf.IResolvable | BackupPlanAdvancedBackupSetting[] | undefined;
    private _rule?;
    /**
     * @stability stable
     */
    get rule(): BackupPlanRule[] | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set rule(value: BackupPlanRule[] | cdktf.IResolvable);
    /**
     * @stability stable
     */
    get ruleInput(): cdktf.IResolvable | BackupPlanRule[] | undefined;
    /**
     * @stability stable
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
