import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
/**
 * AWS CloudFormation.
 *
 * @stability stable
 */
export interface CloudformationStackConfig extends cdktf.TerraformMetaArguments {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cloudformation_stack#capabilities CloudformationStack#capabilities}.
     *
     * @stability stable
     */
    readonly capabilities?: string[];
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cloudformation_stack#disable_rollback CloudformationStack#disable_rollback}.
     *
     * @stability stable
     */
    readonly disableRollback?: boolean | cdktf.IResolvable;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cloudformation_stack#iam_role_arn CloudformationStack#iam_role_arn}.
     *
     * @stability stable
     */
    readonly iamRoleArn?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cloudformation_stack#name CloudformationStack#name}.
     *
     * @stability stable
     */
    readonly name: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cloudformation_stack#notification_arns CloudformationStack#notification_arns}.
     *
     * @stability stable
     */
    readonly notificationArns?: string[];
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cloudformation_stack#on_failure CloudformationStack#on_failure}.
     *
     * @stability stable
     */
    readonly onFailure?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cloudformation_stack#parameters CloudformationStack#parameters}.
     *
     * @stability stable
     */
    readonly parameters?: {
        [key: string]: string;
    };
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cloudformation_stack#policy_body CloudformationStack#policy_body}.
     *
     * @stability stable
     */
    readonly policyBody?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cloudformation_stack#policy_url CloudformationStack#policy_url}.
     *
     * @stability stable
     */
    readonly policyUrl?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cloudformation_stack#tags CloudformationStack#tags}.
     *
     * @stability stable
     */
    readonly tags?: {
        [key: string]: string;
    };
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cloudformation_stack#tags_all CloudformationStack#tags_all}.
     *
     * @stability stable
     */
    readonly tagsAll?: {
        [key: string]: string;
    };
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cloudformation_stack#template_body CloudformationStack#template_body}.
     *
     * @stability stable
     */
    readonly templateBody?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cloudformation_stack#template_url CloudformationStack#template_url}.
     *
     * @stability stable
     */
    readonly templateUrl?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cloudformation_stack#timeout_in_minutes CloudformationStack#timeout_in_minutes}.
     *
     * @stability stable
     */
    readonly timeoutInMinutes?: number;
    /**
     * timeouts block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cloudformation_stack#timeouts CloudformationStack#timeouts}
     *
     * @stability stable
     */
    readonly timeouts?: CloudformationStackTimeouts;
}
/**
 * @stability stable
 */
export interface CloudformationStackTimeouts {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cloudformation_stack#create CloudformationStack#create}.
     *
     * @stability stable
     */
    readonly create?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cloudformation_stack#delete CloudformationStack#delete}.
     *
     * @stability stable
     */
    readonly delete?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cloudformation_stack#update CloudformationStack#update}.
     *
     * @stability stable
     */
    readonly update?: string;
}
export declare function cloudformationStackTimeoutsToTerraform(struct?: CloudformationStackTimeoutsOutputReference | CloudformationStackTimeouts | cdktf.IResolvable): any;
/**
 * @stability stable
 */
export declare class CloudformationStackTimeoutsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): CloudformationStackTimeouts | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: CloudformationStackTimeouts | undefined);
    private _create?;
    /**
     * @stability stable
     */
    get create(): string;
    /**
     * @stability stable
     */
    set create(value: string);
    /**
     * @stability stable
     */
    resetCreate(): void;
    /**
     * @stability stable
     */
    get createInput(): string | undefined;
    private _delete?;
    /**
     * @stability stable
     */
    get delete(): string;
    /**
     * @stability stable
     */
    set delete(value: string);
    /**
     * @stability stable
     */
    resetDelete(): void;
    /**
     * @stability stable
     */
    get deleteInput(): string | undefined;
    private _update?;
    /**
     * @stability stable
     */
    get update(): string;
    /**
     * @stability stable
     */
    set update(value: string);
    /**
     * @stability stable
     */
    resetUpdate(): void;
    /**
     * @stability stable
     */
    get updateInput(): string | undefined;
}
/**
 * Represents a {@link https://www.terraform.io/docs/providers/aws/r/cloudformation_stack aws_cloudformation_stack}.
 *
 * @stability stable
 */
export declare class CloudformationStack extends cdktf.TerraformResource {
    /**
     * @stability stable
     */
    static readonly tfResourceType: string;
    /**
     * Create a new {@link https://www.terraform.io/docs/providers/aws/r/cloudformation_stack aws_cloudformation_stack} Resource.
     *
     * @param scope The scope in which to define this construct.
     * @param id The scoped construct ID.
     * @stability stable
     */
    constructor(scope: Construct, id: string, config: CloudformationStackConfig);
    private _capabilities?;
    /**
     * @stability stable
     */
    get capabilities(): string[];
    /**
     * @stability stable
     */
    set capabilities(value: string[]);
    /**
     * @stability stable
     */
    resetCapabilities(): void;
    /**
     * @stability stable
     */
    get capabilitiesInput(): string[] | undefined;
    private _disableRollback?;
    /**
     * @stability stable
     */
    get disableRollback(): boolean | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set disableRollback(value: boolean | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetDisableRollback(): void;
    /**
     * @stability stable
     */
    get disableRollbackInput(): boolean | cdktf.IResolvable | undefined;
    private _iamRoleArn?;
    /**
     * @stability stable
     */
    get iamRoleArn(): string;
    /**
     * @stability stable
     */
    set iamRoleArn(value: string);
    /**
     * @stability stable
     */
    resetIamRoleArn(): void;
    /**
     * @stability stable
     */
    get iamRoleArnInput(): string | undefined;
    /**
     * @stability stable
     */
    get id(): string;
    private _name?;
    /**
     * @stability stable
     */
    get name(): string;
    /**
     * @stability stable
     */
    set name(value: string);
    /**
     * @stability stable
     */
    get nameInput(): string | undefined;
    private _notificationArns?;
    /**
     * @stability stable
     */
    get notificationArns(): string[];
    /**
     * @stability stable
     */
    set notificationArns(value: string[]);
    /**
     * @stability stable
     */
    resetNotificationArns(): void;
    /**
     * @stability stable
     */
    get notificationArnsInput(): string[] | undefined;
    private _onFailure?;
    /**
     * @stability stable
     */
    get onFailure(): string;
    /**
     * @stability stable
     */
    set onFailure(value: string);
    /**
     * @stability stable
     */
    resetOnFailure(): void;
    /**
     * @stability stable
     */
    get onFailureInput(): string | undefined;
    /**
     * @stability stable
     */
    outputs(key: string): string | cdktf.IResolvable;
    private _parameters?;
    /**
     * @stability stable
     */
    get parameters(): {
        [key: string]: string;
    };
    /**
     * @stability stable
     */
    set parameters(value: {
        [key: string]: string;
    });
    /**
     * @stability stable
     */
    resetParameters(): void;
    /**
     * @stability stable
     */
    get parametersInput(): {
        [key: string]: string;
    } | undefined;
    private _policyBody?;
    /**
     * @stability stable
     */
    get policyBody(): string;
    /**
     * @stability stable
     */
    set policyBody(value: string);
    /**
     * @stability stable
     */
    resetPolicyBody(): void;
    /**
     * @stability stable
     */
    get policyBodyInput(): string | undefined;
    private _policyUrl?;
    /**
     * @stability stable
     */
    get policyUrl(): string;
    /**
     * @stability stable
     */
    set policyUrl(value: string);
    /**
     * @stability stable
     */
    resetPolicyUrl(): void;
    /**
     * @stability stable
     */
    get policyUrlInput(): string | undefined;
    private _tags?;
    /**
     * @stability stable
     */
    get tags(): {
        [key: string]: string;
    };
    /**
     * @stability stable
     */
    set tags(value: {
        [key: string]: string;
    });
    /**
     * @stability stable
     */
    resetTags(): void;
    /**
     * @stability stable
     */
    get tagsInput(): {
        [key: string]: string;
    } | undefined;
    private _tagsAll?;
    /**
     * @stability stable
     */
    get tagsAll(): {
        [key: string]: string;
    };
    /**
     * @stability stable
     */
    set tagsAll(value: {
        [key: string]: string;
    });
    /**
     * @stability stable
     */
    resetTagsAll(): void;
    /**
     * @stability stable
     */
    get tagsAllInput(): {
        [key: string]: string;
    } | undefined;
    private _templateBody?;
    /**
     * @stability stable
     */
    get templateBody(): string;
    /**
     * @stability stable
     */
    set templateBody(value: string);
    /**
     * @stability stable
     */
    resetTemplateBody(): void;
    /**
     * @stability stable
     */
    get templateBodyInput(): string | undefined;
    private _templateUrl?;
    /**
     * @stability stable
     */
    get templateUrl(): string;
    /**
     * @stability stable
     */
    set templateUrl(value: string);
    /**
     * @stability stable
     */
    resetTemplateUrl(): void;
    /**
     * @stability stable
     */
    get templateUrlInput(): string | undefined;
    private _timeoutInMinutes?;
    /**
     * @stability stable
     */
    get timeoutInMinutes(): number;
    /**
     * @stability stable
     */
    set timeoutInMinutes(value: number);
    /**
     * @stability stable
     */
    resetTimeoutInMinutes(): void;
    /**
     * @stability stable
     */
    get timeoutInMinutesInput(): number | undefined;
    private _timeouts;
    /**
     * @stability stable
     */
    get timeouts(): CloudformationStackTimeoutsOutputReference;
    /**
     * @stability stable
     */
    putTimeouts(value: CloudformationStackTimeouts): void;
    /**
     * @stability stable
     */
    resetTimeouts(): void;
    /**
     * @stability stable
     */
    get timeoutsInput(): CloudformationStackTimeouts | undefined;
    /**
     * @stability stable
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
