import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
/**
 * AWS CodeArtifact.
 *
 * @stability stable
 */
export interface CodeartifactRepositoryConfig extends cdktf.TerraformMetaArguments {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/codeartifact_repository#description CodeartifactRepository#description}.
     *
     * @stability stable
     */
    readonly description?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/codeartifact_repository#domain CodeartifactRepository#domain}.
     *
     * @stability stable
     */
    readonly domain: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/codeartifact_repository#domain_owner CodeartifactRepository#domain_owner}.
     *
     * @stability stable
     */
    readonly domainOwner?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/codeartifact_repository#repository CodeartifactRepository#repository}.
     *
     * @stability stable
     */
    readonly repository: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/codeartifact_repository#tags CodeartifactRepository#tags}.
     *
     * @stability stable
     */
    readonly tags?: {
        [key: string]: string;
    };
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/codeartifact_repository#tags_all CodeartifactRepository#tags_all}.
     *
     * @stability stable
     */
    readonly tagsAll?: {
        [key: string]: string;
    };
    /**
     * external_connections block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/codeartifact_repository#external_connections CodeartifactRepository#external_connections}
     *
     * @stability stable
     */
    readonly externalConnections?: CodeartifactRepositoryExternalConnections;
    /**
     * upstream block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/codeartifact_repository#upstream CodeartifactRepository#upstream}
     *
     * @stability stable
     */
    readonly upstream?: CodeartifactRepositoryUpstream[] | cdktf.IResolvable;
}
/**
 * @stability stable
 */
export interface CodeartifactRepositoryExternalConnections {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/codeartifact_repository#external_connection_name CodeartifactRepository#external_connection_name}.
     *
     * @stability stable
     */
    readonly externalConnectionName: string;
}
export declare function codeartifactRepositoryExternalConnectionsToTerraform(struct?: CodeartifactRepositoryExternalConnectionsOutputReference | CodeartifactRepositoryExternalConnections): any;
/**
 * @stability stable
 */
export declare class CodeartifactRepositoryExternalConnectionsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): CodeartifactRepositoryExternalConnections | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: CodeartifactRepositoryExternalConnections | undefined);
    private _externalConnectionName?;
    /**
     * @stability stable
     */
    get externalConnectionName(): string;
    /**
     * @stability stable
     */
    set externalConnectionName(value: string);
    /**
     * @stability stable
     */
    get externalConnectionNameInput(): string | undefined;
    /**
     * @stability stable
     */
    get packageFormat(): string;
    /**
     * @stability stable
     */
    get status(): string;
}
/**
 * @stability stable
 */
export interface CodeartifactRepositoryUpstream {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/codeartifact_repository#repository_name CodeartifactRepository#repository_name}.
     *
     * @stability stable
     */
    readonly repositoryName: string;
}
export declare function codeartifactRepositoryUpstreamToTerraform(struct?: CodeartifactRepositoryUpstream | cdktf.IResolvable): any;
/**
 * Represents a {@link https://www.terraform.io/docs/providers/aws/r/codeartifact_repository aws_codeartifact_repository}.
 *
 * @stability stable
 */
export declare class CodeartifactRepository extends cdktf.TerraformResource {
    /**
     * @stability stable
     */
    static readonly tfResourceType: string;
    /**
     * Create a new {@link https://www.terraform.io/docs/providers/aws/r/codeartifact_repository aws_codeartifact_repository} Resource.
     *
     * @param scope The scope in which to define this construct.
     * @param id The scoped construct ID.
     * @stability stable
     */
    constructor(scope: Construct, id: string, config: CodeartifactRepositoryConfig);
    /**
     * @stability stable
     */
    get administratorAccount(): string;
    /**
     * @stability stable
     */
    get arn(): string;
    private _description?;
    /**
     * @stability stable
     */
    get description(): string;
    /**
     * @stability stable
     */
    set description(value: string);
    /**
     * @stability stable
     */
    resetDescription(): void;
    /**
     * @stability stable
     */
    get descriptionInput(): string | undefined;
    private _domain?;
    /**
     * @stability stable
     */
    get domain(): string;
    /**
     * @stability stable
     */
    set domain(value: string);
    /**
     * @stability stable
     */
    get domainInput(): string | undefined;
    private _domainOwner?;
    /**
     * @stability stable
     */
    get domainOwner(): string;
    /**
     * @stability stable
     */
    set domainOwner(value: string);
    /**
     * @stability stable
     */
    resetDomainOwner(): void;
    /**
     * @stability stable
     */
    get domainOwnerInput(): string | undefined;
    /**
     * @stability stable
     */
    get id(): string;
    private _repository?;
    /**
     * @stability stable
     */
    get repository(): string;
    /**
     * @stability stable
     */
    set repository(value: string);
    /**
     * @stability stable
     */
    get repositoryInput(): string | undefined;
    private _tags?;
    /**
     * @stability stable
     */
    get tags(): {
        [key: string]: string;
    };
    /**
     * @stability stable
     */
    set tags(value: {
        [key: string]: string;
    });
    /**
     * @stability stable
     */
    resetTags(): void;
    /**
     * @stability stable
     */
    get tagsInput(): {
        [key: string]: string;
    } | undefined;
    private _tagsAll?;
    /**
     * @stability stable
     */
    get tagsAll(): {
        [key: string]: string;
    };
    /**
     * @stability stable
     */
    set tagsAll(value: {
        [key: string]: string;
    });
    /**
     * @stability stable
     */
    resetTagsAll(): void;
    /**
     * @stability stable
     */
    get tagsAllInput(): {
        [key: string]: string;
    } | undefined;
    private _externalConnections;
    /**
     * @stability stable
     */
    get externalConnections(): CodeartifactRepositoryExternalConnectionsOutputReference;
    /**
     * @stability stable
     */
    putExternalConnections(value: CodeartifactRepositoryExternalConnections): void;
    /**
     * @stability stable
     */
    resetExternalConnections(): void;
    /**
     * @stability stable
     */
    get externalConnectionsInput(): CodeartifactRepositoryExternalConnections | undefined;
    private _upstream?;
    /**
     * @stability stable
     */
    get upstream(): CodeartifactRepositoryUpstream[] | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set upstream(value: CodeartifactRepositoryUpstream[] | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetUpstream(): void;
    /**
     * @stability stable
     */
    get upstreamInput(): cdktf.IResolvable | CodeartifactRepositoryUpstream[] | undefined;
    /**
     * @stability stable
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
