import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
/**
 * AWS Config.
 *
 * @stability stable
 */
export interface ConfigDeliveryChannelConfig extends cdktf.TerraformMetaArguments {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/config_delivery_channel#name ConfigDeliveryChannel#name}.
     *
     * @stability stable
     */
    readonly name?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/config_delivery_channel#s3_bucket_name ConfigDeliveryChannel#s3_bucket_name}.
     *
     * @stability stable
     */
    readonly s3BucketName: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/config_delivery_channel#s3_key_prefix ConfigDeliveryChannel#s3_key_prefix}.
     *
     * @stability stable
     */
    readonly s3KeyPrefix?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/config_delivery_channel#s3_kms_key_arn ConfigDeliveryChannel#s3_kms_key_arn}.
     *
     * @stability stable
     */
    readonly s3KmsKeyArn?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/config_delivery_channel#sns_topic_arn ConfigDeliveryChannel#sns_topic_arn}.
     *
     * @stability stable
     */
    readonly snsTopicArn?: string;
    /**
     * snapshot_delivery_properties block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/config_delivery_channel#snapshot_delivery_properties ConfigDeliveryChannel#snapshot_delivery_properties}
     *
     * @stability stable
     */
    readonly snapshotDeliveryProperties?: ConfigDeliveryChannelSnapshotDeliveryProperties;
}
/**
 * @stability stable
 */
export interface ConfigDeliveryChannelSnapshotDeliveryProperties {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/config_delivery_channel#delivery_frequency ConfigDeliveryChannel#delivery_frequency}.
     *
     * @stability stable
     */
    readonly deliveryFrequency?: string;
}
export declare function configDeliveryChannelSnapshotDeliveryPropertiesToTerraform(struct?: ConfigDeliveryChannelSnapshotDeliveryPropertiesOutputReference | ConfigDeliveryChannelSnapshotDeliveryProperties): any;
/**
 * @stability stable
 */
export declare class ConfigDeliveryChannelSnapshotDeliveryPropertiesOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): ConfigDeliveryChannelSnapshotDeliveryProperties | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: ConfigDeliveryChannelSnapshotDeliveryProperties | undefined);
    private _deliveryFrequency?;
    /**
     * @stability stable
     */
    get deliveryFrequency(): string;
    /**
     * @stability stable
     */
    set deliveryFrequency(value: string);
    /**
     * @stability stable
     */
    resetDeliveryFrequency(): void;
    /**
     * @stability stable
     */
    get deliveryFrequencyInput(): string | undefined;
}
/**
 * Represents a {@link https://www.terraform.io/docs/providers/aws/r/config_delivery_channel aws_config_delivery_channel}.
 *
 * @stability stable
 */
export declare class ConfigDeliveryChannel extends cdktf.TerraformResource {
    /**
     * @stability stable
     */
    static readonly tfResourceType: string;
    /**
     * Create a new {@link https://www.terraform.io/docs/providers/aws/r/config_delivery_channel aws_config_delivery_channel} Resource.
     *
     * @param scope The scope in which to define this construct.
     * @param id The scoped construct ID.
     * @stability stable
     */
    constructor(scope: Construct, id: string, config: ConfigDeliveryChannelConfig);
    /**
     * @stability stable
     */
    get id(): string;
    private _name?;
    /**
     * @stability stable
     */
    get name(): string;
    /**
     * @stability stable
     */
    set name(value: string);
    /**
     * @stability stable
     */
    resetName(): void;
    /**
     * @stability stable
     */
    get nameInput(): string | undefined;
    private _s3BucketName?;
    /**
     * @stability stable
     */
    get s3BucketName(): string;
    /**
     * @stability stable
     */
    set s3BucketName(value: string);
    /**
     * @stability stable
     */
    get s3BucketNameInput(): string | undefined;
    private _s3KeyPrefix?;
    /**
     * @stability stable
     */
    get s3KeyPrefix(): string;
    /**
     * @stability stable
     */
    set s3KeyPrefix(value: string);
    /**
     * @stability stable
     */
    resetS3KeyPrefix(): void;
    /**
     * @stability stable
     */
    get s3KeyPrefixInput(): string | undefined;
    private _s3KmsKeyArn?;
    /**
     * @stability stable
     */
    get s3KmsKeyArn(): string;
    /**
     * @stability stable
     */
    set s3KmsKeyArn(value: string);
    /**
     * @stability stable
     */
    resetS3KmsKeyArn(): void;
    /**
     * @stability stable
     */
    get s3KmsKeyArnInput(): string | undefined;
    private _snsTopicArn?;
    /**
     * @stability stable
     */
    get snsTopicArn(): string;
    /**
     * @stability stable
     */
    set snsTopicArn(value: string);
    /**
     * @stability stable
     */
    resetSnsTopicArn(): void;
    /**
     * @stability stable
     */
    get snsTopicArnInput(): string | undefined;
    private _snapshotDeliveryProperties;
    /**
     * @stability stable
     */
    get snapshotDeliveryProperties(): ConfigDeliveryChannelSnapshotDeliveryPropertiesOutputReference;
    /**
     * @stability stable
     */
    putSnapshotDeliveryProperties(value: ConfigDeliveryChannelSnapshotDeliveryProperties): void;
    /**
     * @stability stable
     */
    resetSnapshotDeliveryProperties(): void;
    /**
     * @stability stable
     */
    get snapshotDeliveryPropertiesInput(): ConfigDeliveryChannelSnapshotDeliveryProperties | undefined;
    /**
     * @stability stable
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
