import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
/**
 * AWS Config.
 *
 * @stability stable
 */
export interface ConfigOrganizationConformancePackConfig extends cdktf.TerraformMetaArguments {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/config_organization_conformance_pack#delivery_s3_bucket ConfigOrganizationConformancePack#delivery_s3_bucket}.
     *
     * @stability stable
     */
    readonly deliveryS3Bucket?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/config_organization_conformance_pack#delivery_s3_key_prefix ConfigOrganizationConformancePack#delivery_s3_key_prefix}.
     *
     * @stability stable
     */
    readonly deliveryS3KeyPrefix?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/config_organization_conformance_pack#excluded_accounts ConfigOrganizationConformancePack#excluded_accounts}.
     *
     * @stability stable
     */
    readonly excludedAccounts?: string[];
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/config_organization_conformance_pack#name ConfigOrganizationConformancePack#name}.
     *
     * @stability stable
     */
    readonly name: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/config_organization_conformance_pack#template_body ConfigOrganizationConformancePack#template_body}.
     *
     * @stability stable
     */
    readonly templateBody?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/config_organization_conformance_pack#template_s3_uri ConfigOrganizationConformancePack#template_s3_uri}.
     *
     * @stability stable
     */
    readonly templateS3Uri?: string;
    /**
     * input_parameter block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/config_organization_conformance_pack#input_parameter ConfigOrganizationConformancePack#input_parameter}
     *
     * @stability stable
     */
    readonly inputParameter?: ConfigOrganizationConformancePackInputParameter[] | cdktf.IResolvable;
    /**
     * timeouts block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/config_organization_conformance_pack#timeouts ConfigOrganizationConformancePack#timeouts}
     *
     * @stability stable
     */
    readonly timeouts?: ConfigOrganizationConformancePackTimeouts;
}
/**
 * @stability stable
 */
export interface ConfigOrganizationConformancePackInputParameter {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/config_organization_conformance_pack#parameter_name ConfigOrganizationConformancePack#parameter_name}.
     *
     * @stability stable
     */
    readonly parameterName: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/config_organization_conformance_pack#parameter_value ConfigOrganizationConformancePack#parameter_value}.
     *
     * @stability stable
     */
    readonly parameterValue: string;
}
export declare function configOrganizationConformancePackInputParameterToTerraform(struct?: ConfigOrganizationConformancePackInputParameter | cdktf.IResolvable): any;
/**
 * @stability stable
 */
export interface ConfigOrganizationConformancePackTimeouts {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/config_organization_conformance_pack#create ConfigOrganizationConformancePack#create}.
     *
     * @stability stable
     */
    readonly create?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/config_organization_conformance_pack#delete ConfigOrganizationConformancePack#delete}.
     *
     * @stability stable
     */
    readonly delete?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/config_organization_conformance_pack#update ConfigOrganizationConformancePack#update}.
     *
     * @stability stable
     */
    readonly update?: string;
}
export declare function configOrganizationConformancePackTimeoutsToTerraform(struct?: ConfigOrganizationConformancePackTimeoutsOutputReference | ConfigOrganizationConformancePackTimeouts | cdktf.IResolvable): any;
/**
 * @stability stable
 */
export declare class ConfigOrganizationConformancePackTimeoutsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): ConfigOrganizationConformancePackTimeouts | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: ConfigOrganizationConformancePackTimeouts | undefined);
    private _create?;
    /**
     * @stability stable
     */
    get create(): string;
    /**
     * @stability stable
     */
    set create(value: string);
    /**
     * @stability stable
     */
    resetCreate(): void;
    /**
     * @stability stable
     */
    get createInput(): string | undefined;
    private _delete?;
    /**
     * @stability stable
     */
    get delete(): string;
    /**
     * @stability stable
     */
    set delete(value: string);
    /**
     * @stability stable
     */
    resetDelete(): void;
    /**
     * @stability stable
     */
    get deleteInput(): string | undefined;
    private _update?;
    /**
     * @stability stable
     */
    get update(): string;
    /**
     * @stability stable
     */
    set update(value: string);
    /**
     * @stability stable
     */
    resetUpdate(): void;
    /**
     * @stability stable
     */
    get updateInput(): string | undefined;
}
/**
 * Represents a {@link https://www.terraform.io/docs/providers/aws/r/config_organization_conformance_pack aws_config_organization_conformance_pack}.
 *
 * @stability stable
 */
export declare class ConfigOrganizationConformancePack extends cdktf.TerraformResource {
    /**
     * @stability stable
     */
    static readonly tfResourceType: string;
    /**
     * Create a new {@link https://www.terraform.io/docs/providers/aws/r/config_organization_conformance_pack aws_config_organization_conformance_pack} Resource.
     *
     * @param scope The scope in which to define this construct.
     * @param id The scoped construct ID.
     * @stability stable
     */
    constructor(scope: Construct, id: string, config: ConfigOrganizationConformancePackConfig);
    /**
     * @stability stable
     */
    get arn(): string;
    private _deliveryS3Bucket?;
    /**
     * @stability stable
     */
    get deliveryS3Bucket(): string;
    /**
     * @stability stable
     */
    set deliveryS3Bucket(value: string);
    /**
     * @stability stable
     */
    resetDeliveryS3Bucket(): void;
    /**
     * @stability stable
     */
    get deliveryS3BucketInput(): string | undefined;
    private _deliveryS3KeyPrefix?;
    /**
     * @stability stable
     */
    get deliveryS3KeyPrefix(): string;
    /**
     * @stability stable
     */
    set deliveryS3KeyPrefix(value: string);
    /**
     * @stability stable
     */
    resetDeliveryS3KeyPrefix(): void;
    /**
     * @stability stable
     */
    get deliveryS3KeyPrefixInput(): string | undefined;
    private _excludedAccounts?;
    /**
     * @stability stable
     */
    get excludedAccounts(): string[];
    /**
     * @stability stable
     */
    set excludedAccounts(value: string[]);
    /**
     * @stability stable
     */
    resetExcludedAccounts(): void;
    /**
     * @stability stable
     */
    get excludedAccountsInput(): string[] | undefined;
    /**
     * @stability stable
     */
    get id(): string;
    private _name?;
    /**
     * @stability stable
     */
    get name(): string;
    /**
     * @stability stable
     */
    set name(value: string);
    /**
     * @stability stable
     */
    get nameInput(): string | undefined;
    private _templateBody?;
    /**
     * @stability stable
     */
    get templateBody(): string;
    /**
     * @stability stable
     */
    set templateBody(value: string);
    /**
     * @stability stable
     */
    resetTemplateBody(): void;
    /**
     * @stability stable
     */
    get templateBodyInput(): string | undefined;
    private _templateS3Uri?;
    /**
     * @stability stable
     */
    get templateS3Uri(): string;
    /**
     * @stability stable
     */
    set templateS3Uri(value: string);
    /**
     * @stability stable
     */
    resetTemplateS3Uri(): void;
    /**
     * @stability stable
     */
    get templateS3UriInput(): string | undefined;
    private _inputParameter?;
    /**
     * @stability stable
     */
    get inputParameter(): ConfigOrganizationConformancePackInputParameter[] | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set inputParameter(value: ConfigOrganizationConformancePackInputParameter[] | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetInputParameter(): void;
    /**
     * @stability stable
     */
    get inputParameterInput(): cdktf.IResolvable | ConfigOrganizationConformancePackInputParameter[] | undefined;
    private _timeouts;
    /**
     * @stability stable
     */
    get timeouts(): ConfigOrganizationConformancePackTimeoutsOutputReference;
    /**
     * @stability stable
     */
    putTimeouts(value: ConfigOrganizationConformancePackTimeouts): void;
    /**
     * @stability stable
     */
    resetTimeouts(): void;
    /**
     * @stability stable
     */
    get timeoutsInput(): ConfigOrganizationConformancePackTimeouts | undefined;
    /**
     * @stability stable
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
