import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
/**
 * AWS Connect.
 *
 * @stability stable
 */
export interface ConnectInstanceConfig extends cdktf.TerraformMetaArguments {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/connect_instance#auto_resolve_best_voices_enabled ConnectInstance#auto_resolve_best_voices_enabled}.
     *
     * @stability stable
     */
    readonly autoResolveBestVoicesEnabled?: boolean | cdktf.IResolvable;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/connect_instance#contact_flow_logs_enabled ConnectInstance#contact_flow_logs_enabled}.
     *
     * @stability stable
     */
    readonly contactFlowLogsEnabled?: boolean | cdktf.IResolvable;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/connect_instance#contact_lens_enabled ConnectInstance#contact_lens_enabled}.
     *
     * @stability stable
     */
    readonly contactLensEnabled?: boolean | cdktf.IResolvable;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/connect_instance#directory_id ConnectInstance#directory_id}.
     *
     * @stability stable
     */
    readonly directoryId?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/connect_instance#early_media_enabled ConnectInstance#early_media_enabled}.
     *
     * @stability stable
     */
    readonly earlyMediaEnabled?: boolean | cdktf.IResolvable;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/connect_instance#identity_management_type ConnectInstance#identity_management_type}.
     *
     * @stability stable
     */
    readonly identityManagementType: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/connect_instance#inbound_calls_enabled ConnectInstance#inbound_calls_enabled}.
     *
     * @stability stable
     */
    readonly inboundCallsEnabled: boolean | cdktf.IResolvable;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/connect_instance#instance_alias ConnectInstance#instance_alias}.
     *
     * @stability stable
     */
    readonly instanceAlias?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/connect_instance#outbound_calls_enabled ConnectInstance#outbound_calls_enabled}.
     *
     * @stability stable
     */
    readonly outboundCallsEnabled: boolean | cdktf.IResolvable;
    /**
     * timeouts block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/connect_instance#timeouts ConnectInstance#timeouts}
     *
     * @stability stable
     */
    readonly timeouts?: ConnectInstanceTimeouts;
}
/**
 * @stability stable
 */
export interface ConnectInstanceTimeouts {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/connect_instance#create ConnectInstance#create}.
     *
     * @stability stable
     */
    readonly create?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/connect_instance#delete ConnectInstance#delete}.
     *
     * @stability stable
     */
    readonly delete?: string;
}
export declare function connectInstanceTimeoutsToTerraform(struct?: ConnectInstanceTimeoutsOutputReference | ConnectInstanceTimeouts | cdktf.IResolvable): any;
/**
 * @stability stable
 */
export declare class ConnectInstanceTimeoutsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): ConnectInstanceTimeouts | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: ConnectInstanceTimeouts | undefined);
    private _create?;
    /**
     * @stability stable
     */
    get create(): string;
    /**
     * @stability stable
     */
    set create(value: string);
    /**
     * @stability stable
     */
    resetCreate(): void;
    /**
     * @stability stable
     */
    get createInput(): string | undefined;
    private _delete?;
    /**
     * @stability stable
     */
    get delete(): string;
    /**
     * @stability stable
     */
    set delete(value: string);
    /**
     * @stability stable
     */
    resetDelete(): void;
    /**
     * @stability stable
     */
    get deleteInput(): string | undefined;
}
/**
 * Represents a {@link https://www.terraform.io/docs/providers/aws/r/connect_instance aws_connect_instance}.
 *
 * @stability stable
 */
export declare class ConnectInstance extends cdktf.TerraformResource {
    /**
     * @stability stable
     */
    static readonly tfResourceType: string;
    /**
     * Create a new {@link https://www.terraform.io/docs/providers/aws/r/connect_instance aws_connect_instance} Resource.
     *
     * @param scope The scope in which to define this construct.
     * @param id The scoped construct ID.
     * @stability stable
     */
    constructor(scope: Construct, id: string, config: ConnectInstanceConfig);
    /**
     * @stability stable
     */
    get arn(): string;
    private _autoResolveBestVoicesEnabled?;
    /**
     * @stability stable
     */
    get autoResolveBestVoicesEnabled(): boolean | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set autoResolveBestVoicesEnabled(value: boolean | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetAutoResolveBestVoicesEnabled(): void;
    /**
     * @stability stable
     */
    get autoResolveBestVoicesEnabledInput(): boolean | cdktf.IResolvable | undefined;
    private _contactFlowLogsEnabled?;
    /**
     * @stability stable
     */
    get contactFlowLogsEnabled(): boolean | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set contactFlowLogsEnabled(value: boolean | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetContactFlowLogsEnabled(): void;
    /**
     * @stability stable
     */
    get contactFlowLogsEnabledInput(): boolean | cdktf.IResolvable | undefined;
    private _contactLensEnabled?;
    /**
     * @stability stable
     */
    get contactLensEnabled(): boolean | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set contactLensEnabled(value: boolean | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetContactLensEnabled(): void;
    /**
     * @stability stable
     */
    get contactLensEnabledInput(): boolean | cdktf.IResolvable | undefined;
    /**
     * @stability stable
     */
    get createdTime(): string;
    private _directoryId?;
    /**
     * @stability stable
     */
    get directoryId(): string;
    /**
     * @stability stable
     */
    set directoryId(value: string);
    /**
     * @stability stable
     */
    resetDirectoryId(): void;
    /**
     * @stability stable
     */
    get directoryIdInput(): string | undefined;
    private _earlyMediaEnabled?;
    /**
     * @stability stable
     */
    get earlyMediaEnabled(): boolean | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set earlyMediaEnabled(value: boolean | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetEarlyMediaEnabled(): void;
    /**
     * @stability stable
     */
    get earlyMediaEnabledInput(): boolean | cdktf.IResolvable | undefined;
    /**
     * @stability stable
     */
    get id(): string;
    private _identityManagementType?;
    /**
     * @stability stable
     */
    get identityManagementType(): string;
    /**
     * @stability stable
     */
    set identityManagementType(value: string);
    /**
     * @stability stable
     */
    get identityManagementTypeInput(): string | undefined;
    private _inboundCallsEnabled?;
    /**
     * @stability stable
     */
    get inboundCallsEnabled(): boolean | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set inboundCallsEnabled(value: boolean | cdktf.IResolvable);
    /**
     * @stability stable
     */
    get inboundCallsEnabledInput(): boolean | cdktf.IResolvable | undefined;
    private _instanceAlias?;
    /**
     * @stability stable
     */
    get instanceAlias(): string;
    /**
     * @stability stable
     */
    set instanceAlias(value: string);
    /**
     * @stability stable
     */
    resetInstanceAlias(): void;
    /**
     * @stability stable
     */
    get instanceAliasInput(): string | undefined;
    private _outboundCallsEnabled?;
    /**
     * @stability stable
     */
    get outboundCallsEnabled(): boolean | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set outboundCallsEnabled(value: boolean | cdktf.IResolvable);
    /**
     * @stability stable
     */
    get outboundCallsEnabledInput(): boolean | cdktf.IResolvable | undefined;
    /**
     * @stability stable
     */
    get serviceRole(): string;
    /**
     * @stability stable
     */
    get status(): string;
    private _timeouts;
    /**
     * @stability stable
     */
    get timeouts(): ConnectInstanceTimeoutsOutputReference;
    /**
     * @stability stable
     */
    putTimeouts(value: ConnectInstanceTimeouts): void;
    /**
     * @stability stable
     */
    resetTimeouts(): void;
    /**
     * @stability stable
     */
    get timeoutsInput(): ConnectInstanceTimeouts | undefined;
    /**
     * @stability stable
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
