import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
/**
 * AWS DataSync.
 *
 * @stability stable
 */
export interface DatasyncLocationEfsConfig extends cdktf.TerraformMetaArguments {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/datasync_location_efs#efs_file_system_arn DatasyncLocationEfs#efs_file_system_arn}.
     *
     * @stability stable
     */
    readonly efsFileSystemArn: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/datasync_location_efs#subdirectory DatasyncLocationEfs#subdirectory}.
     *
     * @stability stable
     */
    readonly subdirectory?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/datasync_location_efs#tags DatasyncLocationEfs#tags}.
     *
     * @stability stable
     */
    readonly tags?: {
        [key: string]: string;
    };
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/datasync_location_efs#tags_all DatasyncLocationEfs#tags_all}.
     *
     * @stability stable
     */
    readonly tagsAll?: {
        [key: string]: string;
    };
    /**
     * ec2_config block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/datasync_location_efs#ec2_config DatasyncLocationEfs#ec2_config}
     *
     * @stability stable
     */
    readonly ec2Config: DatasyncLocationEfsEc2Config;
}
/**
 * @stability stable
 */
export interface DatasyncLocationEfsEc2Config {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/datasync_location_efs#security_group_arns DatasyncLocationEfs#security_group_arns}.
     *
     * @stability stable
     */
    readonly securityGroupArns: string[];
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/datasync_location_efs#subnet_arn DatasyncLocationEfs#subnet_arn}.
     *
     * @stability stable
     */
    readonly subnetArn: string;
}
export declare function datasyncLocationEfsEc2ConfigToTerraform(struct?: DatasyncLocationEfsEc2ConfigOutputReference | DatasyncLocationEfsEc2Config): any;
/**
 * @stability stable
 */
export declare class DatasyncLocationEfsEc2ConfigOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): DatasyncLocationEfsEc2Config | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: DatasyncLocationEfsEc2Config | undefined);
    private _securityGroupArns?;
    /**
     * @stability stable
     */
    get securityGroupArns(): string[];
    /**
     * @stability stable
     */
    set securityGroupArns(value: string[]);
    /**
     * @stability stable
     */
    get securityGroupArnsInput(): string[] | undefined;
    private _subnetArn?;
    /**
     * @stability stable
     */
    get subnetArn(): string;
    /**
     * @stability stable
     */
    set subnetArn(value: string);
    /**
     * @stability stable
     */
    get subnetArnInput(): string | undefined;
}
/**
 * Represents a {@link https://www.terraform.io/docs/providers/aws/r/datasync_location_efs aws_datasync_location_efs}.
 *
 * @stability stable
 */
export declare class DatasyncLocationEfs extends cdktf.TerraformResource {
    /**
     * @stability stable
     */
    static readonly tfResourceType: string;
    /**
     * Create a new {@link https://www.terraform.io/docs/providers/aws/r/datasync_location_efs aws_datasync_location_efs} Resource.
     *
     * @param scope The scope in which to define this construct.
     * @param id The scoped construct ID.
     * @stability stable
     */
    constructor(scope: Construct, id: string, config: DatasyncLocationEfsConfig);
    /**
     * @stability stable
     */
    get arn(): string;
    private _efsFileSystemArn?;
    /**
     * @stability stable
     */
    get efsFileSystemArn(): string;
    /**
     * @stability stable
     */
    set efsFileSystemArn(value: string);
    /**
     * @stability stable
     */
    get efsFileSystemArnInput(): string | undefined;
    /**
     * @stability stable
     */
    get id(): string;
    private _subdirectory?;
    /**
     * @stability stable
     */
    get subdirectory(): string;
    /**
     * @stability stable
     */
    set subdirectory(value: string);
    /**
     * @stability stable
     */
    resetSubdirectory(): void;
    /**
     * @stability stable
     */
    get subdirectoryInput(): string | undefined;
    private _tags?;
    /**
     * @stability stable
     */
    get tags(): {
        [key: string]: string;
    };
    /**
     * @stability stable
     */
    set tags(value: {
        [key: string]: string;
    });
    /**
     * @stability stable
     */
    resetTags(): void;
    /**
     * @stability stable
     */
    get tagsInput(): {
        [key: string]: string;
    } | undefined;
    private _tagsAll?;
    /**
     * @stability stable
     */
    get tagsAll(): {
        [key: string]: string;
    };
    /**
     * @stability stable
     */
    set tagsAll(value: {
        [key: string]: string;
    });
    /**
     * @stability stable
     */
    resetTagsAll(): void;
    /**
     * @stability stable
     */
    get tagsAllInput(): {
        [key: string]: string;
    } | undefined;
    /**
     * @stability stable
     */
    get uri(): string;
    private _ec2Config;
    /**
     * @stability stable
     */
    get ec2Config(): DatasyncLocationEfsEc2ConfigOutputReference;
    /**
     * @stability stable
     */
    putEc2Config(value: DatasyncLocationEfsEc2Config): void;
    /**
     * @stability stable
     */
    get ec2ConfigInput(): DatasyncLocationEfsEc2Config | undefined;
    /**
     * @stability stable
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
