import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
/**
 * AWS DynamoDB.
 *
 * @stability stable
 */
export interface DataAwsDynamodbTableConfig extends cdktf.TerraformMetaArguments {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/dynamodb_table#name DataAwsDynamodbTable#name}.
     *
     * @stability stable
     */
    readonly name: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/dynamodb_table#tags DataAwsDynamodbTable#tags}.
     *
     * @stability stable
     */
    readonly tags?: {
        [key: string]: string;
    };
    /**
     * server_side_encryption block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/dynamodb_table#server_side_encryption DataAwsDynamodbTable#server_side_encryption}
     *
     * @stability stable
     */
    readonly serverSideEncryption?: DataAwsDynamodbTableServerSideEncryption;
}
/**
 * @stability stable
 */
export declare class DataAwsDynamodbTableAttribute extends cdktf.ComplexComputedList {
    /**
     * @stability stable
     */
    get name(): string;
    /**
     * @stability stable
     */
    get type(): string;
}
/**
 * @stability stable
 */
export declare class DataAwsDynamodbTableGlobalSecondaryIndex extends cdktf.ComplexComputedList {
    /**
     * @stability stable
     */
    get hashKey(): string;
    /**
     * @stability stable
     */
    get name(): string;
    /**
     * @stability stable
     */
    get nonKeyAttributes(): string[];
    /**
     * @stability stable
     */
    get projectionType(): string;
    /**
     * @stability stable
     */
    get rangeKey(): string;
    /**
     * @stability stable
     */
    get readCapacity(): number;
    /**
     * @stability stable
     */
    get writeCapacity(): number;
}
/**
 * @stability stable
 */
export declare class DataAwsDynamodbTableLocalSecondaryIndex extends cdktf.ComplexComputedList {
    /**
     * @stability stable
     */
    get name(): string;
    /**
     * @stability stable
     */
    get nonKeyAttributes(): string[];
    /**
     * @stability stable
     */
    get projectionType(): string;
    /**
     * @stability stable
     */
    get rangeKey(): string;
}
/**
 * @stability stable
 */
export declare class DataAwsDynamodbTablePointInTimeRecovery extends cdktf.ComplexComputedList {
    /**
     * @stability stable
     */
    get enabled(): cdktf.IResolvable;
}
/**
 * @stability stable
 */
export declare class DataAwsDynamodbTableReplica extends cdktf.ComplexComputedList {
    /**
     * @stability stable
     */
    get kmsKeyArn(): string;
    /**
     * @stability stable
     */
    get regionName(): string;
}
/**
 * @stability stable
 */
export declare class DataAwsDynamodbTableTtl extends cdktf.ComplexComputedList {
    /**
     * @stability stable
     */
    get attributeName(): string;
    /**
     * @stability stable
     */
    get enabled(): cdktf.IResolvable;
}
/**
 * @stability stable
 */
export interface DataAwsDynamodbTableServerSideEncryption {
}
export declare function dataAwsDynamodbTableServerSideEncryptionToTerraform(struct?: DataAwsDynamodbTableServerSideEncryptionOutputReference | DataAwsDynamodbTableServerSideEncryption): any;
/**
 * @stability stable
 */
export declare class DataAwsDynamodbTableServerSideEncryptionOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): DataAwsDynamodbTableServerSideEncryption | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: DataAwsDynamodbTableServerSideEncryption | undefined);
    /**
     * @stability stable
     */
    get enabled(): cdktf.IResolvable;
    /**
     * @stability stable
     */
    get kmsKeyArn(): string;
}
/**
 * Represents a {@link https://www.terraform.io/docs/providers/aws/d/dynamodb_table aws_dynamodb_table}.
 *
 * @stability stable
 */
export declare class DataAwsDynamodbTable extends cdktf.TerraformDataSource {
    /**
     * @stability stable
     */
    static readonly tfResourceType: string;
    /**
     * Create a new {@link https://www.terraform.io/docs/providers/aws/d/dynamodb_table aws_dynamodb_table} Data Source.
     *
     * @param scope The scope in which to define this construct.
     * @param id The scoped construct ID.
     * @stability stable
     */
    constructor(scope: Construct, id: string, config: DataAwsDynamodbTableConfig);
    /**
     * @stability stable
     */
    get arn(): string;
    /**
     * @stability stable
     */
    attribute(index: string): DataAwsDynamodbTableAttribute;
    /**
     * @stability stable
     */
    get billingMode(): string;
    /**
     * @stability stable
     */
    globalSecondaryIndex(index: string): DataAwsDynamodbTableGlobalSecondaryIndex;
    /**
     * @stability stable
     */
    get hashKey(): string;
    /**
     * @stability stable
     */
    get id(): string;
    /**
     * @stability stable
     */
    localSecondaryIndex(index: string): DataAwsDynamodbTableLocalSecondaryIndex;
    private _name?;
    /**
     * @stability stable
     */
    get name(): string;
    /**
     * @stability stable
     */
    set name(value: string);
    /**
     * @stability stable
     */
    get nameInput(): string | undefined;
    /**
     * @stability stable
     */
    pointInTimeRecovery(index: string): DataAwsDynamodbTablePointInTimeRecovery;
    /**
     * @stability stable
     */
    get rangeKey(): string;
    /**
     * @stability stable
     */
    get readCapacity(): number;
    /**
     * @stability stable
     */
    replica(index: string): DataAwsDynamodbTableReplica;
    /**
     * @stability stable
     */
    get streamArn(): string;
    /**
     * @stability stable
     */
    get streamEnabled(): cdktf.IResolvable;
    /**
     * @stability stable
     */
    get streamLabel(): string;
    /**
     * @stability stable
     */
    get streamViewType(): string;
    /**
     * @stability stable
     */
    get tableClass(): string;
    private _tags?;
    /**
     * @stability stable
     */
    get tags(): {
        [key: string]: string;
    };
    /**
     * @stability stable
     */
    set tags(value: {
        [key: string]: string;
    });
    /**
     * @stability stable
     */
    resetTags(): void;
    /**
     * @stability stable
     */
    get tagsInput(): {
        [key: string]: string;
    } | undefined;
    /**
     * @stability stable
     */
    ttl(index: string): DataAwsDynamodbTableTtl;
    /**
     * @stability stable
     */
    get writeCapacity(): number;
    private _serverSideEncryption;
    /**
     * @stability stable
     */
    get serverSideEncryption(): DataAwsDynamodbTableServerSideEncryptionOutputReference;
    /**
     * @stability stable
     */
    putServerSideEncryption(value: DataAwsDynamodbTableServerSideEncryption): void;
    /**
     * @stability stable
     */
    resetServerSideEncryption(): void;
    /**
     * @stability stable
     */
    get serverSideEncryptionInput(): DataAwsDynamodbTableServerSideEncryption | undefined;
    /**
     * @stability stable
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
