import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
/**
 * AWS EC2.
 *
 * @stability stable
 */
export interface DataAwsEc2InstanceTypeConfig extends cdktf.TerraformMetaArguments {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/ec2_instance_type#default_cores DataAwsEc2InstanceType#default_cores}.
     *
     * @stability stable
     */
    readonly defaultCores?: number;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/ec2_instance_type#default_threads_per_core DataAwsEc2InstanceType#default_threads_per_core}.
     *
     * @stability stable
     */
    readonly defaultThreadsPerCore?: number;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/ec2_instance_type#hypervisor DataAwsEc2InstanceType#hypervisor}.
     *
     * @stability stable
     */
    readonly hypervisor?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/ec2_instance_type#instance_type DataAwsEc2InstanceType#instance_type}.
     *
     * @stability stable
     */
    readonly instanceType: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/ec2_instance_type#maximum_ipv6_addresses_per_interface DataAwsEc2InstanceType#maximum_ipv6_addresses_per_interface}.
     *
     * @stability stable
     */
    readonly maximumIpv6AddressesPerInterface?: number;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/ec2_instance_type#total_fpga_memory DataAwsEc2InstanceType#total_fpga_memory}.
     *
     * @stability stable
     */
    readonly totalFpgaMemory?: number;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/ec2_instance_type#total_gpu_memory DataAwsEc2InstanceType#total_gpu_memory}.
     *
     * @stability stable
     */
    readonly totalGpuMemory?: number;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/ec2_instance_type#total_instance_storage DataAwsEc2InstanceType#total_instance_storage}.
     *
     * @stability stable
     */
    readonly totalInstanceStorage?: number;
    /**
     * fpgas block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/ec2_instance_type#fpgas DataAwsEc2InstanceType#fpgas}
     *
     * @stability stable
     */
    readonly fpgas?: DataAwsEc2InstanceTypeFpgas[] | cdktf.IResolvable;
    /**
     * gpus block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/ec2_instance_type#gpus DataAwsEc2InstanceType#gpus}
     *
     * @stability stable
     */
    readonly gpus?: DataAwsEc2InstanceTypeGpus[] | cdktf.IResolvable;
    /**
     * inference_accelerators block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/ec2_instance_type#inference_accelerators DataAwsEc2InstanceType#inference_accelerators}
     *
     * @stability stable
     */
    readonly inferenceAccelerators?: DataAwsEc2InstanceTypeInferenceAccelerators[] | cdktf.IResolvable;
    /**
     * instance_disks block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/ec2_instance_type#instance_disks DataAwsEc2InstanceType#instance_disks}
     *
     * @stability stable
     */
    readonly instanceDisks?: DataAwsEc2InstanceTypeInstanceDisks[] | cdktf.IResolvable;
}
/**
 * @stability stable
 */
export interface DataAwsEc2InstanceTypeFpgas {
}
export declare function dataAwsEc2InstanceTypeFpgasToTerraform(struct?: DataAwsEc2InstanceTypeFpgas | cdktf.IResolvable): any;
/**
 * @stability stable
 */
export interface DataAwsEc2InstanceTypeGpus {
}
export declare function dataAwsEc2InstanceTypeGpusToTerraform(struct?: DataAwsEc2InstanceTypeGpus | cdktf.IResolvable): any;
/**
 * @stability stable
 */
export interface DataAwsEc2InstanceTypeInferenceAccelerators {
}
export declare function dataAwsEc2InstanceTypeInferenceAcceleratorsToTerraform(struct?: DataAwsEc2InstanceTypeInferenceAccelerators | cdktf.IResolvable): any;
/**
 * @stability stable
 */
export interface DataAwsEc2InstanceTypeInstanceDisks {
}
export declare function dataAwsEc2InstanceTypeInstanceDisksToTerraform(struct?: DataAwsEc2InstanceTypeInstanceDisks | cdktf.IResolvable): any;
/**
 * Represents a {@link https://www.terraform.io/docs/providers/aws/d/ec2_instance_type aws_ec2_instance_type}.
 *
 * @stability stable
 */
export declare class DataAwsEc2InstanceType extends cdktf.TerraformDataSource {
    /**
     * @stability stable
     */
    static readonly tfResourceType: string;
    /**
     * Create a new {@link https://www.terraform.io/docs/providers/aws/d/ec2_instance_type aws_ec2_instance_type} Data Source.
     *
     * @param scope The scope in which to define this construct.
     * @param id The scoped construct ID.
     * @stability stable
     */
    constructor(scope: Construct, id: string, config: DataAwsEc2InstanceTypeConfig);
    /**
     * @stability stable
     */
    get autoRecoverySupported(): cdktf.IResolvable;
    /**
     * @stability stable
     */
    get bareMetal(): cdktf.IResolvable;
    /**
     * @stability stable
     */
    get burstablePerformanceSupported(): cdktf.IResolvable;
    /**
     * @stability stable
     */
    get currentGeneration(): cdktf.IResolvable;
    /**
     * @stability stable
     */
    get dedicatedHostsSupported(): cdktf.IResolvable;
    private _defaultCores?;
    /**
     * @stability stable
     */
    get defaultCores(): number;
    /**
     * @stability stable
     */
    set defaultCores(value: number);
    /**
     * @stability stable
     */
    resetDefaultCores(): void;
    /**
     * @stability stable
     */
    get defaultCoresInput(): number | undefined;
    private _defaultThreadsPerCore?;
    /**
     * @stability stable
     */
    get defaultThreadsPerCore(): number;
    /**
     * @stability stable
     */
    set defaultThreadsPerCore(value: number);
    /**
     * @stability stable
     */
    resetDefaultThreadsPerCore(): void;
    /**
     * @stability stable
     */
    get defaultThreadsPerCoreInput(): number | undefined;
    /**
     * @stability stable
     */
    get defaultVcpus(): number;
    /**
     * @stability stable
     */
    get ebsEncryptionSupport(): string;
    /**
     * @stability stable
     */
    get ebsNvmeSupport(): string;
    /**
     * @stability stable
     */
    get ebsOptimizedSupport(): string;
    /**
     * @stability stable
     */
    get ebsPerformanceBaselineBandwidth(): number;
    /**
     * @stability stable
     */
    get ebsPerformanceBaselineIops(): number;
    /**
     * @stability stable
     */
    get ebsPerformanceBaselineThroughput(): number;
    /**
     * @stability stable
     */
    get ebsPerformanceMaximumBandwidth(): number;
    /**
     * @stability stable
     */
    get ebsPerformanceMaximumIops(): number;
    /**
     * @stability stable
     */
    get ebsPerformanceMaximumThroughput(): number;
    /**
     * @stability stable
     */
    get efaSupported(): cdktf.IResolvable;
    /**
     * @stability stable
     */
    get enaSupport(): string;
    /**
     * @stability stable
     */
    get encryptionInTransitSupported(): cdktf.IResolvable;
    /**
     * @stability stable
     */
    get freeTierEligible(): cdktf.IResolvable;
    /**
     * @stability stable
     */
    get hibernationSupported(): cdktf.IResolvable;
    private _hypervisor?;
    /**
     * @stability stable
     */
    get hypervisor(): string;
    /**
     * @stability stable
     */
    set hypervisor(value: string);
    /**
     * @stability stable
     */
    resetHypervisor(): void;
    /**
     * @stability stable
     */
    get hypervisorInput(): string | undefined;
    /**
     * @stability stable
     */
    get id(): string;
    /**
     * @stability stable
     */
    get instanceStorageSupported(): cdktf.IResolvable;
    private _instanceType?;
    /**
     * @stability stable
     */
    get instanceType(): string;
    /**
     * @stability stable
     */
    set instanceType(value: string);
    /**
     * @stability stable
     */
    get instanceTypeInput(): string | undefined;
    /**
     * @stability stable
     */
    get ipv6Supported(): cdktf.IResolvable;
    /**
     * @stability stable
     */
    get maximumIpv4AddressesPerInterface(): number;
    private _maximumIpv6AddressesPerInterface?;
    /**
     * @stability stable
     */
    get maximumIpv6AddressesPerInterface(): number;
    /**
     * @stability stable
     */
    set maximumIpv6AddressesPerInterface(value: number);
    /**
     * @stability stable
     */
    resetMaximumIpv6AddressesPerInterface(): void;
    /**
     * @stability stable
     */
    get maximumIpv6AddressesPerInterfaceInput(): number | undefined;
    /**
     * @stability stable
     */
    get maximumNetworkInterfaces(): number;
    /**
     * @stability stable
     */
    get memorySize(): number;
    /**
     * @stability stable
     */
    get networkPerformance(): string;
    /**
     * @stability stable
     */
    get supportedArchitectures(): string[];
    /**
     * @stability stable
     */
    get supportedPlacementStrategies(): string[];
    /**
     * @stability stable
     */
    get supportedRootDeviceTypes(): string[];
    /**
     * @stability stable
     */
    get supportedUsagesClasses(): string[];
    /**
     * @stability stable
     */
    get supportedVirtualizationTypes(): string[];
    /**
     * @stability stable
     */
    get sustainedClockSpeed(): number;
    private _totalFpgaMemory?;
    /**
     * @stability stable
     */
    get totalFpgaMemory(): number;
    /**
     * @stability stable
     */
    set totalFpgaMemory(value: number);
    /**
     * @stability stable
     */
    resetTotalFpgaMemory(): void;
    /**
     * @stability stable
     */
    get totalFpgaMemoryInput(): number | undefined;
    private _totalGpuMemory?;
    /**
     * @stability stable
     */
    get totalGpuMemory(): number;
    /**
     * @stability stable
     */
    set totalGpuMemory(value: number);
    /**
     * @stability stable
     */
    resetTotalGpuMemory(): void;
    /**
     * @stability stable
     */
    get totalGpuMemoryInput(): number | undefined;
    private _totalInstanceStorage?;
    /**
     * @stability stable
     */
    get totalInstanceStorage(): number;
    /**
     * @stability stable
     */
    set totalInstanceStorage(value: number);
    /**
     * @stability stable
     */
    resetTotalInstanceStorage(): void;
    /**
     * @stability stable
     */
    get totalInstanceStorageInput(): number | undefined;
    /**
     * @stability stable
     */
    get validCores(): number[];
    /**
     * @stability stable
     */
    get validThreadsPerCore(): number[];
    private _fpgas?;
    /**
     * @stability stable
     */
    get fpgas(): DataAwsEc2InstanceTypeFpgas[] | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set fpgas(value: DataAwsEc2InstanceTypeFpgas[] | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetFpgas(): void;
    /**
     * @stability stable
     */
    get fpgasInput(): cdktf.IResolvable | DataAwsEc2InstanceTypeFpgas[] | undefined;
    private _gpus?;
    /**
     * @stability stable
     */
    get gpus(): DataAwsEc2InstanceTypeGpus[] | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set gpus(value: DataAwsEc2InstanceTypeGpus[] | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetGpus(): void;
    /**
     * @stability stable
     */
    get gpusInput(): cdktf.IResolvable | DataAwsEc2InstanceTypeGpus[] | undefined;
    private _inferenceAccelerators?;
    /**
     * @stability stable
     */
    get inferenceAccelerators(): DataAwsEc2InstanceTypeInferenceAccelerators[] | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set inferenceAccelerators(value: DataAwsEc2InstanceTypeInferenceAccelerators[] | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetInferenceAccelerators(): void;
    /**
     * @stability stable
     */
    get inferenceAcceleratorsInput(): cdktf.IResolvable | DataAwsEc2InstanceTypeInferenceAccelerators[] | undefined;
    private _instanceDisks?;
    /**
     * @stability stable
     */
    get instanceDisks(): DataAwsEc2InstanceTypeInstanceDisks[] | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set instanceDisks(value: DataAwsEc2InstanceTypeInstanceDisks[] | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetInstanceDisks(): void;
    /**
     * @stability stable
     */
    get instanceDisksInput(): cdktf.IResolvable | DataAwsEc2InstanceTypeInstanceDisks[] | undefined;
    /**
     * @stability stable
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
