import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
/**
 * AWS EC2.
 *
 * @stability stable
 */
export interface Ec2TransitGatewayConfig extends cdktf.TerraformMetaArguments {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ec2_transit_gateway#amazon_side_asn Ec2TransitGateway#amazon_side_asn}.
     *
     * @stability stable
     */
    readonly amazonSideAsn?: number;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ec2_transit_gateway#auto_accept_shared_attachments Ec2TransitGateway#auto_accept_shared_attachments}.
     *
     * @stability stable
     */
    readonly autoAcceptSharedAttachments?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ec2_transit_gateway#default_route_table_association Ec2TransitGateway#default_route_table_association}.
     *
     * @stability stable
     */
    readonly defaultRouteTableAssociation?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ec2_transit_gateway#default_route_table_propagation Ec2TransitGateway#default_route_table_propagation}.
     *
     * @stability stable
     */
    readonly defaultRouteTablePropagation?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ec2_transit_gateway#description Ec2TransitGateway#description}.
     *
     * @stability stable
     */
    readonly description?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ec2_transit_gateway#dns_support Ec2TransitGateway#dns_support}.
     *
     * @stability stable
     */
    readonly dnsSupport?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ec2_transit_gateway#tags Ec2TransitGateway#tags}.
     *
     * @stability stable
     */
    readonly tags?: {
        [key: string]: string;
    };
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ec2_transit_gateway#tags_all Ec2TransitGateway#tags_all}.
     *
     * @stability stable
     */
    readonly tagsAll?: {
        [key: string]: string;
    };
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ec2_transit_gateway#vpn_ecmp_support Ec2TransitGateway#vpn_ecmp_support}.
     *
     * @stability stable
     */
    readonly vpnEcmpSupport?: string;
}
/**
 * Represents a {@link https://www.terraform.io/docs/providers/aws/r/ec2_transit_gateway aws_ec2_transit_gateway}.
 *
 * @stability stable
 */
export declare class Ec2TransitGateway extends cdktf.TerraformResource {
    /**
     * @stability stable
     */
    static readonly tfResourceType: string;
    /**
     * Create a new {@link https://www.terraform.io/docs/providers/aws/r/ec2_transit_gateway aws_ec2_transit_gateway} Resource.
     *
     * @param scope The scope in which to define this construct.
     * @param id The scoped construct ID.
     * @stability stable
     */
    constructor(scope: Construct, id: string, config?: Ec2TransitGatewayConfig);
    private _amazonSideAsn?;
    /**
     * @stability stable
     */
    get amazonSideAsn(): number;
    /**
     * @stability stable
     */
    set amazonSideAsn(value: number);
    /**
     * @stability stable
     */
    resetAmazonSideAsn(): void;
    /**
     * @stability stable
     */
    get amazonSideAsnInput(): number | undefined;
    /**
     * @stability stable
     */
    get arn(): string;
    /**
     * @stability stable
     */
    get associationDefaultRouteTableId(): string;
    private _autoAcceptSharedAttachments?;
    /**
     * @stability stable
     */
    get autoAcceptSharedAttachments(): string;
    /**
     * @stability stable
     */
    set autoAcceptSharedAttachments(value: string);
    /**
     * @stability stable
     */
    resetAutoAcceptSharedAttachments(): void;
    /**
     * @stability stable
     */
    get autoAcceptSharedAttachmentsInput(): string | undefined;
    private _defaultRouteTableAssociation?;
    /**
     * @stability stable
     */
    get defaultRouteTableAssociation(): string;
    /**
     * @stability stable
     */
    set defaultRouteTableAssociation(value: string);
    /**
     * @stability stable
     */
    resetDefaultRouteTableAssociation(): void;
    /**
     * @stability stable
     */
    get defaultRouteTableAssociationInput(): string | undefined;
    private _defaultRouteTablePropagation?;
    /**
     * @stability stable
     */
    get defaultRouteTablePropagation(): string;
    /**
     * @stability stable
     */
    set defaultRouteTablePropagation(value: string);
    /**
     * @stability stable
     */
    resetDefaultRouteTablePropagation(): void;
    /**
     * @stability stable
     */
    get defaultRouteTablePropagationInput(): string | undefined;
    private _description?;
    /**
     * @stability stable
     */
    get description(): string;
    /**
     * @stability stable
     */
    set description(value: string);
    /**
     * @stability stable
     */
    resetDescription(): void;
    /**
     * @stability stable
     */
    get descriptionInput(): string | undefined;
    private _dnsSupport?;
    /**
     * @stability stable
     */
    get dnsSupport(): string;
    /**
     * @stability stable
     */
    set dnsSupport(value: string);
    /**
     * @stability stable
     */
    resetDnsSupport(): void;
    /**
     * @stability stable
     */
    get dnsSupportInput(): string | undefined;
    /**
     * @stability stable
     */
    get id(): string;
    /**
     * @stability stable
     */
    get ownerId(): string;
    /**
     * @stability stable
     */
    get propagationDefaultRouteTableId(): string;
    private _tags?;
    /**
     * @stability stable
     */
    get tags(): {
        [key: string]: string;
    };
    /**
     * @stability stable
     */
    set tags(value: {
        [key: string]: string;
    });
    /**
     * @stability stable
     */
    resetTags(): void;
    /**
     * @stability stable
     */
    get tagsInput(): {
        [key: string]: string;
    } | undefined;
    private _tagsAll?;
    /**
     * @stability stable
     */
    get tagsAll(): {
        [key: string]: string;
    };
    /**
     * @stability stable
     */
    set tagsAll(value: {
        [key: string]: string;
    });
    /**
     * @stability stable
     */
    resetTagsAll(): void;
    /**
     * @stability stable
     */
    get tagsAllInput(): {
        [key: string]: string;
    } | undefined;
    private _vpnEcmpSupport?;
    /**
     * @stability stable
     */
    get vpnEcmpSupport(): string;
    /**
     * @stability stable
     */
    set vpnEcmpSupport(value: string);
    /**
     * @stability stable
     */
    resetVpnEcmpSupport(): void;
    /**
     * @stability stable
     */
    get vpnEcmpSupportInput(): string | undefined;
    /**
     * @stability stable
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
