import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
/**
 * AWS EC2.
 *
 * @stability stable
 */
export interface EipConfig extends cdktf.TerraformMetaArguments {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/eip#address Eip#address}.
     *
     * @stability stable
     */
    readonly address?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/eip#associate_with_private_ip Eip#associate_with_private_ip}.
     *
     * @stability stable
     */
    readonly associateWithPrivateIp?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/eip#customer_owned_ipv4_pool Eip#customer_owned_ipv4_pool}.
     *
     * @stability stable
     */
    readonly customerOwnedIpv4Pool?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/eip#instance Eip#instance}.
     *
     * @stability stable
     */
    readonly instance?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/eip#network_border_group Eip#network_border_group}.
     *
     * @stability stable
     */
    readonly networkBorderGroup?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/eip#network_interface Eip#network_interface}.
     *
     * @stability stable
     */
    readonly networkInterface?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/eip#public_ipv4_pool Eip#public_ipv4_pool}.
     *
     * @stability stable
     */
    readonly publicIpv4Pool?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/eip#tags Eip#tags}.
     *
     * @stability stable
     */
    readonly tags?: {
        [key: string]: string;
    };
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/eip#tags_all Eip#tags_all}.
     *
     * @stability stable
     */
    readonly tagsAll?: {
        [key: string]: string;
    };
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/eip#vpc Eip#vpc}.
     *
     * @stability stable
     */
    readonly vpc?: boolean | cdktf.IResolvable;
    /**
     * timeouts block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/eip#timeouts Eip#timeouts}
     *
     * @stability stable
     */
    readonly timeouts?: EipTimeouts;
}
/**
 * @stability stable
 */
export interface EipTimeouts {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/eip#delete Eip#delete}.
     *
     * @stability stable
     */
    readonly delete?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/eip#read Eip#read}.
     *
     * @stability stable
     */
    readonly read?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/eip#update Eip#update}.
     *
     * @stability stable
     */
    readonly update?: string;
}
export declare function eipTimeoutsToTerraform(struct?: EipTimeoutsOutputReference | EipTimeouts | cdktf.IResolvable): any;
/**
 * @stability stable
 */
export declare class EipTimeoutsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): EipTimeouts | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: EipTimeouts | undefined);
    private _delete?;
    /**
     * @stability stable
     */
    get delete(): string;
    /**
     * @stability stable
     */
    set delete(value: string);
    /**
     * @stability stable
     */
    resetDelete(): void;
    /**
     * @stability stable
     */
    get deleteInput(): string | undefined;
    private _read?;
    /**
     * @stability stable
     */
    get read(): string;
    /**
     * @stability stable
     */
    set read(value: string);
    /**
     * @stability stable
     */
    resetRead(): void;
    /**
     * @stability stable
     */
    get readInput(): string | undefined;
    private _update?;
    /**
     * @stability stable
     */
    get update(): string;
    /**
     * @stability stable
     */
    set update(value: string);
    /**
     * @stability stable
     */
    resetUpdate(): void;
    /**
     * @stability stable
     */
    get updateInput(): string | undefined;
}
/**
 * Represents a {@link https://www.terraform.io/docs/providers/aws/r/eip aws_eip}.
 *
 * @stability stable
 */
export declare class Eip extends cdktf.TerraformResource {
    /**
     * @stability stable
     */
    static readonly tfResourceType: string;
    /**
     * Create a new {@link https://www.terraform.io/docs/providers/aws/r/eip aws_eip} Resource.
     *
     * @param scope The scope in which to define this construct.
     * @param id The scoped construct ID.
     * @stability stable
     */
    constructor(scope: Construct, id: string, config?: EipConfig);
    private _address?;
    /**
     * @stability stable
     */
    get address(): string;
    /**
     * @stability stable
     */
    set address(value: string);
    /**
     * @stability stable
     */
    resetAddress(): void;
    /**
     * @stability stable
     */
    get addressInput(): string | undefined;
    /**
     * @stability stable
     */
    get allocationId(): string;
    private _associateWithPrivateIp?;
    /**
     * @stability stable
     */
    get associateWithPrivateIp(): string;
    /**
     * @stability stable
     */
    set associateWithPrivateIp(value: string);
    /**
     * @stability stable
     */
    resetAssociateWithPrivateIp(): void;
    /**
     * @stability stable
     */
    get associateWithPrivateIpInput(): string | undefined;
    /**
     * @stability stable
     */
    get associationId(): string;
    /**
     * @stability stable
     */
    get carrierIp(): string;
    /**
     * @stability stable
     */
    get customerOwnedIp(): string;
    private _customerOwnedIpv4Pool?;
    /**
     * @stability stable
     */
    get customerOwnedIpv4Pool(): string;
    /**
     * @stability stable
     */
    set customerOwnedIpv4Pool(value: string);
    /**
     * @stability stable
     */
    resetCustomerOwnedIpv4Pool(): void;
    /**
     * @stability stable
     */
    get customerOwnedIpv4PoolInput(): string | undefined;
    /**
     * @stability stable
     */
    get domain(): string;
    /**
     * @stability stable
     */
    get id(): string;
    private _instance?;
    /**
     * @stability stable
     */
    get instance(): string;
    /**
     * @stability stable
     */
    set instance(value: string);
    /**
     * @stability stable
     */
    resetInstance(): void;
    /**
     * @stability stable
     */
    get instanceInput(): string | undefined;
    private _networkBorderGroup?;
    /**
     * @stability stable
     */
    get networkBorderGroup(): string;
    /**
     * @stability stable
     */
    set networkBorderGroup(value: string);
    /**
     * @stability stable
     */
    resetNetworkBorderGroup(): void;
    /**
     * @stability stable
     */
    get networkBorderGroupInput(): string | undefined;
    private _networkInterface?;
    /**
     * @stability stable
     */
    get networkInterface(): string;
    /**
     * @stability stable
     */
    set networkInterface(value: string);
    /**
     * @stability stable
     */
    resetNetworkInterface(): void;
    /**
     * @stability stable
     */
    get networkInterfaceInput(): string | undefined;
    /**
     * @stability stable
     */
    get privateDns(): string;
    /**
     * @stability stable
     */
    get privateIp(): string;
    /**
     * @stability stable
     */
    get publicDns(): string;
    /**
     * @stability stable
     */
    get publicIp(): string;
    private _publicIpv4Pool?;
    /**
     * @stability stable
     */
    get publicIpv4Pool(): string;
    /**
     * @stability stable
     */
    set publicIpv4Pool(value: string);
    /**
     * @stability stable
     */
    resetPublicIpv4Pool(): void;
    /**
     * @stability stable
     */
    get publicIpv4PoolInput(): string | undefined;
    private _tags?;
    /**
     * @stability stable
     */
    get tags(): {
        [key: string]: string;
    };
    /**
     * @stability stable
     */
    set tags(value: {
        [key: string]: string;
    });
    /**
     * @stability stable
     */
    resetTags(): void;
    /**
     * @stability stable
     */
    get tagsInput(): {
        [key: string]: string;
    } | undefined;
    private _tagsAll?;
    /**
     * @stability stable
     */
    get tagsAll(): {
        [key: string]: string;
    };
    /**
     * @stability stable
     */
    set tagsAll(value: {
        [key: string]: string;
    });
    /**
     * @stability stable
     */
    resetTagsAll(): void;
    /**
     * @stability stable
     */
    get tagsAllInput(): {
        [key: string]: string;
    } | undefined;
    private _vpc?;
    /**
     * @stability stable
     */
    get vpc(): boolean | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set vpc(value: boolean | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetVpc(): void;
    /**
     * @stability stable
     */
    get vpcInput(): boolean | cdktf.IResolvable | undefined;
    private _timeouts;
    /**
     * @stability stable
     */
    get timeouts(): EipTimeoutsOutputReference;
    /**
     * @stability stable
     */
    putTimeouts(value: EipTimeouts): void;
    /**
     * @stability stable
     */
    resetTimeouts(): void;
    /**
     * @stability stable
     */
    get timeoutsInput(): EipTimeouts | undefined;
    /**
     * @stability stable
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
