import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
/**
 * AWS EC2 Container Registry.
 *
 * @stability stable
 */
export interface EcrReplicationConfigurationConfig extends cdktf.TerraformMetaArguments {
    /**
     * replication_configuration block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ecr_replication_configuration#replication_configuration EcrReplicationConfiguration#replication_configuration}
     *
     * @stability stable
     */
    readonly replicationConfiguration?: EcrReplicationConfigurationReplicationConfiguration;
}
/**
 * @stability stable
 */
export interface EcrReplicationConfigurationReplicationConfigurationRuleDestination {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ecr_replication_configuration#region EcrReplicationConfiguration#region}.
     *
     * @stability stable
     */
    readonly region: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ecr_replication_configuration#registry_id EcrReplicationConfiguration#registry_id}.
     *
     * @stability stable
     */
    readonly registryId: string;
}
export declare function ecrReplicationConfigurationReplicationConfigurationRuleDestinationToTerraform(struct?: EcrReplicationConfigurationReplicationConfigurationRuleDestination | cdktf.IResolvable): any;
/**
 * @stability stable
 */
export interface EcrReplicationConfigurationReplicationConfigurationRuleRepositoryFilter {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ecr_replication_configuration#filter EcrReplicationConfiguration#filter}.
     *
     * @stability stable
     */
    readonly filter: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ecr_replication_configuration#filter_type EcrReplicationConfiguration#filter_type}.
     *
     * @stability stable
     */
    readonly filterType: string;
}
export declare function ecrReplicationConfigurationReplicationConfigurationRuleRepositoryFilterToTerraform(struct?: EcrReplicationConfigurationReplicationConfigurationRuleRepositoryFilter | cdktf.IResolvable): any;
/**
 * @stability stable
 */
export interface EcrReplicationConfigurationReplicationConfigurationRule {
    /**
     * destination block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ecr_replication_configuration#destination EcrReplicationConfiguration#destination}
     *
     * @stability stable
     */
    readonly destination: EcrReplicationConfigurationReplicationConfigurationRuleDestination[] | cdktf.IResolvable;
    /**
     * repository_filter block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ecr_replication_configuration#repository_filter EcrReplicationConfiguration#repository_filter}
     *
     * @stability stable
     */
    readonly repositoryFilter?: EcrReplicationConfigurationReplicationConfigurationRuleRepositoryFilter[] | cdktf.IResolvable;
}
export declare function ecrReplicationConfigurationReplicationConfigurationRuleToTerraform(struct?: EcrReplicationConfigurationReplicationConfigurationRule | cdktf.IResolvable): any;
/**
 * @stability stable
 */
export interface EcrReplicationConfigurationReplicationConfiguration {
    /**
     * rule block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ecr_replication_configuration#rule EcrReplicationConfiguration#rule}
     *
     * @stability stable
     */
    readonly rule: EcrReplicationConfigurationReplicationConfigurationRule[] | cdktf.IResolvable;
}
export declare function ecrReplicationConfigurationReplicationConfigurationToTerraform(struct?: EcrReplicationConfigurationReplicationConfigurationOutputReference | EcrReplicationConfigurationReplicationConfiguration): any;
/**
 * @stability stable
 */
export declare class EcrReplicationConfigurationReplicationConfigurationOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): EcrReplicationConfigurationReplicationConfiguration | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: EcrReplicationConfigurationReplicationConfiguration | undefined);
    private _rule?;
    /**
     * @stability stable
     */
    get rule(): EcrReplicationConfigurationReplicationConfigurationRule[] | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set rule(value: EcrReplicationConfigurationReplicationConfigurationRule[] | cdktf.IResolvable);
    /**
     * @stability stable
     */
    get ruleInput(): cdktf.IResolvable | EcrReplicationConfigurationReplicationConfigurationRule[] | undefined;
}
/**
 * Represents a {@link https://www.terraform.io/docs/providers/aws/r/ecr_replication_configuration aws_ecr_replication_configuration}.
 *
 * @stability stable
 */
export declare class EcrReplicationConfiguration extends cdktf.TerraformResource {
    /**
     * @stability stable
     */
    static readonly tfResourceType: string;
    /**
     * Create a new {@link https://www.terraform.io/docs/providers/aws/r/ecr_replication_configuration aws_ecr_replication_configuration} Resource.
     *
     * @param scope The scope in which to define this construct.
     * @param id The scoped construct ID.
     * @stability stable
     */
    constructor(scope: Construct, id: string, config?: EcrReplicationConfigurationConfig);
    /**
     * @stability stable
     */
    get id(): string;
    /**
     * @stability stable
     */
    get registryId(): string;
    private _replicationConfiguration;
    /**
     * @stability stable
     */
    get replicationConfiguration(): EcrReplicationConfigurationReplicationConfigurationOutputReference;
    /**
     * @stability stable
     */
    putReplicationConfiguration(value: EcrReplicationConfigurationReplicationConfiguration): void;
    /**
     * @stability stable
     */
    resetReplicationConfiguration(): void;
    /**
     * @stability stable
     */
    get replicationConfigurationInput(): EcrReplicationConfigurationReplicationConfiguration | undefined;
    /**
     * @stability stable
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
