import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
/**
 * AWS EC2 Container Service.
 *
 * @stability stable
 */
export interface EcsServiceConfig extends cdktf.TerraformMetaArguments {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ecs_service#cluster EcsService#cluster}.
     *
     * @stability stable
     */
    readonly cluster?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ecs_service#deployment_maximum_percent EcsService#deployment_maximum_percent}.
     *
     * @stability stable
     */
    readonly deploymentMaximumPercent?: number;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ecs_service#deployment_minimum_healthy_percent EcsService#deployment_minimum_healthy_percent}.
     *
     * @stability stable
     */
    readonly deploymentMinimumHealthyPercent?: number;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ecs_service#desired_count EcsService#desired_count}.
     *
     * @stability stable
     */
    readonly desiredCount?: number;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ecs_service#enable_ecs_managed_tags EcsService#enable_ecs_managed_tags}.
     *
     * @stability stable
     */
    readonly enableEcsManagedTags?: boolean | cdktf.IResolvable;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ecs_service#enable_execute_command EcsService#enable_execute_command}.
     *
     * @stability stable
     */
    readonly enableExecuteCommand?: boolean | cdktf.IResolvable;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ecs_service#force_new_deployment EcsService#force_new_deployment}.
     *
     * @stability stable
     */
    readonly forceNewDeployment?: boolean | cdktf.IResolvable;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ecs_service#health_check_grace_period_seconds EcsService#health_check_grace_period_seconds}.
     *
     * @stability stable
     */
    readonly healthCheckGracePeriodSeconds?: number;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ecs_service#iam_role EcsService#iam_role}.
     *
     * @stability stable
     */
    readonly iamRole?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ecs_service#launch_type EcsService#launch_type}.
     *
     * @stability stable
     */
    readonly launchType?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ecs_service#name EcsService#name}.
     *
     * @stability stable
     */
    readonly name: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ecs_service#platform_version EcsService#platform_version}.
     *
     * @stability stable
     */
    readonly platformVersion?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ecs_service#propagate_tags EcsService#propagate_tags}.
     *
     * @stability stable
     */
    readonly propagateTags?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ecs_service#scheduling_strategy EcsService#scheduling_strategy}.
     *
     * @stability stable
     */
    readonly schedulingStrategy?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ecs_service#tags EcsService#tags}.
     *
     * @stability stable
     */
    readonly tags?: {
        [key: string]: string;
    };
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ecs_service#tags_all EcsService#tags_all}.
     *
     * @stability stable
     */
    readonly tagsAll?: {
        [key: string]: string;
    };
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ecs_service#task_definition EcsService#task_definition}.
     *
     * @stability stable
     */
    readonly taskDefinition?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ecs_service#wait_for_steady_state EcsService#wait_for_steady_state}.
     *
     * @stability stable
     */
    readonly waitForSteadyState?: boolean | cdktf.IResolvable;
    /**
     * capacity_provider_strategy block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ecs_service#capacity_provider_strategy EcsService#capacity_provider_strategy}
     *
     * @stability stable
     */
    readonly capacityProviderStrategy?: EcsServiceCapacityProviderStrategy[] | cdktf.IResolvable;
    /**
     * deployment_circuit_breaker block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ecs_service#deployment_circuit_breaker EcsService#deployment_circuit_breaker}
     *
     * @stability stable
     */
    readonly deploymentCircuitBreaker?: EcsServiceDeploymentCircuitBreaker;
    /**
     * deployment_controller block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ecs_service#deployment_controller EcsService#deployment_controller}
     *
     * @stability stable
     */
    readonly deploymentController?: EcsServiceDeploymentController;
    /**
     * load_balancer block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ecs_service#load_balancer EcsService#load_balancer}
     *
     * @stability stable
     */
    readonly loadBalancer?: EcsServiceLoadBalancer[] | cdktf.IResolvable;
    /**
     * network_configuration block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ecs_service#network_configuration EcsService#network_configuration}
     *
     * @stability stable
     */
    readonly networkConfiguration?: EcsServiceNetworkConfiguration;
    /**
     * ordered_placement_strategy block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ecs_service#ordered_placement_strategy EcsService#ordered_placement_strategy}
     *
     * @stability stable
     */
    readonly orderedPlacementStrategy?: EcsServiceOrderedPlacementStrategy[] | cdktf.IResolvable;
    /**
     * placement_constraints block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ecs_service#placement_constraints EcsService#placement_constraints}
     *
     * @stability stable
     */
    readonly placementConstraints?: EcsServicePlacementConstraints[] | cdktf.IResolvable;
    /**
     * service_registries block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ecs_service#service_registries EcsService#service_registries}
     *
     * @stability stable
     */
    readonly serviceRegistries?: EcsServiceServiceRegistries;
    /**
     * timeouts block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ecs_service#timeouts EcsService#timeouts}
     *
     * @stability stable
     */
    readonly timeouts?: EcsServiceTimeouts;
}
/**
 * @stability stable
 */
export interface EcsServiceCapacityProviderStrategy {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ecs_service#base EcsService#base}.
     *
     * @stability stable
     */
    readonly base?: number;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ecs_service#capacity_provider EcsService#capacity_provider}.
     *
     * @stability stable
     */
    readonly capacityProvider: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ecs_service#weight EcsService#weight}.
     *
     * @stability stable
     */
    readonly weight?: number;
}
export declare function ecsServiceCapacityProviderStrategyToTerraform(struct?: EcsServiceCapacityProviderStrategy | cdktf.IResolvable): any;
/**
 * @stability stable
 */
export interface EcsServiceDeploymentCircuitBreaker {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ecs_service#enable EcsService#enable}.
     *
     * @stability stable
     */
    readonly enable: boolean | cdktf.IResolvable;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ecs_service#rollback EcsService#rollback}.
     *
     * @stability stable
     */
    readonly rollback: boolean | cdktf.IResolvable;
}
export declare function ecsServiceDeploymentCircuitBreakerToTerraform(struct?: EcsServiceDeploymentCircuitBreakerOutputReference | EcsServiceDeploymentCircuitBreaker): any;
/**
 * @stability stable
 */
export declare class EcsServiceDeploymentCircuitBreakerOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): EcsServiceDeploymentCircuitBreaker | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: EcsServiceDeploymentCircuitBreaker | undefined);
    private _enable?;
    /**
     * @stability stable
     */
    get enable(): boolean | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set enable(value: boolean | cdktf.IResolvable);
    /**
     * @stability stable
     */
    get enableInput(): boolean | cdktf.IResolvable | undefined;
    private _rollback?;
    /**
     * @stability stable
     */
    get rollback(): boolean | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set rollback(value: boolean | cdktf.IResolvable);
    /**
     * @stability stable
     */
    get rollbackInput(): boolean | cdktf.IResolvable | undefined;
}
/**
 * @stability stable
 */
export interface EcsServiceDeploymentController {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ecs_service#type EcsService#type}.
     *
     * @stability stable
     */
    readonly type?: string;
}
export declare function ecsServiceDeploymentControllerToTerraform(struct?: EcsServiceDeploymentControllerOutputReference | EcsServiceDeploymentController): any;
/**
 * @stability stable
 */
export declare class EcsServiceDeploymentControllerOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): EcsServiceDeploymentController | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: EcsServiceDeploymentController | undefined);
    private _type?;
    /**
     * @stability stable
     */
    get type(): string;
    /**
     * @stability stable
     */
    set type(value: string);
    /**
     * @stability stable
     */
    resetType(): void;
    /**
     * @stability stable
     */
    get typeInput(): string | undefined;
}
/**
 * @stability stable
 */
export interface EcsServiceLoadBalancer {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ecs_service#container_name EcsService#container_name}.
     *
     * @stability stable
     */
    readonly containerName: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ecs_service#container_port EcsService#container_port}.
     *
     * @stability stable
     */
    readonly containerPort: number;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ecs_service#elb_name EcsService#elb_name}.
     *
     * @stability stable
     */
    readonly elbName?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ecs_service#target_group_arn EcsService#target_group_arn}.
     *
     * @stability stable
     */
    readonly targetGroupArn?: string;
}
export declare function ecsServiceLoadBalancerToTerraform(struct?: EcsServiceLoadBalancer | cdktf.IResolvable): any;
/**
 * @stability stable
 */
export interface EcsServiceNetworkConfiguration {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ecs_service#assign_public_ip EcsService#assign_public_ip}.
     *
     * @stability stable
     */
    readonly assignPublicIp?: boolean | cdktf.IResolvable;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ecs_service#security_groups EcsService#security_groups}.
     *
     * @stability stable
     */
    readonly securityGroups?: string[];
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ecs_service#subnets EcsService#subnets}.
     *
     * @stability stable
     */
    readonly subnets: string[];
}
export declare function ecsServiceNetworkConfigurationToTerraform(struct?: EcsServiceNetworkConfigurationOutputReference | EcsServiceNetworkConfiguration): any;
/**
 * @stability stable
 */
export declare class EcsServiceNetworkConfigurationOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): EcsServiceNetworkConfiguration | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: EcsServiceNetworkConfiguration | undefined);
    private _assignPublicIp?;
    /**
     * @stability stable
     */
    get assignPublicIp(): boolean | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set assignPublicIp(value: boolean | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetAssignPublicIp(): void;
    /**
     * @stability stable
     */
    get assignPublicIpInput(): boolean | cdktf.IResolvable | undefined;
    private _securityGroups?;
    /**
     * @stability stable
     */
    get securityGroups(): string[];
    /**
     * @stability stable
     */
    set securityGroups(value: string[]);
    /**
     * @stability stable
     */
    resetSecurityGroups(): void;
    /**
     * @stability stable
     */
    get securityGroupsInput(): string[] | undefined;
    private _subnets?;
    /**
     * @stability stable
     */
    get subnets(): string[];
    /**
     * @stability stable
     */
    set subnets(value: string[]);
    /**
     * @stability stable
     */
    get subnetsInput(): string[] | undefined;
}
/**
 * @stability stable
 */
export interface EcsServiceOrderedPlacementStrategy {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ecs_service#field EcsService#field}.
     *
     * @stability stable
     */
    readonly field?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ecs_service#type EcsService#type}.
     *
     * @stability stable
     */
    readonly type: string;
}
export declare function ecsServiceOrderedPlacementStrategyToTerraform(struct?: EcsServiceOrderedPlacementStrategy | cdktf.IResolvable): any;
/**
 * @stability stable
 */
export interface EcsServicePlacementConstraints {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ecs_service#expression EcsService#expression}.
     *
     * @stability stable
     */
    readonly expression?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ecs_service#type EcsService#type}.
     *
     * @stability stable
     */
    readonly type: string;
}
export declare function ecsServicePlacementConstraintsToTerraform(struct?: EcsServicePlacementConstraints | cdktf.IResolvable): any;
/**
 * @stability stable
 */
export interface EcsServiceServiceRegistries {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ecs_service#container_name EcsService#container_name}.
     *
     * @stability stable
     */
    readonly containerName?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ecs_service#container_port EcsService#container_port}.
     *
     * @stability stable
     */
    readonly containerPort?: number;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ecs_service#port EcsService#port}.
     *
     * @stability stable
     */
    readonly port?: number;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ecs_service#registry_arn EcsService#registry_arn}.
     *
     * @stability stable
     */
    readonly registryArn: string;
}
export declare function ecsServiceServiceRegistriesToTerraform(struct?: EcsServiceServiceRegistriesOutputReference | EcsServiceServiceRegistries): any;
/**
 * @stability stable
 */
export declare class EcsServiceServiceRegistriesOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): EcsServiceServiceRegistries | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: EcsServiceServiceRegistries | undefined);
    private _containerName?;
    /**
     * @stability stable
     */
    get containerName(): string;
    /**
     * @stability stable
     */
    set containerName(value: string);
    /**
     * @stability stable
     */
    resetContainerName(): void;
    /**
     * @stability stable
     */
    get containerNameInput(): string | undefined;
    private _containerPort?;
    /**
     * @stability stable
     */
    get containerPort(): number;
    /**
     * @stability stable
     */
    set containerPort(value: number);
    /**
     * @stability stable
     */
    resetContainerPort(): void;
    /**
     * @stability stable
     */
    get containerPortInput(): number | undefined;
    private _port?;
    /**
     * @stability stable
     */
    get port(): number;
    /**
     * @stability stable
     */
    set port(value: number);
    /**
     * @stability stable
     */
    resetPort(): void;
    /**
     * @stability stable
     */
    get portInput(): number | undefined;
    private _registryArn?;
    /**
     * @stability stable
     */
    get registryArn(): string;
    /**
     * @stability stable
     */
    set registryArn(value: string);
    /**
     * @stability stable
     */
    get registryArnInput(): string | undefined;
}
/**
 * @stability stable
 */
export interface EcsServiceTimeouts {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ecs_service#delete EcsService#delete}.
     *
     * @stability stable
     */
    readonly delete?: string;
}
export declare function ecsServiceTimeoutsToTerraform(struct?: EcsServiceTimeoutsOutputReference | EcsServiceTimeouts | cdktf.IResolvable): any;
/**
 * @stability stable
 */
export declare class EcsServiceTimeoutsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): EcsServiceTimeouts | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: EcsServiceTimeouts | undefined);
    private _delete?;
    /**
     * @stability stable
     */
    get delete(): string;
    /**
     * @stability stable
     */
    set delete(value: string);
    /**
     * @stability stable
     */
    resetDelete(): void;
    /**
     * @stability stable
     */
    get deleteInput(): string | undefined;
}
/**
 * Represents a {@link https://www.terraform.io/docs/providers/aws/r/ecs_service aws_ecs_service}.
 *
 * @stability stable
 */
export declare class EcsService extends cdktf.TerraformResource {
    /**
     * @stability stable
     */
    static readonly tfResourceType: string;
    /**
     * Create a new {@link https://www.terraform.io/docs/providers/aws/r/ecs_service aws_ecs_service} Resource.
     *
     * @param scope The scope in which to define this construct.
     * @param id The scoped construct ID.
     * @stability stable
     */
    constructor(scope: Construct, id: string, config: EcsServiceConfig);
    private _cluster?;
    /**
     * @stability stable
     */
    get cluster(): string;
    /**
     * @stability stable
     */
    set cluster(value: string);
    /**
     * @stability stable
     */
    resetCluster(): void;
    /**
     * @stability stable
     */
    get clusterInput(): string | undefined;
    private _deploymentMaximumPercent?;
    /**
     * @stability stable
     */
    get deploymentMaximumPercent(): number;
    /**
     * @stability stable
     */
    set deploymentMaximumPercent(value: number);
    /**
     * @stability stable
     */
    resetDeploymentMaximumPercent(): void;
    /**
     * @stability stable
     */
    get deploymentMaximumPercentInput(): number | undefined;
    private _deploymentMinimumHealthyPercent?;
    /**
     * @stability stable
     */
    get deploymentMinimumHealthyPercent(): number;
    /**
     * @stability stable
     */
    set deploymentMinimumHealthyPercent(value: number);
    /**
     * @stability stable
     */
    resetDeploymentMinimumHealthyPercent(): void;
    /**
     * @stability stable
     */
    get deploymentMinimumHealthyPercentInput(): number | undefined;
    private _desiredCount?;
    /**
     * @stability stable
     */
    get desiredCount(): number;
    /**
     * @stability stable
     */
    set desiredCount(value: number);
    /**
     * @stability stable
     */
    resetDesiredCount(): void;
    /**
     * @stability stable
     */
    get desiredCountInput(): number | undefined;
    private _enableEcsManagedTags?;
    /**
     * @stability stable
     */
    get enableEcsManagedTags(): boolean | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set enableEcsManagedTags(value: boolean | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetEnableEcsManagedTags(): void;
    /**
     * @stability stable
     */
    get enableEcsManagedTagsInput(): boolean | cdktf.IResolvable | undefined;
    private _enableExecuteCommand?;
    /**
     * @stability stable
     */
    get enableExecuteCommand(): boolean | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set enableExecuteCommand(value: boolean | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetEnableExecuteCommand(): void;
    /**
     * @stability stable
     */
    get enableExecuteCommandInput(): boolean | cdktf.IResolvable | undefined;
    private _forceNewDeployment?;
    /**
     * @stability stable
     */
    get forceNewDeployment(): boolean | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set forceNewDeployment(value: boolean | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetForceNewDeployment(): void;
    /**
     * @stability stable
     */
    get forceNewDeploymentInput(): boolean | cdktf.IResolvable | undefined;
    private _healthCheckGracePeriodSeconds?;
    /**
     * @stability stable
     */
    get healthCheckGracePeriodSeconds(): number;
    /**
     * @stability stable
     */
    set healthCheckGracePeriodSeconds(value: number);
    /**
     * @stability stable
     */
    resetHealthCheckGracePeriodSeconds(): void;
    /**
     * @stability stable
     */
    get healthCheckGracePeriodSecondsInput(): number | undefined;
    private _iamRole?;
    /**
     * @stability stable
     */
    get iamRole(): string;
    /**
     * @stability stable
     */
    set iamRole(value: string);
    /**
     * @stability stable
     */
    resetIamRole(): void;
    /**
     * @stability stable
     */
    get iamRoleInput(): string | undefined;
    /**
     * @stability stable
     */
    get id(): string;
    private _launchType?;
    /**
     * @stability stable
     */
    get launchType(): string;
    /**
     * @stability stable
     */
    set launchType(value: string);
    /**
     * @stability stable
     */
    resetLaunchType(): void;
    /**
     * @stability stable
     */
    get launchTypeInput(): string | undefined;
    private _name?;
    /**
     * @stability stable
     */
    get name(): string;
    /**
     * @stability stable
     */
    set name(value: string);
    /**
     * @stability stable
     */
    get nameInput(): string | undefined;
    private _platformVersion?;
    /**
     * @stability stable
     */
    get platformVersion(): string;
    /**
     * @stability stable
     */
    set platformVersion(value: string);
    /**
     * @stability stable
     */
    resetPlatformVersion(): void;
    /**
     * @stability stable
     */
    get platformVersionInput(): string | undefined;
    private _propagateTags?;
    /**
     * @stability stable
     */
    get propagateTags(): string;
    /**
     * @stability stable
     */
    set propagateTags(value: string);
    /**
     * @stability stable
     */
    resetPropagateTags(): void;
    /**
     * @stability stable
     */
    get propagateTagsInput(): string | undefined;
    private _schedulingStrategy?;
    /**
     * @stability stable
     */
    get schedulingStrategy(): string;
    /**
     * @stability stable
     */
    set schedulingStrategy(value: string);
    /**
     * @stability stable
     */
    resetSchedulingStrategy(): void;
    /**
     * @stability stable
     */
    get schedulingStrategyInput(): string | undefined;
    private _tags?;
    /**
     * @stability stable
     */
    get tags(): {
        [key: string]: string;
    };
    /**
     * @stability stable
     */
    set tags(value: {
        [key: string]: string;
    });
    /**
     * @stability stable
     */
    resetTags(): void;
    /**
     * @stability stable
     */
    get tagsInput(): {
        [key: string]: string;
    } | undefined;
    private _tagsAll?;
    /**
     * @stability stable
     */
    get tagsAll(): {
        [key: string]: string;
    };
    /**
     * @stability stable
     */
    set tagsAll(value: {
        [key: string]: string;
    });
    /**
     * @stability stable
     */
    resetTagsAll(): void;
    /**
     * @stability stable
     */
    get tagsAllInput(): {
        [key: string]: string;
    } | undefined;
    private _taskDefinition?;
    /**
     * @stability stable
     */
    get taskDefinition(): string;
    /**
     * @stability stable
     */
    set taskDefinition(value: string);
    /**
     * @stability stable
     */
    resetTaskDefinition(): void;
    /**
     * @stability stable
     */
    get taskDefinitionInput(): string | undefined;
    private _waitForSteadyState?;
    /**
     * @stability stable
     */
    get waitForSteadyState(): boolean | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set waitForSteadyState(value: boolean | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetWaitForSteadyState(): void;
    /**
     * @stability stable
     */
    get waitForSteadyStateInput(): boolean | cdktf.IResolvable | undefined;
    private _capacityProviderStrategy?;
    /**
     * @stability stable
     */
    get capacityProviderStrategy(): EcsServiceCapacityProviderStrategy[] | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set capacityProviderStrategy(value: EcsServiceCapacityProviderStrategy[] | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetCapacityProviderStrategy(): void;
    /**
     * @stability stable
     */
    get capacityProviderStrategyInput(): cdktf.IResolvable | EcsServiceCapacityProviderStrategy[] | undefined;
    private _deploymentCircuitBreaker;
    /**
     * @stability stable
     */
    get deploymentCircuitBreaker(): EcsServiceDeploymentCircuitBreakerOutputReference;
    /**
     * @stability stable
     */
    putDeploymentCircuitBreaker(value: EcsServiceDeploymentCircuitBreaker): void;
    /**
     * @stability stable
     */
    resetDeploymentCircuitBreaker(): void;
    /**
     * @stability stable
     */
    get deploymentCircuitBreakerInput(): EcsServiceDeploymentCircuitBreaker | undefined;
    private _deploymentController;
    /**
     * @stability stable
     */
    get deploymentController(): EcsServiceDeploymentControllerOutputReference;
    /**
     * @stability stable
     */
    putDeploymentController(value: EcsServiceDeploymentController): void;
    /**
     * @stability stable
     */
    resetDeploymentController(): void;
    /**
     * @stability stable
     */
    get deploymentControllerInput(): EcsServiceDeploymentController | undefined;
    private _loadBalancer?;
    /**
     * @stability stable
     */
    get loadBalancer(): EcsServiceLoadBalancer[] | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set loadBalancer(value: EcsServiceLoadBalancer[] | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetLoadBalancer(): void;
    /**
     * @stability stable
     */
    get loadBalancerInput(): cdktf.IResolvable | EcsServiceLoadBalancer[] | undefined;
    private _networkConfiguration;
    /**
     * @stability stable
     */
    get networkConfiguration(): EcsServiceNetworkConfigurationOutputReference;
    /**
     * @stability stable
     */
    putNetworkConfiguration(value: EcsServiceNetworkConfiguration): void;
    /**
     * @stability stable
     */
    resetNetworkConfiguration(): void;
    /**
     * @stability stable
     */
    get networkConfigurationInput(): EcsServiceNetworkConfiguration | undefined;
    private _orderedPlacementStrategy?;
    /**
     * @stability stable
     */
    get orderedPlacementStrategy(): EcsServiceOrderedPlacementStrategy[] | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set orderedPlacementStrategy(value: EcsServiceOrderedPlacementStrategy[] | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetOrderedPlacementStrategy(): void;
    /**
     * @stability stable
     */
    get orderedPlacementStrategyInput(): cdktf.IResolvable | EcsServiceOrderedPlacementStrategy[] | undefined;
    private _placementConstraints?;
    /**
     * @stability stable
     */
    get placementConstraints(): EcsServicePlacementConstraints[] | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set placementConstraints(value: EcsServicePlacementConstraints[] | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetPlacementConstraints(): void;
    /**
     * @stability stable
     */
    get placementConstraintsInput(): cdktf.IResolvable | EcsServicePlacementConstraints[] | undefined;
    private _serviceRegistries;
    /**
     * @stability stable
     */
    get serviceRegistries(): EcsServiceServiceRegistriesOutputReference;
    /**
     * @stability stable
     */
    putServiceRegistries(value: EcsServiceServiceRegistries): void;
    /**
     * @stability stable
     */
    resetServiceRegistries(): void;
    /**
     * @stability stable
     */
    get serviceRegistriesInput(): EcsServiceServiceRegistries | undefined;
    private _timeouts;
    /**
     * @stability stable
     */
    get timeouts(): EcsServiceTimeoutsOutputReference;
    /**
     * @stability stable
     */
    putTimeouts(value: EcsServiceTimeouts): void;
    /**
     * @stability stable
     */
    resetTimeouts(): void;
    /**
     * @stability stable
     */
    get timeoutsInput(): EcsServiceTimeouts | undefined;
    /**
     * @stability stable
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
