import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
/**
 * AWS EC2 Container Service.
 *
 * @stability stable
 */
export interface EcsTaskSetConfig extends cdktf.TerraformMetaArguments {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ecs_task_set#cluster EcsTaskSet#cluster}.
     *
     * @stability stable
     */
    readonly cluster: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ecs_task_set#external_id EcsTaskSet#external_id}.
     *
     * @stability stable
     */
    readonly externalId?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ecs_task_set#force_delete EcsTaskSet#force_delete}.
     *
     * @stability stable
     */
    readonly forceDelete?: boolean | cdktf.IResolvable;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ecs_task_set#launch_type EcsTaskSet#launch_type}.
     *
     * @stability stable
     */
    readonly launchType?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ecs_task_set#platform_version EcsTaskSet#platform_version}.
     *
     * @stability stable
     */
    readonly platformVersion?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ecs_task_set#service EcsTaskSet#service}.
     *
     * @stability stable
     */
    readonly service: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ecs_task_set#tags EcsTaskSet#tags}.
     *
     * @stability stable
     */
    readonly tags?: {
        [key: string]: string;
    };
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ecs_task_set#tags_all EcsTaskSet#tags_all}.
     *
     * @stability stable
     */
    readonly tagsAll?: {
        [key: string]: string;
    };
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ecs_task_set#task_definition EcsTaskSet#task_definition}.
     *
     * @stability stable
     */
    readonly taskDefinition: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ecs_task_set#wait_until_stable EcsTaskSet#wait_until_stable}.
     *
     * @stability stable
     */
    readonly waitUntilStable?: boolean | cdktf.IResolvable;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ecs_task_set#wait_until_stable_timeout EcsTaskSet#wait_until_stable_timeout}.
     *
     * @stability stable
     */
    readonly waitUntilStableTimeout?: string;
    /**
     * capacity_provider_strategy block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ecs_task_set#capacity_provider_strategy EcsTaskSet#capacity_provider_strategy}
     *
     * @stability stable
     */
    readonly capacityProviderStrategy?: EcsTaskSetCapacityProviderStrategy[] | cdktf.IResolvable;
    /**
     * load_balancer block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ecs_task_set#load_balancer EcsTaskSet#load_balancer}
     *
     * @stability stable
     */
    readonly loadBalancer?: EcsTaskSetLoadBalancer[] | cdktf.IResolvable;
    /**
     * network_configuration block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ecs_task_set#network_configuration EcsTaskSet#network_configuration}
     *
     * @stability stable
     */
    readonly networkConfiguration?: EcsTaskSetNetworkConfiguration;
    /**
     * scale block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ecs_task_set#scale EcsTaskSet#scale}
     *
     * @stability stable
     */
    readonly scale?: EcsTaskSetScale;
    /**
     * service_registries block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ecs_task_set#service_registries EcsTaskSet#service_registries}
     *
     * @stability stable
     */
    readonly serviceRegistries?: EcsTaskSetServiceRegistries;
}
/**
 * @stability stable
 */
export interface EcsTaskSetCapacityProviderStrategy {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ecs_task_set#base EcsTaskSet#base}.
     *
     * @stability stable
     */
    readonly base?: number;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ecs_task_set#capacity_provider EcsTaskSet#capacity_provider}.
     *
     * @stability stable
     */
    readonly capacityProvider: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ecs_task_set#weight EcsTaskSet#weight}.
     *
     * @stability stable
     */
    readonly weight: number;
}
export declare function ecsTaskSetCapacityProviderStrategyToTerraform(struct?: EcsTaskSetCapacityProviderStrategy | cdktf.IResolvable): any;
/**
 * @stability stable
 */
export interface EcsTaskSetLoadBalancer {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ecs_task_set#container_name EcsTaskSet#container_name}.
     *
     * @stability stable
     */
    readonly containerName: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ecs_task_set#container_port EcsTaskSet#container_port}.
     *
     * @stability stable
     */
    readonly containerPort?: number;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ecs_task_set#load_balancer_name EcsTaskSet#load_balancer_name}.
     *
     * @stability stable
     */
    readonly loadBalancerName?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ecs_task_set#target_group_arn EcsTaskSet#target_group_arn}.
     *
     * @stability stable
     */
    readonly targetGroupArn?: string;
}
export declare function ecsTaskSetLoadBalancerToTerraform(struct?: EcsTaskSetLoadBalancer | cdktf.IResolvable): any;
/**
 * @stability stable
 */
export interface EcsTaskSetNetworkConfiguration {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ecs_task_set#assign_public_ip EcsTaskSet#assign_public_ip}.
     *
     * @stability stable
     */
    readonly assignPublicIp?: boolean | cdktf.IResolvable;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ecs_task_set#security_groups EcsTaskSet#security_groups}.
     *
     * @stability stable
     */
    readonly securityGroups?: string[];
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ecs_task_set#subnets EcsTaskSet#subnets}.
     *
     * @stability stable
     */
    readonly subnets: string[];
}
export declare function ecsTaskSetNetworkConfigurationToTerraform(struct?: EcsTaskSetNetworkConfigurationOutputReference | EcsTaskSetNetworkConfiguration): any;
/**
 * @stability stable
 */
export declare class EcsTaskSetNetworkConfigurationOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): EcsTaskSetNetworkConfiguration | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: EcsTaskSetNetworkConfiguration | undefined);
    private _assignPublicIp?;
    /**
     * @stability stable
     */
    get assignPublicIp(): boolean | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set assignPublicIp(value: boolean | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetAssignPublicIp(): void;
    /**
     * @stability stable
     */
    get assignPublicIpInput(): boolean | cdktf.IResolvable | undefined;
    private _securityGroups?;
    /**
     * @stability stable
     */
    get securityGroups(): string[];
    /**
     * @stability stable
     */
    set securityGroups(value: string[]);
    /**
     * @stability stable
     */
    resetSecurityGroups(): void;
    /**
     * @stability stable
     */
    get securityGroupsInput(): string[] | undefined;
    private _subnets?;
    /**
     * @stability stable
     */
    get subnets(): string[];
    /**
     * @stability stable
     */
    set subnets(value: string[]);
    /**
     * @stability stable
     */
    get subnetsInput(): string[] | undefined;
}
/**
 * @stability stable
 */
export interface EcsTaskSetScale {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ecs_task_set#unit EcsTaskSet#unit}.
     *
     * @stability stable
     */
    readonly unit?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ecs_task_set#value EcsTaskSet#value}.
     *
     * @stability stable
     */
    readonly value?: number;
}
export declare function ecsTaskSetScaleToTerraform(struct?: EcsTaskSetScaleOutputReference | EcsTaskSetScale): any;
/**
 * @stability stable
 */
export declare class EcsTaskSetScaleOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): EcsTaskSetScale | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: EcsTaskSetScale | undefined);
    private _unit?;
    /**
     * @stability stable
     */
    get unit(): string;
    /**
     * @stability stable
     */
    set unit(value: string);
    /**
     * @stability stable
     */
    resetUnit(): void;
    /**
     * @stability stable
     */
    get unitInput(): string | undefined;
    private _value?;
    /**
     * @stability stable
     */
    get value(): number;
    /**
     * @stability stable
     */
    set value(value: number);
    /**
     * @stability stable
     */
    resetValue(): void;
    /**
     * @stability stable
     */
    get valueInput(): number | undefined;
}
/**
 * @stability stable
 */
export interface EcsTaskSetServiceRegistries {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ecs_task_set#container_name EcsTaskSet#container_name}.
     *
     * @stability stable
     */
    readonly containerName?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ecs_task_set#container_port EcsTaskSet#container_port}.
     *
     * @stability stable
     */
    readonly containerPort?: number;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ecs_task_set#port EcsTaskSet#port}.
     *
     * @stability stable
     */
    readonly port?: number;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ecs_task_set#registry_arn EcsTaskSet#registry_arn}.
     *
     * @stability stable
     */
    readonly registryArn: string;
}
export declare function ecsTaskSetServiceRegistriesToTerraform(struct?: EcsTaskSetServiceRegistriesOutputReference | EcsTaskSetServiceRegistries): any;
/**
 * @stability stable
 */
export declare class EcsTaskSetServiceRegistriesOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): EcsTaskSetServiceRegistries | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: EcsTaskSetServiceRegistries | undefined);
    private _containerName?;
    /**
     * @stability stable
     */
    get containerName(): string;
    /**
     * @stability stable
     */
    set containerName(value: string);
    /**
     * @stability stable
     */
    resetContainerName(): void;
    /**
     * @stability stable
     */
    get containerNameInput(): string | undefined;
    private _containerPort?;
    /**
     * @stability stable
     */
    get containerPort(): number;
    /**
     * @stability stable
     */
    set containerPort(value: number);
    /**
     * @stability stable
     */
    resetContainerPort(): void;
    /**
     * @stability stable
     */
    get containerPortInput(): number | undefined;
    private _port?;
    /**
     * @stability stable
     */
    get port(): number;
    /**
     * @stability stable
     */
    set port(value: number);
    /**
     * @stability stable
     */
    resetPort(): void;
    /**
     * @stability stable
     */
    get portInput(): number | undefined;
    private _registryArn?;
    /**
     * @stability stable
     */
    get registryArn(): string;
    /**
     * @stability stable
     */
    set registryArn(value: string);
    /**
     * @stability stable
     */
    get registryArnInput(): string | undefined;
}
/**
 * Represents a {@link https://www.terraform.io/docs/providers/aws/r/ecs_task_set aws_ecs_task_set}.
 *
 * @stability stable
 */
export declare class EcsTaskSet extends cdktf.TerraformResource {
    /**
     * @stability stable
     */
    static readonly tfResourceType: string;
    /**
     * Create a new {@link https://www.terraform.io/docs/providers/aws/r/ecs_task_set aws_ecs_task_set} Resource.
     *
     * @param scope The scope in which to define this construct.
     * @param id The scoped construct ID.
     * @stability stable
     */
    constructor(scope: Construct, id: string, config: EcsTaskSetConfig);
    /**
     * @stability stable
     */
    get arn(): string;
    private _cluster?;
    /**
     * @stability stable
     */
    get cluster(): string;
    /**
     * @stability stable
     */
    set cluster(value: string);
    /**
     * @stability stable
     */
    get clusterInput(): string | undefined;
    private _externalId?;
    /**
     * @stability stable
     */
    get externalId(): string;
    /**
     * @stability stable
     */
    set externalId(value: string);
    /**
     * @stability stable
     */
    resetExternalId(): void;
    /**
     * @stability stable
     */
    get externalIdInput(): string | undefined;
    private _forceDelete?;
    /**
     * @stability stable
     */
    get forceDelete(): boolean | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set forceDelete(value: boolean | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetForceDelete(): void;
    /**
     * @stability stable
     */
    get forceDeleteInput(): boolean | cdktf.IResolvable | undefined;
    /**
     * @stability stable
     */
    get id(): string;
    private _launchType?;
    /**
     * @stability stable
     */
    get launchType(): string;
    /**
     * @stability stable
     */
    set launchType(value: string);
    /**
     * @stability stable
     */
    resetLaunchType(): void;
    /**
     * @stability stable
     */
    get launchTypeInput(): string | undefined;
    private _platformVersion?;
    /**
     * @stability stable
     */
    get platformVersion(): string;
    /**
     * @stability stable
     */
    set platformVersion(value: string);
    /**
     * @stability stable
     */
    resetPlatformVersion(): void;
    /**
     * @stability stable
     */
    get platformVersionInput(): string | undefined;
    private _service?;
    /**
     * @stability stable
     */
    get service(): string;
    /**
     * @stability stable
     */
    set service(value: string);
    /**
     * @stability stable
     */
    get serviceInput(): string | undefined;
    /**
     * @stability stable
     */
    get stabilityStatus(): string;
    /**
     * @stability stable
     */
    get status(): string;
    private _tags?;
    /**
     * @stability stable
     */
    get tags(): {
        [key: string]: string;
    };
    /**
     * @stability stable
     */
    set tags(value: {
        [key: string]: string;
    });
    /**
     * @stability stable
     */
    resetTags(): void;
    /**
     * @stability stable
     */
    get tagsInput(): {
        [key: string]: string;
    } | undefined;
    private _tagsAll?;
    /**
     * @stability stable
     */
    get tagsAll(): {
        [key: string]: string;
    };
    /**
     * @stability stable
     */
    set tagsAll(value: {
        [key: string]: string;
    });
    /**
     * @stability stable
     */
    resetTagsAll(): void;
    /**
     * @stability stable
     */
    get tagsAllInput(): {
        [key: string]: string;
    } | undefined;
    private _taskDefinition?;
    /**
     * @stability stable
     */
    get taskDefinition(): string;
    /**
     * @stability stable
     */
    set taskDefinition(value: string);
    /**
     * @stability stable
     */
    get taskDefinitionInput(): string | undefined;
    /**
     * @stability stable
     */
    get taskSetId(): string;
    private _waitUntilStable?;
    /**
     * @stability stable
     */
    get waitUntilStable(): boolean | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set waitUntilStable(value: boolean | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetWaitUntilStable(): void;
    /**
     * @stability stable
     */
    get waitUntilStableInput(): boolean | cdktf.IResolvable | undefined;
    private _waitUntilStableTimeout?;
    /**
     * @stability stable
     */
    get waitUntilStableTimeout(): string;
    /**
     * @stability stable
     */
    set waitUntilStableTimeout(value: string);
    /**
     * @stability stable
     */
    resetWaitUntilStableTimeout(): void;
    /**
     * @stability stable
     */
    get waitUntilStableTimeoutInput(): string | undefined;
    private _capacityProviderStrategy?;
    /**
     * @stability stable
     */
    get capacityProviderStrategy(): EcsTaskSetCapacityProviderStrategy[] | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set capacityProviderStrategy(value: EcsTaskSetCapacityProviderStrategy[] | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetCapacityProviderStrategy(): void;
    /**
     * @stability stable
     */
    get capacityProviderStrategyInput(): cdktf.IResolvable | EcsTaskSetCapacityProviderStrategy[] | undefined;
    private _loadBalancer?;
    /**
     * @stability stable
     */
    get loadBalancer(): EcsTaskSetLoadBalancer[] | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set loadBalancer(value: EcsTaskSetLoadBalancer[] | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetLoadBalancer(): void;
    /**
     * @stability stable
     */
    get loadBalancerInput(): cdktf.IResolvable | EcsTaskSetLoadBalancer[] | undefined;
    private _networkConfiguration;
    /**
     * @stability stable
     */
    get networkConfiguration(): EcsTaskSetNetworkConfigurationOutputReference;
    /**
     * @stability stable
     */
    putNetworkConfiguration(value: EcsTaskSetNetworkConfiguration): void;
    /**
     * @stability stable
     */
    resetNetworkConfiguration(): void;
    /**
     * @stability stable
     */
    get networkConfigurationInput(): EcsTaskSetNetworkConfiguration | undefined;
    private _scale;
    /**
     * @stability stable
     */
    get scale(): EcsTaskSetScaleOutputReference;
    /**
     * @stability stable
     */
    putScale(value: EcsTaskSetScale): void;
    /**
     * @stability stable
     */
    resetScale(): void;
    /**
     * @stability stable
     */
    get scaleInput(): EcsTaskSetScale | undefined;
    private _serviceRegistries;
    /**
     * @stability stable
     */
    get serviceRegistries(): EcsTaskSetServiceRegistriesOutputReference;
    /**
     * @stability stable
     */
    putServiceRegistries(value: EcsTaskSetServiceRegistries): void;
    /**
     * @stability stable
     */
    resetServiceRegistries(): void;
    /**
     * @stability stable
     */
    get serviceRegistriesInput(): EcsTaskSetServiceRegistries | undefined;
    /**
     * @stability stable
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
