import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
/**
 * AWS ElasticSearch Service.
 *
 * @stability stable
 */
export interface ElasticsearchDomainConfig extends cdktf.TerraformMetaArguments {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/elasticsearch_domain#access_policies ElasticsearchDomain#access_policies}.
     *
     * @stability stable
     */
    readonly accessPolicies?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/elasticsearch_domain#advanced_options ElasticsearchDomain#advanced_options}.
     *
     * @stability stable
     */
    readonly advancedOptions?: {
        [key: string]: string;
    };
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/elasticsearch_domain#domain_name ElasticsearchDomain#domain_name}.
     *
     * @stability stable
     */
    readonly domainName: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/elasticsearch_domain#elasticsearch_version ElasticsearchDomain#elasticsearch_version}.
     *
     * @stability stable
     */
    readonly elasticsearchVersion?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/elasticsearch_domain#tags ElasticsearchDomain#tags}.
     *
     * @stability stable
     */
    readonly tags?: {
        [key: string]: string;
    };
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/elasticsearch_domain#tags_all ElasticsearchDomain#tags_all}.
     *
     * @stability stable
     */
    readonly tagsAll?: {
        [key: string]: string;
    };
    /**
     * advanced_security_options block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/elasticsearch_domain#advanced_security_options ElasticsearchDomain#advanced_security_options}
     *
     * @stability stable
     */
    readonly advancedSecurityOptions?: ElasticsearchDomainAdvancedSecurityOptions;
    /**
     * auto_tune_options block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/elasticsearch_domain#auto_tune_options ElasticsearchDomain#auto_tune_options}
     *
     * @stability stable
     */
    readonly autoTuneOptions?: ElasticsearchDomainAutoTuneOptions;
    /**
     * cluster_config block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/elasticsearch_domain#cluster_config ElasticsearchDomain#cluster_config}
     *
     * @stability stable
     */
    readonly clusterConfig?: ElasticsearchDomainClusterConfig;
    /**
     * cognito_options block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/elasticsearch_domain#cognito_options ElasticsearchDomain#cognito_options}
     *
     * @stability stable
     */
    readonly cognitoOptions?: ElasticsearchDomainCognitoOptions;
    /**
     * domain_endpoint_options block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/elasticsearch_domain#domain_endpoint_options ElasticsearchDomain#domain_endpoint_options}
     *
     * @stability stable
     */
    readonly domainEndpointOptions?: ElasticsearchDomainDomainEndpointOptions;
    /**
     * ebs_options block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/elasticsearch_domain#ebs_options ElasticsearchDomain#ebs_options}
     *
     * @stability stable
     */
    readonly ebsOptions?: ElasticsearchDomainEbsOptions;
    /**
     * encrypt_at_rest block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/elasticsearch_domain#encrypt_at_rest ElasticsearchDomain#encrypt_at_rest}
     *
     * @stability stable
     */
    readonly encryptAtRest?: ElasticsearchDomainEncryptAtRest;
    /**
     * log_publishing_options block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/elasticsearch_domain#log_publishing_options ElasticsearchDomain#log_publishing_options}
     *
     * @stability stable
     */
    readonly logPublishingOptions?: ElasticsearchDomainLogPublishingOptions[] | cdktf.IResolvable;
    /**
     * node_to_node_encryption block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/elasticsearch_domain#node_to_node_encryption ElasticsearchDomain#node_to_node_encryption}
     *
     * @stability stable
     */
    readonly nodeToNodeEncryption?: ElasticsearchDomainNodeToNodeEncryption;
    /**
     * snapshot_options block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/elasticsearch_domain#snapshot_options ElasticsearchDomain#snapshot_options}
     *
     * @stability stable
     */
    readonly snapshotOptions?: ElasticsearchDomainSnapshotOptions;
    /**
     * timeouts block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/elasticsearch_domain#timeouts ElasticsearchDomain#timeouts}
     *
     * @stability stable
     */
    readonly timeouts?: ElasticsearchDomainTimeouts;
    /**
     * vpc_options block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/elasticsearch_domain#vpc_options ElasticsearchDomain#vpc_options}
     *
     * @stability stable
     */
    readonly vpcOptions?: ElasticsearchDomainVpcOptions;
}
/**
 * @stability stable
 */
export interface ElasticsearchDomainAdvancedSecurityOptionsMasterUserOptions {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/elasticsearch_domain#master_user_arn ElasticsearchDomain#master_user_arn}.
     *
     * @stability stable
     */
    readonly masterUserArn?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/elasticsearch_domain#master_user_name ElasticsearchDomain#master_user_name}.
     *
     * @stability stable
     */
    readonly masterUserName?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/elasticsearch_domain#master_user_password ElasticsearchDomain#master_user_password}.
     *
     * @stability stable
     */
    readonly masterUserPassword?: string;
}
export declare function elasticsearchDomainAdvancedSecurityOptionsMasterUserOptionsToTerraform(struct?: ElasticsearchDomainAdvancedSecurityOptionsMasterUserOptionsOutputReference | ElasticsearchDomainAdvancedSecurityOptionsMasterUserOptions): any;
/**
 * @stability stable
 */
export declare class ElasticsearchDomainAdvancedSecurityOptionsMasterUserOptionsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): ElasticsearchDomainAdvancedSecurityOptionsMasterUserOptions | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: ElasticsearchDomainAdvancedSecurityOptionsMasterUserOptions | undefined);
    private _masterUserArn?;
    /**
     * @stability stable
     */
    get masterUserArn(): string;
    /**
     * @stability stable
     */
    set masterUserArn(value: string);
    /**
     * @stability stable
     */
    resetMasterUserArn(): void;
    /**
     * @stability stable
     */
    get masterUserArnInput(): string | undefined;
    private _masterUserName?;
    /**
     * @stability stable
     */
    get masterUserName(): string;
    /**
     * @stability stable
     */
    set masterUserName(value: string);
    /**
     * @stability stable
     */
    resetMasterUserName(): void;
    /**
     * @stability stable
     */
    get masterUserNameInput(): string | undefined;
    private _masterUserPassword?;
    /**
     * @stability stable
     */
    get masterUserPassword(): string;
    /**
     * @stability stable
     */
    set masterUserPassword(value: string);
    /**
     * @stability stable
     */
    resetMasterUserPassword(): void;
    /**
     * @stability stable
     */
    get masterUserPasswordInput(): string | undefined;
}
/**
 * @stability stable
 */
export interface ElasticsearchDomainAdvancedSecurityOptions {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/elasticsearch_domain#enabled ElasticsearchDomain#enabled}.
     *
     * @stability stable
     */
    readonly enabled: boolean | cdktf.IResolvable;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/elasticsearch_domain#internal_user_database_enabled ElasticsearchDomain#internal_user_database_enabled}.
     *
     * @stability stable
     */
    readonly internalUserDatabaseEnabled?: boolean | cdktf.IResolvable;
    /**
     * master_user_options block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/elasticsearch_domain#master_user_options ElasticsearchDomain#master_user_options}
     *
     * @stability stable
     */
    readonly masterUserOptions?: ElasticsearchDomainAdvancedSecurityOptionsMasterUserOptions;
}
export declare function elasticsearchDomainAdvancedSecurityOptionsToTerraform(struct?: ElasticsearchDomainAdvancedSecurityOptionsOutputReference | ElasticsearchDomainAdvancedSecurityOptions): any;
/**
 * @stability stable
 */
export declare class ElasticsearchDomainAdvancedSecurityOptionsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): ElasticsearchDomainAdvancedSecurityOptions | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: ElasticsearchDomainAdvancedSecurityOptions | undefined);
    private _enabled?;
    /**
     * @stability stable
     */
    get enabled(): boolean | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set enabled(value: boolean | cdktf.IResolvable);
    /**
     * @stability stable
     */
    get enabledInput(): boolean | cdktf.IResolvable | undefined;
    private _internalUserDatabaseEnabled?;
    /**
     * @stability stable
     */
    get internalUserDatabaseEnabled(): boolean | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set internalUserDatabaseEnabled(value: boolean | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetInternalUserDatabaseEnabled(): void;
    /**
     * @stability stable
     */
    get internalUserDatabaseEnabledInput(): boolean | cdktf.IResolvable | undefined;
    private _masterUserOptions;
    /**
     * @stability stable
     */
    get masterUserOptions(): ElasticsearchDomainAdvancedSecurityOptionsMasterUserOptionsOutputReference;
    /**
     * @stability stable
     */
    putMasterUserOptions(value: ElasticsearchDomainAdvancedSecurityOptionsMasterUserOptions): void;
    /**
     * @stability stable
     */
    resetMasterUserOptions(): void;
    /**
     * @stability stable
     */
    get masterUserOptionsInput(): ElasticsearchDomainAdvancedSecurityOptionsMasterUserOptions | undefined;
}
/**
 * @stability stable
 */
export interface ElasticsearchDomainAutoTuneOptionsMaintenanceScheduleDuration {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/elasticsearch_domain#unit ElasticsearchDomain#unit}.
     *
     * @stability stable
     */
    readonly unit: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/elasticsearch_domain#value ElasticsearchDomain#value}.
     *
     * @stability stable
     */
    readonly value: number;
}
export declare function elasticsearchDomainAutoTuneOptionsMaintenanceScheduleDurationToTerraform(struct?: ElasticsearchDomainAutoTuneOptionsMaintenanceScheduleDurationOutputReference | ElasticsearchDomainAutoTuneOptionsMaintenanceScheduleDuration): any;
/**
 * @stability stable
 */
export declare class ElasticsearchDomainAutoTuneOptionsMaintenanceScheduleDurationOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): ElasticsearchDomainAutoTuneOptionsMaintenanceScheduleDuration | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: ElasticsearchDomainAutoTuneOptionsMaintenanceScheduleDuration | undefined);
    private _unit?;
    /**
     * @stability stable
     */
    get unit(): string;
    /**
     * @stability stable
     */
    set unit(value: string);
    /**
     * @stability stable
     */
    get unitInput(): string | undefined;
    private _value?;
    /**
     * @stability stable
     */
    get value(): number;
    /**
     * @stability stable
     */
    set value(value: number);
    /**
     * @stability stable
     */
    get valueInput(): number | undefined;
}
/**
 * @stability stable
 */
export interface ElasticsearchDomainAutoTuneOptionsMaintenanceSchedule {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/elasticsearch_domain#cron_expression_for_recurrence ElasticsearchDomain#cron_expression_for_recurrence}.
     *
     * @stability stable
     */
    readonly cronExpressionForRecurrence: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/elasticsearch_domain#start_at ElasticsearchDomain#start_at}.
     *
     * @stability stable
     */
    readonly startAt: string;
    /**
     * duration block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/elasticsearch_domain#duration ElasticsearchDomain#duration}
     *
     * @stability stable
     */
    readonly duration: ElasticsearchDomainAutoTuneOptionsMaintenanceScheduleDuration;
}
export declare function elasticsearchDomainAutoTuneOptionsMaintenanceScheduleToTerraform(struct?: ElasticsearchDomainAutoTuneOptionsMaintenanceSchedule | cdktf.IResolvable): any;
/**
 * @stability stable
 */
export interface ElasticsearchDomainAutoTuneOptions {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/elasticsearch_domain#desired_state ElasticsearchDomain#desired_state}.
     *
     * @stability stable
     */
    readonly desiredState: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/elasticsearch_domain#rollback_on_disable ElasticsearchDomain#rollback_on_disable}.
     *
     * @stability stable
     */
    readonly rollbackOnDisable?: string;
    /**
     * maintenance_schedule block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/elasticsearch_domain#maintenance_schedule ElasticsearchDomain#maintenance_schedule}
     *
     * @stability stable
     */
    readonly maintenanceSchedule?: ElasticsearchDomainAutoTuneOptionsMaintenanceSchedule[] | cdktf.IResolvable;
}
export declare function elasticsearchDomainAutoTuneOptionsToTerraform(struct?: ElasticsearchDomainAutoTuneOptionsOutputReference | ElasticsearchDomainAutoTuneOptions): any;
/**
 * @stability stable
 */
export declare class ElasticsearchDomainAutoTuneOptionsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): ElasticsearchDomainAutoTuneOptions | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: ElasticsearchDomainAutoTuneOptions | undefined);
    private _desiredState?;
    /**
     * @stability stable
     */
    get desiredState(): string;
    /**
     * @stability stable
     */
    set desiredState(value: string);
    /**
     * @stability stable
     */
    get desiredStateInput(): string | undefined;
    private _rollbackOnDisable?;
    /**
     * @stability stable
     */
    get rollbackOnDisable(): string;
    /**
     * @stability stable
     */
    set rollbackOnDisable(value: string);
    /**
     * @stability stable
     */
    resetRollbackOnDisable(): void;
    /**
     * @stability stable
     */
    get rollbackOnDisableInput(): string | undefined;
    private _maintenanceSchedule?;
    /**
     * @stability stable
     */
    get maintenanceSchedule(): ElasticsearchDomainAutoTuneOptionsMaintenanceSchedule[] | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set maintenanceSchedule(value: ElasticsearchDomainAutoTuneOptionsMaintenanceSchedule[] | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetMaintenanceSchedule(): void;
    /**
     * @stability stable
     */
    get maintenanceScheduleInput(): cdktf.IResolvable | ElasticsearchDomainAutoTuneOptionsMaintenanceSchedule[] | undefined;
}
/**
 * @stability stable
 */
export interface ElasticsearchDomainClusterConfigZoneAwarenessConfig {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/elasticsearch_domain#availability_zone_count ElasticsearchDomain#availability_zone_count}.
     *
     * @stability stable
     */
    readonly availabilityZoneCount?: number;
}
export declare function elasticsearchDomainClusterConfigZoneAwarenessConfigToTerraform(struct?: ElasticsearchDomainClusterConfigZoneAwarenessConfigOutputReference | ElasticsearchDomainClusterConfigZoneAwarenessConfig): any;
/**
 * @stability stable
 */
export declare class ElasticsearchDomainClusterConfigZoneAwarenessConfigOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): ElasticsearchDomainClusterConfigZoneAwarenessConfig | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: ElasticsearchDomainClusterConfigZoneAwarenessConfig | undefined);
    private _availabilityZoneCount?;
    /**
     * @stability stable
     */
    get availabilityZoneCount(): number;
    /**
     * @stability stable
     */
    set availabilityZoneCount(value: number);
    /**
     * @stability stable
     */
    resetAvailabilityZoneCount(): void;
    /**
     * @stability stable
     */
    get availabilityZoneCountInput(): number | undefined;
}
/**
 * @stability stable
 */
export interface ElasticsearchDomainClusterConfig {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/elasticsearch_domain#dedicated_master_count ElasticsearchDomain#dedicated_master_count}.
     *
     * @stability stable
     */
    readonly dedicatedMasterCount?: number;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/elasticsearch_domain#dedicated_master_enabled ElasticsearchDomain#dedicated_master_enabled}.
     *
     * @stability stable
     */
    readonly dedicatedMasterEnabled?: boolean | cdktf.IResolvable;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/elasticsearch_domain#dedicated_master_type ElasticsearchDomain#dedicated_master_type}.
     *
     * @stability stable
     */
    readonly dedicatedMasterType?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/elasticsearch_domain#instance_count ElasticsearchDomain#instance_count}.
     *
     * @stability stable
     */
    readonly instanceCount?: number;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/elasticsearch_domain#instance_type ElasticsearchDomain#instance_type}.
     *
     * @stability stable
     */
    readonly instanceType?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/elasticsearch_domain#warm_count ElasticsearchDomain#warm_count}.
     *
     * @stability stable
     */
    readonly warmCount?: number;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/elasticsearch_domain#warm_enabled ElasticsearchDomain#warm_enabled}.
     *
     * @stability stable
     */
    readonly warmEnabled?: boolean | cdktf.IResolvable;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/elasticsearch_domain#warm_type ElasticsearchDomain#warm_type}.
     *
     * @stability stable
     */
    readonly warmType?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/elasticsearch_domain#zone_awareness_enabled ElasticsearchDomain#zone_awareness_enabled}.
     *
     * @stability stable
     */
    readonly zoneAwarenessEnabled?: boolean | cdktf.IResolvable;
    /**
     * zone_awareness_config block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/elasticsearch_domain#zone_awareness_config ElasticsearchDomain#zone_awareness_config}
     *
     * @stability stable
     */
    readonly zoneAwarenessConfig?: ElasticsearchDomainClusterConfigZoneAwarenessConfig;
}
export declare function elasticsearchDomainClusterConfigToTerraform(struct?: ElasticsearchDomainClusterConfigOutputReference | ElasticsearchDomainClusterConfig): any;
/**
 * @stability stable
 */
export declare class ElasticsearchDomainClusterConfigOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): ElasticsearchDomainClusterConfig | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: ElasticsearchDomainClusterConfig | undefined);
    private _dedicatedMasterCount?;
    /**
     * @stability stable
     */
    get dedicatedMasterCount(): number;
    /**
     * @stability stable
     */
    set dedicatedMasterCount(value: number);
    /**
     * @stability stable
     */
    resetDedicatedMasterCount(): void;
    /**
     * @stability stable
     */
    get dedicatedMasterCountInput(): number | undefined;
    private _dedicatedMasterEnabled?;
    /**
     * @stability stable
     */
    get dedicatedMasterEnabled(): boolean | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set dedicatedMasterEnabled(value: boolean | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetDedicatedMasterEnabled(): void;
    /**
     * @stability stable
     */
    get dedicatedMasterEnabledInput(): boolean | cdktf.IResolvable | undefined;
    private _dedicatedMasterType?;
    /**
     * @stability stable
     */
    get dedicatedMasterType(): string;
    /**
     * @stability stable
     */
    set dedicatedMasterType(value: string);
    /**
     * @stability stable
     */
    resetDedicatedMasterType(): void;
    /**
     * @stability stable
     */
    get dedicatedMasterTypeInput(): string | undefined;
    private _instanceCount?;
    /**
     * @stability stable
     */
    get instanceCount(): number;
    /**
     * @stability stable
     */
    set instanceCount(value: number);
    /**
     * @stability stable
     */
    resetInstanceCount(): void;
    /**
     * @stability stable
     */
    get instanceCountInput(): number | undefined;
    private _instanceType?;
    /**
     * @stability stable
     */
    get instanceType(): string;
    /**
     * @stability stable
     */
    set instanceType(value: string);
    /**
     * @stability stable
     */
    resetInstanceType(): void;
    /**
     * @stability stable
     */
    get instanceTypeInput(): string | undefined;
    private _warmCount?;
    /**
     * @stability stable
     */
    get warmCount(): number;
    /**
     * @stability stable
     */
    set warmCount(value: number);
    /**
     * @stability stable
     */
    resetWarmCount(): void;
    /**
     * @stability stable
     */
    get warmCountInput(): number | undefined;
    private _warmEnabled?;
    /**
     * @stability stable
     */
    get warmEnabled(): boolean | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set warmEnabled(value: boolean | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetWarmEnabled(): void;
    /**
     * @stability stable
     */
    get warmEnabledInput(): boolean | cdktf.IResolvable | undefined;
    private _warmType?;
    /**
     * @stability stable
     */
    get warmType(): string;
    /**
     * @stability stable
     */
    set warmType(value: string);
    /**
     * @stability stable
     */
    resetWarmType(): void;
    /**
     * @stability stable
     */
    get warmTypeInput(): string | undefined;
    private _zoneAwarenessEnabled?;
    /**
     * @stability stable
     */
    get zoneAwarenessEnabled(): boolean | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set zoneAwarenessEnabled(value: boolean | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetZoneAwarenessEnabled(): void;
    /**
     * @stability stable
     */
    get zoneAwarenessEnabledInput(): boolean | cdktf.IResolvable | undefined;
    private _zoneAwarenessConfig;
    /**
     * @stability stable
     */
    get zoneAwarenessConfig(): ElasticsearchDomainClusterConfigZoneAwarenessConfigOutputReference;
    /**
     * @stability stable
     */
    putZoneAwarenessConfig(value: ElasticsearchDomainClusterConfigZoneAwarenessConfig): void;
    /**
     * @stability stable
     */
    resetZoneAwarenessConfig(): void;
    /**
     * @stability stable
     */
    get zoneAwarenessConfigInput(): ElasticsearchDomainClusterConfigZoneAwarenessConfig | undefined;
}
/**
 * @stability stable
 */
export interface ElasticsearchDomainCognitoOptions {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/elasticsearch_domain#enabled ElasticsearchDomain#enabled}.
     *
     * @stability stable
     */
    readonly enabled?: boolean | cdktf.IResolvable;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/elasticsearch_domain#identity_pool_id ElasticsearchDomain#identity_pool_id}.
     *
     * @stability stable
     */
    readonly identityPoolId: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/elasticsearch_domain#role_arn ElasticsearchDomain#role_arn}.
     *
     * @stability stable
     */
    readonly roleArn: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/elasticsearch_domain#user_pool_id ElasticsearchDomain#user_pool_id}.
     *
     * @stability stable
     */
    readonly userPoolId: string;
}
export declare function elasticsearchDomainCognitoOptionsToTerraform(struct?: ElasticsearchDomainCognitoOptionsOutputReference | ElasticsearchDomainCognitoOptions): any;
/**
 * @stability stable
 */
export declare class ElasticsearchDomainCognitoOptionsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): ElasticsearchDomainCognitoOptions | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: ElasticsearchDomainCognitoOptions | undefined);
    private _enabled?;
    /**
     * @stability stable
     */
    get enabled(): boolean | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set enabled(value: boolean | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetEnabled(): void;
    /**
     * @stability stable
     */
    get enabledInput(): boolean | cdktf.IResolvable | undefined;
    private _identityPoolId?;
    /**
     * @stability stable
     */
    get identityPoolId(): string;
    /**
     * @stability stable
     */
    set identityPoolId(value: string);
    /**
     * @stability stable
     */
    get identityPoolIdInput(): string | undefined;
    private _roleArn?;
    /**
     * @stability stable
     */
    get roleArn(): string;
    /**
     * @stability stable
     */
    set roleArn(value: string);
    /**
     * @stability stable
     */
    get roleArnInput(): string | undefined;
    private _userPoolId?;
    /**
     * @stability stable
     */
    get userPoolId(): string;
    /**
     * @stability stable
     */
    set userPoolId(value: string);
    /**
     * @stability stable
     */
    get userPoolIdInput(): string | undefined;
}
/**
 * @stability stable
 */
export interface ElasticsearchDomainDomainEndpointOptions {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/elasticsearch_domain#custom_endpoint ElasticsearchDomain#custom_endpoint}.
     *
     * @stability stable
     */
    readonly customEndpoint?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/elasticsearch_domain#custom_endpoint_certificate_arn ElasticsearchDomain#custom_endpoint_certificate_arn}.
     *
     * @stability stable
     */
    readonly customEndpointCertificateArn?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/elasticsearch_domain#custom_endpoint_enabled ElasticsearchDomain#custom_endpoint_enabled}.
     *
     * @stability stable
     */
    readonly customEndpointEnabled?: boolean | cdktf.IResolvable;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/elasticsearch_domain#enforce_https ElasticsearchDomain#enforce_https}.
     *
     * @stability stable
     */
    readonly enforceHttps?: boolean | cdktf.IResolvable;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/elasticsearch_domain#tls_security_policy ElasticsearchDomain#tls_security_policy}.
     *
     * @stability stable
     */
    readonly tlsSecurityPolicy?: string;
}
export declare function elasticsearchDomainDomainEndpointOptionsToTerraform(struct?: ElasticsearchDomainDomainEndpointOptionsOutputReference | ElasticsearchDomainDomainEndpointOptions): any;
/**
 * @stability stable
 */
export declare class ElasticsearchDomainDomainEndpointOptionsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): ElasticsearchDomainDomainEndpointOptions | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: ElasticsearchDomainDomainEndpointOptions | undefined);
    private _customEndpoint?;
    /**
     * @stability stable
     */
    get customEndpoint(): string;
    /**
     * @stability stable
     */
    set customEndpoint(value: string);
    /**
     * @stability stable
     */
    resetCustomEndpoint(): void;
    /**
     * @stability stable
     */
    get customEndpointInput(): string | undefined;
    private _customEndpointCertificateArn?;
    /**
     * @stability stable
     */
    get customEndpointCertificateArn(): string;
    /**
     * @stability stable
     */
    set customEndpointCertificateArn(value: string);
    /**
     * @stability stable
     */
    resetCustomEndpointCertificateArn(): void;
    /**
     * @stability stable
     */
    get customEndpointCertificateArnInput(): string | undefined;
    private _customEndpointEnabled?;
    /**
     * @stability stable
     */
    get customEndpointEnabled(): boolean | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set customEndpointEnabled(value: boolean | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetCustomEndpointEnabled(): void;
    /**
     * @stability stable
     */
    get customEndpointEnabledInput(): boolean | cdktf.IResolvable | undefined;
    private _enforceHttps?;
    /**
     * @stability stable
     */
    get enforceHttps(): boolean | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set enforceHttps(value: boolean | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetEnforceHttps(): void;
    /**
     * @stability stable
     */
    get enforceHttpsInput(): boolean | cdktf.IResolvable | undefined;
    private _tlsSecurityPolicy?;
    /**
     * @stability stable
     */
    get tlsSecurityPolicy(): string;
    /**
     * @stability stable
     */
    set tlsSecurityPolicy(value: string);
    /**
     * @stability stable
     */
    resetTlsSecurityPolicy(): void;
    /**
     * @stability stable
     */
    get tlsSecurityPolicyInput(): string | undefined;
}
/**
 * @stability stable
 */
export interface ElasticsearchDomainEbsOptions {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/elasticsearch_domain#ebs_enabled ElasticsearchDomain#ebs_enabled}.
     *
     * @stability stable
     */
    readonly ebsEnabled: boolean | cdktf.IResolvable;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/elasticsearch_domain#iops ElasticsearchDomain#iops}.
     *
     * @stability stable
     */
    readonly iops?: number;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/elasticsearch_domain#volume_size ElasticsearchDomain#volume_size}.
     *
     * @stability stable
     */
    readonly volumeSize?: number;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/elasticsearch_domain#volume_type ElasticsearchDomain#volume_type}.
     *
     * @stability stable
     */
    readonly volumeType?: string;
}
export declare function elasticsearchDomainEbsOptionsToTerraform(struct?: ElasticsearchDomainEbsOptionsOutputReference | ElasticsearchDomainEbsOptions): any;
/**
 * @stability stable
 */
export declare class ElasticsearchDomainEbsOptionsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): ElasticsearchDomainEbsOptions | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: ElasticsearchDomainEbsOptions | undefined);
    private _ebsEnabled?;
    /**
     * @stability stable
     */
    get ebsEnabled(): boolean | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set ebsEnabled(value: boolean | cdktf.IResolvable);
    /**
     * @stability stable
     */
    get ebsEnabledInput(): boolean | cdktf.IResolvable | undefined;
    private _iops?;
    /**
     * @stability stable
     */
    get iops(): number;
    /**
     * @stability stable
     */
    set iops(value: number);
    /**
     * @stability stable
     */
    resetIops(): void;
    /**
     * @stability stable
     */
    get iopsInput(): number | undefined;
    private _volumeSize?;
    /**
     * @stability stable
     */
    get volumeSize(): number;
    /**
     * @stability stable
     */
    set volumeSize(value: number);
    /**
     * @stability stable
     */
    resetVolumeSize(): void;
    /**
     * @stability stable
     */
    get volumeSizeInput(): number | undefined;
    private _volumeType?;
    /**
     * @stability stable
     */
    get volumeType(): string;
    /**
     * @stability stable
     */
    set volumeType(value: string);
    /**
     * @stability stable
     */
    resetVolumeType(): void;
    /**
     * @stability stable
     */
    get volumeTypeInput(): string | undefined;
}
/**
 * @stability stable
 */
export interface ElasticsearchDomainEncryptAtRest {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/elasticsearch_domain#enabled ElasticsearchDomain#enabled}.
     *
     * @stability stable
     */
    readonly enabled: boolean | cdktf.IResolvable;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/elasticsearch_domain#kms_key_id ElasticsearchDomain#kms_key_id}.
     *
     * @stability stable
     */
    readonly kmsKeyId?: string;
}
export declare function elasticsearchDomainEncryptAtRestToTerraform(struct?: ElasticsearchDomainEncryptAtRestOutputReference | ElasticsearchDomainEncryptAtRest): any;
/**
 * @stability stable
 */
export declare class ElasticsearchDomainEncryptAtRestOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): ElasticsearchDomainEncryptAtRest | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: ElasticsearchDomainEncryptAtRest | undefined);
    private _enabled?;
    /**
     * @stability stable
     */
    get enabled(): boolean | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set enabled(value: boolean | cdktf.IResolvable);
    /**
     * @stability stable
     */
    get enabledInput(): boolean | cdktf.IResolvable | undefined;
    private _kmsKeyId?;
    /**
     * @stability stable
     */
    get kmsKeyId(): string;
    /**
     * @stability stable
     */
    set kmsKeyId(value: string);
    /**
     * @stability stable
     */
    resetKmsKeyId(): void;
    /**
     * @stability stable
     */
    get kmsKeyIdInput(): string | undefined;
}
/**
 * @stability stable
 */
export interface ElasticsearchDomainLogPublishingOptions {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/elasticsearch_domain#cloudwatch_log_group_arn ElasticsearchDomain#cloudwatch_log_group_arn}.
     *
     * @stability stable
     */
    readonly cloudwatchLogGroupArn: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/elasticsearch_domain#enabled ElasticsearchDomain#enabled}.
     *
     * @stability stable
     */
    readonly enabled?: boolean | cdktf.IResolvable;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/elasticsearch_domain#log_type ElasticsearchDomain#log_type}.
     *
     * @stability stable
     */
    readonly logType: string;
}
export declare function elasticsearchDomainLogPublishingOptionsToTerraform(struct?: ElasticsearchDomainLogPublishingOptions | cdktf.IResolvable): any;
/**
 * @stability stable
 */
export interface ElasticsearchDomainNodeToNodeEncryption {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/elasticsearch_domain#enabled ElasticsearchDomain#enabled}.
     *
     * @stability stable
     */
    readonly enabled: boolean | cdktf.IResolvable;
}
export declare function elasticsearchDomainNodeToNodeEncryptionToTerraform(struct?: ElasticsearchDomainNodeToNodeEncryptionOutputReference | ElasticsearchDomainNodeToNodeEncryption): any;
/**
 * @stability stable
 */
export declare class ElasticsearchDomainNodeToNodeEncryptionOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): ElasticsearchDomainNodeToNodeEncryption | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: ElasticsearchDomainNodeToNodeEncryption | undefined);
    private _enabled?;
    /**
     * @stability stable
     */
    get enabled(): boolean | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set enabled(value: boolean | cdktf.IResolvable);
    /**
     * @stability stable
     */
    get enabledInput(): boolean | cdktf.IResolvable | undefined;
}
/**
 * @stability stable
 */
export interface ElasticsearchDomainSnapshotOptions {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/elasticsearch_domain#automated_snapshot_start_hour ElasticsearchDomain#automated_snapshot_start_hour}.
     *
     * @stability stable
     */
    readonly automatedSnapshotStartHour: number;
}
export declare function elasticsearchDomainSnapshotOptionsToTerraform(struct?: ElasticsearchDomainSnapshotOptionsOutputReference | ElasticsearchDomainSnapshotOptions): any;
/**
 * @stability stable
 */
export declare class ElasticsearchDomainSnapshotOptionsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): ElasticsearchDomainSnapshotOptions | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: ElasticsearchDomainSnapshotOptions | undefined);
    private _automatedSnapshotStartHour?;
    /**
     * @stability stable
     */
    get automatedSnapshotStartHour(): number;
    /**
     * @stability stable
     */
    set automatedSnapshotStartHour(value: number);
    /**
     * @stability stable
     */
    get automatedSnapshotStartHourInput(): number | undefined;
}
/**
 * @stability stable
 */
export interface ElasticsearchDomainTimeouts {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/elasticsearch_domain#update ElasticsearchDomain#update}.
     *
     * @stability stable
     */
    readonly update?: string;
}
export declare function elasticsearchDomainTimeoutsToTerraform(struct?: ElasticsearchDomainTimeoutsOutputReference | ElasticsearchDomainTimeouts | cdktf.IResolvable): any;
/**
 * @stability stable
 */
export declare class ElasticsearchDomainTimeoutsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): ElasticsearchDomainTimeouts | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: ElasticsearchDomainTimeouts | undefined);
    private _update?;
    /**
     * @stability stable
     */
    get update(): string;
    /**
     * @stability stable
     */
    set update(value: string);
    /**
     * @stability stable
     */
    resetUpdate(): void;
    /**
     * @stability stable
     */
    get updateInput(): string | undefined;
}
/**
 * @stability stable
 */
export interface ElasticsearchDomainVpcOptions {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/elasticsearch_domain#security_group_ids ElasticsearchDomain#security_group_ids}.
     *
     * @stability stable
     */
    readonly securityGroupIds?: string[];
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/elasticsearch_domain#subnet_ids ElasticsearchDomain#subnet_ids}.
     *
     * @stability stable
     */
    readonly subnetIds?: string[];
}
export declare function elasticsearchDomainVpcOptionsToTerraform(struct?: ElasticsearchDomainVpcOptionsOutputReference | ElasticsearchDomainVpcOptions): any;
/**
 * @stability stable
 */
export declare class ElasticsearchDomainVpcOptionsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): ElasticsearchDomainVpcOptions | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: ElasticsearchDomainVpcOptions | undefined);
    /**
     * @stability stable
     */
    get availabilityZones(): string[];
    private _securityGroupIds?;
    /**
     * @stability stable
     */
    get securityGroupIds(): string[];
    /**
     * @stability stable
     */
    set securityGroupIds(value: string[]);
    /**
     * @stability stable
     */
    resetSecurityGroupIds(): void;
    /**
     * @stability stable
     */
    get securityGroupIdsInput(): string[] | undefined;
    private _subnetIds?;
    /**
     * @stability stable
     */
    get subnetIds(): string[];
    /**
     * @stability stable
     */
    set subnetIds(value: string[]);
    /**
     * @stability stable
     */
    resetSubnetIds(): void;
    /**
     * @stability stable
     */
    get subnetIdsInput(): string[] | undefined;
    /**
     * @stability stable
     */
    get vpcId(): string;
}
/**
 * Represents a {@link https://www.terraform.io/docs/providers/aws/r/elasticsearch_domain aws_elasticsearch_domain}.
 *
 * @stability stable
 */
export declare class ElasticsearchDomain extends cdktf.TerraformResource {
    /**
     * @stability stable
     */
    static readonly tfResourceType: string;
    /**
     * Create a new {@link https://www.terraform.io/docs/providers/aws/r/elasticsearch_domain aws_elasticsearch_domain} Resource.
     *
     * @param scope The scope in which to define this construct.
     * @param id The scoped construct ID.
     * @stability stable
     */
    constructor(scope: Construct, id: string, config: ElasticsearchDomainConfig);
    private _accessPolicies?;
    /**
     * @stability stable
     */
    get accessPolicies(): string;
    /**
     * @stability stable
     */
    set accessPolicies(value: string);
    /**
     * @stability stable
     */
    resetAccessPolicies(): void;
    /**
     * @stability stable
     */
    get accessPoliciesInput(): string | undefined;
    private _advancedOptions?;
    /**
     * @stability stable
     */
    get advancedOptions(): {
        [key: string]: string;
    };
    /**
     * @stability stable
     */
    set advancedOptions(value: {
        [key: string]: string;
    });
    /**
     * @stability stable
     */
    resetAdvancedOptions(): void;
    /**
     * @stability stable
     */
    get advancedOptionsInput(): {
        [key: string]: string;
    } | undefined;
    /**
     * @stability stable
     */
    get arn(): string;
    /**
     * @stability stable
     */
    get domainId(): string;
    private _domainName?;
    /**
     * @stability stable
     */
    get domainName(): string;
    /**
     * @stability stable
     */
    set domainName(value: string);
    /**
     * @stability stable
     */
    get domainNameInput(): string | undefined;
    private _elasticsearchVersion?;
    /**
     * @stability stable
     */
    get elasticsearchVersion(): string;
    /**
     * @stability stable
     */
    set elasticsearchVersion(value: string);
    /**
     * @stability stable
     */
    resetElasticsearchVersion(): void;
    /**
     * @stability stable
     */
    get elasticsearchVersionInput(): string | undefined;
    /**
     * @stability stable
     */
    get endpoint(): string;
    /**
     * @stability stable
     */
    get id(): string;
    /**
     * @stability stable
     */
    get kibanaEndpoint(): string;
    private _tags?;
    /**
     * @stability stable
     */
    get tags(): {
        [key: string]: string;
    };
    /**
     * @stability stable
     */
    set tags(value: {
        [key: string]: string;
    });
    /**
     * @stability stable
     */
    resetTags(): void;
    /**
     * @stability stable
     */
    get tagsInput(): {
        [key: string]: string;
    } | undefined;
    private _tagsAll?;
    /**
     * @stability stable
     */
    get tagsAll(): {
        [key: string]: string;
    };
    /**
     * @stability stable
     */
    set tagsAll(value: {
        [key: string]: string;
    });
    /**
     * @stability stable
     */
    resetTagsAll(): void;
    /**
     * @stability stable
     */
    get tagsAllInput(): {
        [key: string]: string;
    } | undefined;
    private _advancedSecurityOptions;
    /**
     * @stability stable
     */
    get advancedSecurityOptions(): ElasticsearchDomainAdvancedSecurityOptionsOutputReference;
    /**
     * @stability stable
     */
    putAdvancedSecurityOptions(value: ElasticsearchDomainAdvancedSecurityOptions): void;
    /**
     * @stability stable
     */
    resetAdvancedSecurityOptions(): void;
    /**
     * @stability stable
     */
    get advancedSecurityOptionsInput(): ElasticsearchDomainAdvancedSecurityOptions | undefined;
    private _autoTuneOptions;
    /**
     * @stability stable
     */
    get autoTuneOptions(): ElasticsearchDomainAutoTuneOptionsOutputReference;
    /**
     * @stability stable
     */
    putAutoTuneOptions(value: ElasticsearchDomainAutoTuneOptions): void;
    /**
     * @stability stable
     */
    resetAutoTuneOptions(): void;
    /**
     * @stability stable
     */
    get autoTuneOptionsInput(): ElasticsearchDomainAutoTuneOptions | undefined;
    private _clusterConfig;
    /**
     * @stability stable
     */
    get clusterConfig(): ElasticsearchDomainClusterConfigOutputReference;
    /**
     * @stability stable
     */
    putClusterConfig(value: ElasticsearchDomainClusterConfig): void;
    /**
     * @stability stable
     */
    resetClusterConfig(): void;
    /**
     * @stability stable
     */
    get clusterConfigInput(): ElasticsearchDomainClusterConfig | undefined;
    private _cognitoOptions;
    /**
     * @stability stable
     */
    get cognitoOptions(): ElasticsearchDomainCognitoOptionsOutputReference;
    /**
     * @stability stable
     */
    putCognitoOptions(value: ElasticsearchDomainCognitoOptions): void;
    /**
     * @stability stable
     */
    resetCognitoOptions(): void;
    /**
     * @stability stable
     */
    get cognitoOptionsInput(): ElasticsearchDomainCognitoOptions | undefined;
    private _domainEndpointOptions;
    /**
     * @stability stable
     */
    get domainEndpointOptions(): ElasticsearchDomainDomainEndpointOptionsOutputReference;
    /**
     * @stability stable
     */
    putDomainEndpointOptions(value: ElasticsearchDomainDomainEndpointOptions): void;
    /**
     * @stability stable
     */
    resetDomainEndpointOptions(): void;
    /**
     * @stability stable
     */
    get domainEndpointOptionsInput(): ElasticsearchDomainDomainEndpointOptions | undefined;
    private _ebsOptions;
    /**
     * @stability stable
     */
    get ebsOptions(): ElasticsearchDomainEbsOptionsOutputReference;
    /**
     * @stability stable
     */
    putEbsOptions(value: ElasticsearchDomainEbsOptions): void;
    /**
     * @stability stable
     */
    resetEbsOptions(): void;
    /**
     * @stability stable
     */
    get ebsOptionsInput(): ElasticsearchDomainEbsOptions | undefined;
    private _encryptAtRest;
    /**
     * @stability stable
     */
    get encryptAtRest(): ElasticsearchDomainEncryptAtRestOutputReference;
    /**
     * @stability stable
     */
    putEncryptAtRest(value: ElasticsearchDomainEncryptAtRest): void;
    /**
     * @stability stable
     */
    resetEncryptAtRest(): void;
    /**
     * @stability stable
     */
    get encryptAtRestInput(): ElasticsearchDomainEncryptAtRest | undefined;
    private _logPublishingOptions?;
    /**
     * @stability stable
     */
    get logPublishingOptions(): ElasticsearchDomainLogPublishingOptions[] | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set logPublishingOptions(value: ElasticsearchDomainLogPublishingOptions[] | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetLogPublishingOptions(): void;
    /**
     * @stability stable
     */
    get logPublishingOptionsInput(): cdktf.IResolvable | ElasticsearchDomainLogPublishingOptions[] | undefined;
    private _nodeToNodeEncryption;
    /**
     * @stability stable
     */
    get nodeToNodeEncryption(): ElasticsearchDomainNodeToNodeEncryptionOutputReference;
    /**
     * @stability stable
     */
    putNodeToNodeEncryption(value: ElasticsearchDomainNodeToNodeEncryption): void;
    /**
     * @stability stable
     */
    resetNodeToNodeEncryption(): void;
    /**
     * @stability stable
     */
    get nodeToNodeEncryptionInput(): ElasticsearchDomainNodeToNodeEncryption | undefined;
    private _snapshotOptions;
    /**
     * @stability stable
     */
    get snapshotOptions(): ElasticsearchDomainSnapshotOptionsOutputReference;
    /**
     * @stability stable
     */
    putSnapshotOptions(value: ElasticsearchDomainSnapshotOptions): void;
    /**
     * @stability stable
     */
    resetSnapshotOptions(): void;
    /**
     * @stability stable
     */
    get snapshotOptionsInput(): ElasticsearchDomainSnapshotOptions | undefined;
    private _timeouts;
    /**
     * @stability stable
     */
    get timeouts(): ElasticsearchDomainTimeoutsOutputReference;
    /**
     * @stability stable
     */
    putTimeouts(value: ElasticsearchDomainTimeouts): void;
    /**
     * @stability stable
     */
    resetTimeouts(): void;
    /**
     * @stability stable
     */
    get timeoutsInput(): ElasticsearchDomainTimeouts | undefined;
    private _vpcOptions;
    /**
     * @stability stable
     */
    get vpcOptions(): ElasticsearchDomainVpcOptionsOutputReference;
    /**
     * @stability stable
     */
    putVpcOptions(value: ElasticsearchDomainVpcOptions): void;
    /**
     * @stability stable
     */
    resetVpcOptions(): void;
    /**
     * @stability stable
     */
    get vpcOptionsInput(): ElasticsearchDomainVpcOptions | undefined;
    /**
     * @stability stable
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
