import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
/**
 * AWS Elastic Transcoder.
 *
 * @stability stable
 */
export interface ElastictranscoderPipelineConfig extends cdktf.TerraformMetaArguments {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/elastictranscoder_pipeline#aws_kms_key_arn ElastictranscoderPipeline#aws_kms_key_arn}.
     *
     * @stability stable
     */
    readonly awsKmsKeyArn?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/elastictranscoder_pipeline#input_bucket ElastictranscoderPipeline#input_bucket}.
     *
     * @stability stable
     */
    readonly inputBucket: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/elastictranscoder_pipeline#name ElastictranscoderPipeline#name}.
     *
     * @stability stable
     */
    readonly name?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/elastictranscoder_pipeline#output_bucket ElastictranscoderPipeline#output_bucket}.
     *
     * @stability stable
     */
    readonly outputBucket?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/elastictranscoder_pipeline#role ElastictranscoderPipeline#role}.
     *
     * @stability stable
     */
    readonly role: string;
    /**
     * content_config block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/elastictranscoder_pipeline#content_config ElastictranscoderPipeline#content_config}
     *
     * @stability stable
     */
    readonly contentConfig?: ElastictranscoderPipelineContentConfig;
    /**
     * content_config_permissions block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/elastictranscoder_pipeline#content_config_permissions ElastictranscoderPipeline#content_config_permissions}
     *
     * @stability stable
     */
    readonly contentConfigPermissions?: ElastictranscoderPipelineContentConfigPermissions[] | cdktf.IResolvable;
    /**
     * notifications block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/elastictranscoder_pipeline#notifications ElastictranscoderPipeline#notifications}
     *
     * @stability stable
     */
    readonly notifications?: ElastictranscoderPipelineNotifications;
    /**
     * thumbnail_config block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/elastictranscoder_pipeline#thumbnail_config ElastictranscoderPipeline#thumbnail_config}
     *
     * @stability stable
     */
    readonly thumbnailConfig?: ElastictranscoderPipelineThumbnailConfig;
    /**
     * thumbnail_config_permissions block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/elastictranscoder_pipeline#thumbnail_config_permissions ElastictranscoderPipeline#thumbnail_config_permissions}
     *
     * @stability stable
     */
    readonly thumbnailConfigPermissions?: ElastictranscoderPipelineThumbnailConfigPermissions[] | cdktf.IResolvable;
}
/**
 * @stability stable
 */
export interface ElastictranscoderPipelineContentConfig {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/elastictranscoder_pipeline#bucket ElastictranscoderPipeline#bucket}.
     *
     * @stability stable
     */
    readonly bucket?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/elastictranscoder_pipeline#storage_class ElastictranscoderPipeline#storage_class}.
     *
     * @stability stable
     */
    readonly storageClass?: string;
}
export declare function elastictranscoderPipelineContentConfigToTerraform(struct?: ElastictranscoderPipelineContentConfigOutputReference | ElastictranscoderPipelineContentConfig): any;
/**
 * @stability stable
 */
export declare class ElastictranscoderPipelineContentConfigOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): ElastictranscoderPipelineContentConfig | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: ElastictranscoderPipelineContentConfig | undefined);
    private _bucket?;
    /**
     * @stability stable
     */
    get bucket(): string;
    /**
     * @stability stable
     */
    set bucket(value: string);
    /**
     * @stability stable
     */
    resetBucket(): void;
    /**
     * @stability stable
     */
    get bucketInput(): string | undefined;
    private _storageClass?;
    /**
     * @stability stable
     */
    get storageClass(): string;
    /**
     * @stability stable
     */
    set storageClass(value: string);
    /**
     * @stability stable
     */
    resetStorageClass(): void;
    /**
     * @stability stable
     */
    get storageClassInput(): string | undefined;
}
/**
 * @stability stable
 */
export interface ElastictranscoderPipelineContentConfigPermissions {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/elastictranscoder_pipeline#access ElastictranscoderPipeline#access}.
     *
     * @stability stable
     */
    readonly access?: string[];
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/elastictranscoder_pipeline#grantee ElastictranscoderPipeline#grantee}.
     *
     * @stability stable
     */
    readonly grantee?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/elastictranscoder_pipeline#grantee_type ElastictranscoderPipeline#grantee_type}.
     *
     * @stability stable
     */
    readonly granteeType?: string;
}
export declare function elastictranscoderPipelineContentConfigPermissionsToTerraform(struct?: ElastictranscoderPipelineContentConfigPermissions | cdktf.IResolvable): any;
/**
 * @stability stable
 */
export interface ElastictranscoderPipelineNotifications {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/elastictranscoder_pipeline#completed ElastictranscoderPipeline#completed}.
     *
     * @stability stable
     */
    readonly completed?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/elastictranscoder_pipeline#error ElastictranscoderPipeline#error}.
     *
     * @stability stable
     */
    readonly error?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/elastictranscoder_pipeline#progressing ElastictranscoderPipeline#progressing}.
     *
     * @stability stable
     */
    readonly progressing?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/elastictranscoder_pipeline#warning ElastictranscoderPipeline#warning}.
     *
     * @stability stable
     */
    readonly warning?: string;
}
export declare function elastictranscoderPipelineNotificationsToTerraform(struct?: ElastictranscoderPipelineNotificationsOutputReference | ElastictranscoderPipelineNotifications): any;
/**
 * @stability stable
 */
export declare class ElastictranscoderPipelineNotificationsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): ElastictranscoderPipelineNotifications | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: ElastictranscoderPipelineNotifications | undefined);
    private _completed?;
    /**
     * @stability stable
     */
    get completed(): string;
    /**
     * @stability stable
     */
    set completed(value: string);
    /**
     * @stability stable
     */
    resetCompleted(): void;
    /**
     * @stability stable
     */
    get completedInput(): string | undefined;
    private _error?;
    /**
     * @stability stable
     */
    get error(): string;
    /**
     * @stability stable
     */
    set error(value: string);
    /**
     * @stability stable
     */
    resetError(): void;
    /**
     * @stability stable
     */
    get errorInput(): string | undefined;
    private _progressing?;
    /**
     * @stability stable
     */
    get progressing(): string;
    /**
     * @stability stable
     */
    set progressing(value: string);
    /**
     * @stability stable
     */
    resetProgressing(): void;
    /**
     * @stability stable
     */
    get progressingInput(): string | undefined;
    private _warning?;
    /**
     * @stability stable
     */
    get warning(): string;
    /**
     * @stability stable
     */
    set warning(value: string);
    /**
     * @stability stable
     */
    resetWarning(): void;
    /**
     * @stability stable
     */
    get warningInput(): string | undefined;
}
/**
 * @stability stable
 */
export interface ElastictranscoderPipelineThumbnailConfig {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/elastictranscoder_pipeline#bucket ElastictranscoderPipeline#bucket}.
     *
     * @stability stable
     */
    readonly bucket?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/elastictranscoder_pipeline#storage_class ElastictranscoderPipeline#storage_class}.
     *
     * @stability stable
     */
    readonly storageClass?: string;
}
export declare function elastictranscoderPipelineThumbnailConfigToTerraform(struct?: ElastictranscoderPipelineThumbnailConfigOutputReference | ElastictranscoderPipelineThumbnailConfig): any;
/**
 * @stability stable
 */
export declare class ElastictranscoderPipelineThumbnailConfigOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): ElastictranscoderPipelineThumbnailConfig | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: ElastictranscoderPipelineThumbnailConfig | undefined);
    private _bucket?;
    /**
     * @stability stable
     */
    get bucket(): string;
    /**
     * @stability stable
     */
    set bucket(value: string);
    /**
     * @stability stable
     */
    resetBucket(): void;
    /**
     * @stability stable
     */
    get bucketInput(): string | undefined;
    private _storageClass?;
    /**
     * @stability stable
     */
    get storageClass(): string;
    /**
     * @stability stable
     */
    set storageClass(value: string);
    /**
     * @stability stable
     */
    resetStorageClass(): void;
    /**
     * @stability stable
     */
    get storageClassInput(): string | undefined;
}
/**
 * @stability stable
 */
export interface ElastictranscoderPipelineThumbnailConfigPermissions {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/elastictranscoder_pipeline#access ElastictranscoderPipeline#access}.
     *
     * @stability stable
     */
    readonly access?: string[];
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/elastictranscoder_pipeline#grantee ElastictranscoderPipeline#grantee}.
     *
     * @stability stable
     */
    readonly grantee?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/elastictranscoder_pipeline#grantee_type ElastictranscoderPipeline#grantee_type}.
     *
     * @stability stable
     */
    readonly granteeType?: string;
}
export declare function elastictranscoderPipelineThumbnailConfigPermissionsToTerraform(struct?: ElastictranscoderPipelineThumbnailConfigPermissions | cdktf.IResolvable): any;
/**
 * Represents a {@link https://www.terraform.io/docs/providers/aws/r/elastictranscoder_pipeline aws_elastictranscoder_pipeline}.
 *
 * @stability stable
 */
export declare class ElastictranscoderPipeline extends cdktf.TerraformResource {
    /**
     * @stability stable
     */
    static readonly tfResourceType: string;
    /**
     * Create a new {@link https://www.terraform.io/docs/providers/aws/r/elastictranscoder_pipeline aws_elastictranscoder_pipeline} Resource.
     *
     * @param scope The scope in which to define this construct.
     * @param id The scoped construct ID.
     * @stability stable
     */
    constructor(scope: Construct, id: string, config: ElastictranscoderPipelineConfig);
    /**
     * @stability stable
     */
    get arn(): string;
    private _awsKmsKeyArn?;
    /**
     * @stability stable
     */
    get awsKmsKeyArn(): string;
    /**
     * @stability stable
     */
    set awsKmsKeyArn(value: string);
    /**
     * @stability stable
     */
    resetAwsKmsKeyArn(): void;
    /**
     * @stability stable
     */
    get awsKmsKeyArnInput(): string | undefined;
    /**
     * @stability stable
     */
    get id(): string;
    private _inputBucket?;
    /**
     * @stability stable
     */
    get inputBucket(): string;
    /**
     * @stability stable
     */
    set inputBucket(value: string);
    /**
     * @stability stable
     */
    get inputBucketInput(): string | undefined;
    private _name?;
    /**
     * @stability stable
     */
    get name(): string;
    /**
     * @stability stable
     */
    set name(value: string);
    /**
     * @stability stable
     */
    resetName(): void;
    /**
     * @stability stable
     */
    get nameInput(): string | undefined;
    private _outputBucket?;
    /**
     * @stability stable
     */
    get outputBucket(): string;
    /**
     * @stability stable
     */
    set outputBucket(value: string);
    /**
     * @stability stable
     */
    resetOutputBucket(): void;
    /**
     * @stability stable
     */
    get outputBucketInput(): string | undefined;
    private _role?;
    /**
     * @stability stable
     */
    get role(): string;
    /**
     * @stability stable
     */
    set role(value: string);
    /**
     * @stability stable
     */
    get roleInput(): string | undefined;
    private _contentConfig;
    /**
     * @stability stable
     */
    get contentConfig(): ElastictranscoderPipelineContentConfigOutputReference;
    /**
     * @stability stable
     */
    putContentConfig(value: ElastictranscoderPipelineContentConfig): void;
    /**
     * @stability stable
     */
    resetContentConfig(): void;
    /**
     * @stability stable
     */
    get contentConfigInput(): ElastictranscoderPipelineContentConfig | undefined;
    private _contentConfigPermissions?;
    /**
     * @stability stable
     */
    get contentConfigPermissions(): ElastictranscoderPipelineContentConfigPermissions[] | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set contentConfigPermissions(value: ElastictranscoderPipelineContentConfigPermissions[] | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetContentConfigPermissions(): void;
    /**
     * @stability stable
     */
    get contentConfigPermissionsInput(): cdktf.IResolvable | ElastictranscoderPipelineContentConfigPermissions[] | undefined;
    private _notifications;
    /**
     * @stability stable
     */
    get notifications(): ElastictranscoderPipelineNotificationsOutputReference;
    /**
     * @stability stable
     */
    putNotifications(value: ElastictranscoderPipelineNotifications): void;
    /**
     * @stability stable
     */
    resetNotifications(): void;
    /**
     * @stability stable
     */
    get notificationsInput(): ElastictranscoderPipelineNotifications | undefined;
    private _thumbnailConfig;
    /**
     * @stability stable
     */
    get thumbnailConfig(): ElastictranscoderPipelineThumbnailConfigOutputReference;
    /**
     * @stability stable
     */
    putThumbnailConfig(value: ElastictranscoderPipelineThumbnailConfig): void;
    /**
     * @stability stable
     */
    resetThumbnailConfig(): void;
    /**
     * @stability stable
     */
    get thumbnailConfigInput(): ElastictranscoderPipelineThumbnailConfig | undefined;
    private _thumbnailConfigPermissions?;
    /**
     * @stability stable
     */
    get thumbnailConfigPermissions(): ElastictranscoderPipelineThumbnailConfigPermissions[] | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set thumbnailConfigPermissions(value: ElastictranscoderPipelineThumbnailConfigPermissions[] | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetThumbnailConfigPermissions(): void;
    /**
     * @stability stable
     */
    get thumbnailConfigPermissionsInput(): cdktf.IResolvable | ElastictranscoderPipelineThumbnailConfigPermissions[] | undefined;
    /**
     * @stability stable
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
