import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
/**
 * AWS Elastic Load Balancer.
 *
 * @stability stable
 */
export interface AlbConfig extends cdktf.TerraformMetaArguments {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/alb#customer_owned_ipv4_pool Alb#customer_owned_ipv4_pool}.
     *
     * @stability stable
     */
    readonly customerOwnedIpv4Pool?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/alb#desync_mitigation_mode Alb#desync_mitigation_mode}.
     *
     * @stability stable
     */
    readonly desyncMitigationMode?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/alb#drop_invalid_header_fields Alb#drop_invalid_header_fields}.
     *
     * @stability stable
     */
    readonly dropInvalidHeaderFields?: boolean | cdktf.IResolvable;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/alb#enable_cross_zone_load_balancing Alb#enable_cross_zone_load_balancing}.
     *
     * @stability stable
     */
    readonly enableCrossZoneLoadBalancing?: boolean | cdktf.IResolvable;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/alb#enable_deletion_protection Alb#enable_deletion_protection}.
     *
     * @stability stable
     */
    readonly enableDeletionProtection?: boolean | cdktf.IResolvable;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/alb#enable_http2 Alb#enable_http2}.
     *
     * @stability stable
     */
    readonly enableHttp2?: boolean | cdktf.IResolvable;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/alb#enable_waf_fail_open Alb#enable_waf_fail_open}.
     *
     * @stability stable
     */
    readonly enableWafFailOpen?: boolean | cdktf.IResolvable;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/alb#idle_timeout Alb#idle_timeout}.
     *
     * @stability stable
     */
    readonly idleTimeout?: number;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/alb#internal Alb#internal}.
     *
     * @stability stable
     */
    readonly internal?: boolean | cdktf.IResolvable;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/alb#ip_address_type Alb#ip_address_type}.
     *
     * @stability stable
     */
    readonly ipAddressType?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/alb#load_balancer_type Alb#load_balancer_type}.
     *
     * @stability stable
     */
    readonly loadBalancerType?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/alb#name Alb#name}.
     *
     * @stability stable
     */
    readonly name?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/alb#name_prefix Alb#name_prefix}.
     *
     * @stability stable
     */
    readonly namePrefix?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/alb#security_groups Alb#security_groups}.
     *
     * @stability stable
     */
    readonly securityGroups?: string[];
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/alb#subnets Alb#subnets}.
     *
     * @stability stable
     */
    readonly subnets?: string[];
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/alb#tags Alb#tags}.
     *
     * @stability stable
     */
    readonly tags?: {
        [key: string]: string;
    };
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/alb#tags_all Alb#tags_all}.
     *
     * @stability stable
     */
    readonly tagsAll?: {
        [key: string]: string;
    };
    /**
     * access_logs block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/alb#access_logs Alb#access_logs}
     *
     * @stability stable
     */
    readonly accessLogs?: AlbAccessLogs;
    /**
     * subnet_mapping block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/alb#subnet_mapping Alb#subnet_mapping}
     *
     * @stability stable
     */
    readonly subnetMapping?: AlbSubnetMapping[] | cdktf.IResolvable;
    /**
     * timeouts block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/alb#timeouts Alb#timeouts}
     *
     * @stability stable
     */
    readonly timeouts?: AlbTimeouts;
}
/**
 * @stability stable
 */
export interface AlbAccessLogs {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/alb#bucket Alb#bucket}.
     *
     * @stability stable
     */
    readonly bucket: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/alb#enabled Alb#enabled}.
     *
     * @stability stable
     */
    readonly enabled?: boolean | cdktf.IResolvable;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/alb#prefix Alb#prefix}.
     *
     * @stability stable
     */
    readonly prefix?: string;
}
export declare function albAccessLogsToTerraform(struct?: AlbAccessLogsOutputReference | AlbAccessLogs): any;
/**
 * @stability stable
 */
export declare class AlbAccessLogsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): AlbAccessLogs | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: AlbAccessLogs | undefined);
    private _bucket?;
    /**
     * @stability stable
     */
    get bucket(): string;
    /**
     * @stability stable
     */
    set bucket(value: string);
    /**
     * @stability stable
     */
    get bucketInput(): string | undefined;
    private _enabled?;
    /**
     * @stability stable
     */
    get enabled(): boolean | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set enabled(value: boolean | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetEnabled(): void;
    /**
     * @stability stable
     */
    get enabledInput(): boolean | cdktf.IResolvable | undefined;
    private _prefix?;
    /**
     * @stability stable
     */
    get prefix(): string;
    /**
     * @stability stable
     */
    set prefix(value: string);
    /**
     * @stability stable
     */
    resetPrefix(): void;
    /**
     * @stability stable
     */
    get prefixInput(): string | undefined;
}
/**
 * @stability stable
 */
export interface AlbSubnetMapping {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/alb#allocation_id Alb#allocation_id}.
     *
     * @stability stable
     */
    readonly allocationId?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/alb#ipv6_address Alb#ipv6_address}.
     *
     * @stability stable
     */
    readonly ipv6Address?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/alb#private_ipv4_address Alb#private_ipv4_address}.
     *
     * @stability stable
     */
    readonly privateIpv4Address?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/alb#subnet_id Alb#subnet_id}.
     *
     * @stability stable
     */
    readonly subnetId: string;
}
export declare function albSubnetMappingToTerraform(struct?: AlbSubnetMapping | cdktf.IResolvable): any;
/**
 * @stability stable
 */
export interface AlbTimeouts {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/alb#create Alb#create}.
     *
     * @stability stable
     */
    readonly create?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/alb#delete Alb#delete}.
     *
     * @stability stable
     */
    readonly delete?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/alb#update Alb#update}.
     *
     * @stability stable
     */
    readonly update?: string;
}
export declare function albTimeoutsToTerraform(struct?: AlbTimeoutsOutputReference | AlbTimeouts | cdktf.IResolvable): any;
/**
 * @stability stable
 */
export declare class AlbTimeoutsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): AlbTimeouts | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: AlbTimeouts | undefined);
    private _create?;
    /**
     * @stability stable
     */
    get create(): string;
    /**
     * @stability stable
     */
    set create(value: string);
    /**
     * @stability stable
     */
    resetCreate(): void;
    /**
     * @stability stable
     */
    get createInput(): string | undefined;
    private _delete?;
    /**
     * @stability stable
     */
    get delete(): string;
    /**
     * @stability stable
     */
    set delete(value: string);
    /**
     * @stability stable
     */
    resetDelete(): void;
    /**
     * @stability stable
     */
    get deleteInput(): string | undefined;
    private _update?;
    /**
     * @stability stable
     */
    get update(): string;
    /**
     * @stability stable
     */
    set update(value: string);
    /**
     * @stability stable
     */
    resetUpdate(): void;
    /**
     * @stability stable
     */
    get updateInput(): string | undefined;
}
/**
 * Represents a {@link https://www.terraform.io/docs/providers/aws/r/alb aws_alb}.
 *
 * @stability stable
 */
export declare class Alb extends cdktf.TerraformResource {
    /**
     * @stability stable
     */
    static readonly tfResourceType: string;
    /**
     * Create a new {@link https://www.terraform.io/docs/providers/aws/r/alb aws_alb} Resource.
     *
     * @param scope The scope in which to define this construct.
     * @param id The scoped construct ID.
     * @stability stable
     */
    constructor(scope: Construct, id: string, config?: AlbConfig);
    /**
     * @stability stable
     */
    get arn(): string;
    /**
     * @stability stable
     */
    get arnSuffix(): string;
    private _customerOwnedIpv4Pool?;
    /**
     * @stability stable
     */
    get customerOwnedIpv4Pool(): string;
    /**
     * @stability stable
     */
    set customerOwnedIpv4Pool(value: string);
    /**
     * @stability stable
     */
    resetCustomerOwnedIpv4Pool(): void;
    /**
     * @stability stable
     */
    get customerOwnedIpv4PoolInput(): string | undefined;
    private _desyncMitigationMode?;
    /**
     * @stability stable
     */
    get desyncMitigationMode(): string;
    /**
     * @stability stable
     */
    set desyncMitigationMode(value: string);
    /**
     * @stability stable
     */
    resetDesyncMitigationMode(): void;
    /**
     * @stability stable
     */
    get desyncMitigationModeInput(): string | undefined;
    /**
     * @stability stable
     */
    get dnsName(): string;
    private _dropInvalidHeaderFields?;
    /**
     * @stability stable
     */
    get dropInvalidHeaderFields(): boolean | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set dropInvalidHeaderFields(value: boolean | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetDropInvalidHeaderFields(): void;
    /**
     * @stability stable
     */
    get dropInvalidHeaderFieldsInput(): boolean | cdktf.IResolvable | undefined;
    private _enableCrossZoneLoadBalancing?;
    /**
     * @stability stable
     */
    get enableCrossZoneLoadBalancing(): boolean | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set enableCrossZoneLoadBalancing(value: boolean | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetEnableCrossZoneLoadBalancing(): void;
    /**
     * @stability stable
     */
    get enableCrossZoneLoadBalancingInput(): boolean | cdktf.IResolvable | undefined;
    private _enableDeletionProtection?;
    /**
     * @stability stable
     */
    get enableDeletionProtection(): boolean | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set enableDeletionProtection(value: boolean | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetEnableDeletionProtection(): void;
    /**
     * @stability stable
     */
    get enableDeletionProtectionInput(): boolean | cdktf.IResolvable | undefined;
    private _enableHttp2?;
    /**
     * @stability stable
     */
    get enableHttp2(): boolean | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set enableHttp2(value: boolean | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetEnableHttp2(): void;
    /**
     * @stability stable
     */
    get enableHttp2Input(): boolean | cdktf.IResolvable | undefined;
    private _enableWafFailOpen?;
    /**
     * @stability stable
     */
    get enableWafFailOpen(): boolean | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set enableWafFailOpen(value: boolean | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetEnableWafFailOpen(): void;
    /**
     * @stability stable
     */
    get enableWafFailOpenInput(): boolean | cdktf.IResolvable | undefined;
    /**
     * @stability stable
     */
    get id(): string;
    private _idleTimeout?;
    /**
     * @stability stable
     */
    get idleTimeout(): number;
    /**
     * @stability stable
     */
    set idleTimeout(value: number);
    /**
     * @stability stable
     */
    resetIdleTimeout(): void;
    /**
     * @stability stable
     */
    get idleTimeoutInput(): number | undefined;
    private _internal?;
    /**
     * @stability stable
     */
    get internal(): boolean | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set internal(value: boolean | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetInternal(): void;
    /**
     * @stability stable
     */
    get internalInput(): boolean | cdktf.IResolvable | undefined;
    private _ipAddressType?;
    /**
     * @stability stable
     */
    get ipAddressType(): string;
    /**
     * @stability stable
     */
    set ipAddressType(value: string);
    /**
     * @stability stable
     */
    resetIpAddressType(): void;
    /**
     * @stability stable
     */
    get ipAddressTypeInput(): string | undefined;
    private _loadBalancerType?;
    /**
     * @stability stable
     */
    get loadBalancerType(): string;
    /**
     * @stability stable
     */
    set loadBalancerType(value: string);
    /**
     * @stability stable
     */
    resetLoadBalancerType(): void;
    /**
     * @stability stable
     */
    get loadBalancerTypeInput(): string | undefined;
    private _name?;
    /**
     * @stability stable
     */
    get name(): string;
    /**
     * @stability stable
     */
    set name(value: string);
    /**
     * @stability stable
     */
    resetName(): void;
    /**
     * @stability stable
     */
    get nameInput(): string | undefined;
    private _namePrefix?;
    /**
     * @stability stable
     */
    get namePrefix(): string;
    /**
     * @stability stable
     */
    set namePrefix(value: string);
    /**
     * @stability stable
     */
    resetNamePrefix(): void;
    /**
     * @stability stable
     */
    get namePrefixInput(): string | undefined;
    private _securityGroups?;
    /**
     * @stability stable
     */
    get securityGroups(): string[];
    /**
     * @stability stable
     */
    set securityGroups(value: string[]);
    /**
     * @stability stable
     */
    resetSecurityGroups(): void;
    /**
     * @stability stable
     */
    get securityGroupsInput(): string[] | undefined;
    private _subnets?;
    /**
     * @stability stable
     */
    get subnets(): string[];
    /**
     * @stability stable
     */
    set subnets(value: string[]);
    /**
     * @stability stable
     */
    resetSubnets(): void;
    /**
     * @stability stable
     */
    get subnetsInput(): string[] | undefined;
    private _tags?;
    /**
     * @stability stable
     */
    get tags(): {
        [key: string]: string;
    };
    /**
     * @stability stable
     */
    set tags(value: {
        [key: string]: string;
    });
    /**
     * @stability stable
     */
    resetTags(): void;
    /**
     * @stability stable
     */
    get tagsInput(): {
        [key: string]: string;
    } | undefined;
    private _tagsAll?;
    /**
     * @stability stable
     */
    get tagsAll(): {
        [key: string]: string;
    };
    /**
     * @stability stable
     */
    set tagsAll(value: {
        [key: string]: string;
    });
    /**
     * @stability stable
     */
    resetTagsAll(): void;
    /**
     * @stability stable
     */
    get tagsAllInput(): {
        [key: string]: string;
    } | undefined;
    /**
     * @stability stable
     */
    get vpcId(): string;
    /**
     * @stability stable
     */
    get zoneId(): string;
    private _accessLogs;
    /**
     * @stability stable
     */
    get accessLogs(): AlbAccessLogsOutputReference;
    /**
     * @stability stable
     */
    putAccessLogs(value: AlbAccessLogs): void;
    /**
     * @stability stable
     */
    resetAccessLogs(): void;
    /**
     * @stability stable
     */
    get accessLogsInput(): AlbAccessLogs | undefined;
    private _subnetMapping?;
    /**
     * @stability stable
     */
    get subnetMapping(): AlbSubnetMapping[] | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set subnetMapping(value: AlbSubnetMapping[] | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetSubnetMapping(): void;
    /**
     * @stability stable
     */
    get subnetMappingInput(): cdktf.IResolvable | AlbSubnetMapping[] | undefined;
    private _timeouts;
    /**
     * @stability stable
     */
    get timeouts(): AlbTimeoutsOutputReference;
    /**
     * @stability stable
     */
    putTimeouts(value: AlbTimeouts): void;
    /**
     * @stability stable
     */
    resetTimeouts(): void;
    /**
     * @stability stable
     */
    get timeoutsInput(): AlbTimeouts | undefined;
    /**
     * @stability stable
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
