import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
/**
 * AWS Elastic Load Balancer.
 *
 * @stability stable
 */
export interface LbConfig extends cdktf.TerraformMetaArguments {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lb#customer_owned_ipv4_pool Lb#customer_owned_ipv4_pool}.
     *
     * @stability stable
     */
    readonly customerOwnedIpv4Pool?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lb#desync_mitigation_mode Lb#desync_mitigation_mode}.
     *
     * @stability stable
     */
    readonly desyncMitigationMode?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lb#drop_invalid_header_fields Lb#drop_invalid_header_fields}.
     *
     * @stability stable
     */
    readonly dropInvalidHeaderFields?: boolean | cdktf.IResolvable;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lb#enable_cross_zone_load_balancing Lb#enable_cross_zone_load_balancing}.
     *
     * @stability stable
     */
    readonly enableCrossZoneLoadBalancing?: boolean | cdktf.IResolvable;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lb#enable_deletion_protection Lb#enable_deletion_protection}.
     *
     * @stability stable
     */
    readonly enableDeletionProtection?: boolean | cdktf.IResolvable;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lb#enable_http2 Lb#enable_http2}.
     *
     * @stability stable
     */
    readonly enableHttp2?: boolean | cdktf.IResolvable;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lb#enable_waf_fail_open Lb#enable_waf_fail_open}.
     *
     * @stability stable
     */
    readonly enableWafFailOpen?: boolean | cdktf.IResolvable;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lb#idle_timeout Lb#idle_timeout}.
     *
     * @stability stable
     */
    readonly idleTimeout?: number;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lb#internal Lb#internal}.
     *
     * @stability stable
     */
    readonly internal?: boolean | cdktf.IResolvable;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lb#ip_address_type Lb#ip_address_type}.
     *
     * @stability stable
     */
    readonly ipAddressType?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lb#load_balancer_type Lb#load_balancer_type}.
     *
     * @stability stable
     */
    readonly loadBalancerType?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lb#name Lb#name}.
     *
     * @stability stable
     */
    readonly name?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lb#name_prefix Lb#name_prefix}.
     *
     * @stability stable
     */
    readonly namePrefix?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lb#security_groups Lb#security_groups}.
     *
     * @stability stable
     */
    readonly securityGroups?: string[];
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lb#subnets Lb#subnets}.
     *
     * @stability stable
     */
    readonly subnets?: string[];
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lb#tags Lb#tags}.
     *
     * @stability stable
     */
    readonly tags?: {
        [key: string]: string;
    };
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lb#tags_all Lb#tags_all}.
     *
     * @stability stable
     */
    readonly tagsAll?: {
        [key: string]: string;
    };
    /**
     * access_logs block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lb#access_logs Lb#access_logs}
     *
     * @stability stable
     */
    readonly accessLogs?: LbAccessLogs;
    /**
     * subnet_mapping block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lb#subnet_mapping Lb#subnet_mapping}
     *
     * @stability stable
     */
    readonly subnetMapping?: LbSubnetMapping[] | cdktf.IResolvable;
    /**
     * timeouts block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lb#timeouts Lb#timeouts}
     *
     * @stability stable
     */
    readonly timeouts?: LbTimeouts;
}
/**
 * @stability stable
 */
export interface LbAccessLogs {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lb#bucket Lb#bucket}.
     *
     * @stability stable
     */
    readonly bucket: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lb#enabled Lb#enabled}.
     *
     * @stability stable
     */
    readonly enabled?: boolean | cdktf.IResolvable;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lb#prefix Lb#prefix}.
     *
     * @stability stable
     */
    readonly prefix?: string;
}
export declare function lbAccessLogsToTerraform(struct?: LbAccessLogsOutputReference | LbAccessLogs): any;
/**
 * @stability stable
 */
export declare class LbAccessLogsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): LbAccessLogs | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: LbAccessLogs | undefined);
    private _bucket?;
    /**
     * @stability stable
     */
    get bucket(): string;
    /**
     * @stability stable
     */
    set bucket(value: string);
    /**
     * @stability stable
     */
    get bucketInput(): string | undefined;
    private _enabled?;
    /**
     * @stability stable
     */
    get enabled(): boolean | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set enabled(value: boolean | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetEnabled(): void;
    /**
     * @stability stable
     */
    get enabledInput(): boolean | cdktf.IResolvable | undefined;
    private _prefix?;
    /**
     * @stability stable
     */
    get prefix(): string;
    /**
     * @stability stable
     */
    set prefix(value: string);
    /**
     * @stability stable
     */
    resetPrefix(): void;
    /**
     * @stability stable
     */
    get prefixInput(): string | undefined;
}
/**
 * @stability stable
 */
export interface LbSubnetMapping {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lb#allocation_id Lb#allocation_id}.
     *
     * @stability stable
     */
    readonly allocationId?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lb#ipv6_address Lb#ipv6_address}.
     *
     * @stability stable
     */
    readonly ipv6Address?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lb#private_ipv4_address Lb#private_ipv4_address}.
     *
     * @stability stable
     */
    readonly privateIpv4Address?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lb#subnet_id Lb#subnet_id}.
     *
     * @stability stable
     */
    readonly subnetId: string;
}
export declare function lbSubnetMappingToTerraform(struct?: LbSubnetMapping | cdktf.IResolvable): any;
/**
 * @stability stable
 */
export interface LbTimeouts {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lb#create Lb#create}.
     *
     * @stability stable
     */
    readonly create?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lb#delete Lb#delete}.
     *
     * @stability stable
     */
    readonly delete?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lb#update Lb#update}.
     *
     * @stability stable
     */
    readonly update?: string;
}
export declare function lbTimeoutsToTerraform(struct?: LbTimeoutsOutputReference | LbTimeouts | cdktf.IResolvable): any;
/**
 * @stability stable
 */
export declare class LbTimeoutsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): LbTimeouts | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: LbTimeouts | undefined);
    private _create?;
    /**
     * @stability stable
     */
    get create(): string;
    /**
     * @stability stable
     */
    set create(value: string);
    /**
     * @stability stable
     */
    resetCreate(): void;
    /**
     * @stability stable
     */
    get createInput(): string | undefined;
    private _delete?;
    /**
     * @stability stable
     */
    get delete(): string;
    /**
     * @stability stable
     */
    set delete(value: string);
    /**
     * @stability stable
     */
    resetDelete(): void;
    /**
     * @stability stable
     */
    get deleteInput(): string | undefined;
    private _update?;
    /**
     * @stability stable
     */
    get update(): string;
    /**
     * @stability stable
     */
    set update(value: string);
    /**
     * @stability stable
     */
    resetUpdate(): void;
    /**
     * @stability stable
     */
    get updateInput(): string | undefined;
}
/**
 * Represents a {@link https://www.terraform.io/docs/providers/aws/r/lb aws_lb}.
 *
 * @stability stable
 */
export declare class Lb extends cdktf.TerraformResource {
    /**
     * @stability stable
     */
    static readonly tfResourceType: string;
    /**
     * Create a new {@link https://www.terraform.io/docs/providers/aws/r/lb aws_lb} Resource.
     *
     * @param scope The scope in which to define this construct.
     * @param id The scoped construct ID.
     * @stability stable
     */
    constructor(scope: Construct, id: string, config?: LbConfig);
    /**
     * @stability stable
     */
    get arn(): string;
    /**
     * @stability stable
     */
    get arnSuffix(): string;
    private _customerOwnedIpv4Pool?;
    /**
     * @stability stable
     */
    get customerOwnedIpv4Pool(): string;
    /**
     * @stability stable
     */
    set customerOwnedIpv4Pool(value: string);
    /**
     * @stability stable
     */
    resetCustomerOwnedIpv4Pool(): void;
    /**
     * @stability stable
     */
    get customerOwnedIpv4PoolInput(): string | undefined;
    private _desyncMitigationMode?;
    /**
     * @stability stable
     */
    get desyncMitigationMode(): string;
    /**
     * @stability stable
     */
    set desyncMitigationMode(value: string);
    /**
     * @stability stable
     */
    resetDesyncMitigationMode(): void;
    /**
     * @stability stable
     */
    get desyncMitigationModeInput(): string | undefined;
    /**
     * @stability stable
     */
    get dnsName(): string;
    private _dropInvalidHeaderFields?;
    /**
     * @stability stable
     */
    get dropInvalidHeaderFields(): boolean | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set dropInvalidHeaderFields(value: boolean | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetDropInvalidHeaderFields(): void;
    /**
     * @stability stable
     */
    get dropInvalidHeaderFieldsInput(): boolean | cdktf.IResolvable | undefined;
    private _enableCrossZoneLoadBalancing?;
    /**
     * @stability stable
     */
    get enableCrossZoneLoadBalancing(): boolean | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set enableCrossZoneLoadBalancing(value: boolean | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetEnableCrossZoneLoadBalancing(): void;
    /**
     * @stability stable
     */
    get enableCrossZoneLoadBalancingInput(): boolean | cdktf.IResolvable | undefined;
    private _enableDeletionProtection?;
    /**
     * @stability stable
     */
    get enableDeletionProtection(): boolean | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set enableDeletionProtection(value: boolean | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetEnableDeletionProtection(): void;
    /**
     * @stability stable
     */
    get enableDeletionProtectionInput(): boolean | cdktf.IResolvable | undefined;
    private _enableHttp2?;
    /**
     * @stability stable
     */
    get enableHttp2(): boolean | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set enableHttp2(value: boolean | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetEnableHttp2(): void;
    /**
     * @stability stable
     */
    get enableHttp2Input(): boolean | cdktf.IResolvable | undefined;
    private _enableWafFailOpen?;
    /**
     * @stability stable
     */
    get enableWafFailOpen(): boolean | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set enableWafFailOpen(value: boolean | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetEnableWafFailOpen(): void;
    /**
     * @stability stable
     */
    get enableWafFailOpenInput(): boolean | cdktf.IResolvable | undefined;
    /**
     * @stability stable
     */
    get id(): string;
    private _idleTimeout?;
    /**
     * @stability stable
     */
    get idleTimeout(): number;
    /**
     * @stability stable
     */
    set idleTimeout(value: number);
    /**
     * @stability stable
     */
    resetIdleTimeout(): void;
    /**
     * @stability stable
     */
    get idleTimeoutInput(): number | undefined;
    private _internal?;
    /**
     * @stability stable
     */
    get internal(): boolean | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set internal(value: boolean | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetInternal(): void;
    /**
     * @stability stable
     */
    get internalInput(): boolean | cdktf.IResolvable | undefined;
    private _ipAddressType?;
    /**
     * @stability stable
     */
    get ipAddressType(): string;
    /**
     * @stability stable
     */
    set ipAddressType(value: string);
    /**
     * @stability stable
     */
    resetIpAddressType(): void;
    /**
     * @stability stable
     */
    get ipAddressTypeInput(): string | undefined;
    private _loadBalancerType?;
    /**
     * @stability stable
     */
    get loadBalancerType(): string;
    /**
     * @stability stable
     */
    set loadBalancerType(value: string);
    /**
     * @stability stable
     */
    resetLoadBalancerType(): void;
    /**
     * @stability stable
     */
    get loadBalancerTypeInput(): string | undefined;
    private _name?;
    /**
     * @stability stable
     */
    get name(): string;
    /**
     * @stability stable
     */
    set name(value: string);
    /**
     * @stability stable
     */
    resetName(): void;
    /**
     * @stability stable
     */
    get nameInput(): string | undefined;
    private _namePrefix?;
    /**
     * @stability stable
     */
    get namePrefix(): string;
    /**
     * @stability stable
     */
    set namePrefix(value: string);
    /**
     * @stability stable
     */
    resetNamePrefix(): void;
    /**
     * @stability stable
     */
    get namePrefixInput(): string | undefined;
    private _securityGroups?;
    /**
     * @stability stable
     */
    get securityGroups(): string[];
    /**
     * @stability stable
     */
    set securityGroups(value: string[]);
    /**
     * @stability stable
     */
    resetSecurityGroups(): void;
    /**
     * @stability stable
     */
    get securityGroupsInput(): string[] | undefined;
    private _subnets?;
    /**
     * @stability stable
     */
    get subnets(): string[];
    /**
     * @stability stable
     */
    set subnets(value: string[]);
    /**
     * @stability stable
     */
    resetSubnets(): void;
    /**
     * @stability stable
     */
    get subnetsInput(): string[] | undefined;
    private _tags?;
    /**
     * @stability stable
     */
    get tags(): {
        [key: string]: string;
    };
    /**
     * @stability stable
     */
    set tags(value: {
        [key: string]: string;
    });
    /**
     * @stability stable
     */
    resetTags(): void;
    /**
     * @stability stable
     */
    get tagsInput(): {
        [key: string]: string;
    } | undefined;
    private _tagsAll?;
    /**
     * @stability stable
     */
    get tagsAll(): {
        [key: string]: string;
    };
    /**
     * @stability stable
     */
    set tagsAll(value: {
        [key: string]: string;
    });
    /**
     * @stability stable
     */
    resetTagsAll(): void;
    /**
     * @stability stable
     */
    get tagsAllInput(): {
        [key: string]: string;
    } | undefined;
    /**
     * @stability stable
     */
    get vpcId(): string;
    /**
     * @stability stable
     */
    get zoneId(): string;
    private _accessLogs;
    /**
     * @stability stable
     */
    get accessLogs(): LbAccessLogsOutputReference;
    /**
     * @stability stable
     */
    putAccessLogs(value: LbAccessLogs): void;
    /**
     * @stability stable
     */
    resetAccessLogs(): void;
    /**
     * @stability stable
     */
    get accessLogsInput(): LbAccessLogs | undefined;
    private _subnetMapping?;
    /**
     * @stability stable
     */
    get subnetMapping(): LbSubnetMapping[] | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set subnetMapping(value: LbSubnetMapping[] | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetSubnetMapping(): void;
    /**
     * @stability stable
     */
    get subnetMappingInput(): cdktf.IResolvable | LbSubnetMapping[] | undefined;
    private _timeouts;
    /**
     * @stability stable
     */
    get timeouts(): LbTimeoutsOutputReference;
    /**
     * @stability stable
     */
    putTimeouts(value: LbTimeouts): void;
    /**
     * @stability stable
     */
    resetTimeouts(): void;
    /**
     * @stability stable
     */
    get timeoutsInput(): LbTimeouts | undefined;
    /**
     * @stability stable
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
