import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
/**
 * AWS Elastic MapReduce.
 *
 * @stability stable
 */
export interface EmrStudioConfig extends cdktf.TerraformMetaArguments {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/emr_studio#auth_mode EmrStudio#auth_mode}.
     *
     * @stability stable
     */
    readonly authMode: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/emr_studio#default_s3_location EmrStudio#default_s3_location}.
     *
     * @stability stable
     */
    readonly defaultS3Location: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/emr_studio#description EmrStudio#description}.
     *
     * @stability stable
     */
    readonly description?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/emr_studio#engine_security_group_id EmrStudio#engine_security_group_id}.
     *
     * @stability stable
     */
    readonly engineSecurityGroupId: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/emr_studio#idp_auth_url EmrStudio#idp_auth_url}.
     *
     * @stability stable
     */
    readonly idpAuthUrl?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/emr_studio#idp_relay_state_parameter_name EmrStudio#idp_relay_state_parameter_name}.
     *
     * @stability stable
     */
    readonly idpRelayStateParameterName?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/emr_studio#name EmrStudio#name}.
     *
     * @stability stable
     */
    readonly name: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/emr_studio#service_role EmrStudio#service_role}.
     *
     * @stability stable
     */
    readonly serviceRole: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/emr_studio#subnet_ids EmrStudio#subnet_ids}.
     *
     * @stability stable
     */
    readonly subnetIds: string[];
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/emr_studio#tags EmrStudio#tags}.
     *
     * @stability stable
     */
    readonly tags?: {
        [key: string]: string;
    };
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/emr_studio#tags_all EmrStudio#tags_all}.
     *
     * @stability stable
     */
    readonly tagsAll?: {
        [key: string]: string;
    };
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/emr_studio#user_role EmrStudio#user_role}.
     *
     * @stability stable
     */
    readonly userRole?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/emr_studio#vpc_id EmrStudio#vpc_id}.
     *
     * @stability stable
     */
    readonly vpcId: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/emr_studio#workspace_security_group_id EmrStudio#workspace_security_group_id}.
     *
     * @stability stable
     */
    readonly workspaceSecurityGroupId: string;
}
/**
 * Represents a {@link https://www.terraform.io/docs/providers/aws/r/emr_studio aws_emr_studio}.
 *
 * @stability stable
 */
export declare class EmrStudio extends cdktf.TerraformResource {
    /**
     * @stability stable
     */
    static readonly tfResourceType: string;
    /**
     * Create a new {@link https://www.terraform.io/docs/providers/aws/r/emr_studio aws_emr_studio} Resource.
     *
     * @param scope The scope in which to define this construct.
     * @param id The scoped construct ID.
     * @stability stable
     */
    constructor(scope: Construct, id: string, config: EmrStudioConfig);
    /**
     * @stability stable
     */
    get arn(): string;
    private _authMode?;
    /**
     * @stability stable
     */
    get authMode(): string;
    /**
     * @stability stable
     */
    set authMode(value: string);
    /**
     * @stability stable
     */
    get authModeInput(): string | undefined;
    private _defaultS3Location?;
    /**
     * @stability stable
     */
    get defaultS3Location(): string;
    /**
     * @stability stable
     */
    set defaultS3Location(value: string);
    /**
     * @stability stable
     */
    get defaultS3LocationInput(): string | undefined;
    private _description?;
    /**
     * @stability stable
     */
    get description(): string;
    /**
     * @stability stable
     */
    set description(value: string);
    /**
     * @stability stable
     */
    resetDescription(): void;
    /**
     * @stability stable
     */
    get descriptionInput(): string | undefined;
    private _engineSecurityGroupId?;
    /**
     * @stability stable
     */
    get engineSecurityGroupId(): string;
    /**
     * @stability stable
     */
    set engineSecurityGroupId(value: string);
    /**
     * @stability stable
     */
    get engineSecurityGroupIdInput(): string | undefined;
    /**
     * @stability stable
     */
    get id(): string;
    private _idpAuthUrl?;
    /**
     * @stability stable
     */
    get idpAuthUrl(): string;
    /**
     * @stability stable
     */
    set idpAuthUrl(value: string);
    /**
     * @stability stable
     */
    resetIdpAuthUrl(): void;
    /**
     * @stability stable
     */
    get idpAuthUrlInput(): string | undefined;
    private _idpRelayStateParameterName?;
    /**
     * @stability stable
     */
    get idpRelayStateParameterName(): string;
    /**
     * @stability stable
     */
    set idpRelayStateParameterName(value: string);
    /**
     * @stability stable
     */
    resetIdpRelayStateParameterName(): void;
    /**
     * @stability stable
     */
    get idpRelayStateParameterNameInput(): string | undefined;
    private _name?;
    /**
     * @stability stable
     */
    get name(): string;
    /**
     * @stability stable
     */
    set name(value: string);
    /**
     * @stability stable
     */
    get nameInput(): string | undefined;
    private _serviceRole?;
    /**
     * @stability stable
     */
    get serviceRole(): string;
    /**
     * @stability stable
     */
    set serviceRole(value: string);
    /**
     * @stability stable
     */
    get serviceRoleInput(): string | undefined;
    private _subnetIds?;
    /**
     * @stability stable
     */
    get subnetIds(): string[];
    /**
     * @stability stable
     */
    set subnetIds(value: string[]);
    /**
     * @stability stable
     */
    get subnetIdsInput(): string[] | undefined;
    private _tags?;
    /**
     * @stability stable
     */
    get tags(): {
        [key: string]: string;
    };
    /**
     * @stability stable
     */
    set tags(value: {
        [key: string]: string;
    });
    /**
     * @stability stable
     */
    resetTags(): void;
    /**
     * @stability stable
     */
    get tagsInput(): {
        [key: string]: string;
    } | undefined;
    private _tagsAll?;
    /**
     * @stability stable
     */
    get tagsAll(): {
        [key: string]: string;
    };
    /**
     * @stability stable
     */
    set tagsAll(value: {
        [key: string]: string;
    });
    /**
     * @stability stable
     */
    resetTagsAll(): void;
    /**
     * @stability stable
     */
    get tagsAllInput(): {
        [key: string]: string;
    } | undefined;
    /**
     * @stability stable
     */
    get url(): string;
    private _userRole?;
    /**
     * @stability stable
     */
    get userRole(): string;
    /**
     * @stability stable
     */
    set userRole(value: string);
    /**
     * @stability stable
     */
    resetUserRole(): void;
    /**
     * @stability stable
     */
    get userRoleInput(): string | undefined;
    private _vpcId?;
    /**
     * @stability stable
     */
    get vpcId(): string;
    /**
     * @stability stable
     */
    set vpcId(value: string);
    /**
     * @stability stable
     */
    get vpcIdInput(): string | undefined;
    private _workspaceSecurityGroupId?;
    /**
     * @stability stable
     */
    get workspaceSecurityGroupId(): string;
    /**
     * @stability stable
     */
    set workspaceSecurityGroupId(value: string);
    /**
     * @stability stable
     */
    get workspaceSecurityGroupIdInput(): string | undefined;
    /**
     * @stability stable
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
