import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
/**
 * AWS File System FSx.
 *
 * @stability stable
 */
export interface FsxOpenzfsFileSystemConfig extends cdktf.TerraformMetaArguments {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/fsx_openzfs_file_system#automatic_backup_retention_days FsxOpenzfsFileSystem#automatic_backup_retention_days}.
     *
     * @stability stable
     */
    readonly automaticBackupRetentionDays?: number;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/fsx_openzfs_file_system#backup_id FsxOpenzfsFileSystem#backup_id}.
     *
     * @stability stable
     */
    readonly backupId?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/fsx_openzfs_file_system#copy_tags_to_backups FsxOpenzfsFileSystem#copy_tags_to_backups}.
     *
     * @stability stable
     */
    readonly copyTagsToBackups?: boolean | cdktf.IResolvable;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/fsx_openzfs_file_system#copy_tags_to_volumes FsxOpenzfsFileSystem#copy_tags_to_volumes}.
     *
     * @stability stable
     */
    readonly copyTagsToVolumes?: boolean | cdktf.IResolvable;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/fsx_openzfs_file_system#daily_automatic_backup_start_time FsxOpenzfsFileSystem#daily_automatic_backup_start_time}.
     *
     * @stability stable
     */
    readonly dailyAutomaticBackupStartTime?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/fsx_openzfs_file_system#deployment_type FsxOpenzfsFileSystem#deployment_type}.
     *
     * @stability stable
     */
    readonly deploymentType: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/fsx_openzfs_file_system#kms_key_id FsxOpenzfsFileSystem#kms_key_id}.
     *
     * @stability stable
     */
    readonly kmsKeyId?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/fsx_openzfs_file_system#security_group_ids FsxOpenzfsFileSystem#security_group_ids}.
     *
     * @stability stable
     */
    readonly securityGroupIds?: string[];
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/fsx_openzfs_file_system#storage_capacity FsxOpenzfsFileSystem#storage_capacity}.
     *
     * @stability stable
     */
    readonly storageCapacity?: number;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/fsx_openzfs_file_system#storage_type FsxOpenzfsFileSystem#storage_type}.
     *
     * @stability stable
     */
    readonly storageType?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/fsx_openzfs_file_system#subnet_ids FsxOpenzfsFileSystem#subnet_ids}.
     *
     * @stability stable
     */
    readonly subnetIds: string[];
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/fsx_openzfs_file_system#tags FsxOpenzfsFileSystem#tags}.
     *
     * @stability stable
     */
    readonly tags?: {
        [key: string]: string;
    };
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/fsx_openzfs_file_system#tags_all FsxOpenzfsFileSystem#tags_all}.
     *
     * @stability stable
     */
    readonly tagsAll?: {
        [key: string]: string;
    };
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/fsx_openzfs_file_system#throughput_capacity FsxOpenzfsFileSystem#throughput_capacity}.
     *
     * @stability stable
     */
    readonly throughputCapacity: number;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/fsx_openzfs_file_system#weekly_maintenance_start_time FsxOpenzfsFileSystem#weekly_maintenance_start_time}.
     *
     * @stability stable
     */
    readonly weeklyMaintenanceStartTime?: string;
    /**
     * disk_iops_configuration block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/fsx_openzfs_file_system#disk_iops_configuration FsxOpenzfsFileSystem#disk_iops_configuration}
     *
     * @stability stable
     */
    readonly diskIopsConfiguration?: FsxOpenzfsFileSystemDiskIopsConfiguration;
    /**
     * root_volume_configuration block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/fsx_openzfs_file_system#root_volume_configuration FsxOpenzfsFileSystem#root_volume_configuration}
     *
     * @stability stable
     */
    readonly rootVolumeConfiguration?: FsxOpenzfsFileSystemRootVolumeConfiguration;
    /**
     * timeouts block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/fsx_openzfs_file_system#timeouts FsxOpenzfsFileSystem#timeouts}
     *
     * @stability stable
     */
    readonly timeouts?: FsxOpenzfsFileSystemTimeouts;
}
/**
 * @stability stable
 */
export interface FsxOpenzfsFileSystemDiskIopsConfiguration {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/fsx_openzfs_file_system#iops FsxOpenzfsFileSystem#iops}.
     *
     * @stability stable
     */
    readonly iops?: number;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/fsx_openzfs_file_system#mode FsxOpenzfsFileSystem#mode}.
     *
     * @stability stable
     */
    readonly mode?: string;
}
export declare function fsxOpenzfsFileSystemDiskIopsConfigurationToTerraform(struct?: FsxOpenzfsFileSystemDiskIopsConfigurationOutputReference | FsxOpenzfsFileSystemDiskIopsConfiguration): any;
/**
 * @stability stable
 */
export declare class FsxOpenzfsFileSystemDiskIopsConfigurationOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): FsxOpenzfsFileSystemDiskIopsConfiguration | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: FsxOpenzfsFileSystemDiskIopsConfiguration | undefined);
    private _iops?;
    /**
     * @stability stable
     */
    get iops(): number;
    /**
     * @stability stable
     */
    set iops(value: number);
    /**
     * @stability stable
     */
    resetIops(): void;
    /**
     * @stability stable
     */
    get iopsInput(): number | undefined;
    private _mode?;
    /**
     * @stability stable
     */
    get mode(): string;
    /**
     * @stability stable
     */
    set mode(value: string);
    /**
     * @stability stable
     */
    resetMode(): void;
    /**
     * @stability stable
     */
    get modeInput(): string | undefined;
}
/**
 * @stability stable
 */
export interface FsxOpenzfsFileSystemRootVolumeConfigurationNfsExportsClientConfigurations {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/fsx_openzfs_file_system#clients FsxOpenzfsFileSystem#clients}.
     *
     * @stability stable
     */
    readonly clients: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/fsx_openzfs_file_system#options FsxOpenzfsFileSystem#options}.
     *
     * @stability stable
     */
    readonly options: string[];
}
export declare function fsxOpenzfsFileSystemRootVolumeConfigurationNfsExportsClientConfigurationsToTerraform(struct?: FsxOpenzfsFileSystemRootVolumeConfigurationNfsExportsClientConfigurations | cdktf.IResolvable): any;
/**
 * @stability stable
 */
export interface FsxOpenzfsFileSystemRootVolumeConfigurationNfsExports {
    /**
     * client_configurations block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/fsx_openzfs_file_system#client_configurations FsxOpenzfsFileSystem#client_configurations}
     *
     * @stability stable
     */
    readonly clientConfigurations: FsxOpenzfsFileSystemRootVolumeConfigurationNfsExportsClientConfigurations[] | cdktf.IResolvable;
}
export declare function fsxOpenzfsFileSystemRootVolumeConfigurationNfsExportsToTerraform(struct?: FsxOpenzfsFileSystemRootVolumeConfigurationNfsExportsOutputReference | FsxOpenzfsFileSystemRootVolumeConfigurationNfsExports): any;
/**
 * @stability stable
 */
export declare class FsxOpenzfsFileSystemRootVolumeConfigurationNfsExportsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): FsxOpenzfsFileSystemRootVolumeConfigurationNfsExports | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: FsxOpenzfsFileSystemRootVolumeConfigurationNfsExports | undefined);
    private _clientConfigurations?;
    /**
     * @stability stable
     */
    get clientConfigurations(): FsxOpenzfsFileSystemRootVolumeConfigurationNfsExportsClientConfigurations[] | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set clientConfigurations(value: FsxOpenzfsFileSystemRootVolumeConfigurationNfsExportsClientConfigurations[] | cdktf.IResolvable);
    /**
     * @stability stable
     */
    get clientConfigurationsInput(): cdktf.IResolvable | FsxOpenzfsFileSystemRootVolumeConfigurationNfsExportsClientConfigurations[] | undefined;
}
/**
 * @stability stable
 */
export interface FsxOpenzfsFileSystemRootVolumeConfigurationUserAndGroupQuotas {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/fsx_openzfs_file_system#id FsxOpenzfsFileSystem#id}.
     *
     * @stability stable
     */
    readonly id: number;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/fsx_openzfs_file_system#storage_capacity_quota_gib FsxOpenzfsFileSystem#storage_capacity_quota_gib}.
     *
     * @stability stable
     */
    readonly storageCapacityQuotaGib: number;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/fsx_openzfs_file_system#type FsxOpenzfsFileSystem#type}.
     *
     * @stability stable
     */
    readonly type: string;
}
export declare function fsxOpenzfsFileSystemRootVolumeConfigurationUserAndGroupQuotasToTerraform(struct?: FsxOpenzfsFileSystemRootVolumeConfigurationUserAndGroupQuotas | cdktf.IResolvable): any;
/**
 * @stability stable
 */
export interface FsxOpenzfsFileSystemRootVolumeConfiguration {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/fsx_openzfs_file_system#copy_tags_to_snapshots FsxOpenzfsFileSystem#copy_tags_to_snapshots}.
     *
     * @stability stable
     */
    readonly copyTagsToSnapshots?: boolean | cdktf.IResolvable;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/fsx_openzfs_file_system#data_compression_type FsxOpenzfsFileSystem#data_compression_type}.
     *
     * @stability stable
     */
    readonly dataCompressionType?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/fsx_openzfs_file_system#read_only FsxOpenzfsFileSystem#read_only}.
     *
     * @stability stable
     */
    readonly readOnly?: boolean | cdktf.IResolvable;
    /**
     * nfs_exports block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/fsx_openzfs_file_system#nfs_exports FsxOpenzfsFileSystem#nfs_exports}
     *
     * @stability stable
     */
    readonly nfsExports?: FsxOpenzfsFileSystemRootVolumeConfigurationNfsExports;
    /**
     * user_and_group_quotas block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/fsx_openzfs_file_system#user_and_group_quotas FsxOpenzfsFileSystem#user_and_group_quotas}
     *
     * @stability stable
     */
    readonly userAndGroupQuotas?: FsxOpenzfsFileSystemRootVolumeConfigurationUserAndGroupQuotas[] | cdktf.IResolvable;
}
export declare function fsxOpenzfsFileSystemRootVolumeConfigurationToTerraform(struct?: FsxOpenzfsFileSystemRootVolumeConfigurationOutputReference | FsxOpenzfsFileSystemRootVolumeConfiguration): any;
/**
 * @stability stable
 */
export declare class FsxOpenzfsFileSystemRootVolumeConfigurationOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): FsxOpenzfsFileSystemRootVolumeConfiguration | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: FsxOpenzfsFileSystemRootVolumeConfiguration | undefined);
    private _copyTagsToSnapshots?;
    /**
     * @stability stable
     */
    get copyTagsToSnapshots(): boolean | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set copyTagsToSnapshots(value: boolean | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetCopyTagsToSnapshots(): void;
    /**
     * @stability stable
     */
    get copyTagsToSnapshotsInput(): boolean | cdktf.IResolvable | undefined;
    private _dataCompressionType?;
    /**
     * @stability stable
     */
    get dataCompressionType(): string;
    /**
     * @stability stable
     */
    set dataCompressionType(value: string);
    /**
     * @stability stable
     */
    resetDataCompressionType(): void;
    /**
     * @stability stable
     */
    get dataCompressionTypeInput(): string | undefined;
    private _readOnly?;
    /**
     * @stability stable
     */
    get readOnly(): boolean | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set readOnly(value: boolean | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetReadOnly(): void;
    /**
     * @stability stable
     */
    get readOnlyInput(): boolean | cdktf.IResolvable | undefined;
    private _nfsExports;
    /**
     * @stability stable
     */
    get nfsExports(): FsxOpenzfsFileSystemRootVolumeConfigurationNfsExportsOutputReference;
    /**
     * @stability stable
     */
    putNfsExports(value: FsxOpenzfsFileSystemRootVolumeConfigurationNfsExports): void;
    /**
     * @stability stable
     */
    resetNfsExports(): void;
    /**
     * @stability stable
     */
    get nfsExportsInput(): FsxOpenzfsFileSystemRootVolumeConfigurationNfsExports | undefined;
    private _userAndGroupQuotas?;
    /**
     * @stability stable
     */
    get userAndGroupQuotas(): FsxOpenzfsFileSystemRootVolumeConfigurationUserAndGroupQuotas[] | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set userAndGroupQuotas(value: FsxOpenzfsFileSystemRootVolumeConfigurationUserAndGroupQuotas[] | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetUserAndGroupQuotas(): void;
    /**
     * @stability stable
     */
    get userAndGroupQuotasInput(): cdktf.IResolvable | FsxOpenzfsFileSystemRootVolumeConfigurationUserAndGroupQuotas[] | undefined;
}
/**
 * @stability stable
 */
export interface FsxOpenzfsFileSystemTimeouts {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/fsx_openzfs_file_system#create FsxOpenzfsFileSystem#create}.
     *
     * @stability stable
     */
    readonly create?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/fsx_openzfs_file_system#delete FsxOpenzfsFileSystem#delete}.
     *
     * @stability stable
     */
    readonly delete?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/fsx_openzfs_file_system#update FsxOpenzfsFileSystem#update}.
     *
     * @stability stable
     */
    readonly update?: string;
}
export declare function fsxOpenzfsFileSystemTimeoutsToTerraform(struct?: FsxOpenzfsFileSystemTimeoutsOutputReference | FsxOpenzfsFileSystemTimeouts | cdktf.IResolvable): any;
/**
 * @stability stable
 */
export declare class FsxOpenzfsFileSystemTimeoutsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): FsxOpenzfsFileSystemTimeouts | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: FsxOpenzfsFileSystemTimeouts | undefined);
    private _create?;
    /**
     * @stability stable
     */
    get create(): string;
    /**
     * @stability stable
     */
    set create(value: string);
    /**
     * @stability stable
     */
    resetCreate(): void;
    /**
     * @stability stable
     */
    get createInput(): string | undefined;
    private _delete?;
    /**
     * @stability stable
     */
    get delete(): string;
    /**
     * @stability stable
     */
    set delete(value: string);
    /**
     * @stability stable
     */
    resetDelete(): void;
    /**
     * @stability stable
     */
    get deleteInput(): string | undefined;
    private _update?;
    /**
     * @stability stable
     */
    get update(): string;
    /**
     * @stability stable
     */
    set update(value: string);
    /**
     * @stability stable
     */
    resetUpdate(): void;
    /**
     * @stability stable
     */
    get updateInput(): string | undefined;
}
/**
 * Represents a {@link https://www.terraform.io/docs/providers/aws/r/fsx_openzfs_file_system aws_fsx_openzfs_file_system}.
 *
 * @stability stable
 */
export declare class FsxOpenzfsFileSystem extends cdktf.TerraformResource {
    /**
     * @stability stable
     */
    static readonly tfResourceType: string;
    /**
     * Create a new {@link https://www.terraform.io/docs/providers/aws/r/fsx_openzfs_file_system aws_fsx_openzfs_file_system} Resource.
     *
     * @param scope The scope in which to define this construct.
     * @param id The scoped construct ID.
     * @stability stable
     */
    constructor(scope: Construct, id: string, config: FsxOpenzfsFileSystemConfig);
    /**
     * @stability stable
     */
    get arn(): string;
    private _automaticBackupRetentionDays?;
    /**
     * @stability stable
     */
    get automaticBackupRetentionDays(): number;
    /**
     * @stability stable
     */
    set automaticBackupRetentionDays(value: number);
    /**
     * @stability stable
     */
    resetAutomaticBackupRetentionDays(): void;
    /**
     * @stability stable
     */
    get automaticBackupRetentionDaysInput(): number | undefined;
    private _backupId?;
    /**
     * @stability stable
     */
    get backupId(): string;
    /**
     * @stability stable
     */
    set backupId(value: string);
    /**
     * @stability stable
     */
    resetBackupId(): void;
    /**
     * @stability stable
     */
    get backupIdInput(): string | undefined;
    private _copyTagsToBackups?;
    /**
     * @stability stable
     */
    get copyTagsToBackups(): boolean | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set copyTagsToBackups(value: boolean | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetCopyTagsToBackups(): void;
    /**
     * @stability stable
     */
    get copyTagsToBackupsInput(): boolean | cdktf.IResolvable | undefined;
    private _copyTagsToVolumes?;
    /**
     * @stability stable
     */
    get copyTagsToVolumes(): boolean | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set copyTagsToVolumes(value: boolean | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetCopyTagsToVolumes(): void;
    /**
     * @stability stable
     */
    get copyTagsToVolumesInput(): boolean | cdktf.IResolvable | undefined;
    private _dailyAutomaticBackupStartTime?;
    /**
     * @stability stable
     */
    get dailyAutomaticBackupStartTime(): string;
    /**
     * @stability stable
     */
    set dailyAutomaticBackupStartTime(value: string);
    /**
     * @stability stable
     */
    resetDailyAutomaticBackupStartTime(): void;
    /**
     * @stability stable
     */
    get dailyAutomaticBackupStartTimeInput(): string | undefined;
    private _deploymentType?;
    /**
     * @stability stable
     */
    get deploymentType(): string;
    /**
     * @stability stable
     */
    set deploymentType(value: string);
    /**
     * @stability stable
     */
    get deploymentTypeInput(): string | undefined;
    /**
     * @stability stable
     */
    get dnsName(): string;
    /**
     * @stability stable
     */
    get id(): string;
    private _kmsKeyId?;
    /**
     * @stability stable
     */
    get kmsKeyId(): string;
    /**
     * @stability stable
     */
    set kmsKeyId(value: string);
    /**
     * @stability stable
     */
    resetKmsKeyId(): void;
    /**
     * @stability stable
     */
    get kmsKeyIdInput(): string | undefined;
    /**
     * @stability stable
     */
    get networkInterfaceIds(): string[];
    /**
     * @stability stable
     */
    get ownerId(): string;
    /**
     * @stability stable
     */
    get rootVolumeId(): string;
    private _securityGroupIds?;
    /**
     * @stability stable
     */
    get securityGroupIds(): string[];
    /**
     * @stability stable
     */
    set securityGroupIds(value: string[]);
    /**
     * @stability stable
     */
    resetSecurityGroupIds(): void;
    /**
     * @stability stable
     */
    get securityGroupIdsInput(): string[] | undefined;
    private _storageCapacity?;
    /**
     * @stability stable
     */
    get storageCapacity(): number;
    /**
     * @stability stable
     */
    set storageCapacity(value: number);
    /**
     * @stability stable
     */
    resetStorageCapacity(): void;
    /**
     * @stability stable
     */
    get storageCapacityInput(): number | undefined;
    private _storageType?;
    /**
     * @stability stable
     */
    get storageType(): string;
    /**
     * @stability stable
     */
    set storageType(value: string);
    /**
     * @stability stable
     */
    resetStorageType(): void;
    /**
     * @stability stable
     */
    get storageTypeInput(): string | undefined;
    private _subnetIds?;
    /**
     * @stability stable
     */
    get subnetIds(): string[];
    /**
     * @stability stable
     */
    set subnetIds(value: string[]);
    /**
     * @stability stable
     */
    get subnetIdsInput(): string[] | undefined;
    private _tags?;
    /**
     * @stability stable
     */
    get tags(): {
        [key: string]: string;
    };
    /**
     * @stability stable
     */
    set tags(value: {
        [key: string]: string;
    });
    /**
     * @stability stable
     */
    resetTags(): void;
    /**
     * @stability stable
     */
    get tagsInput(): {
        [key: string]: string;
    } | undefined;
    private _tagsAll?;
    /**
     * @stability stable
     */
    get tagsAll(): {
        [key: string]: string;
    };
    /**
     * @stability stable
     */
    set tagsAll(value: {
        [key: string]: string;
    });
    /**
     * @stability stable
     */
    resetTagsAll(): void;
    /**
     * @stability stable
     */
    get tagsAllInput(): {
        [key: string]: string;
    } | undefined;
    private _throughputCapacity?;
    /**
     * @stability stable
     */
    get throughputCapacity(): number;
    /**
     * @stability stable
     */
    set throughputCapacity(value: number);
    /**
     * @stability stable
     */
    get throughputCapacityInput(): number | undefined;
    /**
     * @stability stable
     */
    get vpcId(): string;
    private _weeklyMaintenanceStartTime?;
    /**
     * @stability stable
     */
    get weeklyMaintenanceStartTime(): string;
    /**
     * @stability stable
     */
    set weeklyMaintenanceStartTime(value: string);
    /**
     * @stability stable
     */
    resetWeeklyMaintenanceStartTime(): void;
    /**
     * @stability stable
     */
    get weeklyMaintenanceStartTimeInput(): string | undefined;
    private _diskIopsConfiguration;
    /**
     * @stability stable
     */
    get diskIopsConfiguration(): FsxOpenzfsFileSystemDiskIopsConfigurationOutputReference;
    /**
     * @stability stable
     */
    putDiskIopsConfiguration(value: FsxOpenzfsFileSystemDiskIopsConfiguration): void;
    /**
     * @stability stable
     */
    resetDiskIopsConfiguration(): void;
    /**
     * @stability stable
     */
    get diskIopsConfigurationInput(): FsxOpenzfsFileSystemDiskIopsConfiguration | undefined;
    private _rootVolumeConfiguration;
    /**
     * @stability stable
     */
    get rootVolumeConfiguration(): FsxOpenzfsFileSystemRootVolumeConfigurationOutputReference;
    /**
     * @stability stable
     */
    putRootVolumeConfiguration(value: FsxOpenzfsFileSystemRootVolumeConfiguration): void;
    /**
     * @stability stable
     */
    resetRootVolumeConfiguration(): void;
    /**
     * @stability stable
     */
    get rootVolumeConfigurationInput(): FsxOpenzfsFileSystemRootVolumeConfiguration | undefined;
    private _timeouts;
    /**
     * @stability stable
     */
    get timeouts(): FsxOpenzfsFileSystemTimeoutsOutputReference;
    /**
     * @stability stable
     */
    putTimeouts(value: FsxOpenzfsFileSystemTimeouts): void;
    /**
     * @stability stable
     */
    resetTimeouts(): void;
    /**
     * @stability stable
     */
    get timeoutsInput(): FsxOpenzfsFileSystemTimeouts | undefined;
    /**
     * @stability stable
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
