import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
/**
 * AWS Glue.
 *
 * @stability stable
 */
export interface GlueJobConfig extends cdktf.TerraformMetaArguments {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_job#connections GlueJob#connections}.
     *
     * @stability stable
     */
    readonly connections?: string[];
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_job#default_arguments GlueJob#default_arguments}.
     *
     * @stability stable
     */
    readonly defaultArguments?: {
        [key: string]: string;
    };
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_job#description GlueJob#description}.
     *
     * @stability stable
     */
    readonly description?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_job#glue_version GlueJob#glue_version}.
     *
     * @stability stable
     */
    readonly glueVersion?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_job#max_capacity GlueJob#max_capacity}.
     *
     * @stability stable
     */
    readonly maxCapacity?: number;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_job#max_retries GlueJob#max_retries}.
     *
     * @stability stable
     */
    readonly maxRetries?: number;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_job#name GlueJob#name}.
     *
     * @stability stable
     */
    readonly name: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_job#non_overridable_arguments GlueJob#non_overridable_arguments}.
     *
     * @stability stable
     */
    readonly nonOverridableArguments?: {
        [key: string]: string;
    };
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_job#number_of_workers GlueJob#number_of_workers}.
     *
     * @stability stable
     */
    readonly numberOfWorkers?: number;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_job#role_arn GlueJob#role_arn}.
     *
     * @stability stable
     */
    readonly roleArn: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_job#security_configuration GlueJob#security_configuration}.
     *
     * @stability stable
     */
    readonly securityConfiguration?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_job#tags GlueJob#tags}.
     *
     * @stability stable
     */
    readonly tags?: {
        [key: string]: string;
    };
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_job#tags_all GlueJob#tags_all}.
     *
     * @stability stable
     */
    readonly tagsAll?: {
        [key: string]: string;
    };
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_job#timeout GlueJob#timeout}.
     *
     * @stability stable
     */
    readonly timeout?: number;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_job#worker_type GlueJob#worker_type}.
     *
     * @stability stable
     */
    readonly workerType?: string;
    /**
     * command block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_job#command GlueJob#command}
     *
     * @stability stable
     */
    readonly command: GlueJobCommand;
    /**
     * execution_property block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_job#execution_property GlueJob#execution_property}
     *
     * @stability stable
     */
    readonly executionProperty?: GlueJobExecutionProperty;
    /**
     * notification_property block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_job#notification_property GlueJob#notification_property}
     *
     * @stability stable
     */
    readonly notificationProperty?: GlueJobNotificationProperty;
}
/**
 * @stability stable
 */
export interface GlueJobCommand {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_job#name GlueJob#name}.
     *
     * @stability stable
     */
    readonly name?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_job#python_version GlueJob#python_version}.
     *
     * @stability stable
     */
    readonly pythonVersion?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_job#script_location GlueJob#script_location}.
     *
     * @stability stable
     */
    readonly scriptLocation: string;
}
export declare function glueJobCommandToTerraform(struct?: GlueJobCommandOutputReference | GlueJobCommand): any;
/**
 * @stability stable
 */
export declare class GlueJobCommandOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): GlueJobCommand | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: GlueJobCommand | undefined);
    private _name?;
    /**
     * @stability stable
     */
    get name(): string;
    /**
     * @stability stable
     */
    set name(value: string);
    /**
     * @stability stable
     */
    resetName(): void;
    /**
     * @stability stable
     */
    get nameInput(): string | undefined;
    private _pythonVersion?;
    /**
     * @stability stable
     */
    get pythonVersion(): string;
    /**
     * @stability stable
     */
    set pythonVersion(value: string);
    /**
     * @stability stable
     */
    resetPythonVersion(): void;
    /**
     * @stability stable
     */
    get pythonVersionInput(): string | undefined;
    private _scriptLocation?;
    /**
     * @stability stable
     */
    get scriptLocation(): string;
    /**
     * @stability stable
     */
    set scriptLocation(value: string);
    /**
     * @stability stable
     */
    get scriptLocationInput(): string | undefined;
}
/**
 * @stability stable
 */
export interface GlueJobExecutionProperty {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_job#max_concurrent_runs GlueJob#max_concurrent_runs}.
     *
     * @stability stable
     */
    readonly maxConcurrentRuns?: number;
}
export declare function glueJobExecutionPropertyToTerraform(struct?: GlueJobExecutionPropertyOutputReference | GlueJobExecutionProperty): any;
/**
 * @stability stable
 */
export declare class GlueJobExecutionPropertyOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): GlueJobExecutionProperty | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: GlueJobExecutionProperty | undefined);
    private _maxConcurrentRuns?;
    /**
     * @stability stable
     */
    get maxConcurrentRuns(): number;
    /**
     * @stability stable
     */
    set maxConcurrentRuns(value: number);
    /**
     * @stability stable
     */
    resetMaxConcurrentRuns(): void;
    /**
     * @stability stable
     */
    get maxConcurrentRunsInput(): number | undefined;
}
/**
 * @stability stable
 */
export interface GlueJobNotificationProperty {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_job#notify_delay_after GlueJob#notify_delay_after}.
     *
     * @stability stable
     */
    readonly notifyDelayAfter?: number;
}
export declare function glueJobNotificationPropertyToTerraform(struct?: GlueJobNotificationPropertyOutputReference | GlueJobNotificationProperty): any;
/**
 * @stability stable
 */
export declare class GlueJobNotificationPropertyOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): GlueJobNotificationProperty | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: GlueJobNotificationProperty | undefined);
    private _notifyDelayAfter?;
    /**
     * @stability stable
     */
    get notifyDelayAfter(): number;
    /**
     * @stability stable
     */
    set notifyDelayAfter(value: number);
    /**
     * @stability stable
     */
    resetNotifyDelayAfter(): void;
    /**
     * @stability stable
     */
    get notifyDelayAfterInput(): number | undefined;
}
/**
 * Represents a {@link https://www.terraform.io/docs/providers/aws/r/glue_job aws_glue_job}.
 *
 * @stability stable
 */
export declare class GlueJob extends cdktf.TerraformResource {
    /**
     * @stability stable
     */
    static readonly tfResourceType: string;
    /**
     * Create a new {@link https://www.terraform.io/docs/providers/aws/r/glue_job aws_glue_job} Resource.
     *
     * @param scope The scope in which to define this construct.
     * @param id The scoped construct ID.
     * @stability stable
     */
    constructor(scope: Construct, id: string, config: GlueJobConfig);
    /**
     * @stability stable
     */
    get arn(): string;
    private _connections?;
    /**
     * @stability stable
     */
    get connections(): string[];
    /**
     * @stability stable
     */
    set connections(value: string[]);
    /**
     * @stability stable
     */
    resetConnections(): void;
    /**
     * @stability stable
     */
    get connectionsInput(): string[] | undefined;
    private _defaultArguments?;
    /**
     * @stability stable
     */
    get defaultArguments(): {
        [key: string]: string;
    };
    /**
     * @stability stable
     */
    set defaultArguments(value: {
        [key: string]: string;
    });
    /**
     * @stability stable
     */
    resetDefaultArguments(): void;
    /**
     * @stability stable
     */
    get defaultArgumentsInput(): {
        [key: string]: string;
    } | undefined;
    private _description?;
    /**
     * @stability stable
     */
    get description(): string;
    /**
     * @stability stable
     */
    set description(value: string);
    /**
     * @stability stable
     */
    resetDescription(): void;
    /**
     * @stability stable
     */
    get descriptionInput(): string | undefined;
    private _glueVersion?;
    /**
     * @stability stable
     */
    get glueVersion(): string;
    /**
     * @stability stable
     */
    set glueVersion(value: string);
    /**
     * @stability stable
     */
    resetGlueVersion(): void;
    /**
     * @stability stable
     */
    get glueVersionInput(): string | undefined;
    /**
     * @stability stable
     */
    get id(): string;
    private _maxCapacity?;
    /**
     * @stability stable
     */
    get maxCapacity(): number;
    /**
     * @stability stable
     */
    set maxCapacity(value: number);
    /**
     * @stability stable
     */
    resetMaxCapacity(): void;
    /**
     * @stability stable
     */
    get maxCapacityInput(): number | undefined;
    private _maxRetries?;
    /**
     * @stability stable
     */
    get maxRetries(): number;
    /**
     * @stability stable
     */
    set maxRetries(value: number);
    /**
     * @stability stable
     */
    resetMaxRetries(): void;
    /**
     * @stability stable
     */
    get maxRetriesInput(): number | undefined;
    private _name?;
    /**
     * @stability stable
     */
    get name(): string;
    /**
     * @stability stable
     */
    set name(value: string);
    /**
     * @stability stable
     */
    get nameInput(): string | undefined;
    private _nonOverridableArguments?;
    /**
     * @stability stable
     */
    get nonOverridableArguments(): {
        [key: string]: string;
    };
    /**
     * @stability stable
     */
    set nonOverridableArguments(value: {
        [key: string]: string;
    });
    /**
     * @stability stable
     */
    resetNonOverridableArguments(): void;
    /**
     * @stability stable
     */
    get nonOverridableArgumentsInput(): {
        [key: string]: string;
    } | undefined;
    private _numberOfWorkers?;
    /**
     * @stability stable
     */
    get numberOfWorkers(): number;
    /**
     * @stability stable
     */
    set numberOfWorkers(value: number);
    /**
     * @stability stable
     */
    resetNumberOfWorkers(): void;
    /**
     * @stability stable
     */
    get numberOfWorkersInput(): number | undefined;
    private _roleArn?;
    /**
     * @stability stable
     */
    get roleArn(): string;
    /**
     * @stability stable
     */
    set roleArn(value: string);
    /**
     * @stability stable
     */
    get roleArnInput(): string | undefined;
    private _securityConfiguration?;
    /**
     * @stability stable
     */
    get securityConfiguration(): string;
    /**
     * @stability stable
     */
    set securityConfiguration(value: string);
    /**
     * @stability stable
     */
    resetSecurityConfiguration(): void;
    /**
     * @stability stable
     */
    get securityConfigurationInput(): string | undefined;
    private _tags?;
    /**
     * @stability stable
     */
    get tags(): {
        [key: string]: string;
    };
    /**
     * @stability stable
     */
    set tags(value: {
        [key: string]: string;
    });
    /**
     * @stability stable
     */
    resetTags(): void;
    /**
     * @stability stable
     */
    get tagsInput(): {
        [key: string]: string;
    } | undefined;
    private _tagsAll?;
    /**
     * @stability stable
     */
    get tagsAll(): {
        [key: string]: string;
    };
    /**
     * @stability stable
     */
    set tagsAll(value: {
        [key: string]: string;
    });
    /**
     * @stability stable
     */
    resetTagsAll(): void;
    /**
     * @stability stable
     */
    get tagsAllInput(): {
        [key: string]: string;
    } | undefined;
    private _timeout?;
    /**
     * @stability stable
     */
    get timeout(): number;
    /**
     * @stability stable
     */
    set timeout(value: number);
    /**
     * @stability stable
     */
    resetTimeout(): void;
    /**
     * @stability stable
     */
    get timeoutInput(): number | undefined;
    private _workerType?;
    /**
     * @stability stable
     */
    get workerType(): string;
    /**
     * @stability stable
     */
    set workerType(value: string);
    /**
     * @stability stable
     */
    resetWorkerType(): void;
    /**
     * @stability stable
     */
    get workerTypeInput(): string | undefined;
    private _command;
    /**
     * @stability stable
     */
    get command(): GlueJobCommandOutputReference;
    /**
     * @stability stable
     */
    putCommand(value: GlueJobCommand): void;
    /**
     * @stability stable
     */
    get commandInput(): GlueJobCommand | undefined;
    private _executionProperty;
    /**
     * @stability stable
     */
    get executionProperty(): GlueJobExecutionPropertyOutputReference;
    /**
     * @stability stable
     */
    putExecutionProperty(value: GlueJobExecutionProperty): void;
    /**
     * @stability stable
     */
    resetExecutionProperty(): void;
    /**
     * @stability stable
     */
    get executionPropertyInput(): GlueJobExecutionProperty | undefined;
    private _notificationProperty;
    /**
     * @stability stable
     */
    get notificationProperty(): GlueJobNotificationPropertyOutputReference;
    /**
     * @stability stable
     */
    putNotificationProperty(value: GlueJobNotificationProperty): void;
    /**
     * @stability stable
     */
    resetNotificationProperty(): void;
    /**
     * @stability stable
     */
    get notificationPropertyInput(): GlueJobNotificationProperty | undefined;
    /**
     * @stability stable
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
