import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
/**
 * AWS Glue.
 *
 * @stability stable
 */
export interface GluePartitionConfig extends cdktf.TerraformMetaArguments {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_partition#catalog_id GluePartition#catalog_id}.
     *
     * @stability stable
     */
    readonly catalogId?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_partition#database_name GluePartition#database_name}.
     *
     * @stability stable
     */
    readonly databaseName: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_partition#parameters GluePartition#parameters}.
     *
     * @stability stable
     */
    readonly parameters?: {
        [key: string]: string;
    };
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_partition#partition_values GluePartition#partition_values}.
     *
     * @stability stable
     */
    readonly partitionValues: string[];
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_partition#table_name GluePartition#table_name}.
     *
     * @stability stable
     */
    readonly tableName: string;
    /**
     * storage_descriptor block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_partition#storage_descriptor GluePartition#storage_descriptor}
     *
     * @stability stable
     */
    readonly storageDescriptor?: GluePartitionStorageDescriptor;
}
/**
 * @stability stable
 */
export interface GluePartitionStorageDescriptorColumns {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_partition#comment GluePartition#comment}.
     *
     * @stability stable
     */
    readonly comment?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_partition#name GluePartition#name}.
     *
     * @stability stable
     */
    readonly name: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_partition#type GluePartition#type}.
     *
     * @stability stable
     */
    readonly type?: string;
}
export declare function gluePartitionStorageDescriptorColumnsToTerraform(struct?: GluePartitionStorageDescriptorColumns | cdktf.IResolvable): any;
/**
 * @stability stable
 */
export interface GluePartitionStorageDescriptorSerDeInfo {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_partition#name GluePartition#name}.
     *
     * @stability stable
     */
    readonly name?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_partition#parameters GluePartition#parameters}.
     *
     * @stability stable
     */
    readonly parameters?: {
        [key: string]: string;
    };
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_partition#serialization_library GluePartition#serialization_library}.
     *
     * @stability stable
     */
    readonly serializationLibrary?: string;
}
export declare function gluePartitionStorageDescriptorSerDeInfoToTerraform(struct?: GluePartitionStorageDescriptorSerDeInfoOutputReference | GluePartitionStorageDescriptorSerDeInfo): any;
/**
 * @stability stable
 */
export declare class GluePartitionStorageDescriptorSerDeInfoOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): GluePartitionStorageDescriptorSerDeInfo | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: GluePartitionStorageDescriptorSerDeInfo | undefined);
    private _name?;
    /**
     * @stability stable
     */
    get name(): string;
    /**
     * @stability stable
     */
    set name(value: string);
    /**
     * @stability stable
     */
    resetName(): void;
    /**
     * @stability stable
     */
    get nameInput(): string | undefined;
    private _parameters?;
    /**
     * @stability stable
     */
    get parameters(): {
        [key: string]: string;
    };
    /**
     * @stability stable
     */
    set parameters(value: {
        [key: string]: string;
    });
    /**
     * @stability stable
     */
    resetParameters(): void;
    /**
     * @stability stable
     */
    get parametersInput(): {
        [key: string]: string;
    } | undefined;
    private _serializationLibrary?;
    /**
     * @stability stable
     */
    get serializationLibrary(): string;
    /**
     * @stability stable
     */
    set serializationLibrary(value: string);
    /**
     * @stability stable
     */
    resetSerializationLibrary(): void;
    /**
     * @stability stable
     */
    get serializationLibraryInput(): string | undefined;
}
/**
 * @stability stable
 */
export interface GluePartitionStorageDescriptorSkewedInfo {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_partition#skewed_column_names GluePartition#skewed_column_names}.
     *
     * @stability stable
     */
    readonly skewedColumnNames?: string[];
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_partition#skewed_column_value_location_maps GluePartition#skewed_column_value_location_maps}.
     *
     * @stability stable
     */
    readonly skewedColumnValueLocationMaps?: {
        [key: string]: string;
    };
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_partition#skewed_column_values GluePartition#skewed_column_values}.
     *
     * @stability stable
     */
    readonly skewedColumnValues?: string[];
}
export declare function gluePartitionStorageDescriptorSkewedInfoToTerraform(struct?: GluePartitionStorageDescriptorSkewedInfoOutputReference | GluePartitionStorageDescriptorSkewedInfo): any;
/**
 * @stability stable
 */
export declare class GluePartitionStorageDescriptorSkewedInfoOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): GluePartitionStorageDescriptorSkewedInfo | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: GluePartitionStorageDescriptorSkewedInfo | undefined);
    private _skewedColumnNames?;
    /**
     * @stability stable
     */
    get skewedColumnNames(): string[];
    /**
     * @stability stable
     */
    set skewedColumnNames(value: string[]);
    /**
     * @stability stable
     */
    resetSkewedColumnNames(): void;
    /**
     * @stability stable
     */
    get skewedColumnNamesInput(): string[] | undefined;
    private _skewedColumnValueLocationMaps?;
    /**
     * @stability stable
     */
    get skewedColumnValueLocationMaps(): {
        [key: string]: string;
    };
    /**
     * @stability stable
     */
    set skewedColumnValueLocationMaps(value: {
        [key: string]: string;
    });
    /**
     * @stability stable
     */
    resetSkewedColumnValueLocationMaps(): void;
    /**
     * @stability stable
     */
    get skewedColumnValueLocationMapsInput(): {
        [key: string]: string;
    } | undefined;
    private _skewedColumnValues?;
    /**
     * @stability stable
     */
    get skewedColumnValues(): string[];
    /**
     * @stability stable
     */
    set skewedColumnValues(value: string[]);
    /**
     * @stability stable
     */
    resetSkewedColumnValues(): void;
    /**
     * @stability stable
     */
    get skewedColumnValuesInput(): string[] | undefined;
}
/**
 * @stability stable
 */
export interface GluePartitionStorageDescriptorSortColumns {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_partition#column GluePartition#column}.
     *
     * @stability stable
     */
    readonly column: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_partition#sort_order GluePartition#sort_order}.
     *
     * @stability stable
     */
    readonly sortOrder: number;
}
export declare function gluePartitionStorageDescriptorSortColumnsToTerraform(struct?: GluePartitionStorageDescriptorSortColumns | cdktf.IResolvable): any;
/**
 * @stability stable
 */
export interface GluePartitionStorageDescriptor {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_partition#bucket_columns GluePartition#bucket_columns}.
     *
     * @stability stable
     */
    readonly bucketColumns?: string[];
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_partition#compressed GluePartition#compressed}.
     *
     * @stability stable
     */
    readonly compressed?: boolean | cdktf.IResolvable;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_partition#input_format GluePartition#input_format}.
     *
     * @stability stable
     */
    readonly inputFormat?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_partition#location GluePartition#location}.
     *
     * @stability stable
     */
    readonly location?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_partition#number_of_buckets GluePartition#number_of_buckets}.
     *
     * @stability stable
     */
    readonly numberOfBuckets?: number;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_partition#output_format GluePartition#output_format}.
     *
     * @stability stable
     */
    readonly outputFormat?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_partition#parameters GluePartition#parameters}.
     *
     * @stability stable
     */
    readonly parameters?: {
        [key: string]: string;
    };
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_partition#stored_as_sub_directories GluePartition#stored_as_sub_directories}.
     *
     * @stability stable
     */
    readonly storedAsSubDirectories?: boolean | cdktf.IResolvable;
    /**
     * columns block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_partition#columns GluePartition#columns}
     *
     * @stability stable
     */
    readonly columns?: GluePartitionStorageDescriptorColumns[] | cdktf.IResolvable;
    /**
     * ser_de_info block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_partition#ser_de_info GluePartition#ser_de_info}
     *
     * @stability stable
     */
    readonly serDeInfo?: GluePartitionStorageDescriptorSerDeInfo;
    /**
     * skewed_info block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_partition#skewed_info GluePartition#skewed_info}
     *
     * @stability stable
     */
    readonly skewedInfo?: GluePartitionStorageDescriptorSkewedInfo;
    /**
     * sort_columns block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_partition#sort_columns GluePartition#sort_columns}
     *
     * @stability stable
     */
    readonly sortColumns?: GluePartitionStorageDescriptorSortColumns[] | cdktf.IResolvable;
}
export declare function gluePartitionStorageDescriptorToTerraform(struct?: GluePartitionStorageDescriptorOutputReference | GluePartitionStorageDescriptor): any;
/**
 * @stability stable
 */
export declare class GluePartitionStorageDescriptorOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): GluePartitionStorageDescriptor | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: GluePartitionStorageDescriptor | undefined);
    private _bucketColumns?;
    /**
     * @stability stable
     */
    get bucketColumns(): string[];
    /**
     * @stability stable
     */
    set bucketColumns(value: string[]);
    /**
     * @stability stable
     */
    resetBucketColumns(): void;
    /**
     * @stability stable
     */
    get bucketColumnsInput(): string[] | undefined;
    private _compressed?;
    /**
     * @stability stable
     */
    get compressed(): boolean | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set compressed(value: boolean | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetCompressed(): void;
    /**
     * @stability stable
     */
    get compressedInput(): boolean | cdktf.IResolvable | undefined;
    private _inputFormat?;
    /**
     * @stability stable
     */
    get inputFormat(): string;
    /**
     * @stability stable
     */
    set inputFormat(value: string);
    /**
     * @stability stable
     */
    resetInputFormat(): void;
    /**
     * @stability stable
     */
    get inputFormatInput(): string | undefined;
    private _location?;
    /**
     * @stability stable
     */
    get location(): string;
    /**
     * @stability stable
     */
    set location(value: string);
    /**
     * @stability stable
     */
    resetLocation(): void;
    /**
     * @stability stable
     */
    get locationInput(): string | undefined;
    private _numberOfBuckets?;
    /**
     * @stability stable
     */
    get numberOfBuckets(): number;
    /**
     * @stability stable
     */
    set numberOfBuckets(value: number);
    /**
     * @stability stable
     */
    resetNumberOfBuckets(): void;
    /**
     * @stability stable
     */
    get numberOfBucketsInput(): number | undefined;
    private _outputFormat?;
    /**
     * @stability stable
     */
    get outputFormat(): string;
    /**
     * @stability stable
     */
    set outputFormat(value: string);
    /**
     * @stability stable
     */
    resetOutputFormat(): void;
    /**
     * @stability stable
     */
    get outputFormatInput(): string | undefined;
    private _parameters?;
    /**
     * @stability stable
     */
    get parameters(): {
        [key: string]: string;
    };
    /**
     * @stability stable
     */
    set parameters(value: {
        [key: string]: string;
    });
    /**
     * @stability stable
     */
    resetParameters(): void;
    /**
     * @stability stable
     */
    get parametersInput(): {
        [key: string]: string;
    } | undefined;
    private _storedAsSubDirectories?;
    /**
     * @stability stable
     */
    get storedAsSubDirectories(): boolean | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set storedAsSubDirectories(value: boolean | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetStoredAsSubDirectories(): void;
    /**
     * @stability stable
     */
    get storedAsSubDirectoriesInput(): boolean | cdktf.IResolvable | undefined;
    private _columns?;
    /**
     * @stability stable
     */
    get columns(): GluePartitionStorageDescriptorColumns[] | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set columns(value: GluePartitionStorageDescriptorColumns[] | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetColumns(): void;
    /**
     * @stability stable
     */
    get columnsInput(): cdktf.IResolvable | GluePartitionStorageDescriptorColumns[] | undefined;
    private _serDeInfo;
    /**
     * @stability stable
     */
    get serDeInfo(): GluePartitionStorageDescriptorSerDeInfoOutputReference;
    /**
     * @stability stable
     */
    putSerDeInfo(value: GluePartitionStorageDescriptorSerDeInfo): void;
    /**
     * @stability stable
     */
    resetSerDeInfo(): void;
    /**
     * @stability stable
     */
    get serDeInfoInput(): GluePartitionStorageDescriptorSerDeInfo | undefined;
    private _skewedInfo;
    /**
     * @stability stable
     */
    get skewedInfo(): GluePartitionStorageDescriptorSkewedInfoOutputReference;
    /**
     * @stability stable
     */
    putSkewedInfo(value: GluePartitionStorageDescriptorSkewedInfo): void;
    /**
     * @stability stable
     */
    resetSkewedInfo(): void;
    /**
     * @stability stable
     */
    get skewedInfoInput(): GluePartitionStorageDescriptorSkewedInfo | undefined;
    private _sortColumns?;
    /**
     * @stability stable
     */
    get sortColumns(): GluePartitionStorageDescriptorSortColumns[] | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set sortColumns(value: GluePartitionStorageDescriptorSortColumns[] | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetSortColumns(): void;
    /**
     * @stability stable
     */
    get sortColumnsInput(): cdktf.IResolvable | GluePartitionStorageDescriptorSortColumns[] | undefined;
}
/**
 * Represents a {@link https://www.terraform.io/docs/providers/aws/r/glue_partition aws_glue_partition}.
 *
 * @stability stable
 */
export declare class GluePartition extends cdktf.TerraformResource {
    /**
     * @stability stable
     */
    static readonly tfResourceType: string;
    /**
     * Create a new {@link https://www.terraform.io/docs/providers/aws/r/glue_partition aws_glue_partition} Resource.
     *
     * @param scope The scope in which to define this construct.
     * @param id The scoped construct ID.
     * @stability stable
     */
    constructor(scope: Construct, id: string, config: GluePartitionConfig);
    private _catalogId?;
    /**
     * @stability stable
     */
    get catalogId(): string;
    /**
     * @stability stable
     */
    set catalogId(value: string);
    /**
     * @stability stable
     */
    resetCatalogId(): void;
    /**
     * @stability stable
     */
    get catalogIdInput(): string | undefined;
    /**
     * @stability stable
     */
    get creationTime(): string;
    private _databaseName?;
    /**
     * @stability stable
     */
    get databaseName(): string;
    /**
     * @stability stable
     */
    set databaseName(value: string);
    /**
     * @stability stable
     */
    get databaseNameInput(): string | undefined;
    /**
     * @stability stable
     */
    get id(): string;
    /**
     * @stability stable
     */
    get lastAccessedTime(): string;
    /**
     * @stability stable
     */
    get lastAnalyzedTime(): string;
    private _parameters?;
    /**
     * @stability stable
     */
    get parameters(): {
        [key: string]: string;
    };
    /**
     * @stability stable
     */
    set parameters(value: {
        [key: string]: string;
    });
    /**
     * @stability stable
     */
    resetParameters(): void;
    /**
     * @stability stable
     */
    get parametersInput(): {
        [key: string]: string;
    } | undefined;
    private _partitionValues?;
    /**
     * @stability stable
     */
    get partitionValues(): string[];
    /**
     * @stability stable
     */
    set partitionValues(value: string[]);
    /**
     * @stability stable
     */
    get partitionValuesInput(): string[] | undefined;
    private _tableName?;
    /**
     * @stability stable
     */
    get tableName(): string;
    /**
     * @stability stable
     */
    set tableName(value: string);
    /**
     * @stability stable
     */
    get tableNameInput(): string | undefined;
    private _storageDescriptor;
    /**
     * @stability stable
     */
    get storageDescriptor(): GluePartitionStorageDescriptorOutputReference;
    /**
     * @stability stable
     */
    putStorageDescriptor(value: GluePartitionStorageDescriptor): void;
    /**
     * @stability stable
     */
    resetStorageDescriptor(): void;
    /**
     * @stability stable
     */
    get storageDescriptorInput(): GluePartitionStorageDescriptor | undefined;
    /**
     * @stability stable
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
