import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
/**
 * AWS GuardDuty.
 *
 * @stability stable
 */
export interface GuarddutyDetectorConfig extends cdktf.TerraformMetaArguments {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/guardduty_detector#enable GuarddutyDetector#enable}.
     *
     * @stability stable
     */
    readonly enable?: boolean | cdktf.IResolvable;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/guardduty_detector#finding_publishing_frequency GuarddutyDetector#finding_publishing_frequency}.
     *
     * @stability stable
     */
    readonly findingPublishingFrequency?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/guardduty_detector#tags GuarddutyDetector#tags}.
     *
     * @stability stable
     */
    readonly tags?: {
        [key: string]: string;
    };
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/guardduty_detector#tags_all GuarddutyDetector#tags_all}.
     *
     * @stability stable
     */
    readonly tagsAll?: {
        [key: string]: string;
    };
    /**
     * datasources block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/guardduty_detector#datasources GuarddutyDetector#datasources}
     *
     * @stability stable
     */
    readonly datasources?: GuarddutyDetectorDatasources;
}
/**
 * @stability stable
 */
export interface GuarddutyDetectorDatasourcesS3Logs {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/guardduty_detector#enable GuarddutyDetector#enable}.
     *
     * @stability stable
     */
    readonly enable: boolean | cdktf.IResolvable;
}
export declare function guarddutyDetectorDatasourcesS3LogsToTerraform(struct?: GuarddutyDetectorDatasourcesS3LogsOutputReference | GuarddutyDetectorDatasourcesS3Logs): any;
/**
 * @stability stable
 */
export declare class GuarddutyDetectorDatasourcesS3LogsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): GuarddutyDetectorDatasourcesS3Logs | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: GuarddutyDetectorDatasourcesS3Logs | undefined);
    private _enable?;
    /**
     * @stability stable
     */
    get enable(): boolean | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set enable(value: boolean | cdktf.IResolvable);
    /**
     * @stability stable
     */
    get enableInput(): boolean | cdktf.IResolvable | undefined;
}
/**
 * @stability stable
 */
export interface GuarddutyDetectorDatasources {
    /**
     * s3_logs block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/guardduty_detector#s3_logs GuarddutyDetector#s3_logs}
     *
     * @stability stable
     */
    readonly s3Logs?: GuarddutyDetectorDatasourcesS3Logs;
}
export declare function guarddutyDetectorDatasourcesToTerraform(struct?: GuarddutyDetectorDatasourcesOutputReference | GuarddutyDetectorDatasources): any;
/**
 * @stability stable
 */
export declare class GuarddutyDetectorDatasourcesOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): GuarddutyDetectorDatasources | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: GuarddutyDetectorDatasources | undefined);
    private _s3Logs;
    /**
     * @stability stable
     */
    get s3Logs(): GuarddutyDetectorDatasourcesS3LogsOutputReference;
    /**
     * @stability stable
     */
    putS3Logs(value: GuarddutyDetectorDatasourcesS3Logs): void;
    /**
     * @stability stable
     */
    resetS3Logs(): void;
    /**
     * @stability stable
     */
    get s3LogsInput(): GuarddutyDetectorDatasourcesS3Logs | undefined;
}
/**
 * Represents a {@link https://www.terraform.io/docs/providers/aws/r/guardduty_detector aws_guardduty_detector}.
 *
 * @stability stable
 */
export declare class GuarddutyDetector extends cdktf.TerraformResource {
    /**
     * @stability stable
     */
    static readonly tfResourceType: string;
    /**
     * Create a new {@link https://www.terraform.io/docs/providers/aws/r/guardduty_detector aws_guardduty_detector} Resource.
     *
     * @param scope The scope in which to define this construct.
     * @param id The scoped construct ID.
     * @stability stable
     */
    constructor(scope: Construct, id: string, config?: GuarddutyDetectorConfig);
    /**
     * @stability stable
     */
    get accountId(): string;
    /**
     * @stability stable
     */
    get arn(): string;
    private _enable?;
    /**
     * @stability stable
     */
    get enable(): boolean | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set enable(value: boolean | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetEnable(): void;
    /**
     * @stability stable
     */
    get enableInput(): boolean | cdktf.IResolvable | undefined;
    private _findingPublishingFrequency?;
    /**
     * @stability stable
     */
    get findingPublishingFrequency(): string;
    /**
     * @stability stable
     */
    set findingPublishingFrequency(value: string);
    /**
     * @stability stable
     */
    resetFindingPublishingFrequency(): void;
    /**
     * @stability stable
     */
    get findingPublishingFrequencyInput(): string | undefined;
    /**
     * @stability stable
     */
    get id(): string;
    private _tags?;
    /**
     * @stability stable
     */
    get tags(): {
        [key: string]: string;
    };
    /**
     * @stability stable
     */
    set tags(value: {
        [key: string]: string;
    });
    /**
     * @stability stable
     */
    resetTags(): void;
    /**
     * @stability stable
     */
    get tagsInput(): {
        [key: string]: string;
    } | undefined;
    private _tagsAll?;
    /**
     * @stability stable
     */
    get tagsAll(): {
        [key: string]: string;
    };
    /**
     * @stability stable
     */
    set tagsAll(value: {
        [key: string]: string;
    });
    /**
     * @stability stable
     */
    resetTagsAll(): void;
    /**
     * @stability stable
     */
    get tagsAllInput(): {
        [key: string]: string;
    } | undefined;
    private _datasources;
    /**
     * @stability stable
     */
    get datasources(): GuarddutyDetectorDatasourcesOutputReference;
    /**
     * @stability stable
     */
    putDatasources(value: GuarddutyDetectorDatasources): void;
    /**
     * @stability stable
     */
    resetDatasources(): void;
    /**
     * @stability stable
     */
    get datasourcesInput(): GuarddutyDetectorDatasources | undefined;
    /**
     * @stability stable
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
