import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
/**
 * AWS Image Builder.
 *
 * @stability stable
 */
export interface ImagebuilderImageConfig extends cdktf.TerraformMetaArguments {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/imagebuilder_image#distribution_configuration_arn ImagebuilderImage#distribution_configuration_arn}.
     *
     * @stability stable
     */
    readonly distributionConfigurationArn?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/imagebuilder_image#enhanced_image_metadata_enabled ImagebuilderImage#enhanced_image_metadata_enabled}.
     *
     * @stability stable
     */
    readonly enhancedImageMetadataEnabled?: boolean | cdktf.IResolvable;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/imagebuilder_image#image_recipe_arn ImagebuilderImage#image_recipe_arn}.
     *
     * @stability stable
     */
    readonly imageRecipeArn: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/imagebuilder_image#infrastructure_configuration_arn ImagebuilderImage#infrastructure_configuration_arn}.
     *
     * @stability stable
     */
    readonly infrastructureConfigurationArn: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/imagebuilder_image#tags ImagebuilderImage#tags}.
     *
     * @stability stable
     */
    readonly tags?: {
        [key: string]: string;
    };
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/imagebuilder_image#tags_all ImagebuilderImage#tags_all}.
     *
     * @stability stable
     */
    readonly tagsAll?: {
        [key: string]: string;
    };
    /**
     * image_tests_configuration block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/imagebuilder_image#image_tests_configuration ImagebuilderImage#image_tests_configuration}
     *
     * @stability stable
     */
    readonly imageTestsConfiguration?: ImagebuilderImageImageTestsConfiguration;
    /**
     * timeouts block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/imagebuilder_image#timeouts ImagebuilderImage#timeouts}
     *
     * @stability stable
     */
    readonly timeouts?: ImagebuilderImageTimeouts;
}
/**
 * @stability stable
 */
export declare class ImagebuilderImageOutputResourcesAmis extends cdktf.ComplexComputedList {
    /**
     * @stability stable
     */
    get accountId(): string;
    /**
     * @stability stable
     */
    get description(): string;
    /**
     * @stability stable
     */
    get image(): string;
    /**
     * @stability stable
     */
    get name(): string;
    /**
     * @stability stable
     */
    get region(): string;
}
/**
 * @stability stable
 */
export declare class ImagebuilderImageOutputResources extends cdktf.ComplexComputedList {
    /**
     * @stability stable
     */
    get amis(): cdktf.IResolvable;
}
/**
 * @stability stable
 */
export interface ImagebuilderImageImageTestsConfiguration {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/imagebuilder_image#image_tests_enabled ImagebuilderImage#image_tests_enabled}.
     *
     * @stability stable
     */
    readonly imageTestsEnabled?: boolean | cdktf.IResolvable;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/imagebuilder_image#timeout_minutes ImagebuilderImage#timeout_minutes}.
     *
     * @stability stable
     */
    readonly timeoutMinutes?: number;
}
export declare function imagebuilderImageImageTestsConfigurationToTerraform(struct?: ImagebuilderImageImageTestsConfigurationOutputReference | ImagebuilderImageImageTestsConfiguration): any;
/**
 * @stability stable
 */
export declare class ImagebuilderImageImageTestsConfigurationOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): ImagebuilderImageImageTestsConfiguration | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: ImagebuilderImageImageTestsConfiguration | undefined);
    private _imageTestsEnabled?;
    /**
     * @stability stable
     */
    get imageTestsEnabled(): boolean | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set imageTestsEnabled(value: boolean | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetImageTestsEnabled(): void;
    /**
     * @stability stable
     */
    get imageTestsEnabledInput(): boolean | cdktf.IResolvable | undefined;
    private _timeoutMinutes?;
    /**
     * @stability stable
     */
    get timeoutMinutes(): number;
    /**
     * @stability stable
     */
    set timeoutMinutes(value: number);
    /**
     * @stability stable
     */
    resetTimeoutMinutes(): void;
    /**
     * @stability stable
     */
    get timeoutMinutesInput(): number | undefined;
}
/**
 * @stability stable
 */
export interface ImagebuilderImageTimeouts {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/imagebuilder_image#create ImagebuilderImage#create}.
     *
     * @stability stable
     */
    readonly create?: string;
}
export declare function imagebuilderImageTimeoutsToTerraform(struct?: ImagebuilderImageTimeoutsOutputReference | ImagebuilderImageTimeouts | cdktf.IResolvable): any;
/**
 * @stability stable
 */
export declare class ImagebuilderImageTimeoutsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): ImagebuilderImageTimeouts | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: ImagebuilderImageTimeouts | undefined);
    private _create?;
    /**
     * @stability stable
     */
    get create(): string;
    /**
     * @stability stable
     */
    set create(value: string);
    /**
     * @stability stable
     */
    resetCreate(): void;
    /**
     * @stability stable
     */
    get createInput(): string | undefined;
}
/**
 * Represents a {@link https://www.terraform.io/docs/providers/aws/r/imagebuilder_image aws_imagebuilder_image}.
 *
 * @stability stable
 */
export declare class ImagebuilderImage extends cdktf.TerraformResource {
    /**
     * @stability stable
     */
    static readonly tfResourceType: string;
    /**
     * Create a new {@link https://www.terraform.io/docs/providers/aws/r/imagebuilder_image aws_imagebuilder_image} Resource.
     *
     * @param scope The scope in which to define this construct.
     * @param id The scoped construct ID.
     * @stability stable
     */
    constructor(scope: Construct, id: string, config: ImagebuilderImageConfig);
    /**
     * @stability stable
     */
    get arn(): string;
    /**
     * @stability stable
     */
    get dateCreated(): string;
    private _distributionConfigurationArn?;
    /**
     * @stability stable
     */
    get distributionConfigurationArn(): string;
    /**
     * @stability stable
     */
    set distributionConfigurationArn(value: string);
    /**
     * @stability stable
     */
    resetDistributionConfigurationArn(): void;
    /**
     * @stability stable
     */
    get distributionConfigurationArnInput(): string | undefined;
    private _enhancedImageMetadataEnabled?;
    /**
     * @stability stable
     */
    get enhancedImageMetadataEnabled(): boolean | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set enhancedImageMetadataEnabled(value: boolean | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetEnhancedImageMetadataEnabled(): void;
    /**
     * @stability stable
     */
    get enhancedImageMetadataEnabledInput(): boolean | cdktf.IResolvable | undefined;
    /**
     * @stability stable
     */
    get id(): string;
    private _imageRecipeArn?;
    /**
     * @stability stable
     */
    get imageRecipeArn(): string;
    /**
     * @stability stable
     */
    set imageRecipeArn(value: string);
    /**
     * @stability stable
     */
    get imageRecipeArnInput(): string | undefined;
    private _infrastructureConfigurationArn?;
    /**
     * @stability stable
     */
    get infrastructureConfigurationArn(): string;
    /**
     * @stability stable
     */
    set infrastructureConfigurationArn(value: string);
    /**
     * @stability stable
     */
    get infrastructureConfigurationArnInput(): string | undefined;
    /**
     * @stability stable
     */
    get name(): string;
    /**
     * @stability stable
     */
    get osVersion(): string;
    /**
     * @stability stable
     */
    outputResources(index: string): ImagebuilderImageOutputResources;
    /**
     * @stability stable
     */
    get platform(): string;
    private _tags?;
    /**
     * @stability stable
     */
    get tags(): {
        [key: string]: string;
    };
    /**
     * @stability stable
     */
    set tags(value: {
        [key: string]: string;
    });
    /**
     * @stability stable
     */
    resetTags(): void;
    /**
     * @stability stable
     */
    get tagsInput(): {
        [key: string]: string;
    } | undefined;
    private _tagsAll?;
    /**
     * @stability stable
     */
    get tagsAll(): {
        [key: string]: string;
    };
    /**
     * @stability stable
     */
    set tagsAll(value: {
        [key: string]: string;
    });
    /**
     * @stability stable
     */
    resetTagsAll(): void;
    /**
     * @stability stable
     */
    get tagsAllInput(): {
        [key: string]: string;
    } | undefined;
    /**
     * @stability stable
     */
    get version(): string;
    private _imageTestsConfiguration;
    /**
     * @stability stable
     */
    get imageTestsConfiguration(): ImagebuilderImageImageTestsConfigurationOutputReference;
    /**
     * @stability stable
     */
    putImageTestsConfiguration(value: ImagebuilderImageImageTestsConfiguration): void;
    /**
     * @stability stable
     */
    resetImageTestsConfiguration(): void;
    /**
     * @stability stable
     */
    get imageTestsConfigurationInput(): ImagebuilderImageImageTestsConfiguration | undefined;
    private _timeouts;
    /**
     * @stability stable
     */
    get timeouts(): ImagebuilderImageTimeoutsOutputReference;
    /**
     * @stability stable
     */
    putTimeouts(value: ImagebuilderImageTimeouts): void;
    /**
     * @stability stable
     */
    resetTimeouts(): void;
    /**
     * @stability stable
     */
    get timeoutsInput(): ImagebuilderImageTimeouts | undefined;
    /**
     * @stability stable
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
