import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
/**
 * AWS Key Management Service.
 *
 * @stability stable
 */
export interface KmsGrantConfig extends cdktf.TerraformMetaArguments {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/kms_grant#grant_creation_tokens KmsGrant#grant_creation_tokens}.
     *
     * @stability stable
     */
    readonly grantCreationTokens?: string[];
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/kms_grant#grantee_principal KmsGrant#grantee_principal}.
     *
     * @stability stable
     */
    readonly granteePrincipal: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/kms_grant#key_id KmsGrant#key_id}.
     *
     * @stability stable
     */
    readonly keyId: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/kms_grant#name KmsGrant#name}.
     *
     * @stability stable
     */
    readonly name?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/kms_grant#operations KmsGrant#operations}.
     *
     * @stability stable
     */
    readonly operations: string[];
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/kms_grant#retire_on_delete KmsGrant#retire_on_delete}.
     *
     * @stability stable
     */
    readonly retireOnDelete?: boolean | cdktf.IResolvable;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/kms_grant#retiring_principal KmsGrant#retiring_principal}.
     *
     * @stability stable
     */
    readonly retiringPrincipal?: string;
    /**
     * constraints block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/kms_grant#constraints KmsGrant#constraints}
     *
     * @stability stable
     */
    readonly constraints?: KmsGrantConstraints[] | cdktf.IResolvable;
}
/**
 * @stability stable
 */
export interface KmsGrantConstraints {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/kms_grant#encryption_context_equals KmsGrant#encryption_context_equals}.
     *
     * @stability stable
     */
    readonly encryptionContextEquals?: {
        [key: string]: string;
    };
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/kms_grant#encryption_context_subset KmsGrant#encryption_context_subset}.
     *
     * @stability stable
     */
    readonly encryptionContextSubset?: {
        [key: string]: string;
    };
}
export declare function kmsGrantConstraintsToTerraform(struct?: KmsGrantConstraints | cdktf.IResolvable): any;
/**
 * Represents a {@link https://www.terraform.io/docs/providers/aws/r/kms_grant aws_kms_grant}.
 *
 * @stability stable
 */
export declare class KmsGrant extends cdktf.TerraformResource {
    /**
     * @stability stable
     */
    static readonly tfResourceType: string;
    /**
     * Create a new {@link https://www.terraform.io/docs/providers/aws/r/kms_grant aws_kms_grant} Resource.
     *
     * @param scope The scope in which to define this construct.
     * @param id The scoped construct ID.
     * @stability stable
     */
    constructor(scope: Construct, id: string, config: KmsGrantConfig);
    private _grantCreationTokens?;
    /**
     * @stability stable
     */
    get grantCreationTokens(): string[];
    /**
     * @stability stable
     */
    set grantCreationTokens(value: string[]);
    /**
     * @stability stable
     */
    resetGrantCreationTokens(): void;
    /**
     * @stability stable
     */
    get grantCreationTokensInput(): string[] | undefined;
    /**
     * @stability stable
     */
    get grantId(): string;
    /**
     * @stability stable
     */
    get grantToken(): string;
    private _granteePrincipal?;
    /**
     * @stability stable
     */
    get granteePrincipal(): string;
    /**
     * @stability stable
     */
    set granteePrincipal(value: string);
    /**
     * @stability stable
     */
    get granteePrincipalInput(): string | undefined;
    /**
     * @stability stable
     */
    get id(): string;
    private _keyId?;
    /**
     * @stability stable
     */
    get keyId(): string;
    /**
     * @stability stable
     */
    set keyId(value: string);
    /**
     * @stability stable
     */
    get keyIdInput(): string | undefined;
    private _name?;
    /**
     * @stability stable
     */
    get name(): string;
    /**
     * @stability stable
     */
    set name(value: string);
    /**
     * @stability stable
     */
    resetName(): void;
    /**
     * @stability stable
     */
    get nameInput(): string | undefined;
    private _operations?;
    /**
     * @stability stable
     */
    get operations(): string[];
    /**
     * @stability stable
     */
    set operations(value: string[]);
    /**
     * @stability stable
     */
    get operationsInput(): string[] | undefined;
    private _retireOnDelete?;
    /**
     * @stability stable
     */
    get retireOnDelete(): boolean | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set retireOnDelete(value: boolean | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetRetireOnDelete(): void;
    /**
     * @stability stable
     */
    get retireOnDeleteInput(): boolean | cdktf.IResolvable | undefined;
    private _retiringPrincipal?;
    /**
     * @stability stable
     */
    get retiringPrincipal(): string;
    /**
     * @stability stable
     */
    set retiringPrincipal(value: string);
    /**
     * @stability stable
     */
    resetRetiringPrincipal(): void;
    /**
     * @stability stable
     */
    get retiringPrincipalInput(): string | undefined;
    private _constraints?;
    /**
     * @stability stable
     */
    get constraints(): KmsGrantConstraints[] | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set constraints(value: KmsGrantConstraints[] | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetConstraints(): void;
    /**
     * @stability stable
     */
    get constraintsInput(): cdktf.IResolvable | KmsGrantConstraints[] | undefined;
    /**
     * @stability stable
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
