import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
/**
 * AWS Key Management Service.
 *
 * @stability stable
 */
export interface KmsKeyConfig extends cdktf.TerraformMetaArguments {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/kms_key#bypass_policy_lockout_safety_check KmsKey#bypass_policy_lockout_safety_check}.
     *
     * @stability stable
     */
    readonly bypassPolicyLockoutSafetyCheck?: boolean | cdktf.IResolvable;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/kms_key#customer_master_key_spec KmsKey#customer_master_key_spec}.
     *
     * @stability stable
     */
    readonly customerMasterKeySpec?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/kms_key#deletion_window_in_days KmsKey#deletion_window_in_days}.
     *
     * @stability stable
     */
    readonly deletionWindowInDays?: number;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/kms_key#description KmsKey#description}.
     *
     * @stability stable
     */
    readonly description?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/kms_key#enable_key_rotation KmsKey#enable_key_rotation}.
     *
     * @stability stable
     */
    readonly enableKeyRotation?: boolean | cdktf.IResolvable;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/kms_key#is_enabled KmsKey#is_enabled}.
     *
     * @stability stable
     */
    readonly isEnabled?: boolean | cdktf.IResolvable;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/kms_key#key_usage KmsKey#key_usage}.
     *
     * @stability stable
     */
    readonly keyUsage?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/kms_key#multi_region KmsKey#multi_region}.
     *
     * @stability stable
     */
    readonly multiRegion?: boolean | cdktf.IResolvable;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/kms_key#policy KmsKey#policy}.
     *
     * @stability stable
     */
    readonly policy?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/kms_key#tags KmsKey#tags}.
     *
     * @stability stable
     */
    readonly tags?: {
        [key: string]: string;
    };
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/kms_key#tags_all KmsKey#tags_all}.
     *
     * @stability stable
     */
    readonly tagsAll?: {
        [key: string]: string;
    };
}
/**
 * Represents a {@link https://www.terraform.io/docs/providers/aws/r/kms_key aws_kms_key}.
 *
 * @stability stable
 */
export declare class KmsKey extends cdktf.TerraformResource {
    /**
     * @stability stable
     */
    static readonly tfResourceType: string;
    /**
     * Create a new {@link https://www.terraform.io/docs/providers/aws/r/kms_key aws_kms_key} Resource.
     *
     * @param scope The scope in which to define this construct.
     * @param id The scoped construct ID.
     * @stability stable
     */
    constructor(scope: Construct, id: string, config?: KmsKeyConfig);
    /**
     * @stability stable
     */
    get arn(): string;
    private _bypassPolicyLockoutSafetyCheck?;
    /**
     * @stability stable
     */
    get bypassPolicyLockoutSafetyCheck(): boolean | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set bypassPolicyLockoutSafetyCheck(value: boolean | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetBypassPolicyLockoutSafetyCheck(): void;
    /**
     * @stability stable
     */
    get bypassPolicyLockoutSafetyCheckInput(): boolean | cdktf.IResolvable | undefined;
    private _customerMasterKeySpec?;
    /**
     * @stability stable
     */
    get customerMasterKeySpec(): string;
    /**
     * @stability stable
     */
    set customerMasterKeySpec(value: string);
    /**
     * @stability stable
     */
    resetCustomerMasterKeySpec(): void;
    /**
     * @stability stable
     */
    get customerMasterKeySpecInput(): string | undefined;
    private _deletionWindowInDays?;
    /**
     * @stability stable
     */
    get deletionWindowInDays(): number;
    /**
     * @stability stable
     */
    set deletionWindowInDays(value: number);
    /**
     * @stability stable
     */
    resetDeletionWindowInDays(): void;
    /**
     * @stability stable
     */
    get deletionWindowInDaysInput(): number | undefined;
    private _description?;
    /**
     * @stability stable
     */
    get description(): string;
    /**
     * @stability stable
     */
    set description(value: string);
    /**
     * @stability stable
     */
    resetDescription(): void;
    /**
     * @stability stable
     */
    get descriptionInput(): string | undefined;
    private _enableKeyRotation?;
    /**
     * @stability stable
     */
    get enableKeyRotation(): boolean | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set enableKeyRotation(value: boolean | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetEnableKeyRotation(): void;
    /**
     * @stability stable
     */
    get enableKeyRotationInput(): boolean | cdktf.IResolvable | undefined;
    /**
     * @stability stable
     */
    get id(): string;
    private _isEnabled?;
    /**
     * @stability stable
     */
    get isEnabled(): boolean | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set isEnabled(value: boolean | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetIsEnabled(): void;
    /**
     * @stability stable
     */
    get isEnabledInput(): boolean | cdktf.IResolvable | undefined;
    /**
     * @stability stable
     */
    get keyId(): string;
    private _keyUsage?;
    /**
     * @stability stable
     */
    get keyUsage(): string;
    /**
     * @stability stable
     */
    set keyUsage(value: string);
    /**
     * @stability stable
     */
    resetKeyUsage(): void;
    /**
     * @stability stable
     */
    get keyUsageInput(): string | undefined;
    private _multiRegion?;
    /**
     * @stability stable
     */
    get multiRegion(): boolean | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set multiRegion(value: boolean | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetMultiRegion(): void;
    /**
     * @stability stable
     */
    get multiRegionInput(): boolean | cdktf.IResolvable | undefined;
    private _policy?;
    /**
     * @stability stable
     */
    get policy(): string;
    /**
     * @stability stable
     */
    set policy(value: string);
    /**
     * @stability stable
     */
    resetPolicy(): void;
    /**
     * @stability stable
     */
    get policyInput(): string | undefined;
    private _tags?;
    /**
     * @stability stable
     */
    get tags(): {
        [key: string]: string;
    };
    /**
     * @stability stable
     */
    set tags(value: {
        [key: string]: string;
    });
    /**
     * @stability stable
     */
    resetTags(): void;
    /**
     * @stability stable
     */
    get tagsInput(): {
        [key: string]: string;
    } | undefined;
    private _tagsAll?;
    /**
     * @stability stable
     */
    get tagsAll(): {
        [key: string]: string;
    };
    /**
     * @stability stable
     */
    set tagsAll(value: {
        [key: string]: string;
    });
    /**
     * @stability stable
     */
    resetTagsAll(): void;
    /**
     * @stability stable
     */
    get tagsAllInput(): {
        [key: string]: string;
    } | undefined;
    /**
     * @stability stable
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
