import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
/**
 * AWS Lake Formation.
 *
 * @stability stable
 */
export interface LakeformationPermissionsConfig extends cdktf.TerraformMetaArguments {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lakeformation_permissions#catalog_id LakeformationPermissions#catalog_id}.
     *
     * @stability stable
     */
    readonly catalogId?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lakeformation_permissions#catalog_resource LakeformationPermissions#catalog_resource}.
     *
     * @stability stable
     */
    readonly catalogResource?: boolean | cdktf.IResolvable;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lakeformation_permissions#permissions LakeformationPermissions#permissions}.
     *
     * @stability stable
     */
    readonly permissions: string[];
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lakeformation_permissions#permissions_with_grant_option LakeformationPermissions#permissions_with_grant_option}.
     *
     * @stability stable
     */
    readonly permissionsWithGrantOption?: string[];
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lakeformation_permissions#principal LakeformationPermissions#principal}.
     *
     * @stability stable
     */
    readonly principal: string;
    /**
     * data_location block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lakeformation_permissions#data_location LakeformationPermissions#data_location}
     *
     * @stability stable
     */
    readonly dataLocation?: LakeformationPermissionsDataLocation;
    /**
     * database block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lakeformation_permissions#database LakeformationPermissions#database}
     *
     * @stability stable
     */
    readonly database?: LakeformationPermissionsDatabase;
    /**
     * table block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lakeformation_permissions#table LakeformationPermissions#table}
     *
     * @stability stable
     */
    readonly table?: LakeformationPermissionsTable;
    /**
     * table_with_columns block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lakeformation_permissions#table_with_columns LakeformationPermissions#table_with_columns}
     *
     * @stability stable
     */
    readonly tableWithColumns?: LakeformationPermissionsTableWithColumns;
}
/**
 * @stability stable
 */
export interface LakeformationPermissionsDataLocation {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lakeformation_permissions#arn LakeformationPermissions#arn}.
     *
     * @stability stable
     */
    readonly arn: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lakeformation_permissions#catalog_id LakeformationPermissions#catalog_id}.
     *
     * @stability stable
     */
    readonly catalogId?: string;
}
export declare function lakeformationPermissionsDataLocationToTerraform(struct?: LakeformationPermissionsDataLocationOutputReference | LakeformationPermissionsDataLocation): any;
/**
 * @stability stable
 */
export declare class LakeformationPermissionsDataLocationOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): LakeformationPermissionsDataLocation | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: LakeformationPermissionsDataLocation | undefined);
    private _arn?;
    /**
     * @stability stable
     */
    get arn(): string;
    /**
     * @stability stable
     */
    set arn(value: string);
    /**
     * @stability stable
     */
    get arnInput(): string | undefined;
    private _catalogId?;
    /**
     * @stability stable
     */
    get catalogId(): string;
    /**
     * @stability stable
     */
    set catalogId(value: string);
    /**
     * @stability stable
     */
    resetCatalogId(): void;
    /**
     * @stability stable
     */
    get catalogIdInput(): string | undefined;
}
/**
 * @stability stable
 */
export interface LakeformationPermissionsDatabase {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lakeformation_permissions#catalog_id LakeformationPermissions#catalog_id}.
     *
     * @stability stable
     */
    readonly catalogId?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lakeformation_permissions#name LakeformationPermissions#name}.
     *
     * @stability stable
     */
    readonly name: string;
}
export declare function lakeformationPermissionsDatabaseToTerraform(struct?: LakeformationPermissionsDatabaseOutputReference | LakeformationPermissionsDatabase): any;
/**
 * @stability stable
 */
export declare class LakeformationPermissionsDatabaseOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): LakeformationPermissionsDatabase | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: LakeformationPermissionsDatabase | undefined);
    private _catalogId?;
    /**
     * @stability stable
     */
    get catalogId(): string;
    /**
     * @stability stable
     */
    set catalogId(value: string);
    /**
     * @stability stable
     */
    resetCatalogId(): void;
    /**
     * @stability stable
     */
    get catalogIdInput(): string | undefined;
    private _name?;
    /**
     * @stability stable
     */
    get name(): string;
    /**
     * @stability stable
     */
    set name(value: string);
    /**
     * @stability stable
     */
    get nameInput(): string | undefined;
}
/**
 * @stability stable
 */
export interface LakeformationPermissionsTable {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lakeformation_permissions#catalog_id LakeformationPermissions#catalog_id}.
     *
     * @stability stable
     */
    readonly catalogId?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lakeformation_permissions#database_name LakeformationPermissions#database_name}.
     *
     * @stability stable
     */
    readonly databaseName: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lakeformation_permissions#name LakeformationPermissions#name}.
     *
     * @stability stable
     */
    readonly name?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lakeformation_permissions#wildcard LakeformationPermissions#wildcard}.
     *
     * @stability stable
     */
    readonly wildcard?: boolean | cdktf.IResolvable;
}
export declare function lakeformationPermissionsTableToTerraform(struct?: LakeformationPermissionsTableOutputReference | LakeformationPermissionsTable): any;
/**
 * @stability stable
 */
export declare class LakeformationPermissionsTableOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): LakeformationPermissionsTable | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: LakeformationPermissionsTable | undefined);
    private _catalogId?;
    /**
     * @stability stable
     */
    get catalogId(): string;
    /**
     * @stability stable
     */
    set catalogId(value: string);
    /**
     * @stability stable
     */
    resetCatalogId(): void;
    /**
     * @stability stable
     */
    get catalogIdInput(): string | undefined;
    private _databaseName?;
    /**
     * @stability stable
     */
    get databaseName(): string;
    /**
     * @stability stable
     */
    set databaseName(value: string);
    /**
     * @stability stable
     */
    get databaseNameInput(): string | undefined;
    private _name?;
    /**
     * @stability stable
     */
    get name(): string;
    /**
     * @stability stable
     */
    set name(value: string);
    /**
     * @stability stable
     */
    resetName(): void;
    /**
     * @stability stable
     */
    get nameInput(): string | undefined;
    private _wildcard?;
    /**
     * @stability stable
     */
    get wildcard(): boolean | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set wildcard(value: boolean | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetWildcard(): void;
    /**
     * @stability stable
     */
    get wildcardInput(): boolean | cdktf.IResolvable | undefined;
}
/**
 * @stability stable
 */
export interface LakeformationPermissionsTableWithColumns {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lakeformation_permissions#catalog_id LakeformationPermissions#catalog_id}.
     *
     * @stability stable
     */
    readonly catalogId?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lakeformation_permissions#column_names LakeformationPermissions#column_names}.
     *
     * @stability stable
     */
    readonly columnNames?: string[];
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lakeformation_permissions#database_name LakeformationPermissions#database_name}.
     *
     * @stability stable
     */
    readonly databaseName: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lakeformation_permissions#excluded_column_names LakeformationPermissions#excluded_column_names}.
     *
     * @stability stable
     */
    readonly excludedColumnNames?: string[];
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lakeformation_permissions#name LakeformationPermissions#name}.
     *
     * @stability stable
     */
    readonly name: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lakeformation_permissions#wildcard LakeformationPermissions#wildcard}.
     *
     * @stability stable
     */
    readonly wildcard?: boolean | cdktf.IResolvable;
}
export declare function lakeformationPermissionsTableWithColumnsToTerraform(struct?: LakeformationPermissionsTableWithColumnsOutputReference | LakeformationPermissionsTableWithColumns): any;
/**
 * @stability stable
 */
export declare class LakeformationPermissionsTableWithColumnsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): LakeformationPermissionsTableWithColumns | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: LakeformationPermissionsTableWithColumns | undefined);
    private _catalogId?;
    /**
     * @stability stable
     */
    get catalogId(): string;
    /**
     * @stability stable
     */
    set catalogId(value: string);
    /**
     * @stability stable
     */
    resetCatalogId(): void;
    /**
     * @stability stable
     */
    get catalogIdInput(): string | undefined;
    private _columnNames?;
    /**
     * @stability stable
     */
    get columnNames(): string[];
    /**
     * @stability stable
     */
    set columnNames(value: string[]);
    /**
     * @stability stable
     */
    resetColumnNames(): void;
    /**
     * @stability stable
     */
    get columnNamesInput(): string[] | undefined;
    private _databaseName?;
    /**
     * @stability stable
     */
    get databaseName(): string;
    /**
     * @stability stable
     */
    set databaseName(value: string);
    /**
     * @stability stable
     */
    get databaseNameInput(): string | undefined;
    private _excludedColumnNames?;
    /**
     * @stability stable
     */
    get excludedColumnNames(): string[];
    /**
     * @stability stable
     */
    set excludedColumnNames(value: string[]);
    /**
     * @stability stable
     */
    resetExcludedColumnNames(): void;
    /**
     * @stability stable
     */
    get excludedColumnNamesInput(): string[] | undefined;
    private _name?;
    /**
     * @stability stable
     */
    get name(): string;
    /**
     * @stability stable
     */
    set name(value: string);
    /**
     * @stability stable
     */
    get nameInput(): string | undefined;
    private _wildcard?;
    /**
     * @stability stable
     */
    get wildcard(): boolean | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set wildcard(value: boolean | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetWildcard(): void;
    /**
     * @stability stable
     */
    get wildcardInput(): boolean | cdktf.IResolvable | undefined;
}
/**
 * Represents a {@link https://www.terraform.io/docs/providers/aws/r/lakeformation_permissions aws_lakeformation_permissions}.
 *
 * @stability stable
 */
export declare class LakeformationPermissions extends cdktf.TerraformResource {
    /**
     * @stability stable
     */
    static readonly tfResourceType: string;
    /**
     * Create a new {@link https://www.terraform.io/docs/providers/aws/r/lakeformation_permissions aws_lakeformation_permissions} Resource.
     *
     * @param scope The scope in which to define this construct.
     * @param id The scoped construct ID.
     * @stability stable
     */
    constructor(scope: Construct, id: string, config: LakeformationPermissionsConfig);
    private _catalogId?;
    /**
     * @stability stable
     */
    get catalogId(): string;
    /**
     * @stability stable
     */
    set catalogId(value: string);
    /**
     * @stability stable
     */
    resetCatalogId(): void;
    /**
     * @stability stable
     */
    get catalogIdInput(): string | undefined;
    private _catalogResource?;
    /**
     * @stability stable
     */
    get catalogResource(): boolean | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set catalogResource(value: boolean | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetCatalogResource(): void;
    /**
     * @stability stable
     */
    get catalogResourceInput(): boolean | cdktf.IResolvable | undefined;
    /**
     * @stability stable
     */
    get id(): string;
    private _permissions?;
    /**
     * @stability stable
     */
    get permissions(): string[];
    /**
     * @stability stable
     */
    set permissions(value: string[]);
    /**
     * @stability stable
     */
    get permissionsInput(): string[] | undefined;
    private _permissionsWithGrantOption?;
    /**
     * @stability stable
     */
    get permissionsWithGrantOption(): string[];
    /**
     * @stability stable
     */
    set permissionsWithGrantOption(value: string[]);
    /**
     * @stability stable
     */
    resetPermissionsWithGrantOption(): void;
    /**
     * @stability stable
     */
    get permissionsWithGrantOptionInput(): string[] | undefined;
    private _principal?;
    /**
     * @stability stable
     */
    get principal(): string;
    /**
     * @stability stable
     */
    set principal(value: string);
    /**
     * @stability stable
     */
    get principalInput(): string | undefined;
    private _dataLocation;
    /**
     * @stability stable
     */
    get dataLocation(): LakeformationPermissionsDataLocationOutputReference;
    /**
     * @stability stable
     */
    putDataLocation(value: LakeformationPermissionsDataLocation): void;
    /**
     * @stability stable
     */
    resetDataLocation(): void;
    /**
     * @stability stable
     */
    get dataLocationInput(): LakeformationPermissionsDataLocation | undefined;
    private _database;
    /**
     * @stability stable
     */
    get database(): LakeformationPermissionsDatabaseOutputReference;
    /**
     * @stability stable
     */
    putDatabase(value: LakeformationPermissionsDatabase): void;
    /**
     * @stability stable
     */
    resetDatabase(): void;
    /**
     * @stability stable
     */
    get databaseInput(): LakeformationPermissionsDatabase | undefined;
    private _table;
    /**
     * @stability stable
     */
    get table(): LakeformationPermissionsTableOutputReference;
    /**
     * @stability stable
     */
    putTable(value: LakeformationPermissionsTable): void;
    /**
     * @stability stable
     */
    resetTable(): void;
    /**
     * @stability stable
     */
    get tableInput(): LakeformationPermissionsTable | undefined;
    private _tableWithColumns;
    /**
     * @stability stable
     */
    get tableWithColumns(): LakeformationPermissionsTableWithColumnsOutputReference;
    /**
     * @stability stable
     */
    putTableWithColumns(value: LakeformationPermissionsTableWithColumns): void;
    /**
     * @stability stable
     */
    resetTableWithColumns(): void;
    /**
     * @stability stable
     */
    get tableWithColumnsInput(): LakeformationPermissionsTableWithColumns | undefined;
    /**
     * @stability stable
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
