import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
/**
 * AWS Lambda.
 *
 * @stability stable
 */
export interface LambdaCodeSigningConfigConfig extends cdktf.TerraformMetaArguments {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lambda_code_signing_config#description LambdaCodeSigningConfig#description}.
     *
     * @stability stable
     */
    readonly description?: string;
    /**
     * allowed_publishers block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lambda_code_signing_config#allowed_publishers LambdaCodeSigningConfig#allowed_publishers}
     *
     * @stability stable
     */
    readonly allowedPublishers: LambdaCodeSigningConfigAllowedPublishers;
    /**
     * policies block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lambda_code_signing_config#policies LambdaCodeSigningConfig#policies}
     *
     * @stability stable
     */
    readonly policies?: LambdaCodeSigningConfigPolicies;
}
/**
 * @stability stable
 */
export interface LambdaCodeSigningConfigAllowedPublishers {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lambda_code_signing_config#signing_profile_version_arns LambdaCodeSigningConfig#signing_profile_version_arns}.
     *
     * @stability stable
     */
    readonly signingProfileVersionArns: string[];
}
export declare function lambdaCodeSigningConfigAllowedPublishersToTerraform(struct?: LambdaCodeSigningConfigAllowedPublishersOutputReference | LambdaCodeSigningConfigAllowedPublishers): any;
/**
 * @stability stable
 */
export declare class LambdaCodeSigningConfigAllowedPublishersOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): LambdaCodeSigningConfigAllowedPublishers | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: LambdaCodeSigningConfigAllowedPublishers | undefined);
    private _signingProfileVersionArns?;
    /**
     * @stability stable
     */
    get signingProfileVersionArns(): string[];
    /**
     * @stability stable
     */
    set signingProfileVersionArns(value: string[]);
    /**
     * @stability stable
     */
    get signingProfileVersionArnsInput(): string[] | undefined;
}
/**
 * @stability stable
 */
export interface LambdaCodeSigningConfigPolicies {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lambda_code_signing_config#untrusted_artifact_on_deployment LambdaCodeSigningConfig#untrusted_artifact_on_deployment}.
     *
     * @stability stable
     */
    readonly untrustedArtifactOnDeployment: string;
}
export declare function lambdaCodeSigningConfigPoliciesToTerraform(struct?: LambdaCodeSigningConfigPoliciesOutputReference | LambdaCodeSigningConfigPolicies): any;
/**
 * @stability stable
 */
export declare class LambdaCodeSigningConfigPoliciesOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): LambdaCodeSigningConfigPolicies | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: LambdaCodeSigningConfigPolicies | undefined);
    private _untrustedArtifactOnDeployment?;
    /**
     * @stability stable
     */
    get untrustedArtifactOnDeployment(): string;
    /**
     * @stability stable
     */
    set untrustedArtifactOnDeployment(value: string);
    /**
     * @stability stable
     */
    get untrustedArtifactOnDeploymentInput(): string | undefined;
}
/**
 * Represents a {@link https://www.terraform.io/docs/providers/aws/r/lambda_code_signing_config aws_lambda_code_signing_config}.
 *
 * @stability stable
 */
export declare class LambdaCodeSigningConfig extends cdktf.TerraformResource {
    /**
     * @stability stable
     */
    static readonly tfResourceType: string;
    /**
     * Create a new {@link https://www.terraform.io/docs/providers/aws/r/lambda_code_signing_config aws_lambda_code_signing_config} Resource.
     *
     * @param scope The scope in which to define this construct.
     * @param id The scoped construct ID.
     * @stability stable
     */
    constructor(scope: Construct, id: string, config: LambdaCodeSigningConfigConfig);
    /**
     * @stability stable
     */
    get arn(): string;
    /**
     * @stability stable
     */
    get configId(): string;
    private _description?;
    /**
     * @stability stable
     */
    get description(): string;
    /**
     * @stability stable
     */
    set description(value: string);
    /**
     * @stability stable
     */
    resetDescription(): void;
    /**
     * @stability stable
     */
    get descriptionInput(): string | undefined;
    /**
     * @stability stable
     */
    get id(): string;
    /**
     * @stability stable
     */
    get lastModified(): string;
    private _allowedPublishers;
    /**
     * @stability stable
     */
    get allowedPublishers(): LambdaCodeSigningConfigAllowedPublishersOutputReference;
    /**
     * @stability stable
     */
    putAllowedPublishers(value: LambdaCodeSigningConfigAllowedPublishers): void;
    /**
     * @stability stable
     */
    get allowedPublishersInput(): LambdaCodeSigningConfigAllowedPublishers | undefined;
    private _policies;
    /**
     * @stability stable
     */
    get policies(): LambdaCodeSigningConfigPoliciesOutputReference;
    /**
     * @stability stable
     */
    putPolicies(value: LambdaCodeSigningConfigPolicies): void;
    /**
     * @stability stable
     */
    resetPolicies(): void;
    /**
     * @stability stable
     */
    get policiesInput(): LambdaCodeSigningConfigPolicies | undefined;
    /**
     * @stability stable
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
