import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
/**
 * AWS Lambda.
 *
 * @stability stable
 */
export interface LambdaEventSourceMappingConfig extends cdktf.TerraformMetaArguments {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lambda_event_source_mapping#batch_size LambdaEventSourceMapping#batch_size}.
     *
     * @stability stable
     */
    readonly batchSize?: number;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lambda_event_source_mapping#bisect_batch_on_function_error LambdaEventSourceMapping#bisect_batch_on_function_error}.
     *
     * @stability stable
     */
    readonly bisectBatchOnFunctionError?: boolean | cdktf.IResolvable;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lambda_event_source_mapping#enabled LambdaEventSourceMapping#enabled}.
     *
     * @stability stable
     */
    readonly enabled?: boolean | cdktf.IResolvable;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lambda_event_source_mapping#event_source_arn LambdaEventSourceMapping#event_source_arn}.
     *
     * @stability stable
     */
    readonly eventSourceArn?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lambda_event_source_mapping#function_name LambdaEventSourceMapping#function_name}.
     *
     * @stability stable
     */
    readonly functionName: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lambda_event_source_mapping#function_response_types LambdaEventSourceMapping#function_response_types}.
     *
     * @stability stable
     */
    readonly functionResponseTypes?: string[];
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lambda_event_source_mapping#maximum_batching_window_in_seconds LambdaEventSourceMapping#maximum_batching_window_in_seconds}.
     *
     * @stability stable
     */
    readonly maximumBatchingWindowInSeconds?: number;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lambda_event_source_mapping#maximum_record_age_in_seconds LambdaEventSourceMapping#maximum_record_age_in_seconds}.
     *
     * @stability stable
     */
    readonly maximumRecordAgeInSeconds?: number;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lambda_event_source_mapping#maximum_retry_attempts LambdaEventSourceMapping#maximum_retry_attempts}.
     *
     * @stability stable
     */
    readonly maximumRetryAttempts?: number;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lambda_event_source_mapping#parallelization_factor LambdaEventSourceMapping#parallelization_factor}.
     *
     * @stability stable
     */
    readonly parallelizationFactor?: number;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lambda_event_source_mapping#queues LambdaEventSourceMapping#queues}.
     *
     * @stability stable
     */
    readonly queues?: string[];
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lambda_event_source_mapping#starting_position LambdaEventSourceMapping#starting_position}.
     *
     * @stability stable
     */
    readonly startingPosition?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lambda_event_source_mapping#starting_position_timestamp LambdaEventSourceMapping#starting_position_timestamp}.
     *
     * @stability stable
     */
    readonly startingPositionTimestamp?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lambda_event_source_mapping#topics LambdaEventSourceMapping#topics}.
     *
     * @stability stable
     */
    readonly topics?: string[];
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lambda_event_source_mapping#tumbling_window_in_seconds LambdaEventSourceMapping#tumbling_window_in_seconds}.
     *
     * @stability stable
     */
    readonly tumblingWindowInSeconds?: number;
    /**
     * destination_config block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lambda_event_source_mapping#destination_config LambdaEventSourceMapping#destination_config}
     *
     * @stability stable
     */
    readonly destinationConfig?: LambdaEventSourceMappingDestinationConfig;
    /**
     * filter_criteria block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lambda_event_source_mapping#filter_criteria LambdaEventSourceMapping#filter_criteria}
     *
     * @stability stable
     */
    readonly filterCriteria?: LambdaEventSourceMappingFilterCriteria;
    /**
     * self_managed_event_source block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lambda_event_source_mapping#self_managed_event_source LambdaEventSourceMapping#self_managed_event_source}
     *
     * @stability stable
     */
    readonly selfManagedEventSource?: LambdaEventSourceMappingSelfManagedEventSource;
    /**
     * source_access_configuration block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lambda_event_source_mapping#source_access_configuration LambdaEventSourceMapping#source_access_configuration}
     *
     * @stability stable
     */
    readonly sourceAccessConfiguration?: LambdaEventSourceMappingSourceAccessConfiguration[] | cdktf.IResolvable;
}
/**
 * @stability stable
 */
export interface LambdaEventSourceMappingDestinationConfigOnFailure {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lambda_event_source_mapping#destination_arn LambdaEventSourceMapping#destination_arn}.
     *
     * @stability stable
     */
    readonly destinationArn: string;
}
export declare function lambdaEventSourceMappingDestinationConfigOnFailureToTerraform(struct?: LambdaEventSourceMappingDestinationConfigOnFailureOutputReference | LambdaEventSourceMappingDestinationConfigOnFailure): any;
/**
 * @stability stable
 */
export declare class LambdaEventSourceMappingDestinationConfigOnFailureOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): LambdaEventSourceMappingDestinationConfigOnFailure | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: LambdaEventSourceMappingDestinationConfigOnFailure | undefined);
    private _destinationArn?;
    /**
     * @stability stable
     */
    get destinationArn(): string;
    /**
     * @stability stable
     */
    set destinationArn(value: string);
    /**
     * @stability stable
     */
    get destinationArnInput(): string | undefined;
}
/**
 * @stability stable
 */
export interface LambdaEventSourceMappingDestinationConfig {
    /**
     * on_failure block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lambda_event_source_mapping#on_failure LambdaEventSourceMapping#on_failure}
     *
     * @stability stable
     */
    readonly onFailure?: LambdaEventSourceMappingDestinationConfigOnFailure;
}
export declare function lambdaEventSourceMappingDestinationConfigToTerraform(struct?: LambdaEventSourceMappingDestinationConfigOutputReference | LambdaEventSourceMappingDestinationConfig): any;
/**
 * @stability stable
 */
export declare class LambdaEventSourceMappingDestinationConfigOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): LambdaEventSourceMappingDestinationConfig | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: LambdaEventSourceMappingDestinationConfig | undefined);
    private _onFailure;
    /**
     * @stability stable
     */
    get onFailure(): LambdaEventSourceMappingDestinationConfigOnFailureOutputReference;
    /**
     * @stability stable
     */
    putOnFailure(value: LambdaEventSourceMappingDestinationConfigOnFailure): void;
    /**
     * @stability stable
     */
    resetOnFailure(): void;
    /**
     * @stability stable
     */
    get onFailureInput(): LambdaEventSourceMappingDestinationConfigOnFailure | undefined;
}
/**
 * @stability stable
 */
export interface LambdaEventSourceMappingFilterCriteriaFilter {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lambda_event_source_mapping#pattern LambdaEventSourceMapping#pattern}.
     *
     * @stability stable
     */
    readonly pattern?: string;
}
export declare function lambdaEventSourceMappingFilterCriteriaFilterToTerraform(struct?: LambdaEventSourceMappingFilterCriteriaFilter | cdktf.IResolvable): any;
/**
 * @stability stable
 */
export interface LambdaEventSourceMappingFilterCriteria {
    /**
     * filter block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lambda_event_source_mapping#filter LambdaEventSourceMapping#filter}
     *
     * @stability stable
     */
    readonly filter?: LambdaEventSourceMappingFilterCriteriaFilter[] | cdktf.IResolvable;
}
export declare function lambdaEventSourceMappingFilterCriteriaToTerraform(struct?: LambdaEventSourceMappingFilterCriteriaOutputReference | LambdaEventSourceMappingFilterCriteria): any;
/**
 * @stability stable
 */
export declare class LambdaEventSourceMappingFilterCriteriaOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): LambdaEventSourceMappingFilterCriteria | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: LambdaEventSourceMappingFilterCriteria | undefined);
    private _filter?;
    /**
     * @stability stable
     */
    get filter(): LambdaEventSourceMappingFilterCriteriaFilter[] | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set filter(value: LambdaEventSourceMappingFilterCriteriaFilter[] | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetFilter(): void;
    /**
     * @stability stable
     */
    get filterInput(): cdktf.IResolvable | LambdaEventSourceMappingFilterCriteriaFilter[] | undefined;
}
/**
 * @stability stable
 */
export interface LambdaEventSourceMappingSelfManagedEventSource {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lambda_event_source_mapping#endpoints LambdaEventSourceMapping#endpoints}.
     *
     * @stability stable
     */
    readonly endpoints: {
        [key: string]: string;
    };
}
export declare function lambdaEventSourceMappingSelfManagedEventSourceToTerraform(struct?: LambdaEventSourceMappingSelfManagedEventSourceOutputReference | LambdaEventSourceMappingSelfManagedEventSource): any;
/**
 * @stability stable
 */
export declare class LambdaEventSourceMappingSelfManagedEventSourceOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): LambdaEventSourceMappingSelfManagedEventSource | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: LambdaEventSourceMappingSelfManagedEventSource | undefined);
    private _endpoints?;
    /**
     * @stability stable
     */
    get endpoints(): {
        [key: string]: string;
    };
    /**
     * @stability stable
     */
    set endpoints(value: {
        [key: string]: string;
    });
    /**
     * @stability stable
     */
    get endpointsInput(): {
        [key: string]: string;
    } | undefined;
}
/**
 * @stability stable
 */
export interface LambdaEventSourceMappingSourceAccessConfiguration {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lambda_event_source_mapping#type LambdaEventSourceMapping#type}.
     *
     * @stability stable
     */
    readonly type: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lambda_event_source_mapping#uri LambdaEventSourceMapping#uri}.
     *
     * @stability stable
     */
    readonly uri: string;
}
export declare function lambdaEventSourceMappingSourceAccessConfigurationToTerraform(struct?: LambdaEventSourceMappingSourceAccessConfiguration | cdktf.IResolvable): any;
/**
 * Represents a {@link https://www.terraform.io/docs/providers/aws/r/lambda_event_source_mapping aws_lambda_event_source_mapping}.
 *
 * @stability stable
 */
export declare class LambdaEventSourceMapping extends cdktf.TerraformResource {
    /**
     * @stability stable
     */
    static readonly tfResourceType: string;
    /**
     * Create a new {@link https://www.terraform.io/docs/providers/aws/r/lambda_event_source_mapping aws_lambda_event_source_mapping} Resource.
     *
     * @param scope The scope in which to define this construct.
     * @param id The scoped construct ID.
     * @stability stable
     */
    constructor(scope: Construct, id: string, config: LambdaEventSourceMappingConfig);
    private _batchSize?;
    /**
     * @stability stable
     */
    get batchSize(): number;
    /**
     * @stability stable
     */
    set batchSize(value: number);
    /**
     * @stability stable
     */
    resetBatchSize(): void;
    /**
     * @stability stable
     */
    get batchSizeInput(): number | undefined;
    private _bisectBatchOnFunctionError?;
    /**
     * @stability stable
     */
    get bisectBatchOnFunctionError(): boolean | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set bisectBatchOnFunctionError(value: boolean | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetBisectBatchOnFunctionError(): void;
    /**
     * @stability stable
     */
    get bisectBatchOnFunctionErrorInput(): boolean | cdktf.IResolvable | undefined;
    private _enabled?;
    /**
     * @stability stable
     */
    get enabled(): boolean | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set enabled(value: boolean | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetEnabled(): void;
    /**
     * @stability stable
     */
    get enabledInput(): boolean | cdktf.IResolvable | undefined;
    private _eventSourceArn?;
    /**
     * @stability stable
     */
    get eventSourceArn(): string;
    /**
     * @stability stable
     */
    set eventSourceArn(value: string);
    /**
     * @stability stable
     */
    resetEventSourceArn(): void;
    /**
     * @stability stable
     */
    get eventSourceArnInput(): string | undefined;
    /**
     * @stability stable
     */
    get functionArn(): string;
    private _functionName?;
    /**
     * @stability stable
     */
    get functionName(): string;
    /**
     * @stability stable
     */
    set functionName(value: string);
    /**
     * @stability stable
     */
    get functionNameInput(): string | undefined;
    private _functionResponseTypes?;
    /**
     * @stability stable
     */
    get functionResponseTypes(): string[];
    /**
     * @stability stable
     */
    set functionResponseTypes(value: string[]);
    /**
     * @stability stable
     */
    resetFunctionResponseTypes(): void;
    /**
     * @stability stable
     */
    get functionResponseTypesInput(): string[] | undefined;
    /**
     * @stability stable
     */
    get id(): string;
    /**
     * @stability stable
     */
    get lastModified(): string;
    /**
     * @stability stable
     */
    get lastProcessingResult(): string;
    private _maximumBatchingWindowInSeconds?;
    /**
     * @stability stable
     */
    get maximumBatchingWindowInSeconds(): number;
    /**
     * @stability stable
     */
    set maximumBatchingWindowInSeconds(value: number);
    /**
     * @stability stable
     */
    resetMaximumBatchingWindowInSeconds(): void;
    /**
     * @stability stable
     */
    get maximumBatchingWindowInSecondsInput(): number | undefined;
    private _maximumRecordAgeInSeconds?;
    /**
     * @stability stable
     */
    get maximumRecordAgeInSeconds(): number;
    /**
     * @stability stable
     */
    set maximumRecordAgeInSeconds(value: number);
    /**
     * @stability stable
     */
    resetMaximumRecordAgeInSeconds(): void;
    /**
     * @stability stable
     */
    get maximumRecordAgeInSecondsInput(): number | undefined;
    private _maximumRetryAttempts?;
    /**
     * @stability stable
     */
    get maximumRetryAttempts(): number;
    /**
     * @stability stable
     */
    set maximumRetryAttempts(value: number);
    /**
     * @stability stable
     */
    resetMaximumRetryAttempts(): void;
    /**
     * @stability stable
     */
    get maximumRetryAttemptsInput(): number | undefined;
    private _parallelizationFactor?;
    /**
     * @stability stable
     */
    get parallelizationFactor(): number;
    /**
     * @stability stable
     */
    set parallelizationFactor(value: number);
    /**
     * @stability stable
     */
    resetParallelizationFactor(): void;
    /**
     * @stability stable
     */
    get parallelizationFactorInput(): number | undefined;
    private _queues?;
    /**
     * @stability stable
     */
    get queues(): string[];
    /**
     * @stability stable
     */
    set queues(value: string[]);
    /**
     * @stability stable
     */
    resetQueues(): void;
    /**
     * @stability stable
     */
    get queuesInput(): string[] | undefined;
    private _startingPosition?;
    /**
     * @stability stable
     */
    get startingPosition(): string;
    /**
     * @stability stable
     */
    set startingPosition(value: string);
    /**
     * @stability stable
     */
    resetStartingPosition(): void;
    /**
     * @stability stable
     */
    get startingPositionInput(): string | undefined;
    private _startingPositionTimestamp?;
    /**
     * @stability stable
     */
    get startingPositionTimestamp(): string;
    /**
     * @stability stable
     */
    set startingPositionTimestamp(value: string);
    /**
     * @stability stable
     */
    resetStartingPositionTimestamp(): void;
    /**
     * @stability stable
     */
    get startingPositionTimestampInput(): string | undefined;
    /**
     * @stability stable
     */
    get state(): string;
    /**
     * @stability stable
     */
    get stateTransitionReason(): string;
    private _topics?;
    /**
     * @stability stable
     */
    get topics(): string[];
    /**
     * @stability stable
     */
    set topics(value: string[]);
    /**
     * @stability stable
     */
    resetTopics(): void;
    /**
     * @stability stable
     */
    get topicsInput(): string[] | undefined;
    private _tumblingWindowInSeconds?;
    /**
     * @stability stable
     */
    get tumblingWindowInSeconds(): number;
    /**
     * @stability stable
     */
    set tumblingWindowInSeconds(value: number);
    /**
     * @stability stable
     */
    resetTumblingWindowInSeconds(): void;
    /**
     * @stability stable
     */
    get tumblingWindowInSecondsInput(): number | undefined;
    /**
     * @stability stable
     */
    get uuid(): string;
    private _destinationConfig;
    /**
     * @stability stable
     */
    get destinationConfig(): LambdaEventSourceMappingDestinationConfigOutputReference;
    /**
     * @stability stable
     */
    putDestinationConfig(value: LambdaEventSourceMappingDestinationConfig): void;
    /**
     * @stability stable
     */
    resetDestinationConfig(): void;
    /**
     * @stability stable
     */
    get destinationConfigInput(): LambdaEventSourceMappingDestinationConfig | undefined;
    private _filterCriteria;
    /**
     * @stability stable
     */
    get filterCriteria(): LambdaEventSourceMappingFilterCriteriaOutputReference;
    /**
     * @stability stable
     */
    putFilterCriteria(value: LambdaEventSourceMappingFilterCriteria): void;
    /**
     * @stability stable
     */
    resetFilterCriteria(): void;
    /**
     * @stability stable
     */
    get filterCriteriaInput(): LambdaEventSourceMappingFilterCriteria | undefined;
    private _selfManagedEventSource;
    /**
     * @stability stable
     */
    get selfManagedEventSource(): LambdaEventSourceMappingSelfManagedEventSourceOutputReference;
    /**
     * @stability stable
     */
    putSelfManagedEventSource(value: LambdaEventSourceMappingSelfManagedEventSource): void;
    /**
     * @stability stable
     */
    resetSelfManagedEventSource(): void;
    /**
     * @stability stable
     */
    get selfManagedEventSourceInput(): LambdaEventSourceMappingSelfManagedEventSource | undefined;
    private _sourceAccessConfiguration?;
    /**
     * @stability stable
     */
    get sourceAccessConfiguration(): LambdaEventSourceMappingSourceAccessConfiguration[] | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set sourceAccessConfiguration(value: LambdaEventSourceMappingSourceAccessConfiguration[] | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetSourceAccessConfiguration(): void;
    /**
     * @stability stable
     */
    get sourceAccessConfigurationInput(): cdktf.IResolvable | LambdaEventSourceMappingSourceAccessConfiguration[] | undefined;
    /**
     * @stability stable
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
