import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
/**
 * AWS Managed Message Queue.
 *
 * @stability stable
 */
export interface MqBrokerConfig extends cdktf.TerraformMetaArguments {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/mq_broker#apply_immediately MqBroker#apply_immediately}.
     *
     * @stability stable
     */
    readonly applyImmediately?: boolean | cdktf.IResolvable;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/mq_broker#authentication_strategy MqBroker#authentication_strategy}.
     *
     * @stability stable
     */
    readonly authenticationStrategy?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/mq_broker#auto_minor_version_upgrade MqBroker#auto_minor_version_upgrade}.
     *
     * @stability stable
     */
    readonly autoMinorVersionUpgrade?: boolean | cdktf.IResolvable;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/mq_broker#broker_name MqBroker#broker_name}.
     *
     * @stability stable
     */
    readonly brokerName: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/mq_broker#deployment_mode MqBroker#deployment_mode}.
     *
     * @stability stable
     */
    readonly deploymentMode?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/mq_broker#engine_type MqBroker#engine_type}.
     *
     * @stability stable
     */
    readonly engineType: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/mq_broker#engine_version MqBroker#engine_version}.
     *
     * @stability stable
     */
    readonly engineVersion: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/mq_broker#host_instance_type MqBroker#host_instance_type}.
     *
     * @stability stable
     */
    readonly hostInstanceType: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/mq_broker#publicly_accessible MqBroker#publicly_accessible}.
     *
     * @stability stable
     */
    readonly publiclyAccessible?: boolean | cdktf.IResolvable;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/mq_broker#security_groups MqBroker#security_groups}.
     *
     * @stability stable
     */
    readonly securityGroups?: string[];
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/mq_broker#storage_type MqBroker#storage_type}.
     *
     * @stability stable
     */
    readonly storageType?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/mq_broker#subnet_ids MqBroker#subnet_ids}.
     *
     * @stability stable
     */
    readonly subnetIds?: string[];
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/mq_broker#tags MqBroker#tags}.
     *
     * @stability stable
     */
    readonly tags?: {
        [key: string]: string;
    };
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/mq_broker#tags_all MqBroker#tags_all}.
     *
     * @stability stable
     */
    readonly tagsAll?: {
        [key: string]: string;
    };
    /**
     * configuration block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/mq_broker#configuration MqBroker#configuration}
     *
     * @stability stable
     */
    readonly configuration?: MqBrokerConfiguration;
    /**
     * encryption_options block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/mq_broker#encryption_options MqBroker#encryption_options}
     *
     * @stability stable
     */
    readonly encryptionOptions?: MqBrokerEncryptionOptions;
    /**
     * ldap_server_metadata block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/mq_broker#ldap_server_metadata MqBroker#ldap_server_metadata}
     *
     * @stability stable
     */
    readonly ldapServerMetadata?: MqBrokerLdapServerMetadata;
    /**
     * logs block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/mq_broker#logs MqBroker#logs}
     *
     * @stability stable
     */
    readonly logs?: MqBrokerLogs;
    /**
     * maintenance_window_start_time block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/mq_broker#maintenance_window_start_time MqBroker#maintenance_window_start_time}
     *
     * @stability stable
     */
    readonly maintenanceWindowStartTime?: MqBrokerMaintenanceWindowStartTime;
    /**
     * user block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/mq_broker#user MqBroker#user}
     *
     * @stability stable
     */
    readonly user: MqBrokerUser[] | cdktf.IResolvable;
}
/**
 * @stability stable
 */
export declare class MqBrokerInstances extends cdktf.ComplexComputedList {
    /**
     * @stability stable
     */
    get consoleUrl(): string;
    /**
     * @stability stable
     */
    get endpoints(): string[];
    /**
     * @stability stable
     */
    get ipAddress(): string;
}
/**
 * @stability stable
 */
export interface MqBrokerConfiguration {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/mq_broker#id MqBroker#id}.
     *
     * @stability stable
     */
    readonly id?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/mq_broker#revision MqBroker#revision}.
     *
     * @stability stable
     */
    readonly revision?: number;
}
export declare function mqBrokerConfigurationToTerraform(struct?: MqBrokerConfigurationOutputReference | MqBrokerConfiguration): any;
/**
 * @stability stable
 */
export declare class MqBrokerConfigurationOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): MqBrokerConfiguration | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: MqBrokerConfiguration | undefined);
    /**
     * @stability stable
     */
    get id(): string;
    private _revision?;
    /**
     * @stability stable
     */
    get revision(): number;
    /**
     * @stability stable
     */
    set revision(value: number);
    /**
     * @stability stable
     */
    resetRevision(): void;
    /**
     * @stability stable
     */
    get revisionInput(): number | undefined;
}
/**
 * @stability stable
 */
export interface MqBrokerEncryptionOptions {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/mq_broker#kms_key_id MqBroker#kms_key_id}.
     *
     * @stability stable
     */
    readonly kmsKeyId?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/mq_broker#use_aws_owned_key MqBroker#use_aws_owned_key}.
     *
     * @stability stable
     */
    readonly useAwsOwnedKey?: boolean | cdktf.IResolvable;
}
export declare function mqBrokerEncryptionOptionsToTerraform(struct?: MqBrokerEncryptionOptionsOutputReference | MqBrokerEncryptionOptions): any;
/**
 * @stability stable
 */
export declare class MqBrokerEncryptionOptionsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): MqBrokerEncryptionOptions | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: MqBrokerEncryptionOptions | undefined);
    private _kmsKeyId?;
    /**
     * @stability stable
     */
    get kmsKeyId(): string;
    /**
     * @stability stable
     */
    set kmsKeyId(value: string);
    /**
     * @stability stable
     */
    resetKmsKeyId(): void;
    /**
     * @stability stable
     */
    get kmsKeyIdInput(): string | undefined;
    private _useAwsOwnedKey?;
    /**
     * @stability stable
     */
    get useAwsOwnedKey(): boolean | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set useAwsOwnedKey(value: boolean | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetUseAwsOwnedKey(): void;
    /**
     * @stability stable
     */
    get useAwsOwnedKeyInput(): boolean | cdktf.IResolvable | undefined;
}
/**
 * @stability stable
 */
export interface MqBrokerLdapServerMetadata {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/mq_broker#hosts MqBroker#hosts}.
     *
     * @stability stable
     */
    readonly hosts?: string[];
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/mq_broker#role_base MqBroker#role_base}.
     *
     * @stability stable
     */
    readonly roleBase?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/mq_broker#role_name MqBroker#role_name}.
     *
     * @stability stable
     */
    readonly roleName?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/mq_broker#role_search_matching MqBroker#role_search_matching}.
     *
     * @stability stable
     */
    readonly roleSearchMatching?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/mq_broker#role_search_subtree MqBroker#role_search_subtree}.
     *
     * @stability stable
     */
    readonly roleSearchSubtree?: boolean | cdktf.IResolvable;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/mq_broker#service_account_password MqBroker#service_account_password}.
     *
     * @stability stable
     */
    readonly serviceAccountPassword?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/mq_broker#service_account_username MqBroker#service_account_username}.
     *
     * @stability stable
     */
    readonly serviceAccountUsername?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/mq_broker#user_base MqBroker#user_base}.
     *
     * @stability stable
     */
    readonly userBase?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/mq_broker#user_role_name MqBroker#user_role_name}.
     *
     * @stability stable
     */
    readonly userRoleName?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/mq_broker#user_search_matching MqBroker#user_search_matching}.
     *
     * @stability stable
     */
    readonly userSearchMatching?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/mq_broker#user_search_subtree MqBroker#user_search_subtree}.
     *
     * @stability stable
     */
    readonly userSearchSubtree?: boolean | cdktf.IResolvable;
}
export declare function mqBrokerLdapServerMetadataToTerraform(struct?: MqBrokerLdapServerMetadataOutputReference | MqBrokerLdapServerMetadata): any;
/**
 * @stability stable
 */
export declare class MqBrokerLdapServerMetadataOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): MqBrokerLdapServerMetadata | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: MqBrokerLdapServerMetadata | undefined);
    private _hosts?;
    /**
     * @stability stable
     */
    get hosts(): string[];
    /**
     * @stability stable
     */
    set hosts(value: string[]);
    /**
     * @stability stable
     */
    resetHosts(): void;
    /**
     * @stability stable
     */
    get hostsInput(): string[] | undefined;
    private _roleBase?;
    /**
     * @stability stable
     */
    get roleBase(): string;
    /**
     * @stability stable
     */
    set roleBase(value: string);
    /**
     * @stability stable
     */
    resetRoleBase(): void;
    /**
     * @stability stable
     */
    get roleBaseInput(): string | undefined;
    private _roleName?;
    /**
     * @stability stable
     */
    get roleName(): string;
    /**
     * @stability stable
     */
    set roleName(value: string);
    /**
     * @stability stable
     */
    resetRoleName(): void;
    /**
     * @stability stable
     */
    get roleNameInput(): string | undefined;
    private _roleSearchMatching?;
    /**
     * @stability stable
     */
    get roleSearchMatching(): string;
    /**
     * @stability stable
     */
    set roleSearchMatching(value: string);
    /**
     * @stability stable
     */
    resetRoleSearchMatching(): void;
    /**
     * @stability stable
     */
    get roleSearchMatchingInput(): string | undefined;
    private _roleSearchSubtree?;
    /**
     * @stability stable
     */
    get roleSearchSubtree(): boolean | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set roleSearchSubtree(value: boolean | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetRoleSearchSubtree(): void;
    /**
     * @stability stable
     */
    get roleSearchSubtreeInput(): boolean | cdktf.IResolvable | undefined;
    private _serviceAccountPassword?;
    /**
     * @stability stable
     */
    get serviceAccountPassword(): string;
    /**
     * @stability stable
     */
    set serviceAccountPassword(value: string);
    /**
     * @stability stable
     */
    resetServiceAccountPassword(): void;
    /**
     * @stability stable
     */
    get serviceAccountPasswordInput(): string | undefined;
    private _serviceAccountUsername?;
    /**
     * @stability stable
     */
    get serviceAccountUsername(): string;
    /**
     * @stability stable
     */
    set serviceAccountUsername(value: string);
    /**
     * @stability stable
     */
    resetServiceAccountUsername(): void;
    /**
     * @stability stable
     */
    get serviceAccountUsernameInput(): string | undefined;
    private _userBase?;
    /**
     * @stability stable
     */
    get userBase(): string;
    /**
     * @stability stable
     */
    set userBase(value: string);
    /**
     * @stability stable
     */
    resetUserBase(): void;
    /**
     * @stability stable
     */
    get userBaseInput(): string | undefined;
    private _userRoleName?;
    /**
     * @stability stable
     */
    get userRoleName(): string;
    /**
     * @stability stable
     */
    set userRoleName(value: string);
    /**
     * @stability stable
     */
    resetUserRoleName(): void;
    /**
     * @stability stable
     */
    get userRoleNameInput(): string | undefined;
    private _userSearchMatching?;
    /**
     * @stability stable
     */
    get userSearchMatching(): string;
    /**
     * @stability stable
     */
    set userSearchMatching(value: string);
    /**
     * @stability stable
     */
    resetUserSearchMatching(): void;
    /**
     * @stability stable
     */
    get userSearchMatchingInput(): string | undefined;
    private _userSearchSubtree?;
    /**
     * @stability stable
     */
    get userSearchSubtree(): boolean | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set userSearchSubtree(value: boolean | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetUserSearchSubtree(): void;
    /**
     * @stability stable
     */
    get userSearchSubtreeInput(): boolean | cdktf.IResolvable | undefined;
}
/**
 * @stability stable
 */
export interface MqBrokerLogs {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/mq_broker#audit MqBroker#audit}.
     *
     * @stability stable
     */
    readonly audit?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/mq_broker#general MqBroker#general}.
     *
     * @stability stable
     */
    readonly general?: boolean | cdktf.IResolvable;
}
export declare function mqBrokerLogsToTerraform(struct?: MqBrokerLogsOutputReference | MqBrokerLogs): any;
/**
 * @stability stable
 */
export declare class MqBrokerLogsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): MqBrokerLogs | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: MqBrokerLogs | undefined);
    private _audit?;
    /**
     * @stability stable
     */
    get audit(): string;
    /**
     * @stability stable
     */
    set audit(value: string);
    /**
     * @stability stable
     */
    resetAudit(): void;
    /**
     * @stability stable
     */
    get auditInput(): string | undefined;
    private _general?;
    /**
     * @stability stable
     */
    get general(): boolean | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set general(value: boolean | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetGeneral(): void;
    /**
     * @stability stable
     */
    get generalInput(): boolean | cdktf.IResolvable | undefined;
}
/**
 * @stability stable
 */
export interface MqBrokerMaintenanceWindowStartTime {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/mq_broker#day_of_week MqBroker#day_of_week}.
     *
     * @stability stable
     */
    readonly dayOfWeek: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/mq_broker#time_of_day MqBroker#time_of_day}.
     *
     * @stability stable
     */
    readonly timeOfDay: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/mq_broker#time_zone MqBroker#time_zone}.
     *
     * @stability stable
     */
    readonly timeZone: string;
}
export declare function mqBrokerMaintenanceWindowStartTimeToTerraform(struct?: MqBrokerMaintenanceWindowStartTimeOutputReference | MqBrokerMaintenanceWindowStartTime): any;
/**
 * @stability stable
 */
export declare class MqBrokerMaintenanceWindowStartTimeOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): MqBrokerMaintenanceWindowStartTime | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: MqBrokerMaintenanceWindowStartTime | undefined);
    private _dayOfWeek?;
    /**
     * @stability stable
     */
    get dayOfWeek(): string;
    /**
     * @stability stable
     */
    set dayOfWeek(value: string);
    /**
     * @stability stable
     */
    get dayOfWeekInput(): string | undefined;
    private _timeOfDay?;
    /**
     * @stability stable
     */
    get timeOfDay(): string;
    /**
     * @stability stable
     */
    set timeOfDay(value: string);
    /**
     * @stability stable
     */
    get timeOfDayInput(): string | undefined;
    private _timeZone?;
    /**
     * @stability stable
     */
    get timeZone(): string;
    /**
     * @stability stable
     */
    set timeZone(value: string);
    /**
     * @stability stable
     */
    get timeZoneInput(): string | undefined;
}
/**
 * @stability stable
 */
export interface MqBrokerUser {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/mq_broker#console_access MqBroker#console_access}.
     *
     * @stability stable
     */
    readonly consoleAccess?: boolean | cdktf.IResolvable;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/mq_broker#groups MqBroker#groups}.
     *
     * @stability stable
     */
    readonly groups?: string[];
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/mq_broker#password MqBroker#password}.
     *
     * @stability stable
     */
    readonly password: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/mq_broker#username MqBroker#username}.
     *
     * @stability stable
     */
    readonly username: string;
}
export declare function mqBrokerUserToTerraform(struct?: MqBrokerUser | cdktf.IResolvable): any;
/**
 * Represents a {@link https://www.terraform.io/docs/providers/aws/r/mq_broker aws_mq_broker}.
 *
 * @stability stable
 */
export declare class MqBroker extends cdktf.TerraformResource {
    /**
     * @stability stable
     */
    static readonly tfResourceType: string;
    /**
     * Create a new {@link https://www.terraform.io/docs/providers/aws/r/mq_broker aws_mq_broker} Resource.
     *
     * @param scope The scope in which to define this construct.
     * @param id The scoped construct ID.
     * @stability stable
     */
    constructor(scope: Construct, id: string, config: MqBrokerConfig);
    private _applyImmediately?;
    /**
     * @stability stable
     */
    get applyImmediately(): boolean | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set applyImmediately(value: boolean | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetApplyImmediately(): void;
    /**
     * @stability stable
     */
    get applyImmediatelyInput(): boolean | cdktf.IResolvable | undefined;
    /**
     * @stability stable
     */
    get arn(): string;
    private _authenticationStrategy?;
    /**
     * @stability stable
     */
    get authenticationStrategy(): string;
    /**
     * @stability stable
     */
    set authenticationStrategy(value: string);
    /**
     * @stability stable
     */
    resetAuthenticationStrategy(): void;
    /**
     * @stability stable
     */
    get authenticationStrategyInput(): string | undefined;
    private _autoMinorVersionUpgrade?;
    /**
     * @stability stable
     */
    get autoMinorVersionUpgrade(): boolean | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set autoMinorVersionUpgrade(value: boolean | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetAutoMinorVersionUpgrade(): void;
    /**
     * @stability stable
     */
    get autoMinorVersionUpgradeInput(): boolean | cdktf.IResolvable | undefined;
    private _brokerName?;
    /**
     * @stability stable
     */
    get brokerName(): string;
    /**
     * @stability stable
     */
    set brokerName(value: string);
    /**
     * @stability stable
     */
    get brokerNameInput(): string | undefined;
    private _deploymentMode?;
    /**
     * @stability stable
     */
    get deploymentMode(): string;
    /**
     * @stability stable
     */
    set deploymentMode(value: string);
    /**
     * @stability stable
     */
    resetDeploymentMode(): void;
    /**
     * @stability stable
     */
    get deploymentModeInput(): string | undefined;
    private _engineType?;
    /**
     * @stability stable
     */
    get engineType(): string;
    /**
     * @stability stable
     */
    set engineType(value: string);
    /**
     * @stability stable
     */
    get engineTypeInput(): string | undefined;
    private _engineVersion?;
    /**
     * @stability stable
     */
    get engineVersion(): string;
    /**
     * @stability stable
     */
    set engineVersion(value: string);
    /**
     * @stability stable
     */
    get engineVersionInput(): string | undefined;
    private _hostInstanceType?;
    /**
     * @stability stable
     */
    get hostInstanceType(): string;
    /**
     * @stability stable
     */
    set hostInstanceType(value: string);
    /**
     * @stability stable
     */
    get hostInstanceTypeInput(): string | undefined;
    /**
     * @stability stable
     */
    get id(): string;
    /**
     * @stability stable
     */
    instances(index: string): MqBrokerInstances;
    private _publiclyAccessible?;
    /**
     * @stability stable
     */
    get publiclyAccessible(): boolean | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set publiclyAccessible(value: boolean | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetPubliclyAccessible(): void;
    /**
     * @stability stable
     */
    get publiclyAccessibleInput(): boolean | cdktf.IResolvable | undefined;
    private _securityGroups?;
    /**
     * @stability stable
     */
    get securityGroups(): string[];
    /**
     * @stability stable
     */
    set securityGroups(value: string[]);
    /**
     * @stability stable
     */
    resetSecurityGroups(): void;
    /**
     * @stability stable
     */
    get securityGroupsInput(): string[] | undefined;
    private _storageType?;
    /**
     * @stability stable
     */
    get storageType(): string;
    /**
     * @stability stable
     */
    set storageType(value: string);
    /**
     * @stability stable
     */
    resetStorageType(): void;
    /**
     * @stability stable
     */
    get storageTypeInput(): string | undefined;
    private _subnetIds?;
    /**
     * @stability stable
     */
    get subnetIds(): string[];
    /**
     * @stability stable
     */
    set subnetIds(value: string[]);
    /**
     * @stability stable
     */
    resetSubnetIds(): void;
    /**
     * @stability stable
     */
    get subnetIdsInput(): string[] | undefined;
    private _tags?;
    /**
     * @stability stable
     */
    get tags(): {
        [key: string]: string;
    };
    /**
     * @stability stable
     */
    set tags(value: {
        [key: string]: string;
    });
    /**
     * @stability stable
     */
    resetTags(): void;
    /**
     * @stability stable
     */
    get tagsInput(): {
        [key: string]: string;
    } | undefined;
    private _tagsAll?;
    /**
     * @stability stable
     */
    get tagsAll(): {
        [key: string]: string;
    };
    /**
     * @stability stable
     */
    set tagsAll(value: {
        [key: string]: string;
    });
    /**
     * @stability stable
     */
    resetTagsAll(): void;
    /**
     * @stability stable
     */
    get tagsAllInput(): {
        [key: string]: string;
    } | undefined;
    private _configuration;
    /**
     * @stability stable
     */
    get configuration(): MqBrokerConfigurationOutputReference;
    /**
     * @stability stable
     */
    putConfiguration(value: MqBrokerConfiguration): void;
    /**
     * @stability stable
     */
    resetConfiguration(): void;
    /**
     * @stability stable
     */
    get configurationInput(): MqBrokerConfiguration | undefined;
    private _encryptionOptions;
    /**
     * @stability stable
     */
    get encryptionOptions(): MqBrokerEncryptionOptionsOutputReference;
    /**
     * @stability stable
     */
    putEncryptionOptions(value: MqBrokerEncryptionOptions): void;
    /**
     * @stability stable
     */
    resetEncryptionOptions(): void;
    /**
     * @stability stable
     */
    get encryptionOptionsInput(): MqBrokerEncryptionOptions | undefined;
    private _ldapServerMetadata;
    /**
     * @stability stable
     */
    get ldapServerMetadata(): MqBrokerLdapServerMetadataOutputReference;
    /**
     * @stability stable
     */
    putLdapServerMetadata(value: MqBrokerLdapServerMetadata): void;
    /**
     * @stability stable
     */
    resetLdapServerMetadata(): void;
    /**
     * @stability stable
     */
    get ldapServerMetadataInput(): MqBrokerLdapServerMetadata | undefined;
    private _logs;
    /**
     * @stability stable
     */
    get logs(): MqBrokerLogsOutputReference;
    /**
     * @stability stable
     */
    putLogs(value: MqBrokerLogs): void;
    /**
     * @stability stable
     */
    resetLogs(): void;
    /**
     * @stability stable
     */
    get logsInput(): MqBrokerLogs | undefined;
    private _maintenanceWindowStartTime;
    /**
     * @stability stable
     */
    get maintenanceWindowStartTime(): MqBrokerMaintenanceWindowStartTimeOutputReference;
    /**
     * @stability stable
     */
    putMaintenanceWindowStartTime(value: MqBrokerMaintenanceWindowStartTime): void;
    /**
     * @stability stable
     */
    resetMaintenanceWindowStartTime(): void;
    /**
     * @stability stable
     */
    get maintenanceWindowStartTimeInput(): MqBrokerMaintenanceWindowStartTime | undefined;
    private _user?;
    /**
     * @stability stable
     */
    get user(): MqBrokerUser[] | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set user(value: MqBrokerUser[] | cdktf.IResolvable);
    /**
     * @stability stable
     */
    get userInput(): cdktf.IResolvable | MqBrokerUser[] | undefined;
    /**
     * @stability stable
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
