import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
/**
 * AWS Managed Workloads for Apache Airflow.
 *
 * @stability stable
 */
export interface MwaaEnvironmentConfig extends cdktf.TerraformMetaArguments {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/mwaa_environment#airflow_configuration_options MwaaEnvironment#airflow_configuration_options}.
     *
     * @stability stable
     */
    readonly airflowConfigurationOptions?: {
        [key: string]: string;
    };
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/mwaa_environment#airflow_version MwaaEnvironment#airflow_version}.
     *
     * @stability stable
     */
    readonly airflowVersion?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/mwaa_environment#dag_s3_path MwaaEnvironment#dag_s3_path}.
     *
     * @stability stable
     */
    readonly dagS3Path: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/mwaa_environment#environment_class MwaaEnvironment#environment_class}.
     *
     * @stability stable
     */
    readonly environmentClass?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/mwaa_environment#execution_role_arn MwaaEnvironment#execution_role_arn}.
     *
     * @stability stable
     */
    readonly executionRoleArn: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/mwaa_environment#kms_key MwaaEnvironment#kms_key}.
     *
     * @stability stable
     */
    readonly kmsKey?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/mwaa_environment#max_workers MwaaEnvironment#max_workers}.
     *
     * @stability stable
     */
    readonly maxWorkers?: number;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/mwaa_environment#min_workers MwaaEnvironment#min_workers}.
     *
     * @stability stable
     */
    readonly minWorkers?: number;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/mwaa_environment#name MwaaEnvironment#name}.
     *
     * @stability stable
     */
    readonly name: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/mwaa_environment#plugins_s3_object_version MwaaEnvironment#plugins_s3_object_version}.
     *
     * @stability stable
     */
    readonly pluginsS3ObjectVersion?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/mwaa_environment#plugins_s3_path MwaaEnvironment#plugins_s3_path}.
     *
     * @stability stable
     */
    readonly pluginsS3Path?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/mwaa_environment#requirements_s3_object_version MwaaEnvironment#requirements_s3_object_version}.
     *
     * @stability stable
     */
    readonly requirementsS3ObjectVersion?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/mwaa_environment#requirements_s3_path MwaaEnvironment#requirements_s3_path}.
     *
     * @stability stable
     */
    readonly requirementsS3Path?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/mwaa_environment#source_bucket_arn MwaaEnvironment#source_bucket_arn}.
     *
     * @stability stable
     */
    readonly sourceBucketArn: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/mwaa_environment#tags MwaaEnvironment#tags}.
     *
     * @stability stable
     */
    readonly tags?: {
        [key: string]: string;
    };
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/mwaa_environment#tags_all MwaaEnvironment#tags_all}.
     *
     * @stability stable
     */
    readonly tagsAll?: {
        [key: string]: string;
    };
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/mwaa_environment#webserver_access_mode MwaaEnvironment#webserver_access_mode}.
     *
     * @stability stable
     */
    readonly webserverAccessMode?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/mwaa_environment#weekly_maintenance_window_start MwaaEnvironment#weekly_maintenance_window_start}.
     *
     * @stability stable
     */
    readonly weeklyMaintenanceWindowStart?: string;
    /**
     * logging_configuration block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/mwaa_environment#logging_configuration MwaaEnvironment#logging_configuration}
     *
     * @stability stable
     */
    readonly loggingConfiguration?: MwaaEnvironmentLoggingConfiguration;
    /**
     * network_configuration block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/mwaa_environment#network_configuration MwaaEnvironment#network_configuration}
     *
     * @stability stable
     */
    readonly networkConfiguration: MwaaEnvironmentNetworkConfiguration;
}
/**
 * @stability stable
 */
export declare class MwaaEnvironmentLastUpdatedError extends cdktf.ComplexComputedList {
    /**
     * @stability stable
     */
    get errorCode(): string;
    /**
     * @stability stable
     */
    get errorMessage(): string;
}
/**
 * @stability stable
 */
export declare class MwaaEnvironmentLastUpdated extends cdktf.ComplexComputedList {
    /**
     * @stability stable
     */
    get createdAt(): string;
    /**
     * @stability stable
     */
    get error(): cdktf.IResolvable;
    /**
     * @stability stable
     */
    get status(): string;
}
/**
 * @stability stable
 */
export interface MwaaEnvironmentLoggingConfigurationDagProcessingLogs {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/mwaa_environment#enabled MwaaEnvironment#enabled}.
     *
     * @stability stable
     */
    readonly enabled?: boolean | cdktf.IResolvable;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/mwaa_environment#log_level MwaaEnvironment#log_level}.
     *
     * @stability stable
     */
    readonly logLevel?: string;
}
export declare function mwaaEnvironmentLoggingConfigurationDagProcessingLogsToTerraform(struct?: MwaaEnvironmentLoggingConfigurationDagProcessingLogsOutputReference | MwaaEnvironmentLoggingConfigurationDagProcessingLogs): any;
/**
 * @stability stable
 */
export declare class MwaaEnvironmentLoggingConfigurationDagProcessingLogsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): MwaaEnvironmentLoggingConfigurationDagProcessingLogs | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: MwaaEnvironmentLoggingConfigurationDagProcessingLogs | undefined);
    /**
     * @stability stable
     */
    get cloudWatchLogGroupArn(): string;
    private _enabled?;
    /**
     * @stability stable
     */
    get enabled(): boolean | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set enabled(value: boolean | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetEnabled(): void;
    /**
     * @stability stable
     */
    get enabledInput(): boolean | cdktf.IResolvable | undefined;
    private _logLevel?;
    /**
     * @stability stable
     */
    get logLevel(): string;
    /**
     * @stability stable
     */
    set logLevel(value: string);
    /**
     * @stability stable
     */
    resetLogLevel(): void;
    /**
     * @stability stable
     */
    get logLevelInput(): string | undefined;
}
/**
 * @stability stable
 */
export interface MwaaEnvironmentLoggingConfigurationSchedulerLogs {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/mwaa_environment#enabled MwaaEnvironment#enabled}.
     *
     * @stability stable
     */
    readonly enabled?: boolean | cdktf.IResolvable;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/mwaa_environment#log_level MwaaEnvironment#log_level}.
     *
     * @stability stable
     */
    readonly logLevel?: string;
}
export declare function mwaaEnvironmentLoggingConfigurationSchedulerLogsToTerraform(struct?: MwaaEnvironmentLoggingConfigurationSchedulerLogsOutputReference | MwaaEnvironmentLoggingConfigurationSchedulerLogs): any;
/**
 * @stability stable
 */
export declare class MwaaEnvironmentLoggingConfigurationSchedulerLogsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): MwaaEnvironmentLoggingConfigurationSchedulerLogs | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: MwaaEnvironmentLoggingConfigurationSchedulerLogs | undefined);
    /**
     * @stability stable
     */
    get cloudWatchLogGroupArn(): string;
    private _enabled?;
    /**
     * @stability stable
     */
    get enabled(): boolean | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set enabled(value: boolean | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetEnabled(): void;
    /**
     * @stability stable
     */
    get enabledInput(): boolean | cdktf.IResolvable | undefined;
    private _logLevel?;
    /**
     * @stability stable
     */
    get logLevel(): string;
    /**
     * @stability stable
     */
    set logLevel(value: string);
    /**
     * @stability stable
     */
    resetLogLevel(): void;
    /**
     * @stability stable
     */
    get logLevelInput(): string | undefined;
}
/**
 * @stability stable
 */
export interface MwaaEnvironmentLoggingConfigurationTaskLogs {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/mwaa_environment#enabled MwaaEnvironment#enabled}.
     *
     * @stability stable
     */
    readonly enabled?: boolean | cdktf.IResolvable;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/mwaa_environment#log_level MwaaEnvironment#log_level}.
     *
     * @stability stable
     */
    readonly logLevel?: string;
}
export declare function mwaaEnvironmentLoggingConfigurationTaskLogsToTerraform(struct?: MwaaEnvironmentLoggingConfigurationTaskLogsOutputReference | MwaaEnvironmentLoggingConfigurationTaskLogs): any;
/**
 * @stability stable
 */
export declare class MwaaEnvironmentLoggingConfigurationTaskLogsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): MwaaEnvironmentLoggingConfigurationTaskLogs | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: MwaaEnvironmentLoggingConfigurationTaskLogs | undefined);
    /**
     * @stability stable
     */
    get cloudWatchLogGroupArn(): string;
    private _enabled?;
    /**
     * @stability stable
     */
    get enabled(): boolean | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set enabled(value: boolean | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetEnabled(): void;
    /**
     * @stability stable
     */
    get enabledInput(): boolean | cdktf.IResolvable | undefined;
    private _logLevel?;
    /**
     * @stability stable
     */
    get logLevel(): string;
    /**
     * @stability stable
     */
    set logLevel(value: string);
    /**
     * @stability stable
     */
    resetLogLevel(): void;
    /**
     * @stability stable
     */
    get logLevelInput(): string | undefined;
}
/**
 * @stability stable
 */
export interface MwaaEnvironmentLoggingConfigurationWebserverLogs {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/mwaa_environment#enabled MwaaEnvironment#enabled}.
     *
     * @stability stable
     */
    readonly enabled?: boolean | cdktf.IResolvable;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/mwaa_environment#log_level MwaaEnvironment#log_level}.
     *
     * @stability stable
     */
    readonly logLevel?: string;
}
export declare function mwaaEnvironmentLoggingConfigurationWebserverLogsToTerraform(struct?: MwaaEnvironmentLoggingConfigurationWebserverLogsOutputReference | MwaaEnvironmentLoggingConfigurationWebserverLogs): any;
/**
 * @stability stable
 */
export declare class MwaaEnvironmentLoggingConfigurationWebserverLogsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): MwaaEnvironmentLoggingConfigurationWebserverLogs | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: MwaaEnvironmentLoggingConfigurationWebserverLogs | undefined);
    /**
     * @stability stable
     */
    get cloudWatchLogGroupArn(): string;
    private _enabled?;
    /**
     * @stability stable
     */
    get enabled(): boolean | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set enabled(value: boolean | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetEnabled(): void;
    /**
     * @stability stable
     */
    get enabledInput(): boolean | cdktf.IResolvable | undefined;
    private _logLevel?;
    /**
     * @stability stable
     */
    get logLevel(): string;
    /**
     * @stability stable
     */
    set logLevel(value: string);
    /**
     * @stability stable
     */
    resetLogLevel(): void;
    /**
     * @stability stable
     */
    get logLevelInput(): string | undefined;
}
/**
 * @stability stable
 */
export interface MwaaEnvironmentLoggingConfigurationWorkerLogs {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/mwaa_environment#enabled MwaaEnvironment#enabled}.
     *
     * @stability stable
     */
    readonly enabled?: boolean | cdktf.IResolvable;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/mwaa_environment#log_level MwaaEnvironment#log_level}.
     *
     * @stability stable
     */
    readonly logLevel?: string;
}
export declare function mwaaEnvironmentLoggingConfigurationWorkerLogsToTerraform(struct?: MwaaEnvironmentLoggingConfigurationWorkerLogsOutputReference | MwaaEnvironmentLoggingConfigurationWorkerLogs): any;
/**
 * @stability stable
 */
export declare class MwaaEnvironmentLoggingConfigurationWorkerLogsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): MwaaEnvironmentLoggingConfigurationWorkerLogs | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: MwaaEnvironmentLoggingConfigurationWorkerLogs | undefined);
    /**
     * @stability stable
     */
    get cloudWatchLogGroupArn(): string;
    private _enabled?;
    /**
     * @stability stable
     */
    get enabled(): boolean | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set enabled(value: boolean | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetEnabled(): void;
    /**
     * @stability stable
     */
    get enabledInput(): boolean | cdktf.IResolvable | undefined;
    private _logLevel?;
    /**
     * @stability stable
     */
    get logLevel(): string;
    /**
     * @stability stable
     */
    set logLevel(value: string);
    /**
     * @stability stable
     */
    resetLogLevel(): void;
    /**
     * @stability stable
     */
    get logLevelInput(): string | undefined;
}
/**
 * @stability stable
 */
export interface MwaaEnvironmentLoggingConfiguration {
    /**
     * dag_processing_logs block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/mwaa_environment#dag_processing_logs MwaaEnvironment#dag_processing_logs}
     *
     * @stability stable
     */
    readonly dagProcessingLogs?: MwaaEnvironmentLoggingConfigurationDagProcessingLogs;
    /**
     * scheduler_logs block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/mwaa_environment#scheduler_logs MwaaEnvironment#scheduler_logs}
     *
     * @stability stable
     */
    readonly schedulerLogs?: MwaaEnvironmentLoggingConfigurationSchedulerLogs;
    /**
     * task_logs block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/mwaa_environment#task_logs MwaaEnvironment#task_logs}
     *
     * @stability stable
     */
    readonly taskLogs?: MwaaEnvironmentLoggingConfigurationTaskLogs;
    /**
     * webserver_logs block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/mwaa_environment#webserver_logs MwaaEnvironment#webserver_logs}
     *
     * @stability stable
     */
    readonly webserverLogs?: MwaaEnvironmentLoggingConfigurationWebserverLogs;
    /**
     * worker_logs block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/mwaa_environment#worker_logs MwaaEnvironment#worker_logs}
     *
     * @stability stable
     */
    readonly workerLogs?: MwaaEnvironmentLoggingConfigurationWorkerLogs;
}
export declare function mwaaEnvironmentLoggingConfigurationToTerraform(struct?: MwaaEnvironmentLoggingConfigurationOutputReference | MwaaEnvironmentLoggingConfiguration): any;
/**
 * @stability stable
 */
export declare class MwaaEnvironmentLoggingConfigurationOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): MwaaEnvironmentLoggingConfiguration | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: MwaaEnvironmentLoggingConfiguration | undefined);
    private _dagProcessingLogs;
    /**
     * @stability stable
     */
    get dagProcessingLogs(): MwaaEnvironmentLoggingConfigurationDagProcessingLogsOutputReference;
    /**
     * @stability stable
     */
    putDagProcessingLogs(value: MwaaEnvironmentLoggingConfigurationDagProcessingLogs): void;
    /**
     * @stability stable
     */
    resetDagProcessingLogs(): void;
    /**
     * @stability stable
     */
    get dagProcessingLogsInput(): MwaaEnvironmentLoggingConfigurationDagProcessingLogs | undefined;
    private _schedulerLogs;
    /**
     * @stability stable
     */
    get schedulerLogs(): MwaaEnvironmentLoggingConfigurationSchedulerLogsOutputReference;
    /**
     * @stability stable
     */
    putSchedulerLogs(value: MwaaEnvironmentLoggingConfigurationSchedulerLogs): void;
    /**
     * @stability stable
     */
    resetSchedulerLogs(): void;
    /**
     * @stability stable
     */
    get schedulerLogsInput(): MwaaEnvironmentLoggingConfigurationSchedulerLogs | undefined;
    private _taskLogs;
    /**
     * @stability stable
     */
    get taskLogs(): MwaaEnvironmentLoggingConfigurationTaskLogsOutputReference;
    /**
     * @stability stable
     */
    putTaskLogs(value: MwaaEnvironmentLoggingConfigurationTaskLogs): void;
    /**
     * @stability stable
     */
    resetTaskLogs(): void;
    /**
     * @stability stable
     */
    get taskLogsInput(): MwaaEnvironmentLoggingConfigurationTaskLogs | undefined;
    private _webserverLogs;
    /**
     * @stability stable
     */
    get webserverLogs(): MwaaEnvironmentLoggingConfigurationWebserverLogsOutputReference;
    /**
     * @stability stable
     */
    putWebserverLogs(value: MwaaEnvironmentLoggingConfigurationWebserverLogs): void;
    /**
     * @stability stable
     */
    resetWebserverLogs(): void;
    /**
     * @stability stable
     */
    get webserverLogsInput(): MwaaEnvironmentLoggingConfigurationWebserverLogs | undefined;
    private _workerLogs;
    /**
     * @stability stable
     */
    get workerLogs(): MwaaEnvironmentLoggingConfigurationWorkerLogsOutputReference;
    /**
     * @stability stable
     */
    putWorkerLogs(value: MwaaEnvironmentLoggingConfigurationWorkerLogs): void;
    /**
     * @stability stable
     */
    resetWorkerLogs(): void;
    /**
     * @stability stable
     */
    get workerLogsInput(): MwaaEnvironmentLoggingConfigurationWorkerLogs | undefined;
}
/**
 * @stability stable
 */
export interface MwaaEnvironmentNetworkConfiguration {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/mwaa_environment#security_group_ids MwaaEnvironment#security_group_ids}.
     *
     * @stability stable
     */
    readonly securityGroupIds: string[];
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/mwaa_environment#subnet_ids MwaaEnvironment#subnet_ids}.
     *
     * @stability stable
     */
    readonly subnetIds: string[];
}
export declare function mwaaEnvironmentNetworkConfigurationToTerraform(struct?: MwaaEnvironmentNetworkConfigurationOutputReference | MwaaEnvironmentNetworkConfiguration): any;
/**
 * @stability stable
 */
export declare class MwaaEnvironmentNetworkConfigurationOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): MwaaEnvironmentNetworkConfiguration | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: MwaaEnvironmentNetworkConfiguration | undefined);
    private _securityGroupIds?;
    /**
     * @stability stable
     */
    get securityGroupIds(): string[];
    /**
     * @stability stable
     */
    set securityGroupIds(value: string[]);
    /**
     * @stability stable
     */
    get securityGroupIdsInput(): string[] | undefined;
    private _subnetIds?;
    /**
     * @stability stable
     */
    get subnetIds(): string[];
    /**
     * @stability stable
     */
    set subnetIds(value: string[]);
    /**
     * @stability stable
     */
    get subnetIdsInput(): string[] | undefined;
}
/**
 * Represents a {@link https://www.terraform.io/docs/providers/aws/r/mwaa_environment aws_mwaa_environment}.
 *
 * @stability stable
 */
export declare class MwaaEnvironment extends cdktf.TerraformResource {
    /**
     * @stability stable
     */
    static readonly tfResourceType: string;
    /**
     * Create a new {@link https://www.terraform.io/docs/providers/aws/r/mwaa_environment aws_mwaa_environment} Resource.
     *
     * @param scope The scope in which to define this construct.
     * @param id The scoped construct ID.
     * @stability stable
     */
    constructor(scope: Construct, id: string, config: MwaaEnvironmentConfig);
    private _airflowConfigurationOptions?;
    /**
     * @stability stable
     */
    get airflowConfigurationOptions(): {
        [key: string]: string;
    };
    /**
     * @stability stable
     */
    set airflowConfigurationOptions(value: {
        [key: string]: string;
    });
    /**
     * @stability stable
     */
    resetAirflowConfigurationOptions(): void;
    /**
     * @stability stable
     */
    get airflowConfigurationOptionsInput(): {
        [key: string]: string;
    } | undefined;
    private _airflowVersion?;
    /**
     * @stability stable
     */
    get airflowVersion(): string;
    /**
     * @stability stable
     */
    set airflowVersion(value: string);
    /**
     * @stability stable
     */
    resetAirflowVersion(): void;
    /**
     * @stability stable
     */
    get airflowVersionInput(): string | undefined;
    /**
     * @stability stable
     */
    get arn(): string;
    /**
     * @stability stable
     */
    get createdAt(): string;
    private _dagS3Path?;
    /**
     * @stability stable
     */
    get dagS3Path(): string;
    /**
     * @stability stable
     */
    set dagS3Path(value: string);
    /**
     * @stability stable
     */
    get dagS3PathInput(): string | undefined;
    private _environmentClass?;
    /**
     * @stability stable
     */
    get environmentClass(): string;
    /**
     * @stability stable
     */
    set environmentClass(value: string);
    /**
     * @stability stable
     */
    resetEnvironmentClass(): void;
    /**
     * @stability stable
     */
    get environmentClassInput(): string | undefined;
    private _executionRoleArn?;
    /**
     * @stability stable
     */
    get executionRoleArn(): string;
    /**
     * @stability stable
     */
    set executionRoleArn(value: string);
    /**
     * @stability stable
     */
    get executionRoleArnInput(): string | undefined;
    /**
     * @stability stable
     */
    get id(): string;
    private _kmsKey?;
    /**
     * @stability stable
     */
    get kmsKey(): string;
    /**
     * @stability stable
     */
    set kmsKey(value: string);
    /**
     * @stability stable
     */
    resetKmsKey(): void;
    /**
     * @stability stable
     */
    get kmsKeyInput(): string | undefined;
    /**
     * @stability stable
     */
    lastUpdated(index: string): MwaaEnvironmentLastUpdated;
    private _maxWorkers?;
    /**
     * @stability stable
     */
    get maxWorkers(): number;
    /**
     * @stability stable
     */
    set maxWorkers(value: number);
    /**
     * @stability stable
     */
    resetMaxWorkers(): void;
    /**
     * @stability stable
     */
    get maxWorkersInput(): number | undefined;
    private _minWorkers?;
    /**
     * @stability stable
     */
    get minWorkers(): number;
    /**
     * @stability stable
     */
    set minWorkers(value: number);
    /**
     * @stability stable
     */
    resetMinWorkers(): void;
    /**
     * @stability stable
     */
    get minWorkersInput(): number | undefined;
    private _name?;
    /**
     * @stability stable
     */
    get name(): string;
    /**
     * @stability stable
     */
    set name(value: string);
    /**
     * @stability stable
     */
    get nameInput(): string | undefined;
    private _pluginsS3ObjectVersion?;
    /**
     * @stability stable
     */
    get pluginsS3ObjectVersion(): string;
    /**
     * @stability stable
     */
    set pluginsS3ObjectVersion(value: string);
    /**
     * @stability stable
     */
    resetPluginsS3ObjectVersion(): void;
    /**
     * @stability stable
     */
    get pluginsS3ObjectVersionInput(): string | undefined;
    private _pluginsS3Path?;
    /**
     * @stability stable
     */
    get pluginsS3Path(): string;
    /**
     * @stability stable
     */
    set pluginsS3Path(value: string);
    /**
     * @stability stable
     */
    resetPluginsS3Path(): void;
    /**
     * @stability stable
     */
    get pluginsS3PathInput(): string | undefined;
    private _requirementsS3ObjectVersion?;
    /**
     * @stability stable
     */
    get requirementsS3ObjectVersion(): string;
    /**
     * @stability stable
     */
    set requirementsS3ObjectVersion(value: string);
    /**
     * @stability stable
     */
    resetRequirementsS3ObjectVersion(): void;
    /**
     * @stability stable
     */
    get requirementsS3ObjectVersionInput(): string | undefined;
    private _requirementsS3Path?;
    /**
     * @stability stable
     */
    get requirementsS3Path(): string;
    /**
     * @stability stable
     */
    set requirementsS3Path(value: string);
    /**
     * @stability stable
     */
    resetRequirementsS3Path(): void;
    /**
     * @stability stable
     */
    get requirementsS3PathInput(): string | undefined;
    /**
     * @stability stable
     */
    get serviceRoleArn(): string;
    private _sourceBucketArn?;
    /**
     * @stability stable
     */
    get sourceBucketArn(): string;
    /**
     * @stability stable
     */
    set sourceBucketArn(value: string);
    /**
     * @stability stable
     */
    get sourceBucketArnInput(): string | undefined;
    /**
     * @stability stable
     */
    get status(): string;
    private _tags?;
    /**
     * @stability stable
     */
    get tags(): {
        [key: string]: string;
    };
    /**
     * @stability stable
     */
    set tags(value: {
        [key: string]: string;
    });
    /**
     * @stability stable
     */
    resetTags(): void;
    /**
     * @stability stable
     */
    get tagsInput(): {
        [key: string]: string;
    } | undefined;
    private _tagsAll?;
    /**
     * @stability stable
     */
    get tagsAll(): {
        [key: string]: string;
    };
    /**
     * @stability stable
     */
    set tagsAll(value: {
        [key: string]: string;
    });
    /**
     * @stability stable
     */
    resetTagsAll(): void;
    /**
     * @stability stable
     */
    get tagsAllInput(): {
        [key: string]: string;
    } | undefined;
    private _webserverAccessMode?;
    /**
     * @stability stable
     */
    get webserverAccessMode(): string;
    /**
     * @stability stable
     */
    set webserverAccessMode(value: string);
    /**
     * @stability stable
     */
    resetWebserverAccessMode(): void;
    /**
     * @stability stable
     */
    get webserverAccessModeInput(): string | undefined;
    /**
     * @stability stable
     */
    get webserverUrl(): string;
    private _weeklyMaintenanceWindowStart?;
    /**
     * @stability stable
     */
    get weeklyMaintenanceWindowStart(): string;
    /**
     * @stability stable
     */
    set weeklyMaintenanceWindowStart(value: string);
    /**
     * @stability stable
     */
    resetWeeklyMaintenanceWindowStart(): void;
    /**
     * @stability stable
     */
    get weeklyMaintenanceWindowStartInput(): string | undefined;
    private _loggingConfiguration;
    /**
     * @stability stable
     */
    get loggingConfiguration(): MwaaEnvironmentLoggingConfigurationOutputReference;
    /**
     * @stability stable
     */
    putLoggingConfiguration(value: MwaaEnvironmentLoggingConfiguration): void;
    /**
     * @stability stable
     */
    resetLoggingConfiguration(): void;
    /**
     * @stability stable
     */
    get loggingConfigurationInput(): MwaaEnvironmentLoggingConfiguration | undefined;
    private _networkConfiguration;
    /**
     * @stability stable
     */
    get networkConfiguration(): MwaaEnvironmentNetworkConfigurationOutputReference;
    /**
     * @stability stable
     */
    putNetworkConfiguration(value: MwaaEnvironmentNetworkConfiguration): void;
    /**
     * @stability stable
     */
    get networkConfigurationInput(): MwaaEnvironmentNetworkConfiguration | undefined;
    /**
     * @stability stable
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
