import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
/**
 * AWS QuickSight.
 *
 * @stability stable
 */
export interface QuicksightDataSourceConfig extends cdktf.TerraformMetaArguments {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/quicksight_data_source#aws_account_id QuicksightDataSource#aws_account_id}.
     *
     * @stability stable
     */
    readonly awsAccountId?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/quicksight_data_source#data_source_id QuicksightDataSource#data_source_id}.
     *
     * @stability stable
     */
    readonly dataSourceId: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/quicksight_data_source#name QuicksightDataSource#name}.
     *
     * @stability stable
     */
    readonly name: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/quicksight_data_source#tags QuicksightDataSource#tags}.
     *
     * @stability stable
     */
    readonly tags?: {
        [key: string]: string;
    };
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/quicksight_data_source#tags_all QuicksightDataSource#tags_all}.
     *
     * @stability stable
     */
    readonly tagsAll?: {
        [key: string]: string;
    };
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/quicksight_data_source#type QuicksightDataSource#type}.
     *
     * @stability stable
     */
    readonly type: string;
    /**
     * credentials block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/quicksight_data_source#credentials QuicksightDataSource#credentials}
     *
     * @stability stable
     */
    readonly credentials?: QuicksightDataSourceCredentials;
    /**
     * parameters block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/quicksight_data_source#parameters QuicksightDataSource#parameters}
     *
     * @stability stable
     */
    readonly parameters: QuicksightDataSourceParameters;
    /**
     * permission block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/quicksight_data_source#permission QuicksightDataSource#permission}
     *
     * @stability stable
     */
    readonly permission?: QuicksightDataSourcePermission[] | cdktf.IResolvable;
    /**
     * ssl_properties block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/quicksight_data_source#ssl_properties QuicksightDataSource#ssl_properties}
     *
     * @stability stable
     */
    readonly sslProperties?: QuicksightDataSourceSslProperties;
    /**
     * vpc_connection_properties block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/quicksight_data_source#vpc_connection_properties QuicksightDataSource#vpc_connection_properties}
     *
     * @stability stable
     */
    readonly vpcConnectionProperties?: QuicksightDataSourceVpcConnectionProperties;
}
/**
 * @stability stable
 */
export interface QuicksightDataSourceCredentialsCredentialPair {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/quicksight_data_source#password QuicksightDataSource#password}.
     *
     * @stability stable
     */
    readonly password: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/quicksight_data_source#username QuicksightDataSource#username}.
     *
     * @stability stable
     */
    readonly username: string;
}
export declare function quicksightDataSourceCredentialsCredentialPairToTerraform(struct?: QuicksightDataSourceCredentialsCredentialPairOutputReference | QuicksightDataSourceCredentialsCredentialPair): any;
/**
 * @stability stable
 */
export declare class QuicksightDataSourceCredentialsCredentialPairOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): QuicksightDataSourceCredentialsCredentialPair | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: QuicksightDataSourceCredentialsCredentialPair | undefined);
    private _password?;
    /**
     * @stability stable
     */
    get password(): string;
    /**
     * @stability stable
     */
    set password(value: string);
    /**
     * @stability stable
     */
    get passwordInput(): string | undefined;
    private _username?;
    /**
     * @stability stable
     */
    get username(): string;
    /**
     * @stability stable
     */
    set username(value: string);
    /**
     * @stability stable
     */
    get usernameInput(): string | undefined;
}
/**
 * @stability stable
 */
export interface QuicksightDataSourceCredentials {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/quicksight_data_source#copy_source_arn QuicksightDataSource#copy_source_arn}.
     *
     * @stability stable
     */
    readonly copySourceArn?: string;
    /**
     * credential_pair block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/quicksight_data_source#credential_pair QuicksightDataSource#credential_pair}
     *
     * @stability stable
     */
    readonly credentialPair?: QuicksightDataSourceCredentialsCredentialPair;
}
export declare function quicksightDataSourceCredentialsToTerraform(struct?: QuicksightDataSourceCredentialsOutputReference | QuicksightDataSourceCredentials): any;
/**
 * @stability stable
 */
export declare class QuicksightDataSourceCredentialsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): QuicksightDataSourceCredentials | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: QuicksightDataSourceCredentials | undefined);
    private _copySourceArn?;
    /**
     * @stability stable
     */
    get copySourceArn(): string;
    /**
     * @stability stable
     */
    set copySourceArn(value: string);
    /**
     * @stability stable
     */
    resetCopySourceArn(): void;
    /**
     * @stability stable
     */
    get copySourceArnInput(): string | undefined;
    private _credentialPair;
    /**
     * @stability stable
     */
    get credentialPair(): QuicksightDataSourceCredentialsCredentialPairOutputReference;
    /**
     * @stability stable
     */
    putCredentialPair(value: QuicksightDataSourceCredentialsCredentialPair): void;
    /**
     * @stability stable
     */
    resetCredentialPair(): void;
    /**
     * @stability stable
     */
    get credentialPairInput(): QuicksightDataSourceCredentialsCredentialPair | undefined;
}
/**
 * @stability stable
 */
export interface QuicksightDataSourceParametersAmazonElasticsearch {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/quicksight_data_source#domain QuicksightDataSource#domain}.
     *
     * @stability stable
     */
    readonly domain: string;
}
export declare function quicksightDataSourceParametersAmazonElasticsearchToTerraform(struct?: QuicksightDataSourceParametersAmazonElasticsearchOutputReference | QuicksightDataSourceParametersAmazonElasticsearch): any;
/**
 * @stability stable
 */
export declare class QuicksightDataSourceParametersAmazonElasticsearchOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): QuicksightDataSourceParametersAmazonElasticsearch | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: QuicksightDataSourceParametersAmazonElasticsearch | undefined);
    private _domain?;
    /**
     * @stability stable
     */
    get domain(): string;
    /**
     * @stability stable
     */
    set domain(value: string);
    /**
     * @stability stable
     */
    get domainInput(): string | undefined;
}
/**
 * @stability stable
 */
export interface QuicksightDataSourceParametersAthena {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/quicksight_data_source#work_group QuicksightDataSource#work_group}.
     *
     * @stability stable
     */
    readonly workGroup?: string;
}
export declare function quicksightDataSourceParametersAthenaToTerraform(struct?: QuicksightDataSourceParametersAthenaOutputReference | QuicksightDataSourceParametersAthena): any;
/**
 * @stability stable
 */
export declare class QuicksightDataSourceParametersAthenaOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): QuicksightDataSourceParametersAthena | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: QuicksightDataSourceParametersAthena | undefined);
    private _workGroup?;
    /**
     * @stability stable
     */
    get workGroup(): string;
    /**
     * @stability stable
     */
    set workGroup(value: string);
    /**
     * @stability stable
     */
    resetWorkGroup(): void;
    /**
     * @stability stable
     */
    get workGroupInput(): string | undefined;
}
/**
 * @stability stable
 */
export interface QuicksightDataSourceParametersAurora {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/quicksight_data_source#database QuicksightDataSource#database}.
     *
     * @stability stable
     */
    readonly database: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/quicksight_data_source#host QuicksightDataSource#host}.
     *
     * @stability stable
     */
    readonly host: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/quicksight_data_source#port QuicksightDataSource#port}.
     *
     * @stability stable
     */
    readonly port: number;
}
export declare function quicksightDataSourceParametersAuroraToTerraform(struct?: QuicksightDataSourceParametersAuroraOutputReference | QuicksightDataSourceParametersAurora): any;
/**
 * @stability stable
 */
export declare class QuicksightDataSourceParametersAuroraOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): QuicksightDataSourceParametersAurora | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: QuicksightDataSourceParametersAurora | undefined);
    private _database?;
    /**
     * @stability stable
     */
    get database(): string;
    /**
     * @stability stable
     */
    set database(value: string);
    /**
     * @stability stable
     */
    get databaseInput(): string | undefined;
    private _host?;
    /**
     * @stability stable
     */
    get host(): string;
    /**
     * @stability stable
     */
    set host(value: string);
    /**
     * @stability stable
     */
    get hostInput(): string | undefined;
    private _port?;
    /**
     * @stability stable
     */
    get port(): number;
    /**
     * @stability stable
     */
    set port(value: number);
    /**
     * @stability stable
     */
    get portInput(): number | undefined;
}
/**
 * @stability stable
 */
export interface QuicksightDataSourceParametersAuroraPostgresql {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/quicksight_data_source#database QuicksightDataSource#database}.
     *
     * @stability stable
     */
    readonly database: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/quicksight_data_source#host QuicksightDataSource#host}.
     *
     * @stability stable
     */
    readonly host: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/quicksight_data_source#port QuicksightDataSource#port}.
     *
     * @stability stable
     */
    readonly port: number;
}
export declare function quicksightDataSourceParametersAuroraPostgresqlToTerraform(struct?: QuicksightDataSourceParametersAuroraPostgresqlOutputReference | QuicksightDataSourceParametersAuroraPostgresql): any;
/**
 * @stability stable
 */
export declare class QuicksightDataSourceParametersAuroraPostgresqlOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): QuicksightDataSourceParametersAuroraPostgresql | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: QuicksightDataSourceParametersAuroraPostgresql | undefined);
    private _database?;
    /**
     * @stability stable
     */
    get database(): string;
    /**
     * @stability stable
     */
    set database(value: string);
    /**
     * @stability stable
     */
    get databaseInput(): string | undefined;
    private _host?;
    /**
     * @stability stable
     */
    get host(): string;
    /**
     * @stability stable
     */
    set host(value: string);
    /**
     * @stability stable
     */
    get hostInput(): string | undefined;
    private _port?;
    /**
     * @stability stable
     */
    get port(): number;
    /**
     * @stability stable
     */
    set port(value: number);
    /**
     * @stability stable
     */
    get portInput(): number | undefined;
}
/**
 * @stability stable
 */
export interface QuicksightDataSourceParametersAwsIotAnalytics {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/quicksight_data_source#data_set_name QuicksightDataSource#data_set_name}.
     *
     * @stability stable
     */
    readonly dataSetName: string;
}
export declare function quicksightDataSourceParametersAwsIotAnalyticsToTerraform(struct?: QuicksightDataSourceParametersAwsIotAnalyticsOutputReference | QuicksightDataSourceParametersAwsIotAnalytics): any;
/**
 * @stability stable
 */
export declare class QuicksightDataSourceParametersAwsIotAnalyticsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): QuicksightDataSourceParametersAwsIotAnalytics | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: QuicksightDataSourceParametersAwsIotAnalytics | undefined);
    private _dataSetName?;
    /**
     * @stability stable
     */
    get dataSetName(): string;
    /**
     * @stability stable
     */
    set dataSetName(value: string);
    /**
     * @stability stable
     */
    get dataSetNameInput(): string | undefined;
}
/**
 * @stability stable
 */
export interface QuicksightDataSourceParametersJira {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/quicksight_data_source#site_base_url QuicksightDataSource#site_base_url}.
     *
     * @stability stable
     */
    readonly siteBaseUrl: string;
}
export declare function quicksightDataSourceParametersJiraToTerraform(struct?: QuicksightDataSourceParametersJiraOutputReference | QuicksightDataSourceParametersJira): any;
/**
 * @stability stable
 */
export declare class QuicksightDataSourceParametersJiraOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): QuicksightDataSourceParametersJira | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: QuicksightDataSourceParametersJira | undefined);
    private _siteBaseUrl?;
    /**
     * @stability stable
     */
    get siteBaseUrl(): string;
    /**
     * @stability stable
     */
    set siteBaseUrl(value: string);
    /**
     * @stability stable
     */
    get siteBaseUrlInput(): string | undefined;
}
/**
 * @stability stable
 */
export interface QuicksightDataSourceParametersMariaDb {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/quicksight_data_source#database QuicksightDataSource#database}.
     *
     * @stability stable
     */
    readonly database: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/quicksight_data_source#host QuicksightDataSource#host}.
     *
     * @stability stable
     */
    readonly host: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/quicksight_data_source#port QuicksightDataSource#port}.
     *
     * @stability stable
     */
    readonly port: number;
}
export declare function quicksightDataSourceParametersMariaDbToTerraform(struct?: QuicksightDataSourceParametersMariaDbOutputReference | QuicksightDataSourceParametersMariaDb): any;
/**
 * @stability stable
 */
export declare class QuicksightDataSourceParametersMariaDbOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): QuicksightDataSourceParametersMariaDb | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: QuicksightDataSourceParametersMariaDb | undefined);
    private _database?;
    /**
     * @stability stable
     */
    get database(): string;
    /**
     * @stability stable
     */
    set database(value: string);
    /**
     * @stability stable
     */
    get databaseInput(): string | undefined;
    private _host?;
    /**
     * @stability stable
     */
    get host(): string;
    /**
     * @stability stable
     */
    set host(value: string);
    /**
     * @stability stable
     */
    get hostInput(): string | undefined;
    private _port?;
    /**
     * @stability stable
     */
    get port(): number;
    /**
     * @stability stable
     */
    set port(value: number);
    /**
     * @stability stable
     */
    get portInput(): number | undefined;
}
/**
 * @stability stable
 */
export interface QuicksightDataSourceParametersMysql {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/quicksight_data_source#database QuicksightDataSource#database}.
     *
     * @stability stable
     */
    readonly database: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/quicksight_data_source#host QuicksightDataSource#host}.
     *
     * @stability stable
     */
    readonly host: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/quicksight_data_source#port QuicksightDataSource#port}.
     *
     * @stability stable
     */
    readonly port: number;
}
export declare function quicksightDataSourceParametersMysqlToTerraform(struct?: QuicksightDataSourceParametersMysqlOutputReference | QuicksightDataSourceParametersMysql): any;
/**
 * @stability stable
 */
export declare class QuicksightDataSourceParametersMysqlOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): QuicksightDataSourceParametersMysql | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: QuicksightDataSourceParametersMysql | undefined);
    private _database?;
    /**
     * @stability stable
     */
    get database(): string;
    /**
     * @stability stable
     */
    set database(value: string);
    /**
     * @stability stable
     */
    get databaseInput(): string | undefined;
    private _host?;
    /**
     * @stability stable
     */
    get host(): string;
    /**
     * @stability stable
     */
    set host(value: string);
    /**
     * @stability stable
     */
    get hostInput(): string | undefined;
    private _port?;
    /**
     * @stability stable
     */
    get port(): number;
    /**
     * @stability stable
     */
    set port(value: number);
    /**
     * @stability stable
     */
    get portInput(): number | undefined;
}
/**
 * @stability stable
 */
export interface QuicksightDataSourceParametersOracle {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/quicksight_data_source#database QuicksightDataSource#database}.
     *
     * @stability stable
     */
    readonly database: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/quicksight_data_source#host QuicksightDataSource#host}.
     *
     * @stability stable
     */
    readonly host: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/quicksight_data_source#port QuicksightDataSource#port}.
     *
     * @stability stable
     */
    readonly port: number;
}
export declare function quicksightDataSourceParametersOracleToTerraform(struct?: QuicksightDataSourceParametersOracleOutputReference | QuicksightDataSourceParametersOracle): any;
/**
 * @stability stable
 */
export declare class QuicksightDataSourceParametersOracleOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): QuicksightDataSourceParametersOracle | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: QuicksightDataSourceParametersOracle | undefined);
    private _database?;
    /**
     * @stability stable
     */
    get database(): string;
    /**
     * @stability stable
     */
    set database(value: string);
    /**
     * @stability stable
     */
    get databaseInput(): string | undefined;
    private _host?;
    /**
     * @stability stable
     */
    get host(): string;
    /**
     * @stability stable
     */
    set host(value: string);
    /**
     * @stability stable
     */
    get hostInput(): string | undefined;
    private _port?;
    /**
     * @stability stable
     */
    get port(): number;
    /**
     * @stability stable
     */
    set port(value: number);
    /**
     * @stability stable
     */
    get portInput(): number | undefined;
}
/**
 * @stability stable
 */
export interface QuicksightDataSourceParametersPostgresql {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/quicksight_data_source#database QuicksightDataSource#database}.
     *
     * @stability stable
     */
    readonly database: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/quicksight_data_source#host QuicksightDataSource#host}.
     *
     * @stability stable
     */
    readonly host: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/quicksight_data_source#port QuicksightDataSource#port}.
     *
     * @stability stable
     */
    readonly port: number;
}
export declare function quicksightDataSourceParametersPostgresqlToTerraform(struct?: QuicksightDataSourceParametersPostgresqlOutputReference | QuicksightDataSourceParametersPostgresql): any;
/**
 * @stability stable
 */
export declare class QuicksightDataSourceParametersPostgresqlOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): QuicksightDataSourceParametersPostgresql | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: QuicksightDataSourceParametersPostgresql | undefined);
    private _database?;
    /**
     * @stability stable
     */
    get database(): string;
    /**
     * @stability stable
     */
    set database(value: string);
    /**
     * @stability stable
     */
    get databaseInput(): string | undefined;
    private _host?;
    /**
     * @stability stable
     */
    get host(): string;
    /**
     * @stability stable
     */
    set host(value: string);
    /**
     * @stability stable
     */
    get hostInput(): string | undefined;
    private _port?;
    /**
     * @stability stable
     */
    get port(): number;
    /**
     * @stability stable
     */
    set port(value: number);
    /**
     * @stability stable
     */
    get portInput(): number | undefined;
}
/**
 * @stability stable
 */
export interface QuicksightDataSourceParametersPresto {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/quicksight_data_source#catalog QuicksightDataSource#catalog}.
     *
     * @stability stable
     */
    readonly catalog: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/quicksight_data_source#host QuicksightDataSource#host}.
     *
     * @stability stable
     */
    readonly host: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/quicksight_data_source#port QuicksightDataSource#port}.
     *
     * @stability stable
     */
    readonly port: number;
}
export declare function quicksightDataSourceParametersPrestoToTerraform(struct?: QuicksightDataSourceParametersPrestoOutputReference | QuicksightDataSourceParametersPresto): any;
/**
 * @stability stable
 */
export declare class QuicksightDataSourceParametersPrestoOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): QuicksightDataSourceParametersPresto | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: QuicksightDataSourceParametersPresto | undefined);
    private _catalog?;
    /**
     * @stability stable
     */
    get catalog(): string;
    /**
     * @stability stable
     */
    set catalog(value: string);
    /**
     * @stability stable
     */
    get catalogInput(): string | undefined;
    private _host?;
    /**
     * @stability stable
     */
    get host(): string;
    /**
     * @stability stable
     */
    set host(value: string);
    /**
     * @stability stable
     */
    get hostInput(): string | undefined;
    private _port?;
    /**
     * @stability stable
     */
    get port(): number;
    /**
     * @stability stable
     */
    set port(value: number);
    /**
     * @stability stable
     */
    get portInput(): number | undefined;
}
/**
 * @stability stable
 */
export interface QuicksightDataSourceParametersRds {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/quicksight_data_source#database QuicksightDataSource#database}.
     *
     * @stability stable
     */
    readonly database: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/quicksight_data_source#instance_id QuicksightDataSource#instance_id}.
     *
     * @stability stable
     */
    readonly instanceId: string;
}
export declare function quicksightDataSourceParametersRdsToTerraform(struct?: QuicksightDataSourceParametersRdsOutputReference | QuicksightDataSourceParametersRds): any;
/**
 * @stability stable
 */
export declare class QuicksightDataSourceParametersRdsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): QuicksightDataSourceParametersRds | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: QuicksightDataSourceParametersRds | undefined);
    private _database?;
    /**
     * @stability stable
     */
    get database(): string;
    /**
     * @stability stable
     */
    set database(value: string);
    /**
     * @stability stable
     */
    get databaseInput(): string | undefined;
    private _instanceId?;
    /**
     * @stability stable
     */
    get instanceId(): string;
    /**
     * @stability stable
     */
    set instanceId(value: string);
    /**
     * @stability stable
     */
    get instanceIdInput(): string | undefined;
}
/**
 * @stability stable
 */
export interface QuicksightDataSourceParametersRedshift {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/quicksight_data_source#cluster_id QuicksightDataSource#cluster_id}.
     *
     * @stability stable
     */
    readonly clusterId?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/quicksight_data_source#database QuicksightDataSource#database}.
     *
     * @stability stable
     */
    readonly database: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/quicksight_data_source#host QuicksightDataSource#host}.
     *
     * @stability stable
     */
    readonly host?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/quicksight_data_source#port QuicksightDataSource#port}.
     *
     * @stability stable
     */
    readonly port?: number;
}
export declare function quicksightDataSourceParametersRedshiftToTerraform(struct?: QuicksightDataSourceParametersRedshiftOutputReference | QuicksightDataSourceParametersRedshift): any;
/**
 * @stability stable
 */
export declare class QuicksightDataSourceParametersRedshiftOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): QuicksightDataSourceParametersRedshift | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: QuicksightDataSourceParametersRedshift | undefined);
    private _clusterId?;
    /**
     * @stability stable
     */
    get clusterId(): string;
    /**
     * @stability stable
     */
    set clusterId(value: string);
    /**
     * @stability stable
     */
    resetClusterId(): void;
    /**
     * @stability stable
     */
    get clusterIdInput(): string | undefined;
    private _database?;
    /**
     * @stability stable
     */
    get database(): string;
    /**
     * @stability stable
     */
    set database(value: string);
    /**
     * @stability stable
     */
    get databaseInput(): string | undefined;
    private _host?;
    /**
     * @stability stable
     */
    get host(): string;
    /**
     * @stability stable
     */
    set host(value: string);
    /**
     * @stability stable
     */
    resetHost(): void;
    /**
     * @stability stable
     */
    get hostInput(): string | undefined;
    private _port?;
    /**
     * @stability stable
     */
    get port(): number;
    /**
     * @stability stable
     */
    set port(value: number);
    /**
     * @stability stable
     */
    resetPort(): void;
    /**
     * @stability stable
     */
    get portInput(): number | undefined;
}
/**
 * @stability stable
 */
export interface QuicksightDataSourceParametersS3ManifestFileLocation {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/quicksight_data_source#bucket QuicksightDataSource#bucket}.
     *
     * @stability stable
     */
    readonly bucket: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/quicksight_data_source#key QuicksightDataSource#key}.
     *
     * @stability stable
     */
    readonly key: string;
}
export declare function quicksightDataSourceParametersS3ManifestFileLocationToTerraform(struct?: QuicksightDataSourceParametersS3ManifestFileLocationOutputReference | QuicksightDataSourceParametersS3ManifestFileLocation): any;
/**
 * @stability stable
 */
export declare class QuicksightDataSourceParametersS3ManifestFileLocationOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): QuicksightDataSourceParametersS3ManifestFileLocation | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: QuicksightDataSourceParametersS3ManifestFileLocation | undefined);
    private _bucket?;
    /**
     * @stability stable
     */
    get bucket(): string;
    /**
     * @stability stable
     */
    set bucket(value: string);
    /**
     * @stability stable
     */
    get bucketInput(): string | undefined;
    private _key?;
    /**
     * @stability stable
     */
    get key(): string;
    /**
     * @stability stable
     */
    set key(value: string);
    /**
     * @stability stable
     */
    get keyInput(): string | undefined;
}
/**
 * @stability stable
 */
export interface QuicksightDataSourceParametersS3 {
    /**
     * manifest_file_location block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/quicksight_data_source#manifest_file_location QuicksightDataSource#manifest_file_location}
     *
     * @stability stable
     */
    readonly manifestFileLocation: QuicksightDataSourceParametersS3ManifestFileLocation;
}
export declare function quicksightDataSourceParametersS3ToTerraform(struct?: QuicksightDataSourceParametersS3OutputReference | QuicksightDataSourceParametersS3): any;
/**
 * @stability stable
 */
export declare class QuicksightDataSourceParametersS3OutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): QuicksightDataSourceParametersS3 | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: QuicksightDataSourceParametersS3 | undefined);
    private _manifestFileLocation;
    /**
     * @stability stable
     */
    get manifestFileLocation(): QuicksightDataSourceParametersS3ManifestFileLocationOutputReference;
    /**
     * @stability stable
     */
    putManifestFileLocation(value: QuicksightDataSourceParametersS3ManifestFileLocation): void;
    /**
     * @stability stable
     */
    get manifestFileLocationInput(): QuicksightDataSourceParametersS3ManifestFileLocation | undefined;
}
/**
 * @stability stable
 */
export interface QuicksightDataSourceParametersServiceNow {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/quicksight_data_source#site_base_url QuicksightDataSource#site_base_url}.
     *
     * @stability stable
     */
    readonly siteBaseUrl: string;
}
export declare function quicksightDataSourceParametersServiceNowToTerraform(struct?: QuicksightDataSourceParametersServiceNowOutputReference | QuicksightDataSourceParametersServiceNow): any;
/**
 * @stability stable
 */
export declare class QuicksightDataSourceParametersServiceNowOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): QuicksightDataSourceParametersServiceNow | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: QuicksightDataSourceParametersServiceNow | undefined);
    private _siteBaseUrl?;
    /**
     * @stability stable
     */
    get siteBaseUrl(): string;
    /**
     * @stability stable
     */
    set siteBaseUrl(value: string);
    /**
     * @stability stable
     */
    get siteBaseUrlInput(): string | undefined;
}
/**
 * @stability stable
 */
export interface QuicksightDataSourceParametersSnowflake {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/quicksight_data_source#database QuicksightDataSource#database}.
     *
     * @stability stable
     */
    readonly database: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/quicksight_data_source#host QuicksightDataSource#host}.
     *
     * @stability stable
     */
    readonly host: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/quicksight_data_source#warehouse QuicksightDataSource#warehouse}.
     *
     * @stability stable
     */
    readonly warehouse: string;
}
export declare function quicksightDataSourceParametersSnowflakeToTerraform(struct?: QuicksightDataSourceParametersSnowflakeOutputReference | QuicksightDataSourceParametersSnowflake): any;
/**
 * @stability stable
 */
export declare class QuicksightDataSourceParametersSnowflakeOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): QuicksightDataSourceParametersSnowflake | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: QuicksightDataSourceParametersSnowflake | undefined);
    private _database?;
    /**
     * @stability stable
     */
    get database(): string;
    /**
     * @stability stable
     */
    set database(value: string);
    /**
     * @stability stable
     */
    get databaseInput(): string | undefined;
    private _host?;
    /**
     * @stability stable
     */
    get host(): string;
    /**
     * @stability stable
     */
    set host(value: string);
    /**
     * @stability stable
     */
    get hostInput(): string | undefined;
    private _warehouse?;
    /**
     * @stability stable
     */
    get warehouse(): string;
    /**
     * @stability stable
     */
    set warehouse(value: string);
    /**
     * @stability stable
     */
    get warehouseInput(): string | undefined;
}
/**
 * @stability stable
 */
export interface QuicksightDataSourceParametersSpark {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/quicksight_data_source#host QuicksightDataSource#host}.
     *
     * @stability stable
     */
    readonly host: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/quicksight_data_source#port QuicksightDataSource#port}.
     *
     * @stability stable
     */
    readonly port: number;
}
export declare function quicksightDataSourceParametersSparkToTerraform(struct?: QuicksightDataSourceParametersSparkOutputReference | QuicksightDataSourceParametersSpark): any;
/**
 * @stability stable
 */
export declare class QuicksightDataSourceParametersSparkOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): QuicksightDataSourceParametersSpark | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: QuicksightDataSourceParametersSpark | undefined);
    private _host?;
    /**
     * @stability stable
     */
    get host(): string;
    /**
     * @stability stable
     */
    set host(value: string);
    /**
     * @stability stable
     */
    get hostInput(): string | undefined;
    private _port?;
    /**
     * @stability stable
     */
    get port(): number;
    /**
     * @stability stable
     */
    set port(value: number);
    /**
     * @stability stable
     */
    get portInput(): number | undefined;
}
/**
 * @stability stable
 */
export interface QuicksightDataSourceParametersSqlServer {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/quicksight_data_source#database QuicksightDataSource#database}.
     *
     * @stability stable
     */
    readonly database: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/quicksight_data_source#host QuicksightDataSource#host}.
     *
     * @stability stable
     */
    readonly host: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/quicksight_data_source#port QuicksightDataSource#port}.
     *
     * @stability stable
     */
    readonly port: number;
}
export declare function quicksightDataSourceParametersSqlServerToTerraform(struct?: QuicksightDataSourceParametersSqlServerOutputReference | QuicksightDataSourceParametersSqlServer): any;
/**
 * @stability stable
 */
export declare class QuicksightDataSourceParametersSqlServerOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): QuicksightDataSourceParametersSqlServer | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: QuicksightDataSourceParametersSqlServer | undefined);
    private _database?;
    /**
     * @stability stable
     */
    get database(): string;
    /**
     * @stability stable
     */
    set database(value: string);
    /**
     * @stability stable
     */
    get databaseInput(): string | undefined;
    private _host?;
    /**
     * @stability stable
     */
    get host(): string;
    /**
     * @stability stable
     */
    set host(value: string);
    /**
     * @stability stable
     */
    get hostInput(): string | undefined;
    private _port?;
    /**
     * @stability stable
     */
    get port(): number;
    /**
     * @stability stable
     */
    set port(value: number);
    /**
     * @stability stable
     */
    get portInput(): number | undefined;
}
/**
 * @stability stable
 */
export interface QuicksightDataSourceParametersTeradata {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/quicksight_data_source#database QuicksightDataSource#database}.
     *
     * @stability stable
     */
    readonly database: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/quicksight_data_source#host QuicksightDataSource#host}.
     *
     * @stability stable
     */
    readonly host: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/quicksight_data_source#port QuicksightDataSource#port}.
     *
     * @stability stable
     */
    readonly port: number;
}
export declare function quicksightDataSourceParametersTeradataToTerraform(struct?: QuicksightDataSourceParametersTeradataOutputReference | QuicksightDataSourceParametersTeradata): any;
/**
 * @stability stable
 */
export declare class QuicksightDataSourceParametersTeradataOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): QuicksightDataSourceParametersTeradata | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: QuicksightDataSourceParametersTeradata | undefined);
    private _database?;
    /**
     * @stability stable
     */
    get database(): string;
    /**
     * @stability stable
     */
    set database(value: string);
    /**
     * @stability stable
     */
    get databaseInput(): string | undefined;
    private _host?;
    /**
     * @stability stable
     */
    get host(): string;
    /**
     * @stability stable
     */
    set host(value: string);
    /**
     * @stability stable
     */
    get hostInput(): string | undefined;
    private _port?;
    /**
     * @stability stable
     */
    get port(): number;
    /**
     * @stability stable
     */
    set port(value: number);
    /**
     * @stability stable
     */
    get portInput(): number | undefined;
}
/**
 * @stability stable
 */
export interface QuicksightDataSourceParametersTwitter {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/quicksight_data_source#max_rows QuicksightDataSource#max_rows}.
     *
     * @stability stable
     */
    readonly maxRows: number;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/quicksight_data_source#query QuicksightDataSource#query}.
     *
     * @stability stable
     */
    readonly query: string;
}
export declare function quicksightDataSourceParametersTwitterToTerraform(struct?: QuicksightDataSourceParametersTwitterOutputReference | QuicksightDataSourceParametersTwitter): any;
/**
 * @stability stable
 */
export declare class QuicksightDataSourceParametersTwitterOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): QuicksightDataSourceParametersTwitter | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: QuicksightDataSourceParametersTwitter | undefined);
    private _maxRows?;
    /**
     * @stability stable
     */
    get maxRows(): number;
    /**
     * @stability stable
     */
    set maxRows(value: number);
    /**
     * @stability stable
     */
    get maxRowsInput(): number | undefined;
    private _query?;
    /**
     * @stability stable
     */
    get query(): string;
    /**
     * @stability stable
     */
    set query(value: string);
    /**
     * @stability stable
     */
    get queryInput(): string | undefined;
}
/**
 * @stability stable
 */
export interface QuicksightDataSourceParameters {
    /**
     * amazon_elasticsearch block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/quicksight_data_source#amazon_elasticsearch QuicksightDataSource#amazon_elasticsearch}
     *
     * @stability stable
     */
    readonly amazonElasticsearch?: QuicksightDataSourceParametersAmazonElasticsearch;
    /**
     * athena block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/quicksight_data_source#athena QuicksightDataSource#athena}
     *
     * @stability stable
     */
    readonly athena?: QuicksightDataSourceParametersAthena;
    /**
     * aurora block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/quicksight_data_source#aurora QuicksightDataSource#aurora}
     *
     * @stability stable
     */
    readonly aurora?: QuicksightDataSourceParametersAurora;
    /**
     * aurora_postgresql block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/quicksight_data_source#aurora_postgresql QuicksightDataSource#aurora_postgresql}
     *
     * @stability stable
     */
    readonly auroraPostgresql?: QuicksightDataSourceParametersAuroraPostgresql;
    /**
     * aws_iot_analytics block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/quicksight_data_source#aws_iot_analytics QuicksightDataSource#aws_iot_analytics}
     *
     * @stability stable
     */
    readonly awsIotAnalytics?: QuicksightDataSourceParametersAwsIotAnalytics;
    /**
     * jira block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/quicksight_data_source#jira QuicksightDataSource#jira}
     *
     * @stability stable
     */
    readonly jira?: QuicksightDataSourceParametersJira;
    /**
     * maria_db block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/quicksight_data_source#maria_db QuicksightDataSource#maria_db}
     *
     * @stability stable
     */
    readonly mariaDb?: QuicksightDataSourceParametersMariaDb;
    /**
     * mysql block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/quicksight_data_source#mysql QuicksightDataSource#mysql}
     *
     * @stability stable
     */
    readonly mysql?: QuicksightDataSourceParametersMysql;
    /**
     * oracle block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/quicksight_data_source#oracle QuicksightDataSource#oracle}
     *
     * @stability stable
     */
    readonly oracle?: QuicksightDataSourceParametersOracle;
    /**
     * postgresql block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/quicksight_data_source#postgresql QuicksightDataSource#postgresql}
     *
     * @stability stable
     */
    readonly postgresql?: QuicksightDataSourceParametersPostgresql;
    /**
     * presto block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/quicksight_data_source#presto QuicksightDataSource#presto}
     *
     * @stability stable
     */
    readonly presto?: QuicksightDataSourceParametersPresto;
    /**
     * rds block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/quicksight_data_source#rds QuicksightDataSource#rds}
     *
     * @stability stable
     */
    readonly rds?: QuicksightDataSourceParametersRds;
    /**
     * redshift block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/quicksight_data_source#redshift QuicksightDataSource#redshift}
     *
     * @stability stable
     */
    readonly redshift?: QuicksightDataSourceParametersRedshift;
    /**
     * s3 block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/quicksight_data_source#s3 QuicksightDataSource#s3}
     *
     * @stability stable
     */
    readonly s3?: QuicksightDataSourceParametersS3;
    /**
     * service_now block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/quicksight_data_source#service_now QuicksightDataSource#service_now}
     *
     * @stability stable
     */
    readonly serviceNow?: QuicksightDataSourceParametersServiceNow;
    /**
     * snowflake block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/quicksight_data_source#snowflake QuicksightDataSource#snowflake}
     *
     * @stability stable
     */
    readonly snowflake?: QuicksightDataSourceParametersSnowflake;
    /**
     * spark block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/quicksight_data_source#spark QuicksightDataSource#spark}
     *
     * @stability stable
     */
    readonly spark?: QuicksightDataSourceParametersSpark;
    /**
     * sql_server block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/quicksight_data_source#sql_server QuicksightDataSource#sql_server}
     *
     * @stability stable
     */
    readonly sqlServer?: QuicksightDataSourceParametersSqlServer;
    /**
     * teradata block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/quicksight_data_source#teradata QuicksightDataSource#teradata}
     *
     * @stability stable
     */
    readonly teradata?: QuicksightDataSourceParametersTeradata;
    /**
     * twitter block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/quicksight_data_source#twitter QuicksightDataSource#twitter}
     *
     * @stability stable
     */
    readonly twitter?: QuicksightDataSourceParametersTwitter;
}
export declare function quicksightDataSourceParametersToTerraform(struct?: QuicksightDataSourceParametersOutputReference | QuicksightDataSourceParameters): any;
/**
 * @stability stable
 */
export declare class QuicksightDataSourceParametersOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): QuicksightDataSourceParameters | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: QuicksightDataSourceParameters | undefined);
    private _amazonElasticsearch;
    /**
     * @stability stable
     */
    get amazonElasticsearch(): QuicksightDataSourceParametersAmazonElasticsearchOutputReference;
    /**
     * @stability stable
     */
    putAmazonElasticsearch(value: QuicksightDataSourceParametersAmazonElasticsearch): void;
    /**
     * @stability stable
     */
    resetAmazonElasticsearch(): void;
    /**
     * @stability stable
     */
    get amazonElasticsearchInput(): QuicksightDataSourceParametersAmazonElasticsearch | undefined;
    private _athena;
    /**
     * @stability stable
     */
    get athena(): QuicksightDataSourceParametersAthenaOutputReference;
    /**
     * @stability stable
     */
    putAthena(value: QuicksightDataSourceParametersAthena): void;
    /**
     * @stability stable
     */
    resetAthena(): void;
    /**
     * @stability stable
     */
    get athenaInput(): QuicksightDataSourceParametersAthena | undefined;
    private _aurora;
    /**
     * @stability stable
     */
    get aurora(): QuicksightDataSourceParametersAuroraOutputReference;
    /**
     * @stability stable
     */
    putAurora(value: QuicksightDataSourceParametersAurora): void;
    /**
     * @stability stable
     */
    resetAurora(): void;
    /**
     * @stability stable
     */
    get auroraInput(): QuicksightDataSourceParametersAurora | undefined;
    private _auroraPostgresql;
    /**
     * @stability stable
     */
    get auroraPostgresql(): QuicksightDataSourceParametersAuroraPostgresqlOutputReference;
    /**
     * @stability stable
     */
    putAuroraPostgresql(value: QuicksightDataSourceParametersAuroraPostgresql): void;
    /**
     * @stability stable
     */
    resetAuroraPostgresql(): void;
    /**
     * @stability stable
     */
    get auroraPostgresqlInput(): QuicksightDataSourceParametersAuroraPostgresql | undefined;
    private _awsIotAnalytics;
    /**
     * @stability stable
     */
    get awsIotAnalytics(): QuicksightDataSourceParametersAwsIotAnalyticsOutputReference;
    /**
     * @stability stable
     */
    putAwsIotAnalytics(value: QuicksightDataSourceParametersAwsIotAnalytics): void;
    /**
     * @stability stable
     */
    resetAwsIotAnalytics(): void;
    /**
     * @stability stable
     */
    get awsIotAnalyticsInput(): QuicksightDataSourceParametersAwsIotAnalytics | undefined;
    private _jira;
    /**
     * @stability stable
     */
    get jira(): QuicksightDataSourceParametersJiraOutputReference;
    /**
     * @stability stable
     */
    putJira(value: QuicksightDataSourceParametersJira): void;
    /**
     * @stability stable
     */
    resetJira(): void;
    /**
     * @stability stable
     */
    get jiraInput(): QuicksightDataSourceParametersJira | undefined;
    private _mariaDb;
    /**
     * @stability stable
     */
    get mariaDb(): QuicksightDataSourceParametersMariaDbOutputReference;
    /**
     * @stability stable
     */
    putMariaDb(value: QuicksightDataSourceParametersMariaDb): void;
    /**
     * @stability stable
     */
    resetMariaDb(): void;
    /**
     * @stability stable
     */
    get mariaDbInput(): QuicksightDataSourceParametersMariaDb | undefined;
    private _mysql;
    /**
     * @stability stable
     */
    get mysql(): QuicksightDataSourceParametersMysqlOutputReference;
    /**
     * @stability stable
     */
    putMysql(value: QuicksightDataSourceParametersMysql): void;
    /**
     * @stability stable
     */
    resetMysql(): void;
    /**
     * @stability stable
     */
    get mysqlInput(): QuicksightDataSourceParametersMysql | undefined;
    private _oracle;
    /**
     * @stability stable
     */
    get oracle(): QuicksightDataSourceParametersOracleOutputReference;
    /**
     * @stability stable
     */
    putOracle(value: QuicksightDataSourceParametersOracle): void;
    /**
     * @stability stable
     */
    resetOracle(): void;
    /**
     * @stability stable
     */
    get oracleInput(): QuicksightDataSourceParametersOracle | undefined;
    private _postgresql;
    /**
     * @stability stable
     */
    get postgresql(): QuicksightDataSourceParametersPostgresqlOutputReference;
    /**
     * @stability stable
     */
    putPostgresql(value: QuicksightDataSourceParametersPostgresql): void;
    /**
     * @stability stable
     */
    resetPostgresql(): void;
    /**
     * @stability stable
     */
    get postgresqlInput(): QuicksightDataSourceParametersPostgresql | undefined;
    private _presto;
    /**
     * @stability stable
     */
    get presto(): QuicksightDataSourceParametersPrestoOutputReference;
    /**
     * @stability stable
     */
    putPresto(value: QuicksightDataSourceParametersPresto): void;
    /**
     * @stability stable
     */
    resetPresto(): void;
    /**
     * @stability stable
     */
    get prestoInput(): QuicksightDataSourceParametersPresto | undefined;
    private _rds;
    /**
     * @stability stable
     */
    get rds(): QuicksightDataSourceParametersRdsOutputReference;
    /**
     * @stability stable
     */
    putRds(value: QuicksightDataSourceParametersRds): void;
    /**
     * @stability stable
     */
    resetRds(): void;
    /**
     * @stability stable
     */
    get rdsInput(): QuicksightDataSourceParametersRds | undefined;
    private _redshift;
    /**
     * @stability stable
     */
    get redshift(): QuicksightDataSourceParametersRedshiftOutputReference;
    /**
     * @stability stable
     */
    putRedshift(value: QuicksightDataSourceParametersRedshift): void;
    /**
     * @stability stable
     */
    resetRedshift(): void;
    /**
     * @stability stable
     */
    get redshiftInput(): QuicksightDataSourceParametersRedshift | undefined;
    private _s3;
    /**
     * @stability stable
     */
    get s3(): QuicksightDataSourceParametersS3OutputReference;
    /**
     * @stability stable
     */
    putS3(value: QuicksightDataSourceParametersS3): void;
    /**
     * @stability stable
     */
    resetS3(): void;
    /**
     * @stability stable
     */
    get s3Input(): QuicksightDataSourceParametersS3 | undefined;
    private _serviceNow;
    /**
     * @stability stable
     */
    get serviceNow(): QuicksightDataSourceParametersServiceNowOutputReference;
    /**
     * @stability stable
     */
    putServiceNow(value: QuicksightDataSourceParametersServiceNow): void;
    /**
     * @stability stable
     */
    resetServiceNow(): void;
    /**
     * @stability stable
     */
    get serviceNowInput(): QuicksightDataSourceParametersServiceNow | undefined;
    private _snowflake;
    /**
     * @stability stable
     */
    get snowflake(): QuicksightDataSourceParametersSnowflakeOutputReference;
    /**
     * @stability stable
     */
    putSnowflake(value: QuicksightDataSourceParametersSnowflake): void;
    /**
     * @stability stable
     */
    resetSnowflake(): void;
    /**
     * @stability stable
     */
    get snowflakeInput(): QuicksightDataSourceParametersSnowflake | undefined;
    private _spark;
    /**
     * @stability stable
     */
    get spark(): QuicksightDataSourceParametersSparkOutputReference;
    /**
     * @stability stable
     */
    putSpark(value: QuicksightDataSourceParametersSpark): void;
    /**
     * @stability stable
     */
    resetSpark(): void;
    /**
     * @stability stable
     */
    get sparkInput(): QuicksightDataSourceParametersSpark | undefined;
    private _sqlServer;
    /**
     * @stability stable
     */
    get sqlServer(): QuicksightDataSourceParametersSqlServerOutputReference;
    /**
     * @stability stable
     */
    putSqlServer(value: QuicksightDataSourceParametersSqlServer): void;
    /**
     * @stability stable
     */
    resetSqlServer(): void;
    /**
     * @stability stable
     */
    get sqlServerInput(): QuicksightDataSourceParametersSqlServer | undefined;
    private _teradata;
    /**
     * @stability stable
     */
    get teradata(): QuicksightDataSourceParametersTeradataOutputReference;
    /**
     * @stability stable
     */
    putTeradata(value: QuicksightDataSourceParametersTeradata): void;
    /**
     * @stability stable
     */
    resetTeradata(): void;
    /**
     * @stability stable
     */
    get teradataInput(): QuicksightDataSourceParametersTeradata | undefined;
    private _twitter;
    /**
     * @stability stable
     */
    get twitter(): QuicksightDataSourceParametersTwitterOutputReference;
    /**
     * @stability stable
     */
    putTwitter(value: QuicksightDataSourceParametersTwitter): void;
    /**
     * @stability stable
     */
    resetTwitter(): void;
    /**
     * @stability stable
     */
    get twitterInput(): QuicksightDataSourceParametersTwitter | undefined;
}
/**
 * @stability stable
 */
export interface QuicksightDataSourcePermission {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/quicksight_data_source#actions QuicksightDataSource#actions}.
     *
     * @stability stable
     */
    readonly actions: string[];
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/quicksight_data_source#principal QuicksightDataSource#principal}.
     *
     * @stability stable
     */
    readonly principal: string;
}
export declare function quicksightDataSourcePermissionToTerraform(struct?: QuicksightDataSourcePermission | cdktf.IResolvable): any;
/**
 * @stability stable
 */
export interface QuicksightDataSourceSslProperties {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/quicksight_data_source#disable_ssl QuicksightDataSource#disable_ssl}.
     *
     * @stability stable
     */
    readonly disableSsl: boolean | cdktf.IResolvable;
}
export declare function quicksightDataSourceSslPropertiesToTerraform(struct?: QuicksightDataSourceSslPropertiesOutputReference | QuicksightDataSourceSslProperties): any;
/**
 * @stability stable
 */
export declare class QuicksightDataSourceSslPropertiesOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): QuicksightDataSourceSslProperties | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: QuicksightDataSourceSslProperties | undefined);
    private _disableSsl?;
    /**
     * @stability stable
     */
    get disableSsl(): boolean | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set disableSsl(value: boolean | cdktf.IResolvable);
    /**
     * @stability stable
     */
    get disableSslInput(): boolean | cdktf.IResolvable | undefined;
}
/**
 * @stability stable
 */
export interface QuicksightDataSourceVpcConnectionProperties {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/quicksight_data_source#vpc_connection_arn QuicksightDataSource#vpc_connection_arn}.
     *
     * @stability stable
     */
    readonly vpcConnectionArn: string;
}
export declare function quicksightDataSourceVpcConnectionPropertiesToTerraform(struct?: QuicksightDataSourceVpcConnectionPropertiesOutputReference | QuicksightDataSourceVpcConnectionProperties): any;
/**
 * @stability stable
 */
export declare class QuicksightDataSourceVpcConnectionPropertiesOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): QuicksightDataSourceVpcConnectionProperties | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: QuicksightDataSourceVpcConnectionProperties | undefined);
    private _vpcConnectionArn?;
    /**
     * @stability stable
     */
    get vpcConnectionArn(): string;
    /**
     * @stability stable
     */
    set vpcConnectionArn(value: string);
    /**
     * @stability stable
     */
    get vpcConnectionArnInput(): string | undefined;
}
/**
 * Represents a {@link https://www.terraform.io/docs/providers/aws/r/quicksight_data_source aws_quicksight_data_source}.
 *
 * @stability stable
 */
export declare class QuicksightDataSource extends cdktf.TerraformResource {
    /**
     * @stability stable
     */
    static readonly tfResourceType: string;
    /**
     * Create a new {@link https://www.terraform.io/docs/providers/aws/r/quicksight_data_source aws_quicksight_data_source} Resource.
     *
     * @param scope The scope in which to define this construct.
     * @param id The scoped construct ID.
     * @stability stable
     */
    constructor(scope: Construct, id: string, config: QuicksightDataSourceConfig);
    /**
     * @stability stable
     */
    get arn(): string;
    private _awsAccountId?;
    /**
     * @stability stable
     */
    get awsAccountId(): string;
    /**
     * @stability stable
     */
    set awsAccountId(value: string);
    /**
     * @stability stable
     */
    resetAwsAccountId(): void;
    /**
     * @stability stable
     */
    get awsAccountIdInput(): string | undefined;
    private _dataSourceId?;
    /**
     * @stability stable
     */
    get dataSourceId(): string;
    /**
     * @stability stable
     */
    set dataSourceId(value: string);
    /**
     * @stability stable
     */
    get dataSourceIdInput(): string | undefined;
    /**
     * @stability stable
     */
    get id(): string;
    private _name?;
    /**
     * @stability stable
     */
    get name(): string;
    /**
     * @stability stable
     */
    set name(value: string);
    /**
     * @stability stable
     */
    get nameInput(): string | undefined;
    private _tags?;
    /**
     * @stability stable
     */
    get tags(): {
        [key: string]: string;
    };
    /**
     * @stability stable
     */
    set tags(value: {
        [key: string]: string;
    });
    /**
     * @stability stable
     */
    resetTags(): void;
    /**
     * @stability stable
     */
    get tagsInput(): {
        [key: string]: string;
    } | undefined;
    private _tagsAll?;
    /**
     * @stability stable
     */
    get tagsAll(): {
        [key: string]: string;
    };
    /**
     * @stability stable
     */
    set tagsAll(value: {
        [key: string]: string;
    });
    /**
     * @stability stable
     */
    resetTagsAll(): void;
    /**
     * @stability stable
     */
    get tagsAllInput(): {
        [key: string]: string;
    } | undefined;
    private _type?;
    /**
     * @stability stable
     */
    get type(): string;
    /**
     * @stability stable
     */
    set type(value: string);
    /**
     * @stability stable
     */
    get typeInput(): string | undefined;
    private _credentials;
    /**
     * @stability stable
     */
    get credentials(): QuicksightDataSourceCredentialsOutputReference;
    /**
     * @stability stable
     */
    putCredentials(value: QuicksightDataSourceCredentials): void;
    /**
     * @stability stable
     */
    resetCredentials(): void;
    /**
     * @stability stable
     */
    get credentialsInput(): QuicksightDataSourceCredentials | undefined;
    private _parameters;
    /**
     * @stability stable
     */
    get parameters(): QuicksightDataSourceParametersOutputReference;
    /**
     * @stability stable
     */
    putParameters(value: QuicksightDataSourceParameters): void;
    /**
     * @stability stable
     */
    get parametersInput(): QuicksightDataSourceParameters | undefined;
    private _permission?;
    /**
     * @stability stable
     */
    get permission(): QuicksightDataSourcePermission[] | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set permission(value: QuicksightDataSourcePermission[] | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetPermission(): void;
    /**
     * @stability stable
     */
    get permissionInput(): cdktf.IResolvable | QuicksightDataSourcePermission[] | undefined;
    private _sslProperties;
    /**
     * @stability stable
     */
    get sslProperties(): QuicksightDataSourceSslPropertiesOutputReference;
    /**
     * @stability stable
     */
    putSslProperties(value: QuicksightDataSourceSslProperties): void;
    /**
     * @stability stable
     */
    resetSslProperties(): void;
    /**
     * @stability stable
     */
    get sslPropertiesInput(): QuicksightDataSourceSslProperties | undefined;
    private _vpcConnectionProperties;
    /**
     * @stability stable
     */
    get vpcConnectionProperties(): QuicksightDataSourceVpcConnectionPropertiesOutputReference;
    /**
     * @stability stable
     */
    putVpcConnectionProperties(value: QuicksightDataSourceVpcConnectionProperties): void;
    /**
     * @stability stable
     */
    resetVpcConnectionProperties(): void;
    /**
     * @stability stable
     */
    get vpcConnectionPropertiesInput(): QuicksightDataSourceVpcConnectionProperties | undefined;
    /**
     * @stability stable
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
