import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
/**
 * AWS Simple Storage Service.
 *
 * @stability stable
 */
export interface S3AccessPointConfig extends cdktf.TerraformMetaArguments {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_access_point#account_id S3AccessPoint#account_id}.
     *
     * @stability stable
     */
    readonly accountId?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_access_point#bucket S3AccessPoint#bucket}.
     *
     * @stability stable
     */
    readonly bucket: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_access_point#name S3AccessPoint#name}.
     *
     * @stability stable
     */
    readonly name: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_access_point#policy S3AccessPoint#policy}.
     *
     * @stability stable
     */
    readonly policy?: string;
    /**
     * public_access_block_configuration block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_access_point#public_access_block_configuration S3AccessPoint#public_access_block_configuration}
     *
     * @stability stable
     */
    readonly publicAccessBlockConfiguration?: S3AccessPointPublicAccessBlockConfiguration;
    /**
     * vpc_configuration block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_access_point#vpc_configuration S3AccessPoint#vpc_configuration}
     *
     * @stability stable
     */
    readonly vpcConfiguration?: S3AccessPointVpcConfiguration;
}
/**
 * @stability stable
 */
export interface S3AccessPointPublicAccessBlockConfiguration {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_access_point#block_public_acls S3AccessPoint#block_public_acls}.
     *
     * @stability stable
     */
    readonly blockPublicAcls?: boolean | cdktf.IResolvable;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_access_point#block_public_policy S3AccessPoint#block_public_policy}.
     *
     * @stability stable
     */
    readonly blockPublicPolicy?: boolean | cdktf.IResolvable;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_access_point#ignore_public_acls S3AccessPoint#ignore_public_acls}.
     *
     * @stability stable
     */
    readonly ignorePublicAcls?: boolean | cdktf.IResolvable;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_access_point#restrict_public_buckets S3AccessPoint#restrict_public_buckets}.
     *
     * @stability stable
     */
    readonly restrictPublicBuckets?: boolean | cdktf.IResolvable;
}
export declare function s3AccessPointPublicAccessBlockConfigurationToTerraform(struct?: S3AccessPointPublicAccessBlockConfigurationOutputReference | S3AccessPointPublicAccessBlockConfiguration): any;
/**
 * @stability stable
 */
export declare class S3AccessPointPublicAccessBlockConfigurationOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): S3AccessPointPublicAccessBlockConfiguration | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: S3AccessPointPublicAccessBlockConfiguration | undefined);
    private _blockPublicAcls?;
    /**
     * @stability stable
     */
    get blockPublicAcls(): boolean | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set blockPublicAcls(value: boolean | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetBlockPublicAcls(): void;
    /**
     * @stability stable
     */
    get blockPublicAclsInput(): boolean | cdktf.IResolvable | undefined;
    private _blockPublicPolicy?;
    /**
     * @stability stable
     */
    get blockPublicPolicy(): boolean | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set blockPublicPolicy(value: boolean | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetBlockPublicPolicy(): void;
    /**
     * @stability stable
     */
    get blockPublicPolicyInput(): boolean | cdktf.IResolvable | undefined;
    private _ignorePublicAcls?;
    /**
     * @stability stable
     */
    get ignorePublicAcls(): boolean | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set ignorePublicAcls(value: boolean | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetIgnorePublicAcls(): void;
    /**
     * @stability stable
     */
    get ignorePublicAclsInput(): boolean | cdktf.IResolvable | undefined;
    private _restrictPublicBuckets?;
    /**
     * @stability stable
     */
    get restrictPublicBuckets(): boolean | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set restrictPublicBuckets(value: boolean | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetRestrictPublicBuckets(): void;
    /**
     * @stability stable
     */
    get restrictPublicBucketsInput(): boolean | cdktf.IResolvable | undefined;
}
/**
 * @stability stable
 */
export interface S3AccessPointVpcConfiguration {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_access_point#vpc_id S3AccessPoint#vpc_id}.
     *
     * @stability stable
     */
    readonly vpcId: string;
}
export declare function s3AccessPointVpcConfigurationToTerraform(struct?: S3AccessPointVpcConfigurationOutputReference | S3AccessPointVpcConfiguration): any;
/**
 * @stability stable
 */
export declare class S3AccessPointVpcConfigurationOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): S3AccessPointVpcConfiguration | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: S3AccessPointVpcConfiguration | undefined);
    private _vpcId?;
    /**
     * @stability stable
     */
    get vpcId(): string;
    /**
     * @stability stable
     */
    set vpcId(value: string);
    /**
     * @stability stable
     */
    get vpcIdInput(): string | undefined;
}
/**
 * Represents a {@link https://www.terraform.io/docs/providers/aws/r/s3_access_point aws_s3_access_point}.
 *
 * @stability stable
 */
export declare class S3AccessPoint extends cdktf.TerraformResource {
    /**
     * @stability stable
     */
    static readonly tfResourceType: string;
    /**
     * Create a new {@link https://www.terraform.io/docs/providers/aws/r/s3_access_point aws_s3_access_point} Resource.
     *
     * @param scope The scope in which to define this construct.
     * @param id The scoped construct ID.
     * @stability stable
     */
    constructor(scope: Construct, id: string, config: S3AccessPointConfig);
    private _accountId?;
    /**
     * @stability stable
     */
    get accountId(): string;
    /**
     * @stability stable
     */
    set accountId(value: string);
    /**
     * @stability stable
     */
    resetAccountId(): void;
    /**
     * @stability stable
     */
    get accountIdInput(): string | undefined;
    /**
     * @stability stable
     */
    get alias(): string;
    /**
     * @stability stable
     */
    get arn(): string;
    private _bucket?;
    /**
     * @stability stable
     */
    get bucket(): string;
    /**
     * @stability stable
     */
    set bucket(value: string);
    /**
     * @stability stable
     */
    get bucketInput(): string | undefined;
    /**
     * @stability stable
     */
    get domainName(): string;
    /**
     * @stability stable
     */
    endpoints(key: string): string | cdktf.IResolvable;
    /**
     * @stability stable
     */
    get hasPublicAccessPolicy(): cdktf.IResolvable;
    /**
     * @stability stable
     */
    get id(): string;
    private _name?;
    /**
     * @stability stable
     */
    get name(): string;
    /**
     * @stability stable
     */
    set name(value: string);
    /**
     * @stability stable
     */
    get nameInput(): string | undefined;
    /**
     * @stability stable
     */
    get networkOrigin(): string;
    private _policy?;
    /**
     * @stability stable
     */
    get policy(): string;
    /**
     * @stability stable
     */
    set policy(value: string);
    /**
     * @stability stable
     */
    resetPolicy(): void;
    /**
     * @stability stable
     */
    get policyInput(): string | undefined;
    private _publicAccessBlockConfiguration;
    /**
     * @stability stable
     */
    get publicAccessBlockConfiguration(): S3AccessPointPublicAccessBlockConfigurationOutputReference;
    /**
     * @stability stable
     */
    putPublicAccessBlockConfiguration(value: S3AccessPointPublicAccessBlockConfiguration): void;
    /**
     * @stability stable
     */
    resetPublicAccessBlockConfiguration(): void;
    /**
     * @stability stable
     */
    get publicAccessBlockConfigurationInput(): S3AccessPointPublicAccessBlockConfiguration | undefined;
    private _vpcConfiguration;
    /**
     * @stability stable
     */
    get vpcConfiguration(): S3AccessPointVpcConfigurationOutputReference;
    /**
     * @stability stable
     */
    putVpcConfiguration(value: S3AccessPointVpcConfiguration): void;
    /**
     * @stability stable
     */
    resetVpcConfiguration(): void;
    /**
     * @stability stable
     */
    get vpcConfigurationInput(): S3AccessPointVpcConfiguration | undefined;
    /**
     * @stability stable
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
