import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
/**
 * AWS Simple Storage Service.
 *
 * @stability stable
 */
export interface S3BucketConfig extends cdktf.TerraformMetaArguments {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_bucket#acceleration_status S3Bucket#acceleration_status}.
     *
     * @stability stable
     */
    readonly accelerationStatus?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_bucket#acl S3Bucket#acl}.
     *
     * @stability stable
     */
    readonly acl?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_bucket#bucket S3Bucket#bucket}.
     *
     * @stability stable
     */
    readonly bucket?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_bucket#bucket_prefix S3Bucket#bucket_prefix}.
     *
     * @stability stable
     */
    readonly bucketPrefix?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_bucket#force_destroy S3Bucket#force_destroy}.
     *
     * @stability stable
     */
    readonly forceDestroy?: boolean | cdktf.IResolvable;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_bucket#hosted_zone_id S3Bucket#hosted_zone_id}.
     *
     * @stability stable
     */
    readonly hostedZoneId?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_bucket#policy S3Bucket#policy}.
     *
     * @stability stable
     */
    readonly policy?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_bucket#request_payer S3Bucket#request_payer}.
     *
     * @stability stable
     */
    readonly requestPayer?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_bucket#tags S3Bucket#tags}.
     *
     * @stability stable
     */
    readonly tags?: {
        [key: string]: string;
    };
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_bucket#tags_all S3Bucket#tags_all}.
     *
     * @stability stable
     */
    readonly tagsAll?: {
        [key: string]: string;
    };
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_bucket#website_domain S3Bucket#website_domain}.
     *
     * @stability stable
     */
    readonly websiteDomain?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_bucket#website_endpoint S3Bucket#website_endpoint}.
     *
     * @stability stable
     */
    readonly websiteEndpoint?: string;
    /**
     * cors_rule block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_bucket#cors_rule S3Bucket#cors_rule}
     *
     * @stability stable
     */
    readonly corsRule?: S3BucketCorsRule[] | cdktf.IResolvable;
    /**
     * grant block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_bucket#grant S3Bucket#grant}
     *
     * @stability stable
     */
    readonly grant?: S3BucketGrant[] | cdktf.IResolvable;
    /**
     * lifecycle_rule block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_bucket#lifecycle_rule S3Bucket#lifecycle_rule}
     *
     * @stability stable
     */
    readonly lifecycleRule?: S3BucketLifecycleRule[] | cdktf.IResolvable;
    /**
     * logging block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_bucket#logging S3Bucket#logging}
     *
     * @stability stable
     */
    readonly logging?: S3BucketLogging[] | cdktf.IResolvable;
    /**
     * object_lock_configuration block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_bucket#object_lock_configuration S3Bucket#object_lock_configuration}
     *
     * @stability stable
     */
    readonly objectLockConfiguration?: S3BucketObjectLockConfiguration;
    /**
     * replication_configuration block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_bucket#replication_configuration S3Bucket#replication_configuration}
     *
     * @stability stable
     */
    readonly replicationConfiguration?: S3BucketReplicationConfiguration;
    /**
     * server_side_encryption_configuration block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_bucket#server_side_encryption_configuration S3Bucket#server_side_encryption_configuration}
     *
     * @stability stable
     */
    readonly serverSideEncryptionConfiguration?: S3BucketServerSideEncryptionConfiguration;
    /**
     * versioning block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_bucket#versioning S3Bucket#versioning}
     *
     * @stability stable
     */
    readonly versioning?: S3BucketVersioning;
    /**
     * website block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_bucket#website S3Bucket#website}
     *
     * @stability stable
     */
    readonly website?: S3BucketWebsite;
}
/**
 * @stability stable
 */
export interface S3BucketCorsRule {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_bucket#allowed_headers S3Bucket#allowed_headers}.
     *
     * @stability stable
     */
    readonly allowedHeaders?: string[];
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_bucket#allowed_methods S3Bucket#allowed_methods}.
     *
     * @stability stable
     */
    readonly allowedMethods: string[];
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_bucket#allowed_origins S3Bucket#allowed_origins}.
     *
     * @stability stable
     */
    readonly allowedOrigins: string[];
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_bucket#expose_headers S3Bucket#expose_headers}.
     *
     * @stability stable
     */
    readonly exposeHeaders?: string[];
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_bucket#max_age_seconds S3Bucket#max_age_seconds}.
     *
     * @stability stable
     */
    readonly maxAgeSeconds?: number;
}
export declare function s3BucketCorsRuleToTerraform(struct?: S3BucketCorsRule | cdktf.IResolvable): any;
/**
 * @stability stable
 */
export interface S3BucketGrant {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_bucket#id S3Bucket#id}.
     *
     * @stability stable
     */
    readonly id?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_bucket#permissions S3Bucket#permissions}.
     *
     * @stability stable
     */
    readonly permissions: string[];
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_bucket#type S3Bucket#type}.
     *
     * @stability stable
     */
    readonly type: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_bucket#uri S3Bucket#uri}.
     *
     * @stability stable
     */
    readonly uri?: string;
}
export declare function s3BucketGrantToTerraform(struct?: S3BucketGrant | cdktf.IResolvable): any;
/**
 * @stability stable
 */
export interface S3BucketLifecycleRuleExpiration {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_bucket#date S3Bucket#date}.
     *
     * @stability stable
     */
    readonly date?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_bucket#days S3Bucket#days}.
     *
     * @stability stable
     */
    readonly days?: number;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_bucket#expired_object_delete_marker S3Bucket#expired_object_delete_marker}.
     *
     * @stability stable
     */
    readonly expiredObjectDeleteMarker?: boolean | cdktf.IResolvable;
}
export declare function s3BucketLifecycleRuleExpirationToTerraform(struct?: S3BucketLifecycleRuleExpirationOutputReference | S3BucketLifecycleRuleExpiration): any;
/**
 * @stability stable
 */
export declare class S3BucketLifecycleRuleExpirationOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): S3BucketLifecycleRuleExpiration | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: S3BucketLifecycleRuleExpiration | undefined);
    private _date?;
    /**
     * @stability stable
     */
    get date(): string;
    /**
     * @stability stable
     */
    set date(value: string);
    /**
     * @stability stable
     */
    resetDate(): void;
    /**
     * @stability stable
     */
    get dateInput(): string | undefined;
    private _days?;
    /**
     * @stability stable
     */
    get days(): number;
    /**
     * @stability stable
     */
    set days(value: number);
    /**
     * @stability stable
     */
    resetDays(): void;
    /**
     * @stability stable
     */
    get daysInput(): number | undefined;
    private _expiredObjectDeleteMarker?;
    /**
     * @stability stable
     */
    get expiredObjectDeleteMarker(): boolean | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set expiredObjectDeleteMarker(value: boolean | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetExpiredObjectDeleteMarker(): void;
    /**
     * @stability stable
     */
    get expiredObjectDeleteMarkerInput(): boolean | cdktf.IResolvable | undefined;
}
/**
 * @stability stable
 */
export interface S3BucketLifecycleRuleNoncurrentVersionExpiration {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_bucket#days S3Bucket#days}.
     *
     * @stability stable
     */
    readonly days?: number;
}
export declare function s3BucketLifecycleRuleNoncurrentVersionExpirationToTerraform(struct?: S3BucketLifecycleRuleNoncurrentVersionExpirationOutputReference | S3BucketLifecycleRuleNoncurrentVersionExpiration): any;
/**
 * @stability stable
 */
export declare class S3BucketLifecycleRuleNoncurrentVersionExpirationOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): S3BucketLifecycleRuleNoncurrentVersionExpiration | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: S3BucketLifecycleRuleNoncurrentVersionExpiration | undefined);
    private _days?;
    /**
     * @stability stable
     */
    get days(): number;
    /**
     * @stability stable
     */
    set days(value: number);
    /**
     * @stability stable
     */
    resetDays(): void;
    /**
     * @stability stable
     */
    get daysInput(): number | undefined;
}
/**
 * @stability stable
 */
export interface S3BucketLifecycleRuleNoncurrentVersionTransition {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_bucket#days S3Bucket#days}.
     *
     * @stability stable
     */
    readonly days?: number;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_bucket#storage_class S3Bucket#storage_class}.
     *
     * @stability stable
     */
    readonly storageClass: string;
}
export declare function s3BucketLifecycleRuleNoncurrentVersionTransitionToTerraform(struct?: S3BucketLifecycleRuleNoncurrentVersionTransition | cdktf.IResolvable): any;
/**
 * @stability stable
 */
export interface S3BucketLifecycleRuleTransition {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_bucket#date S3Bucket#date}.
     *
     * @stability stable
     */
    readonly date?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_bucket#days S3Bucket#days}.
     *
     * @stability stable
     */
    readonly days?: number;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_bucket#storage_class S3Bucket#storage_class}.
     *
     * @stability stable
     */
    readonly storageClass: string;
}
export declare function s3BucketLifecycleRuleTransitionToTerraform(struct?: S3BucketLifecycleRuleTransition | cdktf.IResolvable): any;
/**
 * @stability stable
 */
export interface S3BucketLifecycleRule {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_bucket#abort_incomplete_multipart_upload_days S3Bucket#abort_incomplete_multipart_upload_days}.
     *
     * @stability stable
     */
    readonly abortIncompleteMultipartUploadDays?: number;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_bucket#enabled S3Bucket#enabled}.
     *
     * @stability stable
     */
    readonly enabled: boolean | cdktf.IResolvable;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_bucket#id S3Bucket#id}.
     *
     * @stability stable
     */
    readonly id?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_bucket#prefix S3Bucket#prefix}.
     *
     * @stability stable
     */
    readonly prefix?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_bucket#tags S3Bucket#tags}.
     *
     * @stability stable
     */
    readonly tags?: {
        [key: string]: string;
    };
    /**
     * expiration block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_bucket#expiration S3Bucket#expiration}
     *
     * @stability stable
     */
    readonly expiration?: S3BucketLifecycleRuleExpiration;
    /**
     * noncurrent_version_expiration block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_bucket#noncurrent_version_expiration S3Bucket#noncurrent_version_expiration}
     *
     * @stability stable
     */
    readonly noncurrentVersionExpiration?: S3BucketLifecycleRuleNoncurrentVersionExpiration;
    /**
     * noncurrent_version_transition block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_bucket#noncurrent_version_transition S3Bucket#noncurrent_version_transition}
     *
     * @stability stable
     */
    readonly noncurrentVersionTransition?: S3BucketLifecycleRuleNoncurrentVersionTransition[] | cdktf.IResolvable;
    /**
     * transition block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_bucket#transition S3Bucket#transition}
     *
     * @stability stable
     */
    readonly transition?: S3BucketLifecycleRuleTransition[] | cdktf.IResolvable;
}
export declare function s3BucketLifecycleRuleToTerraform(struct?: S3BucketLifecycleRule | cdktf.IResolvable): any;
/**
 * @stability stable
 */
export interface S3BucketLogging {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_bucket#target_bucket S3Bucket#target_bucket}.
     *
     * @stability stable
     */
    readonly targetBucket: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_bucket#target_prefix S3Bucket#target_prefix}.
     *
     * @stability stable
     */
    readonly targetPrefix?: string;
}
export declare function s3BucketLoggingToTerraform(struct?: S3BucketLogging | cdktf.IResolvable): any;
/**
 * @stability stable
 */
export interface S3BucketObjectLockConfigurationRuleDefaultRetention {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_bucket#days S3Bucket#days}.
     *
     * @stability stable
     */
    readonly days?: number;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_bucket#mode S3Bucket#mode}.
     *
     * @stability stable
     */
    readonly mode: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_bucket#years S3Bucket#years}.
     *
     * @stability stable
     */
    readonly years?: number;
}
export declare function s3BucketObjectLockConfigurationRuleDefaultRetentionToTerraform(struct?: S3BucketObjectLockConfigurationRuleDefaultRetentionOutputReference | S3BucketObjectLockConfigurationRuleDefaultRetention): any;
/**
 * @stability stable
 */
export declare class S3BucketObjectLockConfigurationRuleDefaultRetentionOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): S3BucketObjectLockConfigurationRuleDefaultRetention | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: S3BucketObjectLockConfigurationRuleDefaultRetention | undefined);
    private _days?;
    /**
     * @stability stable
     */
    get days(): number;
    /**
     * @stability stable
     */
    set days(value: number);
    /**
     * @stability stable
     */
    resetDays(): void;
    /**
     * @stability stable
     */
    get daysInput(): number | undefined;
    private _mode?;
    /**
     * @stability stable
     */
    get mode(): string;
    /**
     * @stability stable
     */
    set mode(value: string);
    /**
     * @stability stable
     */
    get modeInput(): string | undefined;
    private _years?;
    /**
     * @stability stable
     */
    get years(): number;
    /**
     * @stability stable
     */
    set years(value: number);
    /**
     * @stability stable
     */
    resetYears(): void;
    /**
     * @stability stable
     */
    get yearsInput(): number | undefined;
}
/**
 * @stability stable
 */
export interface S3BucketObjectLockConfigurationRule {
    /**
     * default_retention block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_bucket#default_retention S3Bucket#default_retention}
     *
     * @stability stable
     */
    readonly defaultRetention: S3BucketObjectLockConfigurationRuleDefaultRetention;
}
export declare function s3BucketObjectLockConfigurationRuleToTerraform(struct?: S3BucketObjectLockConfigurationRuleOutputReference | S3BucketObjectLockConfigurationRule): any;
/**
 * @stability stable
 */
export declare class S3BucketObjectLockConfigurationRuleOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): S3BucketObjectLockConfigurationRule | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: S3BucketObjectLockConfigurationRule | undefined);
    private _defaultRetention;
    /**
     * @stability stable
     */
    get defaultRetention(): S3BucketObjectLockConfigurationRuleDefaultRetentionOutputReference;
    /**
     * @stability stable
     */
    putDefaultRetention(value: S3BucketObjectLockConfigurationRuleDefaultRetention): void;
    /**
     * @stability stable
     */
    get defaultRetentionInput(): S3BucketObjectLockConfigurationRuleDefaultRetention | undefined;
}
/**
 * @stability stable
 */
export interface S3BucketObjectLockConfiguration {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_bucket#object_lock_enabled S3Bucket#object_lock_enabled}.
     *
     * @stability stable
     */
    readonly objectLockEnabled: string;
    /**
     * rule block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_bucket#rule S3Bucket#rule}
     *
     * @stability stable
     */
    readonly rule?: S3BucketObjectLockConfigurationRule;
}
export declare function s3BucketObjectLockConfigurationToTerraform(struct?: S3BucketObjectLockConfigurationOutputReference | S3BucketObjectLockConfiguration): any;
/**
 * @stability stable
 */
export declare class S3BucketObjectLockConfigurationOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): S3BucketObjectLockConfiguration | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: S3BucketObjectLockConfiguration | undefined);
    private _objectLockEnabled?;
    /**
     * @stability stable
     */
    get objectLockEnabled(): string;
    /**
     * @stability stable
     */
    set objectLockEnabled(value: string);
    /**
     * @stability stable
     */
    get objectLockEnabledInput(): string | undefined;
    private _rule;
    /**
     * @stability stable
     */
    get rule(): S3BucketObjectLockConfigurationRuleOutputReference;
    /**
     * @stability stable
     */
    putRule(value: S3BucketObjectLockConfigurationRule): void;
    /**
     * @stability stable
     */
    resetRule(): void;
    /**
     * @stability stable
     */
    get ruleInput(): S3BucketObjectLockConfigurationRule | undefined;
}
/**
 * @stability stable
 */
export interface S3BucketReplicationConfigurationRulesDestinationAccessControlTranslation {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_bucket#owner S3Bucket#owner}.
     *
     * @stability stable
     */
    readonly owner: string;
}
export declare function s3BucketReplicationConfigurationRulesDestinationAccessControlTranslationToTerraform(struct?: S3BucketReplicationConfigurationRulesDestinationAccessControlTranslationOutputReference | S3BucketReplicationConfigurationRulesDestinationAccessControlTranslation): any;
/**
 * @stability stable
 */
export declare class S3BucketReplicationConfigurationRulesDestinationAccessControlTranslationOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): S3BucketReplicationConfigurationRulesDestinationAccessControlTranslation | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: S3BucketReplicationConfigurationRulesDestinationAccessControlTranslation | undefined);
    private _owner?;
    /**
     * @stability stable
     */
    get owner(): string;
    /**
     * @stability stable
     */
    set owner(value: string);
    /**
     * @stability stable
     */
    get ownerInput(): string | undefined;
}
/**
 * @stability stable
 */
export interface S3BucketReplicationConfigurationRulesDestinationMetrics {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_bucket#minutes S3Bucket#minutes}.
     *
     * @stability stable
     */
    readonly minutes?: number;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_bucket#status S3Bucket#status}.
     *
     * @stability stable
     */
    readonly status?: string;
}
export declare function s3BucketReplicationConfigurationRulesDestinationMetricsToTerraform(struct?: S3BucketReplicationConfigurationRulesDestinationMetricsOutputReference | S3BucketReplicationConfigurationRulesDestinationMetrics): any;
/**
 * @stability stable
 */
export declare class S3BucketReplicationConfigurationRulesDestinationMetricsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): S3BucketReplicationConfigurationRulesDestinationMetrics | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: S3BucketReplicationConfigurationRulesDestinationMetrics | undefined);
    private _minutes?;
    /**
     * @stability stable
     */
    get minutes(): number;
    /**
     * @stability stable
     */
    set minutes(value: number);
    /**
     * @stability stable
     */
    resetMinutes(): void;
    /**
     * @stability stable
     */
    get minutesInput(): number | undefined;
    private _status?;
    /**
     * @stability stable
     */
    get status(): string;
    /**
     * @stability stable
     */
    set status(value: string);
    /**
     * @stability stable
     */
    resetStatus(): void;
    /**
     * @stability stable
     */
    get statusInput(): string | undefined;
}
/**
 * @stability stable
 */
export interface S3BucketReplicationConfigurationRulesDestinationReplicationTime {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_bucket#minutes S3Bucket#minutes}.
     *
     * @stability stable
     */
    readonly minutes?: number;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_bucket#status S3Bucket#status}.
     *
     * @stability stable
     */
    readonly status?: string;
}
export declare function s3BucketReplicationConfigurationRulesDestinationReplicationTimeToTerraform(struct?: S3BucketReplicationConfigurationRulesDestinationReplicationTimeOutputReference | S3BucketReplicationConfigurationRulesDestinationReplicationTime): any;
/**
 * @stability stable
 */
export declare class S3BucketReplicationConfigurationRulesDestinationReplicationTimeOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): S3BucketReplicationConfigurationRulesDestinationReplicationTime | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: S3BucketReplicationConfigurationRulesDestinationReplicationTime | undefined);
    private _minutes?;
    /**
     * @stability stable
     */
    get minutes(): number;
    /**
     * @stability stable
     */
    set minutes(value: number);
    /**
     * @stability stable
     */
    resetMinutes(): void;
    /**
     * @stability stable
     */
    get minutesInput(): number | undefined;
    private _status?;
    /**
     * @stability stable
     */
    get status(): string;
    /**
     * @stability stable
     */
    set status(value: string);
    /**
     * @stability stable
     */
    resetStatus(): void;
    /**
     * @stability stable
     */
    get statusInput(): string | undefined;
}
/**
 * @stability stable
 */
export interface S3BucketReplicationConfigurationRulesDestination {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_bucket#account_id S3Bucket#account_id}.
     *
     * @stability stable
     */
    readonly accountId?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_bucket#bucket S3Bucket#bucket}.
     *
     * @stability stable
     */
    readonly bucket: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_bucket#replica_kms_key_id S3Bucket#replica_kms_key_id}.
     *
     * @stability stable
     */
    readonly replicaKmsKeyId?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_bucket#storage_class S3Bucket#storage_class}.
     *
     * @stability stable
     */
    readonly storageClass?: string;
    /**
     * access_control_translation block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_bucket#access_control_translation S3Bucket#access_control_translation}
     *
     * @stability stable
     */
    readonly accessControlTranslation?: S3BucketReplicationConfigurationRulesDestinationAccessControlTranslation;
    /**
     * metrics block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_bucket#metrics S3Bucket#metrics}
     *
     * @stability stable
     */
    readonly metrics?: S3BucketReplicationConfigurationRulesDestinationMetrics;
    /**
     * replication_time block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_bucket#replication_time S3Bucket#replication_time}
     *
     * @stability stable
     */
    readonly replicationTime?: S3BucketReplicationConfigurationRulesDestinationReplicationTime;
}
export declare function s3BucketReplicationConfigurationRulesDestinationToTerraform(struct?: S3BucketReplicationConfigurationRulesDestinationOutputReference | S3BucketReplicationConfigurationRulesDestination): any;
/**
 * @stability stable
 */
export declare class S3BucketReplicationConfigurationRulesDestinationOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): S3BucketReplicationConfigurationRulesDestination | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: S3BucketReplicationConfigurationRulesDestination | undefined);
    private _accountId?;
    /**
     * @stability stable
     */
    get accountId(): string;
    /**
     * @stability stable
     */
    set accountId(value: string);
    /**
     * @stability stable
     */
    resetAccountId(): void;
    /**
     * @stability stable
     */
    get accountIdInput(): string | undefined;
    private _bucket?;
    /**
     * @stability stable
     */
    get bucket(): string;
    /**
     * @stability stable
     */
    set bucket(value: string);
    /**
     * @stability stable
     */
    get bucketInput(): string | undefined;
    private _replicaKmsKeyId?;
    /**
     * @stability stable
     */
    get replicaKmsKeyId(): string;
    /**
     * @stability stable
     */
    set replicaKmsKeyId(value: string);
    /**
     * @stability stable
     */
    resetReplicaKmsKeyId(): void;
    /**
     * @stability stable
     */
    get replicaKmsKeyIdInput(): string | undefined;
    private _storageClass?;
    /**
     * @stability stable
     */
    get storageClass(): string;
    /**
     * @stability stable
     */
    set storageClass(value: string);
    /**
     * @stability stable
     */
    resetStorageClass(): void;
    /**
     * @stability stable
     */
    get storageClassInput(): string | undefined;
    private _accessControlTranslation;
    /**
     * @stability stable
     */
    get accessControlTranslation(): S3BucketReplicationConfigurationRulesDestinationAccessControlTranslationOutputReference;
    /**
     * @stability stable
     */
    putAccessControlTranslation(value: S3BucketReplicationConfigurationRulesDestinationAccessControlTranslation): void;
    /**
     * @stability stable
     */
    resetAccessControlTranslation(): void;
    /**
     * @stability stable
     */
    get accessControlTranslationInput(): S3BucketReplicationConfigurationRulesDestinationAccessControlTranslation | undefined;
    private _metrics;
    /**
     * @stability stable
     */
    get metrics(): S3BucketReplicationConfigurationRulesDestinationMetricsOutputReference;
    /**
     * @stability stable
     */
    putMetrics(value: S3BucketReplicationConfigurationRulesDestinationMetrics): void;
    /**
     * @stability stable
     */
    resetMetrics(): void;
    /**
     * @stability stable
     */
    get metricsInput(): S3BucketReplicationConfigurationRulesDestinationMetrics | undefined;
    private _replicationTime;
    /**
     * @stability stable
     */
    get replicationTime(): S3BucketReplicationConfigurationRulesDestinationReplicationTimeOutputReference;
    /**
     * @stability stable
     */
    putReplicationTime(value: S3BucketReplicationConfigurationRulesDestinationReplicationTime): void;
    /**
     * @stability stable
     */
    resetReplicationTime(): void;
    /**
     * @stability stable
     */
    get replicationTimeInput(): S3BucketReplicationConfigurationRulesDestinationReplicationTime | undefined;
}
/**
 * @stability stable
 */
export interface S3BucketReplicationConfigurationRulesFilter {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_bucket#prefix S3Bucket#prefix}.
     *
     * @stability stable
     */
    readonly prefix?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_bucket#tags S3Bucket#tags}.
     *
     * @stability stable
     */
    readonly tags?: {
        [key: string]: string;
    };
}
export declare function s3BucketReplicationConfigurationRulesFilterToTerraform(struct?: S3BucketReplicationConfigurationRulesFilterOutputReference | S3BucketReplicationConfigurationRulesFilter): any;
/**
 * @stability stable
 */
export declare class S3BucketReplicationConfigurationRulesFilterOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): S3BucketReplicationConfigurationRulesFilter | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: S3BucketReplicationConfigurationRulesFilter | undefined);
    private _prefix?;
    /**
     * @stability stable
     */
    get prefix(): string;
    /**
     * @stability stable
     */
    set prefix(value: string);
    /**
     * @stability stable
     */
    resetPrefix(): void;
    /**
     * @stability stable
     */
    get prefixInput(): string | undefined;
    private _tags?;
    /**
     * @stability stable
     */
    get tags(): {
        [key: string]: string;
    };
    /**
     * @stability stable
     */
    set tags(value: {
        [key: string]: string;
    });
    /**
     * @stability stable
     */
    resetTags(): void;
    /**
     * @stability stable
     */
    get tagsInput(): {
        [key: string]: string;
    } | undefined;
}
/**
 * @stability stable
 */
export interface S3BucketReplicationConfigurationRulesSourceSelectionCriteriaSseKmsEncryptedObjects {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_bucket#enabled S3Bucket#enabled}.
     *
     * @stability stable
     */
    readonly enabled: boolean | cdktf.IResolvable;
}
export declare function s3BucketReplicationConfigurationRulesSourceSelectionCriteriaSseKmsEncryptedObjectsToTerraform(struct?: S3BucketReplicationConfigurationRulesSourceSelectionCriteriaSseKmsEncryptedObjectsOutputReference | S3BucketReplicationConfigurationRulesSourceSelectionCriteriaSseKmsEncryptedObjects): any;
/**
 * @stability stable
 */
export declare class S3BucketReplicationConfigurationRulesSourceSelectionCriteriaSseKmsEncryptedObjectsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): S3BucketReplicationConfigurationRulesSourceSelectionCriteriaSseKmsEncryptedObjects | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: S3BucketReplicationConfigurationRulesSourceSelectionCriteriaSseKmsEncryptedObjects | undefined);
    private _enabled?;
    /**
     * @stability stable
     */
    get enabled(): boolean | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set enabled(value: boolean | cdktf.IResolvable);
    /**
     * @stability stable
     */
    get enabledInput(): boolean | cdktf.IResolvable | undefined;
}
/**
 * @stability stable
 */
export interface S3BucketReplicationConfigurationRulesSourceSelectionCriteria {
    /**
     * sse_kms_encrypted_objects block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_bucket#sse_kms_encrypted_objects S3Bucket#sse_kms_encrypted_objects}
     *
     * @stability stable
     */
    readonly sseKmsEncryptedObjects?: S3BucketReplicationConfigurationRulesSourceSelectionCriteriaSseKmsEncryptedObjects;
}
export declare function s3BucketReplicationConfigurationRulesSourceSelectionCriteriaToTerraform(struct?: S3BucketReplicationConfigurationRulesSourceSelectionCriteriaOutputReference | S3BucketReplicationConfigurationRulesSourceSelectionCriteria): any;
/**
 * @stability stable
 */
export declare class S3BucketReplicationConfigurationRulesSourceSelectionCriteriaOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): S3BucketReplicationConfigurationRulesSourceSelectionCriteria | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: S3BucketReplicationConfigurationRulesSourceSelectionCriteria | undefined);
    private _sseKmsEncryptedObjects;
    /**
     * @stability stable
     */
    get sseKmsEncryptedObjects(): S3BucketReplicationConfigurationRulesSourceSelectionCriteriaSseKmsEncryptedObjectsOutputReference;
    /**
     * @stability stable
     */
    putSseKmsEncryptedObjects(value: S3BucketReplicationConfigurationRulesSourceSelectionCriteriaSseKmsEncryptedObjects): void;
    /**
     * @stability stable
     */
    resetSseKmsEncryptedObjects(): void;
    /**
     * @stability stable
     */
    get sseKmsEncryptedObjectsInput(): S3BucketReplicationConfigurationRulesSourceSelectionCriteriaSseKmsEncryptedObjects | undefined;
}
/**
 * @stability stable
 */
export interface S3BucketReplicationConfigurationRules {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_bucket#delete_marker_replication_status S3Bucket#delete_marker_replication_status}.
     *
     * @stability stable
     */
    readonly deleteMarkerReplicationStatus?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_bucket#id S3Bucket#id}.
     *
     * @stability stable
     */
    readonly id?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_bucket#prefix S3Bucket#prefix}.
     *
     * @stability stable
     */
    readonly prefix?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_bucket#priority S3Bucket#priority}.
     *
     * @stability stable
     */
    readonly priority?: number;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_bucket#status S3Bucket#status}.
     *
     * @stability stable
     */
    readonly status: string;
    /**
     * destination block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_bucket#destination S3Bucket#destination}
     *
     * @stability stable
     */
    readonly destination: S3BucketReplicationConfigurationRulesDestination;
    /**
     * filter block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_bucket#filter S3Bucket#filter}
     *
     * @stability stable
     */
    readonly filter?: S3BucketReplicationConfigurationRulesFilter;
    /**
     * source_selection_criteria block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_bucket#source_selection_criteria S3Bucket#source_selection_criteria}
     *
     * @stability stable
     */
    readonly sourceSelectionCriteria?: S3BucketReplicationConfigurationRulesSourceSelectionCriteria;
}
export declare function s3BucketReplicationConfigurationRulesToTerraform(struct?: S3BucketReplicationConfigurationRules | cdktf.IResolvable): any;
/**
 * @stability stable
 */
export interface S3BucketReplicationConfiguration {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_bucket#role S3Bucket#role}.
     *
     * @stability stable
     */
    readonly role: string;
    /**
     * rules block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_bucket#rules S3Bucket#rules}
     *
     * @stability stable
     */
    readonly rules: S3BucketReplicationConfigurationRules[] | cdktf.IResolvable;
}
export declare function s3BucketReplicationConfigurationToTerraform(struct?: S3BucketReplicationConfigurationOutputReference | S3BucketReplicationConfiguration): any;
/**
 * @stability stable
 */
export declare class S3BucketReplicationConfigurationOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): S3BucketReplicationConfiguration | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: S3BucketReplicationConfiguration | undefined);
    private _role?;
    /**
     * @stability stable
     */
    get role(): string;
    /**
     * @stability stable
     */
    set role(value: string);
    /**
     * @stability stable
     */
    get roleInput(): string | undefined;
    private _rules?;
    /**
     * @stability stable
     */
    get rules(): S3BucketReplicationConfigurationRules[] | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set rules(value: S3BucketReplicationConfigurationRules[] | cdktf.IResolvable);
    /**
     * @stability stable
     */
    get rulesInput(): cdktf.IResolvable | S3BucketReplicationConfigurationRules[] | undefined;
}
/**
 * @stability stable
 */
export interface S3BucketServerSideEncryptionConfigurationRuleApplyServerSideEncryptionByDefault {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_bucket#kms_master_key_id S3Bucket#kms_master_key_id}.
     *
     * @stability stable
     */
    readonly kmsMasterKeyId?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_bucket#sse_algorithm S3Bucket#sse_algorithm}.
     *
     * @stability stable
     */
    readonly sseAlgorithm: string;
}
export declare function s3BucketServerSideEncryptionConfigurationRuleApplyServerSideEncryptionByDefaultToTerraform(struct?: S3BucketServerSideEncryptionConfigurationRuleApplyServerSideEncryptionByDefaultOutputReference | S3BucketServerSideEncryptionConfigurationRuleApplyServerSideEncryptionByDefault): any;
/**
 * @stability stable
 */
export declare class S3BucketServerSideEncryptionConfigurationRuleApplyServerSideEncryptionByDefaultOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): S3BucketServerSideEncryptionConfigurationRuleApplyServerSideEncryptionByDefault | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: S3BucketServerSideEncryptionConfigurationRuleApplyServerSideEncryptionByDefault | undefined);
    private _kmsMasterKeyId?;
    /**
     * @stability stable
     */
    get kmsMasterKeyId(): string;
    /**
     * @stability stable
     */
    set kmsMasterKeyId(value: string);
    /**
     * @stability stable
     */
    resetKmsMasterKeyId(): void;
    /**
     * @stability stable
     */
    get kmsMasterKeyIdInput(): string | undefined;
    private _sseAlgorithm?;
    /**
     * @stability stable
     */
    get sseAlgorithm(): string;
    /**
     * @stability stable
     */
    set sseAlgorithm(value: string);
    /**
     * @stability stable
     */
    get sseAlgorithmInput(): string | undefined;
}
/**
 * @stability stable
 */
export interface S3BucketServerSideEncryptionConfigurationRule {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_bucket#bucket_key_enabled S3Bucket#bucket_key_enabled}.
     *
     * @stability stable
     */
    readonly bucketKeyEnabled?: boolean | cdktf.IResolvable;
    /**
     * apply_server_side_encryption_by_default block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_bucket#apply_server_side_encryption_by_default S3Bucket#apply_server_side_encryption_by_default}
     *
     * @stability stable
     */
    readonly applyServerSideEncryptionByDefault: S3BucketServerSideEncryptionConfigurationRuleApplyServerSideEncryptionByDefault;
}
export declare function s3BucketServerSideEncryptionConfigurationRuleToTerraform(struct?: S3BucketServerSideEncryptionConfigurationRuleOutputReference | S3BucketServerSideEncryptionConfigurationRule): any;
/**
 * @stability stable
 */
export declare class S3BucketServerSideEncryptionConfigurationRuleOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): S3BucketServerSideEncryptionConfigurationRule | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: S3BucketServerSideEncryptionConfigurationRule | undefined);
    private _bucketKeyEnabled?;
    /**
     * @stability stable
     */
    get bucketKeyEnabled(): boolean | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set bucketKeyEnabled(value: boolean | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetBucketKeyEnabled(): void;
    /**
     * @stability stable
     */
    get bucketKeyEnabledInput(): boolean | cdktf.IResolvable | undefined;
    private _applyServerSideEncryptionByDefault;
    /**
     * @stability stable
     */
    get applyServerSideEncryptionByDefault(): S3BucketServerSideEncryptionConfigurationRuleApplyServerSideEncryptionByDefaultOutputReference;
    /**
     * @stability stable
     */
    putApplyServerSideEncryptionByDefault(value: S3BucketServerSideEncryptionConfigurationRuleApplyServerSideEncryptionByDefault): void;
    /**
     * @stability stable
     */
    get applyServerSideEncryptionByDefaultInput(): S3BucketServerSideEncryptionConfigurationRuleApplyServerSideEncryptionByDefault | undefined;
}
/**
 * @stability stable
 */
export interface S3BucketServerSideEncryptionConfiguration {
    /**
     * rule block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_bucket#rule S3Bucket#rule}
     *
     * @stability stable
     */
    readonly rule: S3BucketServerSideEncryptionConfigurationRule;
}
export declare function s3BucketServerSideEncryptionConfigurationToTerraform(struct?: S3BucketServerSideEncryptionConfigurationOutputReference | S3BucketServerSideEncryptionConfiguration): any;
/**
 * @stability stable
 */
export declare class S3BucketServerSideEncryptionConfigurationOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): S3BucketServerSideEncryptionConfiguration | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: S3BucketServerSideEncryptionConfiguration | undefined);
    private _rule;
    /**
     * @stability stable
     */
    get rule(): S3BucketServerSideEncryptionConfigurationRuleOutputReference;
    /**
     * @stability stable
     */
    putRule(value: S3BucketServerSideEncryptionConfigurationRule): void;
    /**
     * @stability stable
     */
    get ruleInput(): S3BucketServerSideEncryptionConfigurationRule | undefined;
}
/**
 * @stability stable
 */
export interface S3BucketVersioning {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_bucket#enabled S3Bucket#enabled}.
     *
     * @stability stable
     */
    readonly enabled?: boolean | cdktf.IResolvable;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_bucket#mfa_delete S3Bucket#mfa_delete}.
     *
     * @stability stable
     */
    readonly mfaDelete?: boolean | cdktf.IResolvable;
}
export declare function s3BucketVersioningToTerraform(struct?: S3BucketVersioningOutputReference | S3BucketVersioning): any;
/**
 * @stability stable
 */
export declare class S3BucketVersioningOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): S3BucketVersioning | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: S3BucketVersioning | undefined);
    private _enabled?;
    /**
     * @stability stable
     */
    get enabled(): boolean | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set enabled(value: boolean | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetEnabled(): void;
    /**
     * @stability stable
     */
    get enabledInput(): boolean | cdktf.IResolvable | undefined;
    private _mfaDelete?;
    /**
     * @stability stable
     */
    get mfaDelete(): boolean | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set mfaDelete(value: boolean | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetMfaDelete(): void;
    /**
     * @stability stable
     */
    get mfaDeleteInput(): boolean | cdktf.IResolvable | undefined;
}
/**
 * @stability stable
 */
export interface S3BucketWebsite {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_bucket#error_document S3Bucket#error_document}.
     *
     * @stability stable
     */
    readonly errorDocument?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_bucket#index_document S3Bucket#index_document}.
     *
     * @stability stable
     */
    readonly indexDocument?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_bucket#redirect_all_requests_to S3Bucket#redirect_all_requests_to}.
     *
     * @stability stable
     */
    readonly redirectAllRequestsTo?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_bucket#routing_rules S3Bucket#routing_rules}.
     *
     * @stability stable
     */
    readonly routingRules?: string;
}
export declare function s3BucketWebsiteToTerraform(struct?: S3BucketWebsiteOutputReference | S3BucketWebsite): any;
/**
 * @stability stable
 */
export declare class S3BucketWebsiteOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): S3BucketWebsite | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: S3BucketWebsite | undefined);
    private _errorDocument?;
    /**
     * @stability stable
     */
    get errorDocument(): string;
    /**
     * @stability stable
     */
    set errorDocument(value: string);
    /**
     * @stability stable
     */
    resetErrorDocument(): void;
    /**
     * @stability stable
     */
    get errorDocumentInput(): string | undefined;
    private _indexDocument?;
    /**
     * @stability stable
     */
    get indexDocument(): string;
    /**
     * @stability stable
     */
    set indexDocument(value: string);
    /**
     * @stability stable
     */
    resetIndexDocument(): void;
    /**
     * @stability stable
     */
    get indexDocumentInput(): string | undefined;
    private _redirectAllRequestsTo?;
    /**
     * @stability stable
     */
    get redirectAllRequestsTo(): string;
    /**
     * @stability stable
     */
    set redirectAllRequestsTo(value: string);
    /**
     * @stability stable
     */
    resetRedirectAllRequestsTo(): void;
    /**
     * @stability stable
     */
    get redirectAllRequestsToInput(): string | undefined;
    private _routingRules?;
    /**
     * @stability stable
     */
    get routingRules(): string;
    /**
     * @stability stable
     */
    set routingRules(value: string);
    /**
     * @stability stable
     */
    resetRoutingRules(): void;
    /**
     * @stability stable
     */
    get routingRulesInput(): string | undefined;
}
/**
 * Represents a {@link https://www.terraform.io/docs/providers/aws/r/s3_bucket aws_s3_bucket}.
 *
 * @stability stable
 */
export declare class S3Bucket extends cdktf.TerraformResource {
    /**
     * @stability stable
     */
    static readonly tfResourceType: string;
    /**
     * Create a new {@link https://www.terraform.io/docs/providers/aws/r/s3_bucket aws_s3_bucket} Resource.
     *
     * @param scope The scope in which to define this construct.
     * @param id The scoped construct ID.
     * @stability stable
     */
    constructor(scope: Construct, id: string, config?: S3BucketConfig);
    private _accelerationStatus?;
    /**
     * @stability stable
     */
    get accelerationStatus(): string;
    /**
     * @stability stable
     */
    set accelerationStatus(value: string);
    /**
     * @stability stable
     */
    resetAccelerationStatus(): void;
    /**
     * @stability stable
     */
    get accelerationStatusInput(): string | undefined;
    private _acl?;
    /**
     * @stability stable
     */
    get acl(): string;
    /**
     * @stability stable
     */
    set acl(value: string);
    /**
     * @stability stable
     */
    resetAcl(): void;
    /**
     * @stability stable
     */
    get aclInput(): string | undefined;
    /**
     * @stability stable
     */
    get arn(): string;
    private _bucket?;
    /**
     * @stability stable
     */
    get bucket(): string;
    /**
     * @stability stable
     */
    set bucket(value: string);
    /**
     * @stability stable
     */
    resetBucket(): void;
    /**
     * @stability stable
     */
    get bucketInput(): string | undefined;
    /**
     * @stability stable
     */
    get bucketDomainName(): string;
    private _bucketPrefix?;
    /**
     * @stability stable
     */
    get bucketPrefix(): string;
    /**
     * @stability stable
     */
    set bucketPrefix(value: string);
    /**
     * @stability stable
     */
    resetBucketPrefix(): void;
    /**
     * @stability stable
     */
    get bucketPrefixInput(): string | undefined;
    /**
     * @stability stable
     */
    get bucketRegionalDomainName(): string;
    private _forceDestroy?;
    /**
     * @stability stable
     */
    get forceDestroy(): boolean | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set forceDestroy(value: boolean | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetForceDestroy(): void;
    /**
     * @stability stable
     */
    get forceDestroyInput(): boolean | cdktf.IResolvable | undefined;
    private _hostedZoneId?;
    /**
     * @stability stable
     */
    get hostedZoneId(): string;
    /**
     * @stability stable
     */
    set hostedZoneId(value: string);
    /**
     * @stability stable
     */
    resetHostedZoneId(): void;
    /**
     * @stability stable
     */
    get hostedZoneIdInput(): string | undefined;
    /**
     * @stability stable
     */
    get id(): string;
    private _policy?;
    /**
     * @stability stable
     */
    get policy(): string;
    /**
     * @stability stable
     */
    set policy(value: string);
    /**
     * @stability stable
     */
    resetPolicy(): void;
    /**
     * @stability stable
     */
    get policyInput(): string | undefined;
    /**
     * @stability stable
     */
    get region(): string;
    private _requestPayer?;
    /**
     * @stability stable
     */
    get requestPayer(): string;
    /**
     * @stability stable
     */
    set requestPayer(value: string);
    /**
     * @stability stable
     */
    resetRequestPayer(): void;
    /**
     * @stability stable
     */
    get requestPayerInput(): string | undefined;
    private _tags?;
    /**
     * @stability stable
     */
    get tags(): {
        [key: string]: string;
    };
    /**
     * @stability stable
     */
    set tags(value: {
        [key: string]: string;
    });
    /**
     * @stability stable
     */
    resetTags(): void;
    /**
     * @stability stable
     */
    get tagsInput(): {
        [key: string]: string;
    } | undefined;
    private _tagsAll?;
    /**
     * @stability stable
     */
    get tagsAll(): {
        [key: string]: string;
    };
    /**
     * @stability stable
     */
    set tagsAll(value: {
        [key: string]: string;
    });
    /**
     * @stability stable
     */
    resetTagsAll(): void;
    /**
     * @stability stable
     */
    get tagsAllInput(): {
        [key: string]: string;
    } | undefined;
    private _websiteDomain?;
    /**
     * @stability stable
     */
    get websiteDomain(): string;
    /**
     * @stability stable
     */
    set websiteDomain(value: string);
    /**
     * @stability stable
     */
    resetWebsiteDomain(): void;
    /**
     * @stability stable
     */
    get websiteDomainInput(): string | undefined;
    private _websiteEndpoint?;
    /**
     * @stability stable
     */
    get websiteEndpoint(): string;
    /**
     * @stability stable
     */
    set websiteEndpoint(value: string);
    /**
     * @stability stable
     */
    resetWebsiteEndpoint(): void;
    /**
     * @stability stable
     */
    get websiteEndpointInput(): string | undefined;
    private _corsRule?;
    /**
     * @stability stable
     */
    get corsRule(): S3BucketCorsRule[] | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set corsRule(value: S3BucketCorsRule[] | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetCorsRule(): void;
    /**
     * @stability stable
     */
    get corsRuleInput(): cdktf.IResolvable | S3BucketCorsRule[] | undefined;
    private _grant?;
    /**
     * @stability stable
     */
    get grant(): S3BucketGrant[] | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set grant(value: S3BucketGrant[] | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetGrant(): void;
    /**
     * @stability stable
     */
    get grantInput(): cdktf.IResolvable | S3BucketGrant[] | undefined;
    private _lifecycleRule?;
    /**
     * @stability stable
     */
    get lifecycleRule(): S3BucketLifecycleRule[] | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set lifecycleRule(value: S3BucketLifecycleRule[] | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetLifecycleRule(): void;
    /**
     * @stability stable
     */
    get lifecycleRuleInput(): cdktf.IResolvable | S3BucketLifecycleRule[] | undefined;
    private _logging?;
    /**
     * @stability stable
     */
    get logging(): S3BucketLogging[] | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set logging(value: S3BucketLogging[] | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetLogging(): void;
    /**
     * @stability stable
     */
    get loggingInput(): cdktf.IResolvable | S3BucketLogging[] | undefined;
    private _objectLockConfiguration;
    /**
     * @stability stable
     */
    get objectLockConfiguration(): S3BucketObjectLockConfigurationOutputReference;
    /**
     * @stability stable
     */
    putObjectLockConfiguration(value: S3BucketObjectLockConfiguration): void;
    /**
     * @stability stable
     */
    resetObjectLockConfiguration(): void;
    /**
     * @stability stable
     */
    get objectLockConfigurationInput(): S3BucketObjectLockConfiguration | undefined;
    private _replicationConfiguration;
    /**
     * @stability stable
     */
    get replicationConfiguration(): S3BucketReplicationConfigurationOutputReference;
    /**
     * @stability stable
     */
    putReplicationConfiguration(value: S3BucketReplicationConfiguration): void;
    /**
     * @stability stable
     */
    resetReplicationConfiguration(): void;
    /**
     * @stability stable
     */
    get replicationConfigurationInput(): S3BucketReplicationConfiguration | undefined;
    private _serverSideEncryptionConfiguration;
    /**
     * @stability stable
     */
    get serverSideEncryptionConfiguration(): S3BucketServerSideEncryptionConfigurationOutputReference;
    /**
     * @stability stable
     */
    putServerSideEncryptionConfiguration(value: S3BucketServerSideEncryptionConfiguration): void;
    /**
     * @stability stable
     */
    resetServerSideEncryptionConfiguration(): void;
    /**
     * @stability stable
     */
    get serverSideEncryptionConfigurationInput(): S3BucketServerSideEncryptionConfiguration | undefined;
    private _versioning;
    /**
     * @stability stable
     */
    get versioning(): S3BucketVersioningOutputReference;
    /**
     * @stability stable
     */
    putVersioning(value: S3BucketVersioning): void;
    /**
     * @stability stable
     */
    resetVersioning(): void;
    /**
     * @stability stable
     */
    get versioningInput(): S3BucketVersioning | undefined;
    private _website;
    /**
     * @stability stable
     */
    get website(): S3BucketWebsiteOutputReference;
    /**
     * @stability stable
     */
    putWebsite(value: S3BucketWebsite): void;
    /**
     * @stability stable
     */
    resetWebsite(): void;
    /**
     * @stability stable
     */
    get websiteInput(): S3BucketWebsite | undefined;
    /**
     * @stability stable
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
