import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
/**
 * AWS Secrets Manager.
 *
 * @stability stable
 */
export interface SecretsmanagerSecretRotationConfig extends cdktf.TerraformMetaArguments {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/secretsmanager_secret_rotation#rotation_lambda_arn SecretsmanagerSecretRotation#rotation_lambda_arn}.
     *
     * @stability stable
     */
    readonly rotationLambdaArn: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/secretsmanager_secret_rotation#secret_id SecretsmanagerSecretRotation#secret_id}.
     *
     * @stability stable
     */
    readonly secretId: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/secretsmanager_secret_rotation#tags SecretsmanagerSecretRotation#tags}.
     *
     * @stability stable
     */
    readonly tags?: {
        [key: string]: string;
    };
    /**
     * rotation_rules block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/secretsmanager_secret_rotation#rotation_rules SecretsmanagerSecretRotation#rotation_rules}
     *
     * @stability stable
     */
    readonly rotationRules: SecretsmanagerSecretRotationRotationRules;
}
/**
 * @stability stable
 */
export interface SecretsmanagerSecretRotationRotationRules {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/secretsmanager_secret_rotation#automatically_after_days SecretsmanagerSecretRotation#automatically_after_days}.
     *
     * @stability stable
     */
    readonly automaticallyAfterDays: number;
}
export declare function secretsmanagerSecretRotationRotationRulesToTerraform(struct?: SecretsmanagerSecretRotationRotationRulesOutputReference | SecretsmanagerSecretRotationRotationRules): any;
/**
 * @stability stable
 */
export declare class SecretsmanagerSecretRotationRotationRulesOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): SecretsmanagerSecretRotationRotationRules | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: SecretsmanagerSecretRotationRotationRules | undefined);
    private _automaticallyAfterDays?;
    /**
     * @stability stable
     */
    get automaticallyAfterDays(): number;
    /**
     * @stability stable
     */
    set automaticallyAfterDays(value: number);
    /**
     * @stability stable
     */
    get automaticallyAfterDaysInput(): number | undefined;
}
/**
 * Represents a {@link https://www.terraform.io/docs/providers/aws/r/secretsmanager_secret_rotation aws_secretsmanager_secret_rotation}.
 *
 * @stability stable
 */
export declare class SecretsmanagerSecretRotation extends cdktf.TerraformResource {
    /**
     * @stability stable
     */
    static readonly tfResourceType: string;
    /**
     * Create a new {@link https://www.terraform.io/docs/providers/aws/r/secretsmanager_secret_rotation aws_secretsmanager_secret_rotation} Resource.
     *
     * @param scope The scope in which to define this construct.
     * @param id The scoped construct ID.
     * @stability stable
     */
    constructor(scope: Construct, id: string, config: SecretsmanagerSecretRotationConfig);
    /**
     * @stability stable
     */
    get id(): string;
    /**
     * @stability stable
     */
    get rotationEnabled(): cdktf.IResolvable;
    private _rotationLambdaArn?;
    /**
     * @stability stable
     */
    get rotationLambdaArn(): string;
    /**
     * @stability stable
     */
    set rotationLambdaArn(value: string);
    /**
     * @stability stable
     */
    get rotationLambdaArnInput(): string | undefined;
    private _secretId?;
    /**
     * @stability stable
     */
    get secretId(): string;
    /**
     * @stability stable
     */
    set secretId(value: string);
    /**
     * @stability stable
     */
    get secretIdInput(): string | undefined;
    private _tags?;
    /**
     * @stability stable
     */
    get tags(): {
        [key: string]: string;
    };
    /**
     * @stability stable
     */
    set tags(value: {
        [key: string]: string;
    });
    /**
     * @stability stable
     */
    resetTags(): void;
    /**
     * @stability stable
     */
    get tagsInput(): {
        [key: string]: string;
    } | undefined;
    private _rotationRules;
    /**
     * @stability stable
     */
    get rotationRules(): SecretsmanagerSecretRotationRotationRulesOutputReference;
    /**
     * @stability stable
     */
    putRotationRules(value: SecretsmanagerSecretRotationRotationRules): void;
    /**
     * @stability stable
     */
    get rotationRulesInput(): SecretsmanagerSecretRotationRotationRules | undefined;
    /**
     * @stability stable
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
