import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
/**
 * AWS Simple Email Service.
 *
 * @stability stable
 */
export interface SesConfigurationSetConfig extends cdktf.TerraformMetaArguments {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ses_configuration_set#name SesConfigurationSet#name}.
     *
     * @stability stable
     */
    readonly name: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ses_configuration_set#reputation_metrics_enabled SesConfigurationSet#reputation_metrics_enabled}.
     *
     * @stability stable
     */
    readonly reputationMetricsEnabled?: boolean | cdktf.IResolvable;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ses_configuration_set#sending_enabled SesConfigurationSet#sending_enabled}.
     *
     * @stability stable
     */
    readonly sendingEnabled?: boolean | cdktf.IResolvable;
    /**
     * delivery_options block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ses_configuration_set#delivery_options SesConfigurationSet#delivery_options}
     *
     * @stability stable
     */
    readonly deliveryOptions?: SesConfigurationSetDeliveryOptions;
}
/**
 * @stability stable
 */
export interface SesConfigurationSetDeliveryOptions {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ses_configuration_set#tls_policy SesConfigurationSet#tls_policy}.
     *
     * @stability stable
     */
    readonly tlsPolicy?: string;
}
export declare function sesConfigurationSetDeliveryOptionsToTerraform(struct?: SesConfigurationSetDeliveryOptionsOutputReference | SesConfigurationSetDeliveryOptions): any;
/**
 * @stability stable
 */
export declare class SesConfigurationSetDeliveryOptionsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): SesConfigurationSetDeliveryOptions | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: SesConfigurationSetDeliveryOptions | undefined);
    private _tlsPolicy?;
    /**
     * @stability stable
     */
    get tlsPolicy(): string;
    /**
     * @stability stable
     */
    set tlsPolicy(value: string);
    /**
     * @stability stable
     */
    resetTlsPolicy(): void;
    /**
     * @stability stable
     */
    get tlsPolicyInput(): string | undefined;
}
/**
 * Represents a {@link https://www.terraform.io/docs/providers/aws/r/ses_configuration_set aws_ses_configuration_set}.
 *
 * @stability stable
 */
export declare class SesConfigurationSet extends cdktf.TerraformResource {
    /**
     * @stability stable
     */
    static readonly tfResourceType: string;
    /**
     * Create a new {@link https://www.terraform.io/docs/providers/aws/r/ses_configuration_set aws_ses_configuration_set} Resource.
     *
     * @param scope The scope in which to define this construct.
     * @param id The scoped construct ID.
     * @stability stable
     */
    constructor(scope: Construct, id: string, config: SesConfigurationSetConfig);
    /**
     * @stability stable
     */
    get arn(): string;
    /**
     * @stability stable
     */
    get id(): string;
    /**
     * @stability stable
     */
    get lastFreshStart(): string;
    private _name?;
    /**
     * @stability stable
     */
    get name(): string;
    /**
     * @stability stable
     */
    set name(value: string);
    /**
     * @stability stable
     */
    get nameInput(): string | undefined;
    private _reputationMetricsEnabled?;
    /**
     * @stability stable
     */
    get reputationMetricsEnabled(): boolean | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set reputationMetricsEnabled(value: boolean | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetReputationMetricsEnabled(): void;
    /**
     * @stability stable
     */
    get reputationMetricsEnabledInput(): boolean | cdktf.IResolvable | undefined;
    private _sendingEnabled?;
    /**
     * @stability stable
     */
    get sendingEnabled(): boolean | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set sendingEnabled(value: boolean | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetSendingEnabled(): void;
    /**
     * @stability stable
     */
    get sendingEnabledInput(): boolean | cdktf.IResolvable | undefined;
    private _deliveryOptions;
    /**
     * @stability stable
     */
    get deliveryOptions(): SesConfigurationSetDeliveryOptionsOutputReference;
    /**
     * @stability stable
     */
    putDeliveryOptions(value: SesConfigurationSetDeliveryOptions): void;
    /**
     * @stability stable
     */
    resetDeliveryOptions(): void;
    /**
     * @stability stable
     */
    get deliveryOptionsInput(): SesConfigurationSetDeliveryOptions | undefined;
    /**
     * @stability stable
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
