import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
/**
 * AWS Simple Email Service.
 *
 * @stability stable
 */
export interface SesEventDestinationConfig extends cdktf.TerraformMetaArguments {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ses_event_destination#configuration_set_name SesEventDestination#configuration_set_name}.
     *
     * @stability stable
     */
    readonly configurationSetName: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ses_event_destination#enabled SesEventDestination#enabled}.
     *
     * @stability stable
     */
    readonly enabled?: boolean | cdktf.IResolvable;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ses_event_destination#matching_types SesEventDestination#matching_types}.
     *
     * @stability stable
     */
    readonly matchingTypes: string[];
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ses_event_destination#name SesEventDestination#name}.
     *
     * @stability stable
     */
    readonly name: string;
    /**
     * cloudwatch_destination block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ses_event_destination#cloudwatch_destination SesEventDestination#cloudwatch_destination}
     *
     * @stability stable
     */
    readonly cloudwatchDestination?: SesEventDestinationCloudwatchDestination[] | cdktf.IResolvable;
    /**
     * kinesis_destination block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ses_event_destination#kinesis_destination SesEventDestination#kinesis_destination}
     *
     * @stability stable
     */
    readonly kinesisDestination?: SesEventDestinationKinesisDestination;
    /**
     * sns_destination block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ses_event_destination#sns_destination SesEventDestination#sns_destination}
     *
     * @stability stable
     */
    readonly snsDestination?: SesEventDestinationSnsDestination;
}
/**
 * @stability stable
 */
export interface SesEventDestinationCloudwatchDestination {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ses_event_destination#default_value SesEventDestination#default_value}.
     *
     * @stability stable
     */
    readonly defaultValue: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ses_event_destination#dimension_name SesEventDestination#dimension_name}.
     *
     * @stability stable
     */
    readonly dimensionName: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ses_event_destination#value_source SesEventDestination#value_source}.
     *
     * @stability stable
     */
    readonly valueSource: string;
}
export declare function sesEventDestinationCloudwatchDestinationToTerraform(struct?: SesEventDestinationCloudwatchDestination | cdktf.IResolvable): any;
/**
 * @stability stable
 */
export interface SesEventDestinationKinesisDestination {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ses_event_destination#role_arn SesEventDestination#role_arn}.
     *
     * @stability stable
     */
    readonly roleArn: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ses_event_destination#stream_arn SesEventDestination#stream_arn}.
     *
     * @stability stable
     */
    readonly streamArn: string;
}
export declare function sesEventDestinationKinesisDestinationToTerraform(struct?: SesEventDestinationKinesisDestinationOutputReference | SesEventDestinationKinesisDestination): any;
/**
 * @stability stable
 */
export declare class SesEventDestinationKinesisDestinationOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): SesEventDestinationKinesisDestination | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: SesEventDestinationKinesisDestination | undefined);
    private _roleArn?;
    /**
     * @stability stable
     */
    get roleArn(): string;
    /**
     * @stability stable
     */
    set roleArn(value: string);
    /**
     * @stability stable
     */
    get roleArnInput(): string | undefined;
    private _streamArn?;
    /**
     * @stability stable
     */
    get streamArn(): string;
    /**
     * @stability stable
     */
    set streamArn(value: string);
    /**
     * @stability stable
     */
    get streamArnInput(): string | undefined;
}
/**
 * @stability stable
 */
export interface SesEventDestinationSnsDestination {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ses_event_destination#topic_arn SesEventDestination#topic_arn}.
     *
     * @stability stable
     */
    readonly topicArn: string;
}
export declare function sesEventDestinationSnsDestinationToTerraform(struct?: SesEventDestinationSnsDestinationOutputReference | SesEventDestinationSnsDestination): any;
/**
 * @stability stable
 */
export declare class SesEventDestinationSnsDestinationOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): SesEventDestinationSnsDestination | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: SesEventDestinationSnsDestination | undefined);
    private _topicArn?;
    /**
     * @stability stable
     */
    get topicArn(): string;
    /**
     * @stability stable
     */
    set topicArn(value: string);
    /**
     * @stability stable
     */
    get topicArnInput(): string | undefined;
}
/**
 * Represents a {@link https://www.terraform.io/docs/providers/aws/r/ses_event_destination aws_ses_event_destination}.
 *
 * @stability stable
 */
export declare class SesEventDestination extends cdktf.TerraformResource {
    /**
     * @stability stable
     */
    static readonly tfResourceType: string;
    /**
     * Create a new {@link https://www.terraform.io/docs/providers/aws/r/ses_event_destination aws_ses_event_destination} Resource.
     *
     * @param scope The scope in which to define this construct.
     * @param id The scoped construct ID.
     * @stability stable
     */
    constructor(scope: Construct, id: string, config: SesEventDestinationConfig);
    /**
     * @stability stable
     */
    get arn(): string;
    private _configurationSetName?;
    /**
     * @stability stable
     */
    get configurationSetName(): string;
    /**
     * @stability stable
     */
    set configurationSetName(value: string);
    /**
     * @stability stable
     */
    get configurationSetNameInput(): string | undefined;
    private _enabled?;
    /**
     * @stability stable
     */
    get enabled(): boolean | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set enabled(value: boolean | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetEnabled(): void;
    /**
     * @stability stable
     */
    get enabledInput(): boolean | cdktf.IResolvable | undefined;
    /**
     * @stability stable
     */
    get id(): string;
    private _matchingTypes?;
    /**
     * @stability stable
     */
    get matchingTypes(): string[];
    /**
     * @stability stable
     */
    set matchingTypes(value: string[]);
    /**
     * @stability stable
     */
    get matchingTypesInput(): string[] | undefined;
    private _name?;
    /**
     * @stability stable
     */
    get name(): string;
    /**
     * @stability stable
     */
    set name(value: string);
    /**
     * @stability stable
     */
    get nameInput(): string | undefined;
    private _cloudwatchDestination?;
    /**
     * @stability stable
     */
    get cloudwatchDestination(): SesEventDestinationCloudwatchDestination[] | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set cloudwatchDestination(value: SesEventDestinationCloudwatchDestination[] | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetCloudwatchDestination(): void;
    /**
     * @stability stable
     */
    get cloudwatchDestinationInput(): cdktf.IResolvable | SesEventDestinationCloudwatchDestination[] | undefined;
    private _kinesisDestination;
    /**
     * @stability stable
     */
    get kinesisDestination(): SesEventDestinationKinesisDestinationOutputReference;
    /**
     * @stability stable
     */
    putKinesisDestination(value: SesEventDestinationKinesisDestination): void;
    /**
     * @stability stable
     */
    resetKinesisDestination(): void;
    /**
     * @stability stable
     */
    get kinesisDestinationInput(): SesEventDestinationKinesisDestination | undefined;
    private _snsDestination;
    /**
     * @stability stable
     */
    get snsDestination(): SesEventDestinationSnsDestinationOutputReference;
    /**
     * @stability stable
     */
    putSnsDestination(value: SesEventDestinationSnsDestination): void;
    /**
     * @stability stable
     */
    resetSnsDestination(): void;
    /**
     * @stability stable
     */
    get snsDestinationInput(): SesEventDestinationSnsDestination | undefined;
    /**
     * @stability stable
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
