import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
/**
 * AWS Step Functions.
 *
 * @stability stable
 */
export interface SfnStateMachineConfig extends cdktf.TerraformMetaArguments {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sfn_state_machine#definition SfnStateMachine#definition}.
     *
     * @stability stable
     */
    readonly definition: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sfn_state_machine#name SfnStateMachine#name}.
     *
     * @stability stable
     */
    readonly name: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sfn_state_machine#role_arn SfnStateMachine#role_arn}.
     *
     * @stability stable
     */
    readonly roleArn: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sfn_state_machine#tags SfnStateMachine#tags}.
     *
     * @stability stable
     */
    readonly tags?: {
        [key: string]: string;
    };
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sfn_state_machine#tags_all SfnStateMachine#tags_all}.
     *
     * @stability stable
     */
    readonly tagsAll?: {
        [key: string]: string;
    };
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sfn_state_machine#type SfnStateMachine#type}.
     *
     * @stability stable
     */
    readonly type?: string;
    /**
     * logging_configuration block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sfn_state_machine#logging_configuration SfnStateMachine#logging_configuration}
     *
     * @stability stable
     */
    readonly loggingConfiguration?: SfnStateMachineLoggingConfiguration;
    /**
     * tracing_configuration block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sfn_state_machine#tracing_configuration SfnStateMachine#tracing_configuration}
     *
     * @stability stable
     */
    readonly tracingConfiguration?: SfnStateMachineTracingConfiguration;
}
/**
 * @stability stable
 */
export interface SfnStateMachineLoggingConfiguration {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sfn_state_machine#include_execution_data SfnStateMachine#include_execution_data}.
     *
     * @stability stable
     */
    readonly includeExecutionData?: boolean | cdktf.IResolvable;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sfn_state_machine#level SfnStateMachine#level}.
     *
     * @stability stable
     */
    readonly level?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sfn_state_machine#log_destination SfnStateMachine#log_destination}.
     *
     * @stability stable
     */
    readonly logDestination?: string;
}
export declare function sfnStateMachineLoggingConfigurationToTerraform(struct?: SfnStateMachineLoggingConfigurationOutputReference | SfnStateMachineLoggingConfiguration): any;
/**
 * @stability stable
 */
export declare class SfnStateMachineLoggingConfigurationOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): SfnStateMachineLoggingConfiguration | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: SfnStateMachineLoggingConfiguration | undefined);
    private _includeExecutionData?;
    /**
     * @stability stable
     */
    get includeExecutionData(): boolean | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set includeExecutionData(value: boolean | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetIncludeExecutionData(): void;
    /**
     * @stability stable
     */
    get includeExecutionDataInput(): boolean | cdktf.IResolvable | undefined;
    private _level?;
    /**
     * @stability stable
     */
    get level(): string;
    /**
     * @stability stable
     */
    set level(value: string);
    /**
     * @stability stable
     */
    resetLevel(): void;
    /**
     * @stability stable
     */
    get levelInput(): string | undefined;
    private _logDestination?;
    /**
     * @stability stable
     */
    get logDestination(): string;
    /**
     * @stability stable
     */
    set logDestination(value: string);
    /**
     * @stability stable
     */
    resetLogDestination(): void;
    /**
     * @stability stable
     */
    get logDestinationInput(): string | undefined;
}
/**
 * @stability stable
 */
export interface SfnStateMachineTracingConfiguration {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sfn_state_machine#enabled SfnStateMachine#enabled}.
     *
     * @stability stable
     */
    readonly enabled?: boolean | cdktf.IResolvable;
}
export declare function sfnStateMachineTracingConfigurationToTerraform(struct?: SfnStateMachineTracingConfigurationOutputReference | SfnStateMachineTracingConfiguration): any;
/**
 * @stability stable
 */
export declare class SfnStateMachineTracingConfigurationOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): SfnStateMachineTracingConfiguration | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: SfnStateMachineTracingConfiguration | undefined);
    private _enabled?;
    /**
     * @stability stable
     */
    get enabled(): boolean | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set enabled(value: boolean | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetEnabled(): void;
    /**
     * @stability stable
     */
    get enabledInput(): boolean | cdktf.IResolvable | undefined;
}
/**
 * Represents a {@link https://www.terraform.io/docs/providers/aws/r/sfn_state_machine aws_sfn_state_machine}.
 *
 * @stability stable
 */
export declare class SfnStateMachine extends cdktf.TerraformResource {
    /**
     * @stability stable
     */
    static readonly tfResourceType: string;
    /**
     * Create a new {@link https://www.terraform.io/docs/providers/aws/r/sfn_state_machine aws_sfn_state_machine} Resource.
     *
     * @param scope The scope in which to define this construct.
     * @param id The scoped construct ID.
     * @stability stable
     */
    constructor(scope: Construct, id: string, config: SfnStateMachineConfig);
    /**
     * @stability stable
     */
    get arn(): string;
    /**
     * @stability stable
     */
    get creationDate(): string;
    private _definition?;
    /**
     * @stability stable
     */
    get definition(): string;
    /**
     * @stability stable
     */
    set definition(value: string);
    /**
     * @stability stable
     */
    get definitionInput(): string | undefined;
    /**
     * @stability stable
     */
    get id(): string;
    private _name?;
    /**
     * @stability stable
     */
    get name(): string;
    /**
     * @stability stable
     */
    set name(value: string);
    /**
     * @stability stable
     */
    get nameInput(): string | undefined;
    private _roleArn?;
    /**
     * @stability stable
     */
    get roleArn(): string;
    /**
     * @stability stable
     */
    set roleArn(value: string);
    /**
     * @stability stable
     */
    get roleArnInput(): string | undefined;
    /**
     * @stability stable
     */
    get status(): string;
    private _tags?;
    /**
     * @stability stable
     */
    get tags(): {
        [key: string]: string;
    };
    /**
     * @stability stable
     */
    set tags(value: {
        [key: string]: string;
    });
    /**
     * @stability stable
     */
    resetTags(): void;
    /**
     * @stability stable
     */
    get tagsInput(): {
        [key: string]: string;
    } | undefined;
    private _tagsAll?;
    /**
     * @stability stable
     */
    get tagsAll(): {
        [key: string]: string;
    };
    /**
     * @stability stable
     */
    set tagsAll(value: {
        [key: string]: string;
    });
    /**
     * @stability stable
     */
    resetTagsAll(): void;
    /**
     * @stability stable
     */
    get tagsAllInput(): {
        [key: string]: string;
    } | undefined;
    private _type?;
    /**
     * @stability stable
     */
    get type(): string;
    /**
     * @stability stable
     */
    set type(value: string);
    /**
     * @stability stable
     */
    resetType(): void;
    /**
     * @stability stable
     */
    get typeInput(): string | undefined;
    private _loggingConfiguration;
    /**
     * @stability stable
     */
    get loggingConfiguration(): SfnStateMachineLoggingConfigurationOutputReference;
    /**
     * @stability stable
     */
    putLoggingConfiguration(value: SfnStateMachineLoggingConfiguration): void;
    /**
     * @stability stable
     */
    resetLoggingConfiguration(): void;
    /**
     * @stability stable
     */
    get loggingConfigurationInput(): SfnStateMachineLoggingConfiguration | undefined;
    private _tracingConfiguration;
    /**
     * @stability stable
     */
    get tracingConfiguration(): SfnStateMachineTracingConfigurationOutputReference;
    /**
     * @stability stable
     */
    putTracingConfiguration(value: SfnStateMachineTracingConfiguration): void;
    /**
     * @stability stable
     */
    resetTracingConfiguration(): void;
    /**
     * @stability stable
     */
    get tracingConfigurationInput(): SfnStateMachineTracingConfiguration | undefined;
    /**
     * @stability stable
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
