import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
/**
 * AWS Signer.
 *
 * @stability stable
 */
export interface SignerSigningJobConfig extends cdktf.TerraformMetaArguments {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/signer_signing_job#ignore_signing_job_failure SignerSigningJob#ignore_signing_job_failure}.
     *
     * @stability stable
     */
    readonly ignoreSigningJobFailure?: boolean | cdktf.IResolvable;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/signer_signing_job#profile_name SignerSigningJob#profile_name}.
     *
     * @stability stable
     */
    readonly profileName: string;
    /**
     * destination block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/signer_signing_job#destination SignerSigningJob#destination}
     *
     * @stability stable
     */
    readonly destination: SignerSigningJobDestination;
    /**
     * source block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/signer_signing_job#source SignerSigningJob#source}
     *
     * @stability stable
     */
    readonly source: SignerSigningJobSource;
}
/**
 * @stability stable
 */
export declare class SignerSigningJobRevocationRecord extends cdktf.ComplexComputedList {
    /**
     * @stability stable
     */
    get reason(): string;
    /**
     * @stability stable
     */
    get revokedAt(): string;
    /**
     * @stability stable
     */
    get revokedBy(): string;
}
/**
 * @stability stable
 */
export declare class SignerSigningJobSignedObjectS3 extends cdktf.ComplexComputedList {
    /**
     * @stability stable
     */
    get bucket(): string;
    /**
     * @stability stable
     */
    get key(): string;
}
/**
 * @stability stable
 */
export declare class SignerSigningJobSignedObject extends cdktf.ComplexComputedList {
    /**
     * @stability stable
     */
    get s3(): cdktf.IResolvable;
}
/**
 * @stability stable
 */
export interface SignerSigningJobDestinationS3 {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/signer_signing_job#bucket SignerSigningJob#bucket}.
     *
     * @stability stable
     */
    readonly bucket: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/signer_signing_job#prefix SignerSigningJob#prefix}.
     *
     * @stability stable
     */
    readonly prefix?: string;
}
export declare function signerSigningJobDestinationS3ToTerraform(struct?: SignerSigningJobDestinationS3OutputReference | SignerSigningJobDestinationS3): any;
/**
 * @stability stable
 */
export declare class SignerSigningJobDestinationS3OutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): SignerSigningJobDestinationS3 | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: SignerSigningJobDestinationS3 | undefined);
    private _bucket?;
    /**
     * @stability stable
     */
    get bucket(): string;
    /**
     * @stability stable
     */
    set bucket(value: string);
    /**
     * @stability stable
     */
    get bucketInput(): string | undefined;
    private _prefix?;
    /**
     * @stability stable
     */
    get prefix(): string;
    /**
     * @stability stable
     */
    set prefix(value: string);
    /**
     * @stability stable
     */
    resetPrefix(): void;
    /**
     * @stability stable
     */
    get prefixInput(): string | undefined;
}
/**
 * @stability stable
 */
export interface SignerSigningJobDestination {
    /**
     * s3 block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/signer_signing_job#s3 SignerSigningJob#s3}
     *
     * @stability stable
     */
    readonly s3: SignerSigningJobDestinationS3;
}
export declare function signerSigningJobDestinationToTerraform(struct?: SignerSigningJobDestinationOutputReference | SignerSigningJobDestination): any;
/**
 * @stability stable
 */
export declare class SignerSigningJobDestinationOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): SignerSigningJobDestination | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: SignerSigningJobDestination | undefined);
    private _s3;
    /**
     * @stability stable
     */
    get s3(): SignerSigningJobDestinationS3OutputReference;
    /**
     * @stability stable
     */
    putS3(value: SignerSigningJobDestinationS3): void;
    /**
     * @stability stable
     */
    get s3Input(): SignerSigningJobDestinationS3 | undefined;
}
/**
 * @stability stable
 */
export interface SignerSigningJobSourceS3 {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/signer_signing_job#bucket SignerSigningJob#bucket}.
     *
     * @stability stable
     */
    readonly bucket: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/signer_signing_job#key SignerSigningJob#key}.
     *
     * @stability stable
     */
    readonly key: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/signer_signing_job#version SignerSigningJob#version}.
     *
     * @stability stable
     */
    readonly version: string;
}
export declare function signerSigningJobSourceS3ToTerraform(struct?: SignerSigningJobSourceS3OutputReference | SignerSigningJobSourceS3): any;
/**
 * @stability stable
 */
export declare class SignerSigningJobSourceS3OutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): SignerSigningJobSourceS3 | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: SignerSigningJobSourceS3 | undefined);
    private _bucket?;
    /**
     * @stability stable
     */
    get bucket(): string;
    /**
     * @stability stable
     */
    set bucket(value: string);
    /**
     * @stability stable
     */
    get bucketInput(): string | undefined;
    private _key?;
    /**
     * @stability stable
     */
    get key(): string;
    /**
     * @stability stable
     */
    set key(value: string);
    /**
     * @stability stable
     */
    get keyInput(): string | undefined;
    private _version?;
    /**
     * @stability stable
     */
    get version(): string;
    /**
     * @stability stable
     */
    set version(value: string);
    /**
     * @stability stable
     */
    get versionInput(): string | undefined;
}
/**
 * @stability stable
 */
export interface SignerSigningJobSource {
    /**
     * s3 block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/signer_signing_job#s3 SignerSigningJob#s3}
     *
     * @stability stable
     */
    readonly s3: SignerSigningJobSourceS3;
}
export declare function signerSigningJobSourceToTerraform(struct?: SignerSigningJobSourceOutputReference | SignerSigningJobSource): any;
/**
 * @stability stable
 */
export declare class SignerSigningJobSourceOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): SignerSigningJobSource | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: SignerSigningJobSource | undefined);
    private _s3;
    /**
     * @stability stable
     */
    get s3(): SignerSigningJobSourceS3OutputReference;
    /**
     * @stability stable
     */
    putS3(value: SignerSigningJobSourceS3): void;
    /**
     * @stability stable
     */
    get s3Input(): SignerSigningJobSourceS3 | undefined;
}
/**
 * Represents a {@link https://www.terraform.io/docs/providers/aws/r/signer_signing_job aws_signer_signing_job}.
 *
 * @stability stable
 */
export declare class SignerSigningJob extends cdktf.TerraformResource {
    /**
     * @stability stable
     */
    static readonly tfResourceType: string;
    /**
     * Create a new {@link https://www.terraform.io/docs/providers/aws/r/signer_signing_job aws_signer_signing_job} Resource.
     *
     * @param scope The scope in which to define this construct.
     * @param id The scoped construct ID.
     * @stability stable
     */
    constructor(scope: Construct, id: string, config: SignerSigningJobConfig);
    /**
     * @stability stable
     */
    get completedAt(): string;
    /**
     * @stability stable
     */
    get createdAt(): string;
    /**
     * @stability stable
     */
    get id(): string;
    private _ignoreSigningJobFailure?;
    /**
     * @stability stable
     */
    get ignoreSigningJobFailure(): boolean | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set ignoreSigningJobFailure(value: boolean | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetIgnoreSigningJobFailure(): void;
    /**
     * @stability stable
     */
    get ignoreSigningJobFailureInput(): boolean | cdktf.IResolvable | undefined;
    /**
     * @stability stable
     */
    get jobId(): string;
    /**
     * @stability stable
     */
    get jobInvoker(): string;
    /**
     * @stability stable
     */
    get jobOwner(): string;
    /**
     * @stability stable
     */
    get platformDisplayName(): string;
    /**
     * @stability stable
     */
    get platformId(): string;
    private _profileName?;
    /**
     * @stability stable
     */
    get profileName(): string;
    /**
     * @stability stable
     */
    set profileName(value: string);
    /**
     * @stability stable
     */
    get profileNameInput(): string | undefined;
    /**
     * @stability stable
     */
    get profileVersion(): string;
    /**
     * @stability stable
     */
    get requestedBy(): string;
    /**
     * @stability stable
     */
    revocationRecord(index: string): SignerSigningJobRevocationRecord;
    /**
     * @stability stable
     */
    get signatureExpiresAt(): string;
    /**
     * @stability stable
     */
    signedObject(index: string): SignerSigningJobSignedObject;
    /**
     * @stability stable
     */
    get status(): string;
    /**
     * @stability stable
     */
    get statusReason(): string;
    private _destination;
    /**
     * @stability stable
     */
    get destination(): SignerSigningJobDestinationOutputReference;
    /**
     * @stability stable
     */
    putDestination(value: SignerSigningJobDestination): void;
    /**
     * @stability stable
     */
    get destinationInput(): SignerSigningJobDestination | undefined;
    private _source;
    /**
     * @stability stable
     */
    get source(): SignerSigningJobSourceOutputReference;
    /**
     * @stability stable
     */
    putSource(value: SignerSigningJobSource): void;
    /**
     * @stability stable
     */
    get sourceInput(): SignerSigningJobSource | undefined;
    /**
     * @stability stable
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
