import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
/**
 * AWS Simple Queue Service.
 *
 * @stability stable
 */
export interface SqsQueueConfig extends cdktf.TerraformMetaArguments {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sqs_queue#content_based_deduplication SqsQueue#content_based_deduplication}.
     *
     * @stability stable
     */
    readonly contentBasedDeduplication?: boolean | cdktf.IResolvable;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sqs_queue#deduplication_scope SqsQueue#deduplication_scope}.
     *
     * @stability stable
     */
    readonly deduplicationScope?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sqs_queue#delay_seconds SqsQueue#delay_seconds}.
     *
     * @stability stable
     */
    readonly delaySeconds?: number;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sqs_queue#fifo_queue SqsQueue#fifo_queue}.
     *
     * @stability stable
     */
    readonly fifoQueue?: boolean | cdktf.IResolvable;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sqs_queue#fifo_throughput_limit SqsQueue#fifo_throughput_limit}.
     *
     * @stability stable
     */
    readonly fifoThroughputLimit?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sqs_queue#kms_data_key_reuse_period_seconds SqsQueue#kms_data_key_reuse_period_seconds}.
     *
     * @stability stable
     */
    readonly kmsDataKeyReusePeriodSeconds?: number;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sqs_queue#kms_master_key_id SqsQueue#kms_master_key_id}.
     *
     * @stability stable
     */
    readonly kmsMasterKeyId?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sqs_queue#max_message_size SqsQueue#max_message_size}.
     *
     * @stability stable
     */
    readonly maxMessageSize?: number;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sqs_queue#message_retention_seconds SqsQueue#message_retention_seconds}.
     *
     * @stability stable
     */
    readonly messageRetentionSeconds?: number;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sqs_queue#name SqsQueue#name}.
     *
     * @stability stable
     */
    readonly name?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sqs_queue#name_prefix SqsQueue#name_prefix}.
     *
     * @stability stable
     */
    readonly namePrefix?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sqs_queue#policy SqsQueue#policy}.
     *
     * @stability stable
     */
    readonly policy?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sqs_queue#receive_wait_time_seconds SqsQueue#receive_wait_time_seconds}.
     *
     * @stability stable
     */
    readonly receiveWaitTimeSeconds?: number;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sqs_queue#redrive_allow_policy SqsQueue#redrive_allow_policy}.
     *
     * @stability stable
     */
    readonly redriveAllowPolicy?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sqs_queue#redrive_policy SqsQueue#redrive_policy}.
     *
     * @stability stable
     */
    readonly redrivePolicy?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sqs_queue#sqs_managed_sse_enabled SqsQueue#sqs_managed_sse_enabled}.
     *
     * @stability stable
     */
    readonly sqsManagedSseEnabled?: boolean | cdktf.IResolvable;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sqs_queue#tags SqsQueue#tags}.
     *
     * @stability stable
     */
    readonly tags?: {
        [key: string]: string;
    };
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sqs_queue#tags_all SqsQueue#tags_all}.
     *
     * @stability stable
     */
    readonly tagsAll?: {
        [key: string]: string;
    };
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sqs_queue#visibility_timeout_seconds SqsQueue#visibility_timeout_seconds}.
     *
     * @stability stable
     */
    readonly visibilityTimeoutSeconds?: number;
}
/**
 * Represents a {@link https://www.terraform.io/docs/providers/aws/r/sqs_queue aws_sqs_queue}.
 *
 * @stability stable
 */
export declare class SqsQueue extends cdktf.TerraformResource {
    /**
     * @stability stable
     */
    static readonly tfResourceType: string;
    /**
     * Create a new {@link https://www.terraform.io/docs/providers/aws/r/sqs_queue aws_sqs_queue} Resource.
     *
     * @param scope The scope in which to define this construct.
     * @param id The scoped construct ID.
     * @stability stable
     */
    constructor(scope: Construct, id: string, config?: SqsQueueConfig);
    /**
     * @stability stable
     */
    get arn(): string;
    private _contentBasedDeduplication?;
    /**
     * @stability stable
     */
    get contentBasedDeduplication(): boolean | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set contentBasedDeduplication(value: boolean | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetContentBasedDeduplication(): void;
    /**
     * @stability stable
     */
    get contentBasedDeduplicationInput(): boolean | cdktf.IResolvable | undefined;
    private _deduplicationScope?;
    /**
     * @stability stable
     */
    get deduplicationScope(): string;
    /**
     * @stability stable
     */
    set deduplicationScope(value: string);
    /**
     * @stability stable
     */
    resetDeduplicationScope(): void;
    /**
     * @stability stable
     */
    get deduplicationScopeInput(): string | undefined;
    private _delaySeconds?;
    /**
     * @stability stable
     */
    get delaySeconds(): number;
    /**
     * @stability stable
     */
    set delaySeconds(value: number);
    /**
     * @stability stable
     */
    resetDelaySeconds(): void;
    /**
     * @stability stable
     */
    get delaySecondsInput(): number | undefined;
    private _fifoQueue?;
    /**
     * @stability stable
     */
    get fifoQueue(): boolean | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set fifoQueue(value: boolean | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetFifoQueue(): void;
    /**
     * @stability stable
     */
    get fifoQueueInput(): boolean | cdktf.IResolvable | undefined;
    private _fifoThroughputLimit?;
    /**
     * @stability stable
     */
    get fifoThroughputLimit(): string;
    /**
     * @stability stable
     */
    set fifoThroughputLimit(value: string);
    /**
     * @stability stable
     */
    resetFifoThroughputLimit(): void;
    /**
     * @stability stable
     */
    get fifoThroughputLimitInput(): string | undefined;
    /**
     * @stability stable
     */
    get id(): string;
    private _kmsDataKeyReusePeriodSeconds?;
    /**
     * @stability stable
     */
    get kmsDataKeyReusePeriodSeconds(): number;
    /**
     * @stability stable
     */
    set kmsDataKeyReusePeriodSeconds(value: number);
    /**
     * @stability stable
     */
    resetKmsDataKeyReusePeriodSeconds(): void;
    /**
     * @stability stable
     */
    get kmsDataKeyReusePeriodSecondsInput(): number | undefined;
    private _kmsMasterKeyId?;
    /**
     * @stability stable
     */
    get kmsMasterKeyId(): string;
    /**
     * @stability stable
     */
    set kmsMasterKeyId(value: string);
    /**
     * @stability stable
     */
    resetKmsMasterKeyId(): void;
    /**
     * @stability stable
     */
    get kmsMasterKeyIdInput(): string | undefined;
    private _maxMessageSize?;
    /**
     * @stability stable
     */
    get maxMessageSize(): number;
    /**
     * @stability stable
     */
    set maxMessageSize(value: number);
    /**
     * @stability stable
     */
    resetMaxMessageSize(): void;
    /**
     * @stability stable
     */
    get maxMessageSizeInput(): number | undefined;
    private _messageRetentionSeconds?;
    /**
     * @stability stable
     */
    get messageRetentionSeconds(): number;
    /**
     * @stability stable
     */
    set messageRetentionSeconds(value: number);
    /**
     * @stability stable
     */
    resetMessageRetentionSeconds(): void;
    /**
     * @stability stable
     */
    get messageRetentionSecondsInput(): number | undefined;
    private _name?;
    /**
     * @stability stable
     */
    get name(): string;
    /**
     * @stability stable
     */
    set name(value: string);
    /**
     * @stability stable
     */
    resetName(): void;
    /**
     * @stability stable
     */
    get nameInput(): string | undefined;
    private _namePrefix?;
    /**
     * @stability stable
     */
    get namePrefix(): string;
    /**
     * @stability stable
     */
    set namePrefix(value: string);
    /**
     * @stability stable
     */
    resetNamePrefix(): void;
    /**
     * @stability stable
     */
    get namePrefixInput(): string | undefined;
    private _policy?;
    /**
     * @stability stable
     */
    get policy(): string;
    /**
     * @stability stable
     */
    set policy(value: string);
    /**
     * @stability stable
     */
    resetPolicy(): void;
    /**
     * @stability stable
     */
    get policyInput(): string | undefined;
    private _receiveWaitTimeSeconds?;
    /**
     * @stability stable
     */
    get receiveWaitTimeSeconds(): number;
    /**
     * @stability stable
     */
    set receiveWaitTimeSeconds(value: number);
    /**
     * @stability stable
     */
    resetReceiveWaitTimeSeconds(): void;
    /**
     * @stability stable
     */
    get receiveWaitTimeSecondsInput(): number | undefined;
    private _redriveAllowPolicy?;
    /**
     * @stability stable
     */
    get redriveAllowPolicy(): string;
    /**
     * @stability stable
     */
    set redriveAllowPolicy(value: string);
    /**
     * @stability stable
     */
    resetRedriveAllowPolicy(): void;
    /**
     * @stability stable
     */
    get redriveAllowPolicyInput(): string | undefined;
    private _redrivePolicy?;
    /**
     * @stability stable
     */
    get redrivePolicy(): string;
    /**
     * @stability stable
     */
    set redrivePolicy(value: string);
    /**
     * @stability stable
     */
    resetRedrivePolicy(): void;
    /**
     * @stability stable
     */
    get redrivePolicyInput(): string | undefined;
    private _sqsManagedSseEnabled?;
    /**
     * @stability stable
     */
    get sqsManagedSseEnabled(): boolean | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set sqsManagedSseEnabled(value: boolean | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetSqsManagedSseEnabled(): void;
    /**
     * @stability stable
     */
    get sqsManagedSseEnabledInput(): boolean | cdktf.IResolvable | undefined;
    private _tags?;
    /**
     * @stability stable
     */
    get tags(): {
        [key: string]: string;
    };
    /**
     * @stability stable
     */
    set tags(value: {
        [key: string]: string;
    });
    /**
     * @stability stable
     */
    resetTags(): void;
    /**
     * @stability stable
     */
    get tagsInput(): {
        [key: string]: string;
    } | undefined;
    private _tagsAll?;
    /**
     * @stability stable
     */
    get tagsAll(): {
        [key: string]: string;
    };
    /**
     * @stability stable
     */
    set tagsAll(value: {
        [key: string]: string;
    });
    /**
     * @stability stable
     */
    resetTagsAll(): void;
    /**
     * @stability stable
     */
    get tagsAllInput(): {
        [key: string]: string;
    } | undefined;
    /**
     * @stability stable
     */
    get url(): string;
    private _visibilityTimeoutSeconds?;
    /**
     * @stability stable
     */
    get visibilityTimeoutSeconds(): number;
    /**
     * @stability stable
     */
    set visibilityTimeoutSeconds(value: number);
    /**
     * @stability stable
     */
    resetVisibilityTimeoutSeconds(): void;
    /**
     * @stability stable
     */
    get visibilityTimeoutSecondsInput(): number | undefined;
    /**
     * @stability stable
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
