import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
/**
 * AWS Systems Manager.
 *
 * @stability stable
 */
export interface SsmResourceDataSyncConfig extends cdktf.TerraformMetaArguments {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ssm_resource_data_sync#name SsmResourceDataSync#name}.
     *
     * @stability stable
     */
    readonly name: string;
    /**
     * s3_destination block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ssm_resource_data_sync#s3_destination SsmResourceDataSync#s3_destination}
     *
     * @stability stable
     */
    readonly s3Destination: SsmResourceDataSyncS3Destination;
}
/**
 * @stability stable
 */
export interface SsmResourceDataSyncS3Destination {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ssm_resource_data_sync#bucket_name SsmResourceDataSync#bucket_name}.
     *
     * @stability stable
     */
    readonly bucketName: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ssm_resource_data_sync#kms_key_arn SsmResourceDataSync#kms_key_arn}.
     *
     * @stability stable
     */
    readonly kmsKeyArn?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ssm_resource_data_sync#prefix SsmResourceDataSync#prefix}.
     *
     * @stability stable
     */
    readonly prefix?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ssm_resource_data_sync#region SsmResourceDataSync#region}.
     *
     * @stability stable
     */
    readonly region: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ssm_resource_data_sync#sync_format SsmResourceDataSync#sync_format}.
     *
     * @stability stable
     */
    readonly syncFormat?: string;
}
export declare function ssmResourceDataSyncS3DestinationToTerraform(struct?: SsmResourceDataSyncS3DestinationOutputReference | SsmResourceDataSyncS3Destination): any;
/**
 * @stability stable
 */
export declare class SsmResourceDataSyncS3DestinationOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): SsmResourceDataSyncS3Destination | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: SsmResourceDataSyncS3Destination | undefined);
    private _bucketName?;
    /**
     * @stability stable
     */
    get bucketName(): string;
    /**
     * @stability stable
     */
    set bucketName(value: string);
    /**
     * @stability stable
     */
    get bucketNameInput(): string | undefined;
    private _kmsKeyArn?;
    /**
     * @stability stable
     */
    get kmsKeyArn(): string;
    /**
     * @stability stable
     */
    set kmsKeyArn(value: string);
    /**
     * @stability stable
     */
    resetKmsKeyArn(): void;
    /**
     * @stability stable
     */
    get kmsKeyArnInput(): string | undefined;
    private _prefix?;
    /**
     * @stability stable
     */
    get prefix(): string;
    /**
     * @stability stable
     */
    set prefix(value: string);
    /**
     * @stability stable
     */
    resetPrefix(): void;
    /**
     * @stability stable
     */
    get prefixInput(): string | undefined;
    private _region?;
    /**
     * @stability stable
     */
    get region(): string;
    /**
     * @stability stable
     */
    set region(value: string);
    /**
     * @stability stable
     */
    get regionInput(): string | undefined;
    private _syncFormat?;
    /**
     * @stability stable
     */
    get syncFormat(): string;
    /**
     * @stability stable
     */
    set syncFormat(value: string);
    /**
     * @stability stable
     */
    resetSyncFormat(): void;
    /**
     * @stability stable
     */
    get syncFormatInput(): string | undefined;
}
/**
 * Represents a {@link https://www.terraform.io/docs/providers/aws/r/ssm_resource_data_sync aws_ssm_resource_data_sync}.
 *
 * @stability stable
 */
export declare class SsmResourceDataSync extends cdktf.TerraformResource {
    /**
     * @stability stable
     */
    static readonly tfResourceType: string;
    /**
     * Create a new {@link https://www.terraform.io/docs/providers/aws/r/ssm_resource_data_sync aws_ssm_resource_data_sync} Resource.
     *
     * @param scope The scope in which to define this construct.
     * @param id The scoped construct ID.
     * @stability stable
     */
    constructor(scope: Construct, id: string, config: SsmResourceDataSyncConfig);
    /**
     * @stability stable
     */
    get id(): string;
    private _name?;
    /**
     * @stability stable
     */
    get name(): string;
    /**
     * @stability stable
     */
    set name(value: string);
    /**
     * @stability stable
     */
    get nameInput(): string | undefined;
    private _s3Destination;
    /**
     * @stability stable
     */
    get s3Destination(): SsmResourceDataSyncS3DestinationOutputReference;
    /**
     * @stability stable
     */
    putS3Destination(value: SsmResourceDataSyncS3Destination): void;
    /**
     * @stability stable
     */
    get s3DestinationInput(): SsmResourceDataSyncS3Destination | undefined;
    /**
     * @stability stable
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
