import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
/**
 * AWS VPC.
 *
 * @stability stable
 */
export interface DefaultSubnetConfig extends cdktf.TerraformMetaArguments {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/default_subnet#availability_zone DefaultSubnet#availability_zone}.
     *
     * @stability stable
     */
    readonly availabilityZone: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/default_subnet#customer_owned_ipv4_pool DefaultSubnet#customer_owned_ipv4_pool}.
     *
     * @stability stable
     */
    readonly customerOwnedIpv4Pool?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/default_subnet#enable_dns64 DefaultSubnet#enable_dns64}.
     *
     * @stability stable
     */
    readonly enableDns64?: boolean | cdktf.IResolvable;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/default_subnet#enable_resource_name_dns_a_record_on_launch DefaultSubnet#enable_resource_name_dns_a_record_on_launch}.
     *
     * @stability stable
     */
    readonly enableResourceNameDnsARecordOnLaunch?: boolean | cdktf.IResolvable;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/default_subnet#enable_resource_name_dns_aaaa_record_on_launch DefaultSubnet#enable_resource_name_dns_aaaa_record_on_launch}.
     *
     * @stability stable
     */
    readonly enableResourceNameDnsAaaaRecordOnLaunch?: boolean | cdktf.IResolvable;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/default_subnet#ipv6_native DefaultSubnet#ipv6_native}.
     *
     * @stability stable
     */
    readonly ipv6Native?: boolean | cdktf.IResolvable;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/default_subnet#map_customer_owned_ip_on_launch DefaultSubnet#map_customer_owned_ip_on_launch}.
     *
     * @stability stable
     */
    readonly mapCustomerOwnedIpOnLaunch?: boolean | cdktf.IResolvable;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/default_subnet#map_public_ip_on_launch DefaultSubnet#map_public_ip_on_launch}.
     *
     * @stability stable
     */
    readonly mapPublicIpOnLaunch?: boolean | cdktf.IResolvable;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/default_subnet#outpost_arn DefaultSubnet#outpost_arn}.
     *
     * @stability stable
     */
    readonly outpostArn?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/default_subnet#private_dns_hostname_type_on_launch DefaultSubnet#private_dns_hostname_type_on_launch}.
     *
     * @stability stable
     */
    readonly privateDnsHostnameTypeOnLaunch?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/default_subnet#tags DefaultSubnet#tags}.
     *
     * @stability stable
     */
    readonly tags?: {
        [key: string]: string;
    };
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/default_subnet#tags_all DefaultSubnet#tags_all}.
     *
     * @stability stable
     */
    readonly tagsAll?: {
        [key: string]: string;
    };
    /**
     * timeouts block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/default_subnet#timeouts DefaultSubnet#timeouts}
     *
     * @stability stable
     */
    readonly timeouts?: DefaultSubnetTimeouts;
}
/**
 * @stability stable
 */
export interface DefaultSubnetTimeouts {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/default_subnet#create DefaultSubnet#create}.
     *
     * @stability stable
     */
    readonly create?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/default_subnet#delete DefaultSubnet#delete}.
     *
     * @stability stable
     */
    readonly delete?: string;
}
export declare function defaultSubnetTimeoutsToTerraform(struct?: DefaultSubnetTimeoutsOutputReference | DefaultSubnetTimeouts | cdktf.IResolvable): any;
/**
 * @stability stable
 */
export declare class DefaultSubnetTimeoutsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): DefaultSubnetTimeouts | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: DefaultSubnetTimeouts | undefined);
    private _create?;
    /**
     * @stability stable
     */
    get create(): string;
    /**
     * @stability stable
     */
    set create(value: string);
    /**
     * @stability stable
     */
    resetCreate(): void;
    /**
     * @stability stable
     */
    get createInput(): string | undefined;
    private _delete?;
    /**
     * @stability stable
     */
    get delete(): string;
    /**
     * @stability stable
     */
    set delete(value: string);
    /**
     * @stability stable
     */
    resetDelete(): void;
    /**
     * @stability stable
     */
    get deleteInput(): string | undefined;
}
/**
 * Represents a {@link https://www.terraform.io/docs/providers/aws/r/default_subnet aws_default_subnet}.
 *
 * @stability stable
 */
export declare class DefaultSubnet extends cdktf.TerraformResource {
    /**
     * @stability stable
     */
    static readonly tfResourceType: string;
    /**
     * Create a new {@link https://www.terraform.io/docs/providers/aws/r/default_subnet aws_default_subnet} Resource.
     *
     * @param scope The scope in which to define this construct.
     * @param id The scoped construct ID.
     * @stability stable
     */
    constructor(scope: Construct, id: string, config: DefaultSubnetConfig);
    /**
     * @stability stable
     */
    get arn(): string;
    /**
     * @stability stable
     */
    get assignIpv6AddressOnCreation(): cdktf.IResolvable;
    private _availabilityZone?;
    /**
     * @stability stable
     */
    get availabilityZone(): string;
    /**
     * @stability stable
     */
    set availabilityZone(value: string);
    /**
     * @stability stable
     */
    get availabilityZoneInput(): string | undefined;
    /**
     * @stability stable
     */
    get availabilityZoneId(): string;
    /**
     * @stability stable
     */
    get cidrBlock(): string;
    private _customerOwnedIpv4Pool?;
    /**
     * @stability stable
     */
    get customerOwnedIpv4Pool(): string;
    /**
     * @stability stable
     */
    set customerOwnedIpv4Pool(value: string);
    /**
     * @stability stable
     */
    resetCustomerOwnedIpv4Pool(): void;
    /**
     * @stability stable
     */
    get customerOwnedIpv4PoolInput(): string | undefined;
    private _enableDns64?;
    /**
     * @stability stable
     */
    get enableDns64(): boolean | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set enableDns64(value: boolean | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetEnableDns64(): void;
    /**
     * @stability stable
     */
    get enableDns64Input(): boolean | cdktf.IResolvable | undefined;
    private _enableResourceNameDnsARecordOnLaunch?;
    /**
     * @stability stable
     */
    get enableResourceNameDnsARecordOnLaunch(): boolean | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set enableResourceNameDnsARecordOnLaunch(value: boolean | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetEnableResourceNameDnsARecordOnLaunch(): void;
    /**
     * @stability stable
     */
    get enableResourceNameDnsARecordOnLaunchInput(): boolean | cdktf.IResolvable | undefined;
    private _enableResourceNameDnsAaaaRecordOnLaunch?;
    /**
     * @stability stable
     */
    get enableResourceNameDnsAaaaRecordOnLaunch(): boolean | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set enableResourceNameDnsAaaaRecordOnLaunch(value: boolean | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetEnableResourceNameDnsAaaaRecordOnLaunch(): void;
    /**
     * @stability stable
     */
    get enableResourceNameDnsAaaaRecordOnLaunchInput(): boolean | cdktf.IResolvable | undefined;
    /**
     * @stability stable
     */
    get id(): string;
    /**
     * @stability stable
     */
    get ipv6CidrBlock(): string;
    /**
     * @stability stable
     */
    get ipv6CidrBlockAssociationId(): string;
    private _ipv6Native?;
    /**
     * @stability stable
     */
    get ipv6Native(): boolean | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set ipv6Native(value: boolean | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetIpv6Native(): void;
    /**
     * @stability stable
     */
    get ipv6NativeInput(): boolean | cdktf.IResolvable | undefined;
    private _mapCustomerOwnedIpOnLaunch?;
    /**
     * @stability stable
     */
    get mapCustomerOwnedIpOnLaunch(): boolean | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set mapCustomerOwnedIpOnLaunch(value: boolean | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetMapCustomerOwnedIpOnLaunch(): void;
    /**
     * @stability stable
     */
    get mapCustomerOwnedIpOnLaunchInput(): boolean | cdktf.IResolvable | undefined;
    private _mapPublicIpOnLaunch?;
    /**
     * @stability stable
     */
    get mapPublicIpOnLaunch(): boolean | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set mapPublicIpOnLaunch(value: boolean | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetMapPublicIpOnLaunch(): void;
    /**
     * @stability stable
     */
    get mapPublicIpOnLaunchInput(): boolean | cdktf.IResolvable | undefined;
    private _outpostArn?;
    /**
     * @stability stable
     */
    get outpostArn(): string;
    /**
     * @stability stable
     */
    set outpostArn(value: string);
    /**
     * @stability stable
     */
    resetOutpostArn(): void;
    /**
     * @stability stable
     */
    get outpostArnInput(): string | undefined;
    /**
     * @stability stable
     */
    get ownerId(): string;
    private _privateDnsHostnameTypeOnLaunch?;
    /**
     * @stability stable
     */
    get privateDnsHostnameTypeOnLaunch(): string;
    /**
     * @stability stable
     */
    set privateDnsHostnameTypeOnLaunch(value: string);
    /**
     * @stability stable
     */
    resetPrivateDnsHostnameTypeOnLaunch(): void;
    /**
     * @stability stable
     */
    get privateDnsHostnameTypeOnLaunchInput(): string | undefined;
    private _tags?;
    /**
     * @stability stable
     */
    get tags(): {
        [key: string]: string;
    };
    /**
     * @stability stable
     */
    set tags(value: {
        [key: string]: string;
    });
    /**
     * @stability stable
     */
    resetTags(): void;
    /**
     * @stability stable
     */
    get tagsInput(): {
        [key: string]: string;
    } | undefined;
    private _tagsAll?;
    /**
     * @stability stable
     */
    get tagsAll(): {
        [key: string]: string;
    };
    /**
     * @stability stable
     */
    set tagsAll(value: {
        [key: string]: string;
    });
    /**
     * @stability stable
     */
    resetTagsAll(): void;
    /**
     * @stability stable
     */
    get tagsAllInput(): {
        [key: string]: string;
    } | undefined;
    /**
     * @stability stable
     */
    get vpcId(): string;
    private _timeouts;
    /**
     * @stability stable
     */
    get timeouts(): DefaultSubnetTimeoutsOutputReference;
    /**
     * @stability stable
     */
    putTimeouts(value: DefaultSubnetTimeouts): void;
    /**
     * @stability stable
     */
    resetTimeouts(): void;
    /**
     * @stability stable
     */
    get timeoutsInput(): DefaultSubnetTimeouts | undefined;
    /**
     * @stability stable
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
