import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
/**
 * AWS WorkSpaces.
 *
 * @stability stable
 */
export interface WorkspacesDirectoryConfig extends cdktf.TerraformMetaArguments {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/workspaces_directory#directory_id WorkspacesDirectory#directory_id}.
     *
     * @stability stable
     */
    readonly directoryId: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/workspaces_directory#ip_group_ids WorkspacesDirectory#ip_group_ids}.
     *
     * @stability stable
     */
    readonly ipGroupIds?: string[];
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/workspaces_directory#subnet_ids WorkspacesDirectory#subnet_ids}.
     *
     * @stability stable
     */
    readonly subnetIds?: string[];
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/workspaces_directory#tags WorkspacesDirectory#tags}.
     *
     * @stability stable
     */
    readonly tags?: {
        [key: string]: string;
    };
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/workspaces_directory#tags_all WorkspacesDirectory#tags_all}.
     *
     * @stability stable
     */
    readonly tagsAll?: {
        [key: string]: string;
    };
    /**
     * self_service_permissions block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/workspaces_directory#self_service_permissions WorkspacesDirectory#self_service_permissions}
     *
     * @stability stable
     */
    readonly selfServicePermissions?: WorkspacesDirectorySelfServicePermissions;
    /**
     * workspace_access_properties block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/workspaces_directory#workspace_access_properties WorkspacesDirectory#workspace_access_properties}
     *
     * @stability stable
     */
    readonly workspaceAccessProperties?: WorkspacesDirectoryWorkspaceAccessProperties;
    /**
     * workspace_creation_properties block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/workspaces_directory#workspace_creation_properties WorkspacesDirectory#workspace_creation_properties}
     *
     * @stability stable
     */
    readonly workspaceCreationProperties?: WorkspacesDirectoryWorkspaceCreationProperties;
}
/**
 * @stability stable
 */
export interface WorkspacesDirectorySelfServicePermissions {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/workspaces_directory#change_compute_type WorkspacesDirectory#change_compute_type}.
     *
     * @stability stable
     */
    readonly changeComputeType?: boolean | cdktf.IResolvable;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/workspaces_directory#increase_volume_size WorkspacesDirectory#increase_volume_size}.
     *
     * @stability stable
     */
    readonly increaseVolumeSize?: boolean | cdktf.IResolvable;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/workspaces_directory#rebuild_workspace WorkspacesDirectory#rebuild_workspace}.
     *
     * @stability stable
     */
    readonly rebuildWorkspace?: boolean | cdktf.IResolvable;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/workspaces_directory#restart_workspace WorkspacesDirectory#restart_workspace}.
     *
     * @stability stable
     */
    readonly restartWorkspace?: boolean | cdktf.IResolvable;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/workspaces_directory#switch_running_mode WorkspacesDirectory#switch_running_mode}.
     *
     * @stability stable
     */
    readonly switchRunningMode?: boolean | cdktf.IResolvable;
}
export declare function workspacesDirectorySelfServicePermissionsToTerraform(struct?: WorkspacesDirectorySelfServicePermissionsOutputReference | WorkspacesDirectorySelfServicePermissions): any;
/**
 * @stability stable
 */
export declare class WorkspacesDirectorySelfServicePermissionsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): WorkspacesDirectorySelfServicePermissions | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: WorkspacesDirectorySelfServicePermissions | undefined);
    private _changeComputeType?;
    /**
     * @stability stable
     */
    get changeComputeType(): boolean | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set changeComputeType(value: boolean | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetChangeComputeType(): void;
    /**
     * @stability stable
     */
    get changeComputeTypeInput(): boolean | cdktf.IResolvable | undefined;
    private _increaseVolumeSize?;
    /**
     * @stability stable
     */
    get increaseVolumeSize(): boolean | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set increaseVolumeSize(value: boolean | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetIncreaseVolumeSize(): void;
    /**
     * @stability stable
     */
    get increaseVolumeSizeInput(): boolean | cdktf.IResolvable | undefined;
    private _rebuildWorkspace?;
    /**
     * @stability stable
     */
    get rebuildWorkspace(): boolean | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set rebuildWorkspace(value: boolean | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetRebuildWorkspace(): void;
    /**
     * @stability stable
     */
    get rebuildWorkspaceInput(): boolean | cdktf.IResolvable | undefined;
    private _restartWorkspace?;
    /**
     * @stability stable
     */
    get restartWorkspace(): boolean | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set restartWorkspace(value: boolean | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetRestartWorkspace(): void;
    /**
     * @stability stable
     */
    get restartWorkspaceInput(): boolean | cdktf.IResolvable | undefined;
    private _switchRunningMode?;
    /**
     * @stability stable
     */
    get switchRunningMode(): boolean | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set switchRunningMode(value: boolean | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetSwitchRunningMode(): void;
    /**
     * @stability stable
     */
    get switchRunningModeInput(): boolean | cdktf.IResolvable | undefined;
}
/**
 * @stability stable
 */
export interface WorkspacesDirectoryWorkspaceAccessProperties {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/workspaces_directory#device_type_android WorkspacesDirectory#device_type_android}.
     *
     * @stability stable
     */
    readonly deviceTypeAndroid?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/workspaces_directory#device_type_chromeos WorkspacesDirectory#device_type_chromeos}.
     *
     * @stability stable
     */
    readonly deviceTypeChromeos?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/workspaces_directory#device_type_ios WorkspacesDirectory#device_type_ios}.
     *
     * @stability stable
     */
    readonly deviceTypeIos?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/workspaces_directory#device_type_linux WorkspacesDirectory#device_type_linux}.
     *
     * @stability stable
     */
    readonly deviceTypeLinux?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/workspaces_directory#device_type_osx WorkspacesDirectory#device_type_osx}.
     *
     * @stability stable
     */
    readonly deviceTypeOsx?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/workspaces_directory#device_type_web WorkspacesDirectory#device_type_web}.
     *
     * @stability stable
     */
    readonly deviceTypeWeb?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/workspaces_directory#device_type_windows WorkspacesDirectory#device_type_windows}.
     *
     * @stability stable
     */
    readonly deviceTypeWindows?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/workspaces_directory#device_type_zeroclient WorkspacesDirectory#device_type_zeroclient}.
     *
     * @stability stable
     */
    readonly deviceTypeZeroclient?: string;
}
export declare function workspacesDirectoryWorkspaceAccessPropertiesToTerraform(struct?: WorkspacesDirectoryWorkspaceAccessPropertiesOutputReference | WorkspacesDirectoryWorkspaceAccessProperties): any;
/**
 * @stability stable
 */
export declare class WorkspacesDirectoryWorkspaceAccessPropertiesOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): WorkspacesDirectoryWorkspaceAccessProperties | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: WorkspacesDirectoryWorkspaceAccessProperties | undefined);
    private _deviceTypeAndroid?;
    /**
     * @stability stable
     */
    get deviceTypeAndroid(): string;
    /**
     * @stability stable
     */
    set deviceTypeAndroid(value: string);
    /**
     * @stability stable
     */
    resetDeviceTypeAndroid(): void;
    /**
     * @stability stable
     */
    get deviceTypeAndroidInput(): string | undefined;
    private _deviceTypeChromeos?;
    /**
     * @stability stable
     */
    get deviceTypeChromeos(): string;
    /**
     * @stability stable
     */
    set deviceTypeChromeos(value: string);
    /**
     * @stability stable
     */
    resetDeviceTypeChromeos(): void;
    /**
     * @stability stable
     */
    get deviceTypeChromeosInput(): string | undefined;
    private _deviceTypeIos?;
    /**
     * @stability stable
     */
    get deviceTypeIos(): string;
    /**
     * @stability stable
     */
    set deviceTypeIos(value: string);
    /**
     * @stability stable
     */
    resetDeviceTypeIos(): void;
    /**
     * @stability stable
     */
    get deviceTypeIosInput(): string | undefined;
    private _deviceTypeLinux?;
    /**
     * @stability stable
     */
    get deviceTypeLinux(): string;
    /**
     * @stability stable
     */
    set deviceTypeLinux(value: string);
    /**
     * @stability stable
     */
    resetDeviceTypeLinux(): void;
    /**
     * @stability stable
     */
    get deviceTypeLinuxInput(): string | undefined;
    private _deviceTypeOsx?;
    /**
     * @stability stable
     */
    get deviceTypeOsx(): string;
    /**
     * @stability stable
     */
    set deviceTypeOsx(value: string);
    /**
     * @stability stable
     */
    resetDeviceTypeOsx(): void;
    /**
     * @stability stable
     */
    get deviceTypeOsxInput(): string | undefined;
    private _deviceTypeWeb?;
    /**
     * @stability stable
     */
    get deviceTypeWeb(): string;
    /**
     * @stability stable
     */
    set deviceTypeWeb(value: string);
    /**
     * @stability stable
     */
    resetDeviceTypeWeb(): void;
    /**
     * @stability stable
     */
    get deviceTypeWebInput(): string | undefined;
    private _deviceTypeWindows?;
    /**
     * @stability stable
     */
    get deviceTypeWindows(): string;
    /**
     * @stability stable
     */
    set deviceTypeWindows(value: string);
    /**
     * @stability stable
     */
    resetDeviceTypeWindows(): void;
    /**
     * @stability stable
     */
    get deviceTypeWindowsInput(): string | undefined;
    private _deviceTypeZeroclient?;
    /**
     * @stability stable
     */
    get deviceTypeZeroclient(): string;
    /**
     * @stability stable
     */
    set deviceTypeZeroclient(value: string);
    /**
     * @stability stable
     */
    resetDeviceTypeZeroclient(): void;
    /**
     * @stability stable
     */
    get deviceTypeZeroclientInput(): string | undefined;
}
/**
 * @stability stable
 */
export interface WorkspacesDirectoryWorkspaceCreationProperties {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/workspaces_directory#custom_security_group_id WorkspacesDirectory#custom_security_group_id}.
     *
     * @stability stable
     */
    readonly customSecurityGroupId?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/workspaces_directory#default_ou WorkspacesDirectory#default_ou}.
     *
     * @stability stable
     */
    readonly defaultOu?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/workspaces_directory#enable_internet_access WorkspacesDirectory#enable_internet_access}.
     *
     * @stability stable
     */
    readonly enableInternetAccess?: boolean | cdktf.IResolvable;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/workspaces_directory#enable_maintenance_mode WorkspacesDirectory#enable_maintenance_mode}.
     *
     * @stability stable
     */
    readonly enableMaintenanceMode?: boolean | cdktf.IResolvable;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/workspaces_directory#user_enabled_as_local_administrator WorkspacesDirectory#user_enabled_as_local_administrator}.
     *
     * @stability stable
     */
    readonly userEnabledAsLocalAdministrator?: boolean | cdktf.IResolvable;
}
export declare function workspacesDirectoryWorkspaceCreationPropertiesToTerraform(struct?: WorkspacesDirectoryWorkspaceCreationPropertiesOutputReference | WorkspacesDirectoryWorkspaceCreationProperties): any;
/**
 * @stability stable
 */
export declare class WorkspacesDirectoryWorkspaceCreationPropertiesOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): WorkspacesDirectoryWorkspaceCreationProperties | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: WorkspacesDirectoryWorkspaceCreationProperties | undefined);
    private _customSecurityGroupId?;
    /**
     * @stability stable
     */
    get customSecurityGroupId(): string;
    /**
     * @stability stable
     */
    set customSecurityGroupId(value: string);
    /**
     * @stability stable
     */
    resetCustomSecurityGroupId(): void;
    /**
     * @stability stable
     */
    get customSecurityGroupIdInput(): string | undefined;
    private _defaultOu?;
    /**
     * @stability stable
     */
    get defaultOu(): string;
    /**
     * @stability stable
     */
    set defaultOu(value: string);
    /**
     * @stability stable
     */
    resetDefaultOu(): void;
    /**
     * @stability stable
     */
    get defaultOuInput(): string | undefined;
    private _enableInternetAccess?;
    /**
     * @stability stable
     */
    get enableInternetAccess(): boolean | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set enableInternetAccess(value: boolean | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetEnableInternetAccess(): void;
    /**
     * @stability stable
     */
    get enableInternetAccessInput(): boolean | cdktf.IResolvable | undefined;
    private _enableMaintenanceMode?;
    /**
     * @stability stable
     */
    get enableMaintenanceMode(): boolean | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set enableMaintenanceMode(value: boolean | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetEnableMaintenanceMode(): void;
    /**
     * @stability stable
     */
    get enableMaintenanceModeInput(): boolean | cdktf.IResolvable | undefined;
    private _userEnabledAsLocalAdministrator?;
    /**
     * @stability stable
     */
    get userEnabledAsLocalAdministrator(): boolean | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set userEnabledAsLocalAdministrator(value: boolean | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetUserEnabledAsLocalAdministrator(): void;
    /**
     * @stability stable
     */
    get userEnabledAsLocalAdministratorInput(): boolean | cdktf.IResolvable | undefined;
}
/**
 * Represents a {@link https://www.terraform.io/docs/providers/aws/r/workspaces_directory aws_workspaces_directory}.
 *
 * @stability stable
 */
export declare class WorkspacesDirectory extends cdktf.TerraformResource {
    /**
     * @stability stable
     */
    static readonly tfResourceType: string;
    /**
     * Create a new {@link https://www.terraform.io/docs/providers/aws/r/workspaces_directory aws_workspaces_directory} Resource.
     *
     * @param scope The scope in which to define this construct.
     * @param id The scoped construct ID.
     * @stability stable
     */
    constructor(scope: Construct, id: string, config: WorkspacesDirectoryConfig);
    /**
     * @stability stable
     */
    get alias(): string;
    /**
     * @stability stable
     */
    get customerUserName(): string;
    private _directoryId?;
    /**
     * @stability stable
     */
    get directoryId(): string;
    /**
     * @stability stable
     */
    set directoryId(value: string);
    /**
     * @stability stable
     */
    get directoryIdInput(): string | undefined;
    /**
     * @stability stable
     */
    get directoryName(): string;
    /**
     * @stability stable
     */
    get directoryType(): string;
    /**
     * @stability stable
     */
    get dnsIpAddresses(): string[];
    /**
     * @stability stable
     */
    get iamRoleId(): string;
    /**
     * @stability stable
     */
    get id(): string;
    private _ipGroupIds?;
    /**
     * @stability stable
     */
    get ipGroupIds(): string[];
    /**
     * @stability stable
     */
    set ipGroupIds(value: string[]);
    /**
     * @stability stable
     */
    resetIpGroupIds(): void;
    /**
     * @stability stable
     */
    get ipGroupIdsInput(): string[] | undefined;
    /**
     * @stability stable
     */
    get registrationCode(): string;
    private _subnetIds?;
    /**
     * @stability stable
     */
    get subnetIds(): string[];
    /**
     * @stability stable
     */
    set subnetIds(value: string[]);
    /**
     * @stability stable
     */
    resetSubnetIds(): void;
    /**
     * @stability stable
     */
    get subnetIdsInput(): string[] | undefined;
    private _tags?;
    /**
     * @stability stable
     */
    get tags(): {
        [key: string]: string;
    };
    /**
     * @stability stable
     */
    set tags(value: {
        [key: string]: string;
    });
    /**
     * @stability stable
     */
    resetTags(): void;
    /**
     * @stability stable
     */
    get tagsInput(): {
        [key: string]: string;
    } | undefined;
    private _tagsAll?;
    /**
     * @stability stable
     */
    get tagsAll(): {
        [key: string]: string;
    };
    /**
     * @stability stable
     */
    set tagsAll(value: {
        [key: string]: string;
    });
    /**
     * @stability stable
     */
    resetTagsAll(): void;
    /**
     * @stability stable
     */
    get tagsAllInput(): {
        [key: string]: string;
    } | undefined;
    /**
     * @stability stable
     */
    get workspaceSecurityGroupId(): string;
    private _selfServicePermissions;
    /**
     * @stability stable
     */
    get selfServicePermissions(): WorkspacesDirectorySelfServicePermissionsOutputReference;
    /**
     * @stability stable
     */
    putSelfServicePermissions(value: WorkspacesDirectorySelfServicePermissions): void;
    /**
     * @stability stable
     */
    resetSelfServicePermissions(): void;
    /**
     * @stability stable
     */
    get selfServicePermissionsInput(): WorkspacesDirectorySelfServicePermissions | undefined;
    private _workspaceAccessProperties;
    /**
     * @stability stable
     */
    get workspaceAccessProperties(): WorkspacesDirectoryWorkspaceAccessPropertiesOutputReference;
    /**
     * @stability stable
     */
    putWorkspaceAccessProperties(value: WorkspacesDirectoryWorkspaceAccessProperties): void;
    /**
     * @stability stable
     */
    resetWorkspaceAccessProperties(): void;
    /**
     * @stability stable
     */
    get workspaceAccessPropertiesInput(): WorkspacesDirectoryWorkspaceAccessProperties | undefined;
    private _workspaceCreationProperties;
    /**
     * @stability stable
     */
    get workspaceCreationProperties(): WorkspacesDirectoryWorkspaceCreationPropertiesOutputReference;
    /**
     * @stability stable
     */
    putWorkspaceCreationProperties(value: WorkspacesDirectoryWorkspaceCreationProperties): void;
    /**
     * @stability stable
     */
    resetWorkspaceCreationProperties(): void;
    /**
     * @stability stable
     */
    get workspaceCreationPropertiesInput(): WorkspacesDirectoryWorkspaceCreationProperties | undefined;
    /**
     * @stability stable
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
