import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
/**
 * AWS WorkSpaces.
 *
 * @stability stable
 */
export interface WorkspacesWorkspaceConfig extends cdktf.TerraformMetaArguments {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/workspaces_workspace#bundle_id WorkspacesWorkspace#bundle_id}.
     *
     * @stability stable
     */
    readonly bundleId: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/workspaces_workspace#directory_id WorkspacesWorkspace#directory_id}.
     *
     * @stability stable
     */
    readonly directoryId: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/workspaces_workspace#root_volume_encryption_enabled WorkspacesWorkspace#root_volume_encryption_enabled}.
     *
     * @stability stable
     */
    readonly rootVolumeEncryptionEnabled?: boolean | cdktf.IResolvable;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/workspaces_workspace#tags WorkspacesWorkspace#tags}.
     *
     * @stability stable
     */
    readonly tags?: {
        [key: string]: string;
    };
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/workspaces_workspace#tags_all WorkspacesWorkspace#tags_all}.
     *
     * @stability stable
     */
    readonly tagsAll?: {
        [key: string]: string;
    };
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/workspaces_workspace#user_name WorkspacesWorkspace#user_name}.
     *
     * @stability stable
     */
    readonly userName: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/workspaces_workspace#user_volume_encryption_enabled WorkspacesWorkspace#user_volume_encryption_enabled}.
     *
     * @stability stable
     */
    readonly userVolumeEncryptionEnabled?: boolean | cdktf.IResolvable;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/workspaces_workspace#volume_encryption_key WorkspacesWorkspace#volume_encryption_key}.
     *
     * @stability stable
     */
    readonly volumeEncryptionKey?: string;
    /**
     * timeouts block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/workspaces_workspace#timeouts WorkspacesWorkspace#timeouts}
     *
     * @stability stable
     */
    readonly timeouts?: WorkspacesWorkspaceTimeouts;
    /**
     * workspace_properties block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/workspaces_workspace#workspace_properties WorkspacesWorkspace#workspace_properties}
     *
     * @stability stable
     */
    readonly workspaceProperties?: WorkspacesWorkspaceWorkspaceProperties;
}
/**
 * @stability stable
 */
export interface WorkspacesWorkspaceTimeouts {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/workspaces_workspace#create WorkspacesWorkspace#create}.
     *
     * @stability stable
     */
    readonly create?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/workspaces_workspace#delete WorkspacesWorkspace#delete}.
     *
     * @stability stable
     */
    readonly delete?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/workspaces_workspace#update WorkspacesWorkspace#update}.
     *
     * @stability stable
     */
    readonly update?: string;
}
export declare function workspacesWorkspaceTimeoutsToTerraform(struct?: WorkspacesWorkspaceTimeoutsOutputReference | WorkspacesWorkspaceTimeouts | cdktf.IResolvable): any;
/**
 * @stability stable
 */
export declare class WorkspacesWorkspaceTimeoutsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): WorkspacesWorkspaceTimeouts | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: WorkspacesWorkspaceTimeouts | undefined);
    private _create?;
    /**
     * @stability stable
     */
    get create(): string;
    /**
     * @stability stable
     */
    set create(value: string);
    /**
     * @stability stable
     */
    resetCreate(): void;
    /**
     * @stability stable
     */
    get createInput(): string | undefined;
    private _delete?;
    /**
     * @stability stable
     */
    get delete(): string;
    /**
     * @stability stable
     */
    set delete(value: string);
    /**
     * @stability stable
     */
    resetDelete(): void;
    /**
     * @stability stable
     */
    get deleteInput(): string | undefined;
    private _update?;
    /**
     * @stability stable
     */
    get update(): string;
    /**
     * @stability stable
     */
    set update(value: string);
    /**
     * @stability stable
     */
    resetUpdate(): void;
    /**
     * @stability stable
     */
    get updateInput(): string | undefined;
}
/**
 * @stability stable
 */
export interface WorkspacesWorkspaceWorkspaceProperties {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/workspaces_workspace#compute_type_name WorkspacesWorkspace#compute_type_name}.
     *
     * @stability stable
     */
    readonly computeTypeName?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/workspaces_workspace#root_volume_size_gib WorkspacesWorkspace#root_volume_size_gib}.
     *
     * @stability stable
     */
    readonly rootVolumeSizeGib?: number;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/workspaces_workspace#running_mode WorkspacesWorkspace#running_mode}.
     *
     * @stability stable
     */
    readonly runningMode?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/workspaces_workspace#running_mode_auto_stop_timeout_in_minutes WorkspacesWorkspace#running_mode_auto_stop_timeout_in_minutes}.
     *
     * @stability stable
     */
    readonly runningModeAutoStopTimeoutInMinutes?: number;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/workspaces_workspace#user_volume_size_gib WorkspacesWorkspace#user_volume_size_gib}.
     *
     * @stability stable
     */
    readonly userVolumeSizeGib?: number;
}
export declare function workspacesWorkspaceWorkspacePropertiesToTerraform(struct?: WorkspacesWorkspaceWorkspacePropertiesOutputReference | WorkspacesWorkspaceWorkspaceProperties): any;
/**
 * @stability stable
 */
export declare class WorkspacesWorkspaceWorkspacePropertiesOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): WorkspacesWorkspaceWorkspaceProperties | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: WorkspacesWorkspaceWorkspaceProperties | undefined);
    private _computeTypeName?;
    /**
     * @stability stable
     */
    get computeTypeName(): string;
    /**
     * @stability stable
     */
    set computeTypeName(value: string);
    /**
     * @stability stable
     */
    resetComputeTypeName(): void;
    /**
     * @stability stable
     */
    get computeTypeNameInput(): string | undefined;
    private _rootVolumeSizeGib?;
    /**
     * @stability stable
     */
    get rootVolumeSizeGib(): number;
    /**
     * @stability stable
     */
    set rootVolumeSizeGib(value: number);
    /**
     * @stability stable
     */
    resetRootVolumeSizeGib(): void;
    /**
     * @stability stable
     */
    get rootVolumeSizeGibInput(): number | undefined;
    private _runningMode?;
    /**
     * @stability stable
     */
    get runningMode(): string;
    /**
     * @stability stable
     */
    set runningMode(value: string);
    /**
     * @stability stable
     */
    resetRunningMode(): void;
    /**
     * @stability stable
     */
    get runningModeInput(): string | undefined;
    private _runningModeAutoStopTimeoutInMinutes?;
    /**
     * @stability stable
     */
    get runningModeAutoStopTimeoutInMinutes(): number;
    /**
     * @stability stable
     */
    set runningModeAutoStopTimeoutInMinutes(value: number);
    /**
     * @stability stable
     */
    resetRunningModeAutoStopTimeoutInMinutes(): void;
    /**
     * @stability stable
     */
    get runningModeAutoStopTimeoutInMinutesInput(): number | undefined;
    private _userVolumeSizeGib?;
    /**
     * @stability stable
     */
    get userVolumeSizeGib(): number;
    /**
     * @stability stable
     */
    set userVolumeSizeGib(value: number);
    /**
     * @stability stable
     */
    resetUserVolumeSizeGib(): void;
    /**
     * @stability stable
     */
    get userVolumeSizeGibInput(): number | undefined;
}
/**
 * Represents a {@link https://www.terraform.io/docs/providers/aws/r/workspaces_workspace aws_workspaces_workspace}.
 *
 * @stability stable
 */
export declare class WorkspacesWorkspace extends cdktf.TerraformResource {
    /**
     * @stability stable
     */
    static readonly tfResourceType: string;
    /**
     * Create a new {@link https://www.terraform.io/docs/providers/aws/r/workspaces_workspace aws_workspaces_workspace} Resource.
     *
     * @param scope The scope in which to define this construct.
     * @param id The scoped construct ID.
     * @stability stable
     */
    constructor(scope: Construct, id: string, config: WorkspacesWorkspaceConfig);
    private _bundleId?;
    /**
     * @stability stable
     */
    get bundleId(): string;
    /**
     * @stability stable
     */
    set bundleId(value: string);
    /**
     * @stability stable
     */
    get bundleIdInput(): string | undefined;
    /**
     * @stability stable
     */
    get computerName(): string;
    private _directoryId?;
    /**
     * @stability stable
     */
    get directoryId(): string;
    /**
     * @stability stable
     */
    set directoryId(value: string);
    /**
     * @stability stable
     */
    get directoryIdInput(): string | undefined;
    /**
     * @stability stable
     */
    get id(): string;
    /**
     * @stability stable
     */
    get ipAddress(): string;
    private _rootVolumeEncryptionEnabled?;
    /**
     * @stability stable
     */
    get rootVolumeEncryptionEnabled(): boolean | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set rootVolumeEncryptionEnabled(value: boolean | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetRootVolumeEncryptionEnabled(): void;
    /**
     * @stability stable
     */
    get rootVolumeEncryptionEnabledInput(): boolean | cdktf.IResolvable | undefined;
    /**
     * @stability stable
     */
    get state(): string;
    private _tags?;
    /**
     * @stability stable
     */
    get tags(): {
        [key: string]: string;
    };
    /**
     * @stability stable
     */
    set tags(value: {
        [key: string]: string;
    });
    /**
     * @stability stable
     */
    resetTags(): void;
    /**
     * @stability stable
     */
    get tagsInput(): {
        [key: string]: string;
    } | undefined;
    private _tagsAll?;
    /**
     * @stability stable
     */
    get tagsAll(): {
        [key: string]: string;
    };
    /**
     * @stability stable
     */
    set tagsAll(value: {
        [key: string]: string;
    });
    /**
     * @stability stable
     */
    resetTagsAll(): void;
    /**
     * @stability stable
     */
    get tagsAllInput(): {
        [key: string]: string;
    } | undefined;
    private _userName?;
    /**
     * @stability stable
     */
    get userName(): string;
    /**
     * @stability stable
     */
    set userName(value: string);
    /**
     * @stability stable
     */
    get userNameInput(): string | undefined;
    private _userVolumeEncryptionEnabled?;
    /**
     * @stability stable
     */
    get userVolumeEncryptionEnabled(): boolean | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set userVolumeEncryptionEnabled(value: boolean | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetUserVolumeEncryptionEnabled(): void;
    /**
     * @stability stable
     */
    get userVolumeEncryptionEnabledInput(): boolean | cdktf.IResolvable | undefined;
    private _volumeEncryptionKey?;
    /**
     * @stability stable
     */
    get volumeEncryptionKey(): string;
    /**
     * @stability stable
     */
    set volumeEncryptionKey(value: string);
    /**
     * @stability stable
     */
    resetVolumeEncryptionKey(): void;
    /**
     * @stability stable
     */
    get volumeEncryptionKeyInput(): string | undefined;
    private _timeouts;
    /**
     * @stability stable
     */
    get timeouts(): WorkspacesWorkspaceTimeoutsOutputReference;
    /**
     * @stability stable
     */
    putTimeouts(value: WorkspacesWorkspaceTimeouts): void;
    /**
     * @stability stable
     */
    resetTimeouts(): void;
    /**
     * @stability stable
     */
    get timeoutsInput(): WorkspacesWorkspaceTimeouts | undefined;
    private _workspaceProperties;
    /**
     * @stability stable
     */
    get workspaceProperties(): WorkspacesWorkspaceWorkspacePropertiesOutputReference;
    /**
     * @stability stable
     */
    putWorkspaceProperties(value: WorkspacesWorkspaceWorkspaceProperties): void;
    /**
     * @stability stable
     */
    resetWorkspaceProperties(): void;
    /**
     * @stability stable
     */
    get workspacePropertiesInput(): WorkspacesWorkspaceWorkspaceProperties | undefined;
    /**
     * @stability stable
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
